(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    791151,      17430]
NotebookOptionsPosition[    779439,      17044]
NotebookOutlinePosition[    779782,      17059]
CellTagsIndexPosition[    779739,      17056]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[" Effective Theory Analysis of Electroweak Data    ", "Title",
 FontSize->24],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
       "**", "**", "**", "**", "**", "**", "**", "**", "**"}], "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
    "**"}], "******)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "                      ", 
   RowBox[{
    RowBox[{"Authors", ":", 
     RowBox[{"Zhenyu", " ", "Han"}]}], ",", " ", 
    RowBox[{"Witold", " ", "Skiba"}]}], 
   "                                                 ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "                      ", 
   RowBox[{
    RowBox[{"References", ":", " ", 
     RowBox[{"hep", "-", 
      RowBox[{"ph", "/", "0412166"}]}]}], ",", " ", 
    RowBox[{"hep", "-", 
     RowBox[{"ph", "/", "0510125"}]}]}], 
   "                                      ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
  "(*", "                                                                     \
                                   ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "                      ", 
   RowBox[{"Modified", " ", "and", " ", "updated", " ", 
    RowBox[{"by", ":"}]}], 
   "                                                         ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "                      ", 
   RowBox[{
    RowBox[{
    "Alberto", " ", "Filipuzzi", " ", "and", " ", "Mart\[IAcute]n", " ", 
     "Gonz\[AAcute]lez"}], "-", 
    RowBox[{"Alonso", 
     RowBox[{"(", 
      RowBox[{"March", " ", "2012"}], ")"}]}]}], "                         ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "                      ", 
   RowBox[{
   "For", " ", "the", " ", "updates", " ", "please", " ", "refer", " ", 
    RowBox[{"to", ":", " ", 
     RowBox[{"arXiv", ":", "1203.2092"}]}]}], 
   "                                 ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
       "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], "**", "**",
       "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
       "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
      "**"}], "**"}], "**"}], "*****)"}]}]], "Section",
 CellChangeTimes->{{3.510921126937852*^9, 3.5109212053591895`*^9}, {
  3.523880146552738*^9, 3.5238801893521857`*^9}, {3.5299352572940383`*^9, 
  3.5299352593021536`*^9}, {3.540542781403373*^9, 3.5405428769648385`*^9}, {
  3.5405431202477536`*^9, 3.540543148717382*^9}, {3.5405484055130534`*^9, 
  3.540548413914534*^9}, {3.540556443879896*^9, 3.540556462669177*^9}},
 FontSize->14],

Cell["\<\
(*****************************************************************************\
*****************************************)
(*                                            Update Notes                    \
                                                         *)
(*****************************************************************************\
*****************************************)

March 12, 2012: new observables included (leptonic and semileptonic tau \
decays, anomalous magnetic moment of tau, leptonic W decays, \
\[CapitalDelta]CKM), experimental data updated, NP contributions from \
magnetic operators involving tau leptons included (see arXiv:1203.2092).
New files created for the analysis of the fit results.


Mar. 21, 2006: Modificatitons to the SM predictions (except for LEP 2 \
observables) from small changes in the input parameters: Mt, alpha_s(MZ), \
alpha(MZ), Log(Mh) are implemented. Here \"small\" means that the changes in \
input parameters should be within a couple of sigma's of the current \
experimental errors. The corrections are assumed to be linearly dependent on \
the changes. The numerical values of the derivatives are extracted from GAPP \
(hep-ph/0005084). Many thanks to Jens Erler for providing us the new version \
of the program.  The corrections to LEP 2 observables are negligible compared \
with the experimental errors and thus not included. 
     See the section \"Input parameters\".

Oct. 10, 2005: The flavor symmetry is relaxed from U(3)^5 to [U(2)*U(1)]^5. \
Therefore more operators are added to the analysis. 
The new notebooks  are renamed \"ew_chi2_calculation_ext.nb\" and  \
\"ew_chi2_results_ext.nb\",  while the original notebooks for the U(3)^5 \
symmetry case are kept untouched. 

       More observables are added to the program, including the asymmetries \
for the strange quark A_s and A{FB}^{0s} at the Z pole, as well as the total \
cross-sections and forward-backward asymmetries for ee->bb, and ee->cc \
processes at LEP 2.

       The option for the second order corrections from 4-fermion operators \
is removed, because these corrections were only used for comparison reason in \
the previous analysis. NO second order corrections are implemented in the new \
code.  
            
      See hep-ph/0510125  for the details.
      
Aug. 1, 2005: An error found in the effective couplings in DIS \
measurements:g(l,r)(d,u)eff2.It affects the correlations
between the set of two coefficients {aWB, ah} and another set {all3, alq1, \
alq3, alu, ald, ahl1, ahl3, ahq1,ahq3, ahu, ahd}.
The numerical effect is not significant for most of the correlations.The \
constraints on aWB and ah (the S and T parameters) also change by a few \
percent.
    \
\>", "Subsection",
 CellChangeTimes->{{3.523880202238923*^9, 3.5238802056441174`*^9}, {
  3.540542768805652*^9, 3.540542769680702*^9}, {3.5405428836752224`*^9, 
  3.5405430937422376`*^9}, {3.540548371693119*^9, 3.5405483987986693`*^9}},
 FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
   "**********************************************************)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"Calculation", " ", "of", " ", "total", " ", 
    SuperscriptBox["\[Chi]", "2"]}], 
   "                                                                   ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"Default", " ", "choices", " ", "of", " ", 
    RowBox[{"measurements", ":"}]}], 
   "                                                          ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2total", "="}], 
   "                                                                          \
      ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2MW", "+", "            ", 
    RowBox[{"(", 
     RowBox[{"W", " ", "boson", " ", "mass"}], ")"}]}], 
   "                                                         ", "*)"}], "   ",
   "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2Zline", "+", "         ", 
    RowBox[{"(", 
     RowBox[{
     "Z", " ", "line", " ", "shape", " ", "and", " ", "lepton", " ", "FB", 
      " ", "asymmetries"}], ")"}]}], "                               ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2bc", "+", "            ", 
    RowBox[{"(", 
     RowBox[{
     "Z", " ", "pole", " ", "heavy", " ", "flavor", " ", "measurements"}], 
     ")"}]}], "                                     ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2pol", "+", "           ", 
    RowBox[{"(", 
     RowBox[{"Leptonic", " ", "polarization", " ", "asymmetries"}], ")"}]}], 
   "                                    ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2QFB", "+", "           ", 
    RowBox[{"(", 
     RowBox[{"Effective", " ", 
      SubscriptBox["sin\[Theta]", "W"], " ", "from", " ", "inclusive", " ", 
      "hadronic", " ", "charge", " ", "asymmetry"}], ")"}]}], "             ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2DIS", "+", "           ", 
    RowBox[{"(", 
     RowBox[{"Deep", " ", "inelastic", " ", "scattering"}], ")"}]}], 
   "                                            ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2QW", "+", "            ", 
    RowBox[{"(", 
     RowBox[{"Atomic", " ", "parity", " ", "violation"}], ")"}]}], 
   "                                              ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2hadLEP", "+", "        ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "LEP", " ", "II", " ", "combined", " ", "results", " ", "for", " ", 
       "hadronic", " ", "total", " ", "cross"}], "-", "sections"}], ")"}]}], 
   "            ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2muLEP", "+", "         ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "LEP", " ", "II", " ", "combined", " ", "results", " ", "for", " ", 
       "muon", " ", "pair", " ", "cross"}], "-", 
      RowBox[{"sections", " ", "and", " ", "asymmetries"}]}], ")"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2tauLEP", "+", "        ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "LEP", " ", "II", " ", "combined", " ", "results", " ", "for", " ", 
       "tau", " ", "pair", " ", "cross"}], "-", 
      RowBox[{"sections", " ", "and", " ", "asymmetries"}]}], ")"}]}], "  ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2eOPAL", "+", "         ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "OPAL", " ", "result", " ", "for", " ", "electron", " ", "pair", " ", 
       "differential", " ", "cross"}], "-", "sections"}], ")"}]}], 
   "            ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2WL3", "            ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "L3", " ", "result", " ", "for", " ", "W", " ", "pair", " ", 
       "differential", " ", "cross"}], "-", "sections"}], ")"}]}], 
   "                     ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2As", "             ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "assymetries", " ", "for", " ", "the", " ", "strange", " ", "quark", 
       " ", "at", " ", "Z"}], "-", "pole"}], ")"}]}], 
   "                          ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2bLEP", "           ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "LEP", " ", "II", " ", "combined", " ", "results", " ", "for", " ", 
       "ee"}], "\[Rule]", 
      RowBox[{"bb", " ", "process"}]}], ")"}]}], 
   "                            ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"chi2cLEP", "           ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
      "LEP", " ", "II", " ", "combined", " ", "results", " ", "for", " ", 
       "ee"}], "\[Rule]", 
      RowBox[{"cc", " ", "process"}]}], ")"}]}], 
   "                            ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"\[Chi]\[Tau]To\[Mu]", "              ", 
    RowBox[{"(", 
     RowBox[{"Leptonic", " ", "tau", " ", "decays"}], ")"}]}], 
   "                                                  ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"\[Chi]\[Tau]ToPiNu", "           ", 
    RowBox[{"(", 
     RowBox[{"Semileptonic", " ", "tau", " ", "decays"}], ")"}]}], 
   "                                              ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"\[Chi]a\[Tau]", "                ", 
    RowBox[{"(", 
     RowBox[{
     "Anomalous", " ", "magnetic", " ", "moment", " ", "of", " ", "tau"}], 
     ")"}]}], "                                     ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"\[Chi]\[CapitalDelta]CKM", "              ", 
    RowBox[{"(", 
     RowBox[{"\[CapitalDelta]CKM", "  ", 
      RowBox[{"see", ":", " ", 
       RowBox[{"arXiv", ":", 
        RowBox[{"0908.1754", "v1"}]}]}]}], ")"}]}], 
   "                                         ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "           ", 
   RowBox[{"\[Chi]Wl\[Nu]", "               ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"Leptonic", " ", "W", " ", "decays"}], " ", "-", " ", 
       RowBox[{
       "INLCUDED", " ", "ONLY", " ", "IF", " ", "THE", " ", "RELATIVE", " ", 
        "OPTION", " ", "IS"}]}], " ", "=", "1"}], ")"}]}], "       ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", "        ", 
   RowBox[{
    RowBox[{
    "To", " ", "change", " ", "the", " ", "definition", " ", "of", " ", 
     "chi2total"}], ",", " ", 
    RowBox[{
    "go", " ", "to", " ", "the", " ", "last", " ", "line", " ", "of", " ", 
     "this", " ", 
     RowBox[{"program", "."}]}]}], "                  ", "*)"}], "       ", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "        ", 
   RowBox[{
    RowBox[{
    "To", " ", "change", " ", "the", " ", "definition", " ", "of", " ", 
     "individual", " ", 
     RowBox[{"chi2", "'"}], "s"}], ",", " ", 
    RowBox[{"go", " ", "to", " ", "corresponding", "  ", 
     RowBox[{"sections", "."}]}]}], "                ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
   "******************************************************************************)"}\
]}]], "Section",
 CellChangeTimes->{{3.540542550537168*^9, 3.5405426813776517`*^9}, {
  3.5405427255241766`*^9, 3.540542761195217*^9}, {3.540543163120206*^9, 
  3.540543193493943*^9}},
 FontSize->14],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell1"}], "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
   "**********************************************************)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
  "(*", "          ", "Options", 
   "                                                                          \
          ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
   "******************************************************************************)"}\
]}]], "Section",
 FontSize->14],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"radiative", " ", 
    RowBox[{"corrections", ":"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"RADI", "=", 
    RowBox[{"1", ":", 
     RowBox[{
     "include", " ", "initial", " ", "state", " ", "radiation", " ", 
      "corrections", " ", "in", " ", "fermion", " ", "pair", " ", 
      "production", 
      RowBox[{"(", 
       RowBox[{"except", " ", "ee", " ", "channel"}], ")"}]}]}]}], "    ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"RADI", "=", 
    RowBox[{"0", ":", 
     RowBox[{
     "do", " ", "not", " ", "include", " ", "any", " ", "radiative", " ", 
      "corrections"}]}]}], "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"RADI", "=", "1"}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"NuTeV", " ", "results"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"NUTE", "=", 
     RowBox[{"1", ":", " ", 
      RowBox[{
      "include", " ", "NuTeV", " ", "results", " ", "in", " ", "the", " ", 
       "fit"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"NUTE", "=", 
     RowBox[{"0", ":", " ", 
      RowBox[{"do", " ", "not", " ", "include"}]}]}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"NUTE", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Flavor", " ", "symmetry"}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"FLSY", "=", 
     RowBox[{"0", ":", " ", 
      RowBox[{"U", 
       RowBox[{
        RowBox[{"(", "3", ")"}], "^", "5"}]}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"FLSY", "=", 
      RowBox[{
       RowBox[{"1", ":", " ", "leptons"}], "=", 
       RowBox[{
        RowBox[{"[", 
         RowBox[{"U", 
          RowBox[{"(", "2", ")"}], "*", "U", 
          RowBox[{"(", "1", ")"}]}], "]"}], "^", "2"}]}]}], ",", " ", 
     RowBox[{"quarks", "=", 
      RowBox[{
       RowBox[{"[", 
        RowBox[{"U", 
         RowBox[{"(", "2", ")"}], "*", "U", 
         RowBox[{"(", "1", ")"}]}], "]"}], "^", "3"}]}]}], "       ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"FLSY", "=", "1"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Include", " ", "leptonic", " ", "W", " ", "decays"}], " ", 
    "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Wdecays", "=", 
     RowBox[{"0", ":", " ", 
      RowBox[{
       RowBox[{"don", "'"}], "t", " ", "include", " ", "W", " ", 
       "decays"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Wdecays", "=", 
     RowBox[{"1", ":", " ", 
      RowBox[{"include", " ", "W", " ", "decays"}]}]}], "  ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Wdecays", "=", "0"}], ";"}], " ", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
      "Relative", " ", "theoretical", " ", "error", " ", "for", " ", "the", 
       " ", "SM", " ", "prediction", " ", "of", " ", "cross", " ", "section", 
       " ", "and", " ", "FB", " ", "asymmetry", " ", "in", " ", "e"}], "+", 
      "e", "-"}], " ", "\[Rule]", " ", 
     RowBox[{"tau", "+", " ", "tau", "-", 
      RowBox[{
       RowBox[{".", " ", "See"}], " ", "chi2tauLEP", " ", "subsection"}]}]}], 
    " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Values", " ", "from", " ", "page", " ", "14", " ", "of", " ", "hep"}], 
     "-", 
     RowBox[{
      RowBox[{"ex", "/", "0612034"}], "v2"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Delta]SMerrsigmatau", "=", "0.004"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Delta]SMerrfbtau", "=", "0.004"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.50607891282519*^9, 3.5060789172054405`*^9}, 
   3.506337671484335*^9, 3.5067700299083767`*^9, 3.5067707893645105`*^9, 
   3.510921312936979*^9, {3.512291497474647*^9, 3.512291665213241*^9}, {
   3.5136011356615734`*^9, 3.513601152437533*^9}, {3.5146308313628235`*^9, 
   3.5146308314720235`*^9}, {3.514715616576486*^9, 3.51471563019531*^9}, {
   3.514715942228058*^9, 3.5147160397282295`*^9}, {3.5147183341786613`*^9, 
   3.514718354545826*^9}, {3.5148035327788854`*^9, 3.514803622619443*^9}, 
   3.5148049397297564`*^9, {3.514805951391534*^9, 3.514806041575292*^9}, {
   3.5148061227266345`*^9, 3.514806136423458*^9}, 3.5148103213621073`*^9, {
   3.5148107970381427`*^9, 3.514810797053743*^9}, 3.514899875413592*^9, {
   3.515149344645591*^9, 3.515149385580063*^9}, {3.515481537957696*^9, 
   3.515481540514842*^9}, 3.515840243683387*^9, {3.515911213745381*^9, 
   3.5159112472542396`*^9}, 3.515931648634597*^9, 3.5160103698616657`*^9, {
   3.516016555261367*^9, 3.516016559245595*^9}, {3.516082110770417*^9, 
   3.516082119886939*^9}, 3.516527774709194*^9, {3.51653579865993*^9, 
   3.516535830327986*^9}, {3.516703583440095*^9, 3.5167036233293653`*^9}, {
   3.5169685593484097`*^9, 3.5169685594244137`*^9}, 3.5172293376382275`*^9, 
   3.5172341787003417`*^9, 3.5172964339817276`*^9, {3.517297433540899*^9, 
   3.5172974338129144`*^9}, 3.5172995712461686`*^9, {3.517309732183006*^9, 
   3.517309732486023*^9}, {3.5288054417115965`*^9, 3.528805565248662*^9}, {
   3.5299348743871374`*^9, 3.5299348761732397`*^9}, {3.5405387855028205`*^9, 
   3.5405388403219557`*^9}, {3.540539332895129*^9, 3.5405393336101704`*^9}, {
   3.540540260965212*^9, 3.5405403500873094`*^9}, {3.540540875613368*^9, 
   3.540540879013562*^9}, 3.540541620361965*^9, 3.540542114216212*^9, 
   3.5405424909857616`*^9, {3.5405537407302103`*^9, 3.5405537410892305`*^9}, {
   3.540564155394423*^9, 3.5405641562794733`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}],
    "****************************************************)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "          ", 
   RowBox[{"Input", " ", "parameters"}], 
   "                                                                          \
 ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
    "**"}], "**************************************************)"}]}]], \
"Section",
 FontSize->14],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Basic parameters", "Subsection"]], "Subsubsection",
 CellChangeTimes->{{3.5109203549080963`*^9, 3.5109203660621157`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"GF", "=", 
    RowBox[{"1.16637", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "5"}]]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Fermi", " ", "constant", " ", "from", " ", "\[Mu]", " ", "decay"}], " ", 
    "-", " ", 
    RowBox[{"Value", " ", "from", " ", "PDG", " ", "2010"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MZ", "=", "91.1876"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"from", " ", "PDG", " ", "2010"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alpha0", "=", 
    FractionBox["1", "137.035999679"]}], " ", ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"from", " ", "PDG", " ", "2010"}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"me", "=", 
    RowBox[{"0.510998910", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"from", " ", "PDG", " ", "2010"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mmu", "=", "0.105658367"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"from", " ", "PDG", " ", "2010"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mtau", "=", "1.77682"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"from", " ", "PDG", " ", "2010"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mlep", "=", 
   RowBox[{"{", 
    RowBox[{"me", ",", "mmu", ",", "mtau"}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5074687331718245`*^9, 3.507468744132452*^9}, {
   3.510659842617818*^9, 3.510659896328712*^9}, {3.5109034232057753`*^9, 
   3.5109034238297763`*^9}, 3.5109092640423937`*^9, {3.510920350259288*^9, 
   3.5109203511952896`*^9}, {3.5109213374446216`*^9, 
   3.5109213429514313`*^9}, {3.510921952007701*^9, 3.5109219606345167`*^9}, {
   3.511089089265937*^9, 3.511089093462344*^9}, {3.511157784843169*^9, 
   3.511157786590372*^9}, 3.5159383403313274`*^9, {3.5294298211479473`*^9, 
   3.5294298313475304`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Auxiliary parameters", "Subsubsection",
 CellChangeTimes->{{3.510921656901983*^9, 3.510921659304387*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"gev2pbarn", "=", 
    RowBox[{"0.389379323", "*", 
     SuperscriptBox["10", "9"]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"change", " ", "cross"}], "-", 
    RowBox[{"section", " ", "unit", " ", "from", " ", 
     SuperscriptBox["GeV", 
      RowBox[{"-", "2"}]], " ", "to", " ", "pb"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"secondsToGeV", "=", 
    RowBox[{"1.5193", "*", 
     SuperscriptBox["10", "15"], "*", 
     SuperscriptBox["10", "9"]}]}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "change", " ", "life", " ", "time", " ", "from", " ", "second", " ", "to", 
    " ", 
    SuperscriptBox["GeV", 
     RowBox[{"-", "1"}]]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Nf", "=", "3.12"}], ";"}], 
  "                                              ", 
  RowBox[{"(*", " ", 
   RowBox[{"effective", " ", "color"}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.5073793663523397`*^9, 3.507379368068342*^9}, {
  3.510661994966561*^9, 3.5106620549642663`*^9}, {3.510903353208452*^9, 
  3.510903366952077*^9}, {3.5109041543800597`*^9, 3.5109041667352815`*^9}, {
  3.5109092233107224`*^9, 3.5109092235603228`*^9}, {3.5109092919820433`*^9, 
  3.5109092967400513`*^9}, {3.5109101346955233`*^9, 3.510910147581146*^9}, {
  3.510920308232814*^9, 3.5109203128972225`*^9}, {3.51092163244114*^9, 
  3.510921664795597*^9}, {3.5288093257449117`*^9, 3.5288093582865686`*^9}, {
  3.529264655441134*^9, 3.5292646961884055`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Changable input parameters", "Subsection"]], \
"Subsubsection",
 CellChangeTimes->{{3.510920325751645*^9, 3.510920327998049*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "These", " ", "four", " ", "parameters", " ", "can", " ", "be", " ", 
     "modified", " ", "around", " ", "the", " ", "reference", " ", "value", 
     " ", "to", " ", "account", " ", "for", " ", "the", " ", "changes", " ", 
     "in", " ", "the", " ", "SM", " ", "predictions"}], ",", " ", 
    "\[IndentingNewLine]", 
    RowBox[{
    "due", " ", "to", " ", "the", " ", "changes", " ", "in", " ", 
     "experimental", " ", "values", " ", "or", " ", 
     RowBox[{"users", "'"}], " ", 
     RowBox[{"preference", ".", " ", "Changing"}], " ", "the", " ", "input", 
     " ", "parameters", " ", "affects", " ", "the", " ", "SM", " ", 
     "\[IndentingNewLine]", "predictions", " ", "for", " ", "the", " ", 
     "observables"}], ",", " ", 
    RowBox[{
    "but", " ", "NOT", " ", "the", " ", "contributions", " ", "from", " ", 
     "the", " ", "operators", " ", "to", " ", "the", " ", 
     RowBox[{"observables", ".", " ", "We"}], " ", "also", " ", "neglect", 
     " ", "the", " ", "changes", " ", "in", " ", "the", " ", "SM", " ", 
     "theoretical", " ", 
     RowBox[{"errors", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "We", " ", "assume", " ", "linearity", " ", "for", " ", "the", " ", 
    "dependence", " ", "on", " ", "the", " ", "small", " ", "changes", " ", 
    "in", " ", "the", " ", 
    RowBox[{"parameters", ".", " ", "The"}], " ", "linear", " ", "dependence",
     " ", "is", " ", "extracted", " ", "using", " ", "GAPP_", "05"}], "*)"}], 
  "  "}]], "Input",
 CellChangeTimes->{{3.51092032305284*^9, 3.5109203238640413`*^9}, {
   3.5109213867407084`*^9, 3.5109214637892437`*^9}, {3.5109215674670258`*^9, 
   3.510921611490303*^9}, {3.510921712828081*^9, 3.5109217625765686`*^9}, 
   3.5109218015298367`*^9, {3.5109218850523834`*^9, 3.5109219186080427`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Top mass", "Subsubsection",
 CellChangeTimes->{{3.5109219027896147`*^9, 3.5109219042404175`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"mt", "=", "173.2"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"from", " ", "PDG", " ", "2010"}], " ", "*)"}], "       ", 
  RowBox[{"(*", " ", 
   RowBox[{"Old", " ", 
    RowBox[{"value", ":", " ", 
     RowBox[{"176.9", " ", 
      RowBox[{"Mart\[IAcute]n", ":", " ", "173.2"}]}]}]}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.511157879004935*^9, 3.5111579074437847`*^9}, {
  3.5292648430626636`*^9, 3.529264850597477*^9}, {3.52926521690172*^9, 
  3.5292652224085298`*^9}, {3.538483507051864*^9, 3.53848353670556*^9}, {
  3.5384838449631915`*^9, 3.538483845936247*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Alpha strong", "Subsubsection",
 CellChangeTimes->{{3.5109219106364284`*^9, 3.5109219123836317`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"alphas", "=", "0.12"}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{"Mart\[IAcute]n", ":", "  ", "0.12"}], " ", "*)"}], ";"}]], "Input",
 CellChangeTimes->{{3.5384836057395086`*^9, 3.538483608824685*^9}, 
   3.53848387028664*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["alpha electromagnetic at the Z scale", "Subsubsection",
 CellChangeTimes->{{3.510921806787046*^9, 3.5109218122938557`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"alphaMZ", "=", 
   RowBox[{"1", "/", "127.916"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.511158009296364*^9, 3.511158011355567*^9}, {
   3.5292585111821423`*^9, 3.5292585592146263`*^9}, {3.529259048790286*^9, 
   3.529259051613891*^9}, {3.5294298524957404`*^9, 3.5294298633463607`*^9}, {
   3.529430375383648*^9, 3.5294303836831226`*^9}, {3.5384835517774224`*^9, 
   3.5384835966269875`*^9}, 3.538727831808338*^9, 3.5387416010238924`*^9, {
   3.538742088029747*^9, 3.53874209314604*^9}, {3.5387423753761826`*^9, 
   3.538742375436186*^9}, {3.5405393805718565`*^9, 3.5405393866902065`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Higgs mass", "Subsubsection",
 CellChangeTimes->{{3.510921854133129*^9, 3.5109218570503345`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"mh", "=", "113"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{"Mart\[IAcute]n", ":", " ", "113"}], " ", "*)"}], ";"}]], "Input",
 CellChangeTimes->{{3.510921848392319*^9, 3.5109218796235743`*^9}, {
  3.538483531029236*^9, 3.538483545316053*^9}, {3.53872783691463*^9, 
  3.5387278375346656`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Reference values", "Subsubsection",
 CellChangeTimes->{{3.5109220268566327`*^9, 3.510922028822236*^9}}],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"mtref", "=", "176.9"}], ";", "\[IndentingNewLine]", 
   RowBox[{"alphasref", "=", "0.1213"}], ";", "\[IndentingNewLine]", 
   RowBox[{"alphaMZref", "=", 
    RowBox[{"1", "/", "127.906"}]}], ";", "\n", 
   RowBox[{"mhref", "=", "113"}], ";"}], "*)"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Derived parameters", "Subsection"]], "Subsubsection",
 CellChangeTimes->{{3.510920335548462*^9, 3.510920343520076*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"s2\[Theta]", "=", 
   SqrtBox[
    FractionBox[
     RowBox[{"4", "\[Pi]", " ", "alphaMZ"}], 
     RowBox[{
      SqrtBox["2"], "GF", " ", 
      SuperscriptBox["MZ", "2"]}]]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"s2", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"4", "x", 
         RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}]}], "\[Equal]", 
        SuperscriptBox["s2\[Theta]", "2"]}], ",", "x"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}], " ", ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    SuperscriptBox["sin", "2"], " ", "of", " ", "electroweak", " ", "angle"}],
    " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s2", "=", "0.23108"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s", "=", 
   SqrtBox["s2"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"1", "-", "s2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "=", 
    RowBox[{"Cos", "[", 
     RowBox[{"ArcSin", "[", "s", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"v2", "=", 
    FractionBox["1", 
     RowBox[{
      SqrtBox["2"], "GF"}]]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"vev", " ", "\[Tilde]", " ", 
    RowBox[{"246", " ", "GeV"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"v", "=", 
    SuperscriptBox["v2", 
     FractionBox["1", "2"]]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalGamma]Z", "=", "2.4952"}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"We", " ", "use", " ", "it", " ", "in", " ", "the", " ", "e"}], 
     "+", "e", "-"}], " ", "\[Rule]", " ", 
    RowBox[{"tau", "+", "tau", "-", " ", 
     RowBox[{
     "cross", " ", "section", " ", "mediated", " ", "by", " ", "a", " ", 
      "tensor", " ", "operator"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MZ2", "=", 
   SuperscriptBox["MZ", "2"]}], ";"}]}], "Input",
 CellChangeTimes->{{3.510903052861125*^9, 3.5109030679931517`*^9}, {
  3.510903319449993*^9, 3.510903335986022*^9}, {3.510904177000099*^9, 
  3.5109042017105427`*^9}, {3.510909148321391*^9, 3.5109092066966934`*^9}, {
  3.5109218731027627`*^9, 3.510921874756366*^9}, {3.515150083901162*^9, 
  3.5151500842561827`*^9}, {3.5292594901306615`*^9, 3.529259502376683*^9}, {
  3.529259560564785*^9, 3.5292595749480104`*^9}, {3.529260279008447*^9, 
  3.5292602889612646`*^9}, {3.5292647307736664`*^9, 3.5292647404456835`*^9}, {
  3.5292647926589746`*^9, 3.5292648060593987`*^9}, {3.5292652592713947`*^9, 
  3.529265259723795*^9}, {3.5384823982194424`*^9, 3.5384824087070427`*^9}, {
  3.5384825444158044`*^9, 3.5384825599736943`*^9}, {3.540539410986596*^9, 
  3.540539411112603*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g2", "=", 
   RowBox[{"c2", "*", "4", "*", 
    RowBox[{
     RowBox[{"MZ", "^", "2"}], "/", "v2"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gp2", "=", 
   RowBox[{"s2", "*", "4", "*", 
    RowBox[{
     RowBox[{"MZ", "^", "2"}], "/", "v2"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5109036606703925`*^9, 3.510903671091211*^9}, {
  3.5109037919758234`*^9, 3.510903797872634*^9}, {3.510909216977111*^9, 
  3.5109092181159134`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
    "**"}], "**************************************************)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
  "(*", "          ", "Measurements", 
   "                                                                          \
     ", "*)"}], "   ", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
    "**"}], "**************************************************)"}]}]], \
"Section",
 FontSize->14],

Cell[CellGroupData[{

Cell["Z pole and other observables excluding LEP II measurements", \
"Subsection",
 CellChangeTimes->{{3.5109162272110443`*^9, 3.510916231251451*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"From", " ", 
   RowBox[{"PDG", "'"}], "s", " ", "Review", " ", "of", " ", "particle", " ", 
   "physics", " ", 
   RowBox[{"(", "2010", ")"}], " ", "where", " ", "there", " ", "is", " ", 
   "no", " ", "other", " ", "indication"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.5360581227556515`*^9, 3.5360582144513674`*^9}, {
  3.5405394690179152`*^9, 3.5405394909321685`*^9}, {3.5405395947941093`*^9, 
  3.5405396050796976`*^9}}],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"experimental", " ", "value"}], ";", " ", 
    RowBox[{"experimental", " ", "error"}], ";", " ", 
    RowBox[{"SM", " ", "prediction"}], ";", " ", 
    RowBox[{"theoretical", " ", "error"}]}], "     ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    StyleBox[
     RowBox[{"MWexp1", "=", "80.420"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"errMW1", "=", "0.031"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"MWexp2", "=", "80.376"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"errMW2", "=", "0.033"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["   ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"MWSM", "=", "80.390"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrMW", "=", "0.014"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"GammaZexp", "=", "2.4952"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errGammaZ", "=", "0.0023"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"GammaZSM", "=", "2.4972"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"therrGammaZ", "=", "0.0009"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"Gammahadexp", "=", "1.7444"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errGammahad", "=", "0.0020"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox["  ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"GammahadSM", "=", "1.7435"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"therrGammahad", "=", "0.0009"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"sigmah0exp", "=", 
      RowBox[{"41.541", "*", "1000"}]}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errsigmah0", "=", 
      RowBox[{"0.037", "*", "1000"}]}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"sigmah0SM", "=", 
      RowBox[{"41.472", "*", "1000"}]}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"therrsigmah0", "=", 
      RowBox[{"0.008", "*", "1000"}]}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"Reexp", "=", "20.804"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errRe", "=", "0.050"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"ReSM", "=", "20.750"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrRe", "=", "0.010"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"Rmuexp", "=", "20.785"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errRmu", "=", "0.033"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"RmuSM", "=", "20.751"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrRmu", "=", "0.010"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"Rtauexp", "=", "20.764"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errRtau", "=", "0.045"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"RtauSM", "=", "20.790"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrRtau", "=", "0.010"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"Rbexp", "=", "0.21629"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errRb", "=", "0.00066"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"RbSM", "=", "0.21564"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrRb", "=", "0.00005"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"Rcexp", "=", "0.1720"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errRc", "=", "0.0030"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"RcSM", "=", "0.17233"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrRc", "=", "0.00003"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"AFB0eexp", "=", "0.0145"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errAFB0e", "=", "0.0025"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"AFB0eSM", "=", "0.01626"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrAFB0e", "=", "0.00021"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"AFB0muexp", "=", "0.0169"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errAFB0mu", "=", "0.0013"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"AFB0muSM", "=", "0.01626"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrAFB0mu", "=", "0.00021"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"AFB0tauexp", "=", "0.0188"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errAFB0tau", "=", "0.0017"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"AFB0tauSM", "=", "0.01626"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrAFB0tau", "=", "0.00021"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"AFB0bexp", "=", "0.0992"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errAFB0b", "=", "0.0016"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"AFB0bSM", "=", "0.1032"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrAFB0b", "=", "0.0007"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"AFB0cexp", "=", "0.0706"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errAFB0c", "=", "0.0035"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"AFB0cSM", "=", "0.0738"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrAFB0c", "=", "0.0005"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"AFB0sexp", "=", "0.0976"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"errAFB0s", "=", "0.0114"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"AFB0sSM", "=", "0.1033"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrAFB0s", "=", "0.0007"}],
     FontColor->RGBColor[1., 0., 0.]], 
    StyleBox[";",
     FontColor->RGBColor[1., 0., 0.]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"sin2effexp", "=", "0.2324"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errsin2eff", "=", "0.0012"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"sin2effSM", "=", "0.23149"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrsin2eff", "=", "0.00012"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"Aeexp1", "=", "0.15138"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"errAe1", "=", "0.00216"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"Aeexp2", "=", "0.1544"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"errAe2", "=", "0.0060"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"Aeexp3", "=", "0.1498"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"errAe3", "=", "0.0049"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"AeSM", "=", "0.1472"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrAe", "=", "0.0010"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"Amuexp", "=", "0.142"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errAmu", "=", "0.015"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"AmuSM", "=", "0.1472"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrAmu", "=", "0.0010"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"Atauexp1", "=", "0.1439"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"errAtau1", "=", "0.0043"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox["  ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"Atauexp2", "=", "0.136"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"errAtau2", "=", "0.015"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"AtauSM", "=", "0.1472"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrAtau", "=", "0.0010"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"Abexp", "=", "0.925"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errAb", "=", "0.020"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"AbSM", "=", "0.9347"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrAb", "=", "0.0001"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"Acexp", "=", "0.670"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"errAc", "=", "0.026"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[" ",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"AcSM", "=", "0.6678"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrAc", "=", "0.0004"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"Asexp", "=", "0.895"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"errAs", "=", "0.091"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"AsSM", "=", "0.9357"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrAs", "=", "0.0001"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{"25", " ", "measurements", " ", "so", " ", "far"}], " ", "*)"}],
    Background->RGBColor[0.87, 0.94, 1]], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{"NuTev", " ", "data"}], " ", "*)"}],
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", 
   StyleBox[
    RowBox[{
     RowBox[{"gL2exp", "=", "0.3027"}], ";", 
     RowBox[{"errgL2", "=", "0.0018"}], ";", 
     RowBox[{"gL2SM", "=", "0.30397"}], ";", 
     RowBox[{"therrgL2", "=", "0.00017"}], ";"}],
    FontColor->GrayLevel[0]], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{
     RowBox[{"gR2exp", "=", "0.03076"}], ";", 
     RowBox[{"errgR2", "=", "0.00110"}], ";", 
     RowBox[{"gR2SM", "=", "0.03007"}], ";", 
     RowBox[{"therrgR2", "=", "0.00002"}], ";"}],
    FontColor->GrayLevel[0]], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{"Z", " ", "couplings"}], " ", "*)"}],
    FontColor->GrayLevel[0]], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{"From", " ", "section", " ", "7.3", ".2", " ", 
      RowBox[{"of", " ", "[", "2", "]"}]}], " ", "*)"}],
    FontColor->GrayLevel[0]], 
   StyleBox["  ",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"gVeexp", "=", 
      RowBox[{"-", "0.040"}]}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"errgVe", "=", "0.015"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox["  ",
     FontColor->RGBColor[0, 1, 0]], 
    StyleBox[
     RowBox[{"(*", " ", 
      RowBox[{"From", " ", "Appendix", " ", "G", " ", 
       RowBox[{"of", " ", "[", "2", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"Z", "-", 
         RowBox[{"pole", " ", "fit", " ", "value"}]}], ")"}]}], " ", "*)"}],
     FontColor->RGBColor[0, 1, 0]], 
    StyleBox["  ",
     FontColor->RGBColor[0, 1, 0]], 
    StyleBox[
     RowBox[{"gVeSM", "=", 
      RowBox[{"-", "0.0397"}]}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrgVe", "=", "0.0003"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]]}], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{"From", " ", "section", " ", "7.3", ".2", " ", 
      RowBox[{"of", " ", "[", "2", "]"}]}], " ", "*)"}],
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 0]], 
   RowBox[{
    StyleBox[
     RowBox[{"gAeexp", "=", 
      RowBox[{"-", "0.507"}]}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"errgAe", "=", "0.014"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"(*", " ", 
      RowBox[{"From", " ", "Appendix", " ", "G", " ", 
       RowBox[{"of", " ", "[", "2", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"Z", "-", 
         RowBox[{"pole", " ", "fit", " ", "value"}]}], ")"}]}], " ", "*)"}],
     FontColor->RGBColor[0, 1, 0]], 
    StyleBox[" ",
     FontColor->RGBColor[0, 1, 0]], 
    StyleBox[
     RowBox[{"gAeSM", "=", 
      RowBox[{"-", "0.5065"}]}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"therrgAe", "=", "0.0001"}],
     FontColor->GrayLevel[0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{"From", " ", "PDG", " ", "2010"}], " ", "-", " ", 
      RowBox[{
      "ELECTROWEAKMODEL", " ", "AND", " ", "CONSTRAINTS", " ", "ON", " ", 
       "NEWPHYSICS", " ", "review"}]}], "*)"}],
    FontColor->GrayLevel[0]], 
   StyleBox["  ",
    FontColor->GrayLevel[0]], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    StyleBox[
     RowBox[{"QWCsexp", "=", 
      RowBox[{"-", "73.20"}]}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"errQWCs", "=", "0.35"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->GrayLevel[0]], 
    StyleBox["   ",
     FontColor->GrayLevel[0]], 
    StyleBox[
     RowBox[{"QWCsSM", "=", 
      RowBox[{"-", "73.19"}]}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[
     RowBox[{"therrQWCs", "=", "0.02"}],
     FontColor->RGBColor[1, 0, 0]], 
    StyleBox[";",
     FontColor->RGBColor[1, 0, 0]]}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   StyleBox[
    RowBox[{
     RowBox[{"QWTlexp", "=", 
      RowBox[{"-", "116.6"}]}], ";", 
     RowBox[{"errQWTl", "=", "3.7"}], ";", 
     RowBox[{"QWTlSM", "=", 
      RowBox[{"-", "116.81"}]}], ";", 
     RowBox[{"therrQWTl", "=", "0.04"}], ";"}],
    FontColor->GrayLevel[0]], 
   StyleBox[" ",
    FontColor->GrayLevel[0]], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "The", " ", "following", " ", "values", " ", "are", " ", "from", " ", 
      RowBox[{"Z", ".", "Phys", ".", 
       RowBox[{"C45", ":", 
        RowBox[{"361", "-", "379"}]}]}]}], ",", "1990"}], " ", "*)"}], 
   StyleBox["\[IndentingNewLine]",
    FontColor->GrayLevel[0]], 
   RowBox[{
    RowBox[{"RnuexpCDHS", "=", "0.3072"}], ";", 
    RowBox[{"errRnuCDHS", "=", "0.0033"}], ";", 
    RowBox[{"rCDHS", "=", "0.393"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "The", " ", "following", " ", "values", " ", "are", " ", "from", " ", 
      RowBox[{"Phys", ".", " ", "Lett", ".", " ", "B177"}]}], ",", 
     RowBox[{"446", 
      RowBox[{"(", "1986", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RnuexpCHARM", "=", "0.3093"}], ";", 
    RowBox[{"errRnuCHARM", "=", "0.0031"}], ";", " ", 
    RowBox[{"rCHARM", "=", "0.456"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "The", " ", "following", " ", "values", " ", "are", " ", "from", " ", 
      RowBox[{"Eur", ".", " ", "Phys", ".", " ", "J", ".", " ", "C1"}]}], ",", 
     RowBox[{"509", 
      RowBox[{"(", "1998", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kappaexp", "=", "0.5820"}], ";", 
    RowBox[{"errkappa", "=", "0.0041"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "The", " ", "following", " ", "values", " ", "are", " ", "from", " ", 
     "Erler", " ", "and", " ", "Langacker", " ", "in", " ", 
     RowBox[{"PDG", "'"}], "s", " ", "review", " ", "of", " ", "particle", 
     " ", "physics", " ", 
     RowBox[{"(", "2002", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "The", " ", "small", " ", "corrections", " ", "from", " ", "the", " ", 
     "difference", " ", "of", " ", "input", " ", "parameters", " ", "have", 
     " ", "been", " ", "considered", " ", "\[IndentingNewLine]", "but", " ", 
     RowBox[{"don", "'"}], "t", " ", "have", " ", "visible", " ", "effect", "  ", 
     RowBox[{"here", "."}]}], 
    "                                                            ", "*)"}], 
   "                ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RnuSM", "=", "0.3093"}], ";", 
    RowBox[{"therrRnu", "=", "0.0002"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kappaSM", "=", "0.5833"}], ";", 
    RowBox[{"therrkappa", "=", "0.0004"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.510662417060548*^9, 3.5106624243155603`*^9}, {
   3.5106625143745184`*^9, 3.510662580877435*^9}, {3.5106626168666983`*^9, 
   3.510662648706354*^9}, {3.510662692386431*^9, 3.5106627040864515`*^9}, {
   3.510662737876111*^9, 3.5106627672665625`*^9}, {3.510662838184287*^9, 
   3.510662864985134*^9}, {3.510662953250089*^9, 3.510663020626608*^9}, {
   3.5106632928002853`*^9, 3.510663318431131*^9}, {3.51091049137455*^9, 
   3.510910599186339*^9}, {3.510910766683833*^9, 3.510910807384305*^9}, 
   3.5109121711699*^9, {3.5109149914080734`*^9, 3.5109150124837103`*^9}, {
   3.5109155081121807`*^9, 3.5109156475140257`*^9}, {3.5109156832380886`*^9, 
   3.5109158780512304`*^9}, {3.510915957736171*^9, 3.5109161479005046`*^9}, {
   3.5109161873373737`*^9, 3.510916265415511*^9}, {3.510920244912303*^9, 
   3.5109202532115173`*^9}, {3.5111595591778955`*^9, 
   3.5111596046794977`*^9}, {3.5111602114942055`*^9, 3.511160256815798*^9}, {
   3.5111616990292873`*^9, 3.511161736778447*^9}, {3.5111617690462923`*^9, 
   3.511161824326454*^9}, {3.5111731379995594`*^9, 3.511173174096624*^9}, {
   3.529256709020177*^9, 3.5292567275062094`*^9}, {3.5292597128210526`*^9, 
   3.5292597146618557`*^9}, {3.5292605002324357`*^9, 3.529260519248869*^9}, {
   3.529260885833913*^9, 3.529260896317131*^9}, {3.5292610880414677`*^9, 
   3.529261098259486*^9}, {3.5292624274598207`*^9, 3.5292624285986223`*^9}, {
   3.5292624973791437`*^9, 3.52926250121675*^9}, {3.5292631412868743`*^9, 
   3.5292631478700857`*^9}, {3.5292637345559163`*^9, 3.529263752277548*^9}, {
   3.5292653647743797`*^9, 3.529265381326009*^9}, {3.529265425552087*^9, 
   3.529265429155693*^9}, {3.529265808018958*^9, 3.5292658110453634`*^9}, {
   3.5292664937828164`*^9, 3.529266495628922*^9}, {3.529266936984166*^9, 
   3.5292669385872574`*^9}, {3.529267628780734*^9, 3.5292676589794617`*^9}, {
   3.5292681420190897`*^9, 3.5292682001454144`*^9}, {3.529268286977381*^9, 
   3.5292682947588263`*^9}, {3.529268674674672*^9, 3.5292686972479115`*^9}, {
   3.529268812454114*^9, 3.529268838194159*^9}, {3.5292689540867624`*^9, 
   3.5292689717303934`*^9}, {3.529269432945204*^9, 3.52926943648641*^9}, 
   3.529269473552075*^9, 3.529269821136286*^9, {3.5293206214741445`*^9, 
   3.5293207293653154`*^9}, {3.5293217418922286`*^9, 3.529321824107931*^9}, {
   3.529321882104248*^9, 3.52932189560102*^9}, {3.529321937804434*^9, 
   3.5293219867452335`*^9}, {3.5293226115879726`*^9, 
   3.5293226329051914`*^9}, {3.529322700765073*^9, 3.5293227049383116`*^9}, {
   3.5293238208501377`*^9, 3.5293238394232006`*^9}, 3.529325307069145*^9, {
   3.5293253384589405`*^9, 3.5293254411918163`*^9}, {3.5293261633461213`*^9, 
   3.5293261887725754`*^9}, 3.535442093915905*^9, {3.536058243220872*^9, 
   3.536058358367123*^9}, {3.536058432461222*^9, 3.536058501326598*^9}, {
   3.5360585314614286`*^9, 3.5360586159637527`*^9}, {3.5360586520568314`*^9, 
   3.5360586626533012`*^9}, {3.5360586967097263`*^9, 
   3.5360587884226985`*^9}, {3.5360588795472507`*^9, 3.536058977104232*^9}, {
   3.5360590781022987`*^9, 3.536059172829726*^9}, {3.538482889198525*^9, 
   3.5384829131258936`*^9}, {3.538484736451182*^9, 3.5384848339367576`*^9}, {
   3.538484905118829*^9, 3.538485032113093*^9}, {3.5384850916915007`*^9, 
   3.538485158961348*^9}, {3.538485189003066*^9, 3.5384851930943003`*^9}, {
   3.5384852281683064`*^9, 3.5384852540957894`*^9}, {3.538485288879779*^9, 
   3.538485332019246*^9}, {3.5384860493912773`*^9, 3.5384860515313997`*^9}, 
   3.538486083299217*^9, {3.5384861170921497`*^9, 3.5384861217264147`*^9}, {
   3.538742269332117*^9, 3.5387423009299245`*^9}, 3.538743299770055*^9, {
   3.53874339618357*^9, 3.5387434065701637`*^9}, {3.538743456279007*^9, 
   3.5387434918520412`*^9}, {3.538745087598313*^9, 3.538745154249125*^9}, {
   3.5387451920182853`*^9, 3.5387451920842896`*^9}, {3.538745263792391*^9, 
   3.5387452895458636`*^9}, {3.5387453247418766`*^9, 3.538745375357772*^9}, {
   3.538745432640048*^9, 3.538745444168708*^9}, {3.538745590108055*^9, 
   3.5387457426617804`*^9}, {3.5405394616684947`*^9, 3.540539494780389*^9}, {
   3.540539552182672*^9, 3.5405395574179716`*^9}, {3.540539587972719*^9, 
   3.5405396518013697`*^9}}],

Cell[BoxData[
 StyleBox[
  RowBox[{" ", 
   RowBox[{"(*", " ", 
    RowBox[{"32", " ", "measurements", " ", "so", " ", "far", " ", 
     RowBox[{"(", 
      RowBox[{"34", " ", "considering", " ", "NuTev"}], ")"}]}], " ", "*)"}]}],
  Background->RGBColor[0.87, 0.94, 1]]], "Input",
 CellChangeTimes->{
  3.5293262135399923`*^9, {3.540539659653819*^9, 3.540539670085416*^9}}],

Cell[CellGroupData[{

Cell["\<\
Correcting the SM predictions due to the changes in the input parameters\
\>", "Subsubsection",
 CellChangeTimes->{{3.5109202628367343`*^9, 3.5109202651455383`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"derivatives", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.00628", ",", 
       RowBox[{"-", "0.70990"}], ",", "0.13441", ",", 
       RowBox[{"-", "0.06055"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00024", ",", "0.50263", ",", "0.00677", ",", 
       RowBox[{"-", "0.00234"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00016", ",", "0.50384", ",", "0.00640", ",", 
       RowBox[{"-", "0.00196"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.60192", ",", 
       RowBox[{"-", "4981.53794"}], ",", 
       RowBox[{"-", "10.51996"}], ",", "1.92720"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.00036"}], ",", "6.13214", ",", "0.04512", ",", 
       RowBox[{"-", "0.00867"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.00036"}], ",", "6.13219", ",", "0.04512", ",", 
       RowBox[{"-", "0.00867"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.00036"}], ",", "6.14583", ",", "0.04516", ",", 
       RowBox[{"-", "0.00868"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.00004"}], ",", 
       RowBox[{"-", "0.00653"}], ",", 
       RowBox[{"-", "0.00009"}], ",", "0.00003"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", "0.02093", ",", "0.00015", ",", 
       RowBox[{"-", "0.00003"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00006", ",", 
       RowBox[{"-", "0.02211"}], ",", "0.00446", ",", 
       RowBox[{"-", "0.00089"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00006", ",", 
       RowBox[{"-", "0.02211"}], ",", "0.00446", ",", 
       RowBox[{"-", "0.00089"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00006", ",", 
       RowBox[{"-", "0.02211"}], ",", "0.00446", ",", 
       RowBox[{"-", "0.00089"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00018", ",", 
       RowBox[{"-", "0.07112"}], ",", "0.01434", ",", 
       RowBox[{"-", "0.00285"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00014", ",", 
       RowBox[{"-", "0.05512"}], ",", "0.01110", ",", 
       RowBox[{"-", "0.00220"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00018", ",", 
       RowBox[{"-", "0.07118"}], ",", "0.01435", ",", 
       RowBox[{"-", "0.00285"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.00003"}], ",", "0.01272", ",", 
       RowBox[{"-", "0.00257"}], ",", "0.00051"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00025", ",", 
       RowBox[{"-", "0.10013"}], ",", "0.02020", ",", 
       RowBox[{"-", "0.00401"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00025", ",", 
       RowBox[{"-", "0.10013"}], ",", "0.02020", ",", 
       RowBox[{"-", "0.00401"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00025", ",", 
       RowBox[{"-", "0.10013"}], ",", "0.02020", ",", 
       RowBox[{"-", "0.00401"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00001", ",", 
       RowBox[{"-", "0.00836"}], ",", "0.00166", ",", 
       RowBox[{"-", "0.00033"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00011", ",", 
       RowBox[{"-", "0.04501"}], ",", "0.00888", ",", 
       RowBox[{"-", "0.00176"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00002", ",", 
       RowBox[{"-", "0.00831"}], ",", "0.00163", ",", 
       RowBox[{"-", "0.00032"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00008", ",", 
       RowBox[{"-", "0.01551"}], ",", "0.00187", ",", 
       RowBox[{"-", "0.00073"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00000", ",", "0.00515", ",", 
       RowBox[{"-", "0.00064"}], ",", "0.00009"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.00007"}], ",", "0.04485", ",", 
       RowBox[{"-", "0.00921"}], ",", "0.00100"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.00005"}], ",", "0.00044", ",", 
       RowBox[{"-", "0.00001"}], ",", "0.00030"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00074", ",", 
       RowBox[{"-", "5.82365"}], ",", "1.07948", ",", 
       RowBox[{"-", "0.08041"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00031", ",", 
       RowBox[{"-", "8.63592"}], ",", "1.59509", ",", 
       RowBox[{"-", "0.11434"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00008", ",", 
       RowBox[{"-", "0.01174"}], ",", "0.00154", ",", 
       RowBox[{"-", "0.00067"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.00014", ",", 
       RowBox[{"-", "0.01871"}], ",", "0.00261", ",", 
       RowBox[{"-", "0.00121"}]}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"alphaMZref", "=", 
   RowBox[{"1", "/", "127.906"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mtref", "=", "176.9"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"alphasref", "=", "0.1213"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mhref", "=", "113."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dalphaMZ", "=", 
   RowBox[{
    RowBox[{"1", "/", "alphaMZ"}], "-", 
    RowBox[{"1", "/", "alphaMZref"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dmt", "=", 
   RowBox[{"mt", "-", "mtref"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dalphas", "=", 
   RowBox[{"alphas", "-", "alphasref"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dlogmh", "=", 
   RowBox[{
    RowBox[{"Log", "[", "mh", "]"}], "-", 
    RowBox[{"Log", "[", "mhref", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"devs", "=", 
   RowBox[{"{", 
    RowBox[{"dmt", ",", "dalphas", ",", "dalphaMZ", ",", "dlogmh"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SMvalues", "=", 
    RowBox[{"{", 
     RowBox[{
     "MWSM", ",", "GammaZSM", ",", "GammahadSM", ",", "sigmah0SM", ",", 
      "ReSM", ",", "RmuSM", ",", "RtauSM", ",", "RbSM", ",", "RcSM", ",", 
      "AFB0eSM", ",", "AFB0muSM", ",", "AFB0tauSM", ",", "AFB0bSM", ",", 
      "AFB0cSM", ",", "AFB0sSM", ",", "sin2effSM", ",", "AeSM", ",", "AmuSM", 
      ",", "AtauSM", ",", "AbSM", ",", "AcSM", ",", "AsSM", ",", "gL2SM", ",",
       "gR2SM", ",", "gVeSM", ",", "gAeSM", ",", "QWCsSM", ",", "QWTlSM", ",",
       "RnuSM", ",", "kappaSM"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Print", "[", "SMvalues", "]"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", 
      RowBox[{"Length", "[", "SMvalues", "]"}]}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"j", "\[LessEqual]", "4"}], ",", 
       RowBox[{"j", "++"}], ",", 
       RowBox[{
        RowBox[{"SMvalues", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"SMvalues", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "+", 
         RowBox[{
          RowBox[{"devs", "[", 
           RowBox[{"[", "j", "]"}], "]"}], "*", 
          RowBox[{"derivatives", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}]}]}], "]"}]}], "]"}], 
   ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Print", "[", "SMvalues", "]"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MWSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";", 
   RowBox[{"GammaZSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "2", "]"}], "]"}]}], ";", 
   RowBox[{"GammahadSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "3", "]"}], "]"}]}], ";", 
   RowBox[{"sigmah0SM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "4", "]"}], "]"}]}], ";", 
   RowBox[{"ReSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "5", "]"}], "]"}]}], ";", 
   RowBox[{"RmuSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "6", "]"}], "]"}]}], ";", 
   RowBox[{"RtauSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "7", "]"}], "]"}]}], ";", 
   RowBox[{"RbSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "8", "]"}], "]"}]}], ";", 
   RowBox[{"RcSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "9", "]"}], "]"}]}], ";", 
   RowBox[{"AFB0eSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "10", "]"}], "]"}]}], ";", 
   RowBox[{"AFB0muSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "11", "]"}], "]"}]}], ";", 
   RowBox[{"AFB0tauSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "12", "]"}], "]"}]}], ";", 
   RowBox[{"AFB0bSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "13", "]"}], "]"}]}], ";", 
   RowBox[{"AFB0cSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "14", "]"}], "]"}]}], ";", 
   RowBox[{"AFB0sSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "15", "]"}], "]"}]}], ";", 
   RowBox[{"sin2effSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "16", "]"}], "]"}]}], ";", 
   RowBox[{"AeSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "17", "]"}], "]"}]}], ";", 
   RowBox[{"AmuSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "18", "]"}], "]"}]}], ";", 
   RowBox[{"AtauSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "19", "]"}], "]"}]}], ";", 
   RowBox[{"AbSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "20", "]"}], "]"}]}], ";", 
   RowBox[{"AcSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "21", "]"}], "]"}]}], ";", 
   RowBox[{"AsSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "22", "]"}], "]"}]}], ";", 
   RowBox[{"gL2SM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "23", "]"}], "]"}]}], ";", 
   RowBox[{"gR2SM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "24", "]"}], "]"}]}], ";", 
   RowBox[{"gVeSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "25", "]"}], "]"}]}], ";", 
   RowBox[{"gAeSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "26", "]"}], "]"}]}], ";", 
   RowBox[{"QWCsSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "27", "]"}], "]"}]}], ";", 
   RowBox[{"QWTlSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "28", "]"}], "]"}]}], ";", 
   RowBox[{"RnuSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "29", "]"}], "]"}]}], ";", 
   RowBox[{"kappaSM", "=", 
    RowBox[{"SMvalues", "[", 
     RowBox[{"[", "30", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"LEP", " ", "I", " ", "data", " ", "are", " ", "correlated"}], 
    ",", " ", 
    RowBox[{
    "the", " ", "following", " ", "correlation", " ", "matrices", " ", "are", 
     " ", "from", " ", "Table", " ", "2.13", " ", "of", " ", "Physics", " ", 
     "Reports", " ", "427", " ", 
     RowBox[{"(", "2006", ")"}], " ", "257"}], "\[Dash]", "454", ",", " ", 
    RowBox[{
    "the", " ", "last", " ", "report", " ", "from", " ", "LEP", " ", 
     "experimentes", " ", "on", " ", "these", " ", "data"}]}], "  ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Zline", " ", "shape", " ", "and", " ", "lepton", " ", "forward"}], "-", 
    RowBox[{"backward", " ", "asymmetries"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"expsZline", "=", 
   RowBox[{"{", 
    RowBox[{
    "GammaZexp", ",", "sigmah0exp", ",", "Reexp", ",", "Rmuexp", ",", 
     "Rtauexp", ",", "AFB0eexp", ",", "AFB0muexp", ",", "AFB0tauexp"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"errsZline", "=", 
   RowBox[{"{", 
    RowBox[{
    "errGammaZ", ",", " ", "errsigmah0", ",", "errRe", ",", "errRmu", ",", 
     "errRtau", ",", "errAFB0e", ",", "errAFB0mu", ",", "errAFB0tau"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"corrsZline", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1.", ",", "       ", 
        RowBox[{"-", "0.297"}], ",", "    ", 
        RowBox[{"-", "0.011"}], ",", "        ", "0.008", ",", "      ", 
        "0.006", ",", "        ", "0.007", ",", "          ", "0.002", ",", 
        "         ", "0.001"}], "}"}], ",", "   ", "\[IndentingNewLine]", 
      "\t\t", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.297"}], ",", "    ", "1", ",", "                ", 
        "0.105", ",", "        ", "0.131", ",", "      ", "0.092", ",", 
        "         ", "0.001", ",", "          ", "0.003", ",", "         ", 
        "0.002"}], "}"}], ",", "\[IndentingNewLine]", "\t\t", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.011"}], ",", "    ", "0.105", ",", "       ", "1", 
        ",", "                 ", "0.069", ",", "      ", "0.046", ",", 
        "      ", 
        RowBox[{"-", "0.371"}], ",", "           ", "0.020", ",", "         ",
         "0.013"}], "}"}], ",", "\[IndentingNewLine]", "\t\t", 
      RowBox[{"{", 
       RowBox[{
       "0.008", ",", "       ", "0.131", ",", "       ", "0.069", ",", 
        "        ", "1", ",", "               ", "0.069", ",", "         ", 
        "0.001", ",", "           ", "0.012", ",", "       ", 
        RowBox[{"-", "0.003"}]}], "}"}], ",", "\[IndentingNewLine]", "\t\t", 
      RowBox[{"{", 
       RowBox[{
       "0.006", ",", "       ", "0.092", ",", "       ", "0.046", ",", 
        "        ", "0.069", ",", "       ", "1", ",", "                 ", 
        "0.003", ",", "           ", "0.001", ",", "          ", "0.009"}], 
       "}"}], ",", "\[IndentingNewLine]", "\t\t", 
      RowBox[{"{", 
       RowBox[{"0.007", ",", "       ", "0.001", ",", "    ", 
        RowBox[{"-", "0.371"}], ",", "         ", "0.001", ",", "       ", 
        "0.003", ",", "        ", "1", ",", "                 ", 
        RowBox[{"-", "0.024"}], ",", "       ", 
        RowBox[{"-", "0.020"}]}], "}"}], ",", "\[IndentingNewLine]", "\t\t", 
      RowBox[{"{", 
       RowBox[{
       "0.002", ",", "       ", "0.003", ",", "       ", "0.020", ",", 
        "         ", "0.012", ",", "       ", "0.001", ",", "      ", 
        RowBox[{"-", "0.024"}], ",", "          ", "1", ",", 
        "                  ", "0.046"}], "}"}], ",", "\[IndentingNewLine]", 
      "\t\t", 
      RowBox[{"{", 
       RowBox[{
       "0.001", ",", "       ", "0.002", ",", "       ", "0.013", ",", 
        "       ", 
        RowBox[{"-", "0.003"}], ",", "      ", "0.009", ",", "       ", 
        RowBox[{"-", "0.020"}], ",", "          ", "0.046", ",", "          ",
         "1"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Heavy", " ", "flavor", " ", 
     RowBox[{"results", ":", " ", 
      RowBox[{
      "from", " ", "Table", " ", "5.11", " ", "of", " ", "Physics", " ", 
       "Reports", " ", "427", " ", 
       RowBox[{"(", "2006", ")"}], " ", "257"}]}]}], "\[Dash]", "454", ",", 
    " ", 
    RowBox[{
    "the", " ", "last", " ", "report", " ", "from", " ", "LEP", " ", 
     "experimentes", " ", "on", " ", "these", " ", "data"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"expsbc", "=", 
   RowBox[{"{", 
    RowBox[{
    "Rbexp", ",", "Rcexp", ",", "AFB0bexp", ",", "AFB0cexp", ",", "Abexp", 
     ",", "Acexp"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"errsbc", "=", 
   RowBox[{"{", 
    RowBox[{
    "errRb", ",", "errRc", ",", "errAFB0b", ",", "errAFB0c", ",", "errAb", 
     ",", "errAc"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"corrsbc", "=", "     ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "   ", 
      RowBox[{"1", ",", "          ", 
       RowBox[{"-", "0.18"}], ",", "   ", 
       RowBox[{"-", "0.10"}], ",", "         ", "0.07", ",", "     ", 
       RowBox[{"-", "0.08"}], ",", "    ", "0.04"}], "}"}], ",", 
     "\[IndentingNewLine]", "\t\t", 
     RowBox[{"{", "   ", 
      RowBox[{
       RowBox[{"-", "0.18"}], ",", "     ", "1", ",", "             ", "0.04",
        ",", "       ", 
       RowBox[{"-", "0.06"}], ",", "       ", "0.04", ",", "  ", 
       RowBox[{"-", "0.06"}]}], "}"}], ",", "\[IndentingNewLine]", "\t\t", 
     RowBox[{"{", "   ", 
      RowBox[{
       RowBox[{"-", "0.10"}], ",", "     ", "0.04", ",", "      ", "1", ",", 
       "                 ", "0.15", ",", "      ", "0.06", ",", "      ", 
       "0.01"}], "}"}], ",", "\[IndentingNewLine]", "\t\t", 
     RowBox[{"{", "      ", 
      RowBox[{"0.07", ",", "  ", 
       RowBox[{"-", "0.06"}], ",", "      ", "0.15", ",", "          ", "1", 
       ",", "           ", 
       RowBox[{"-", "0.02"}], ",", "     ", "0.04"}], "}"}], ",", 
     "\[IndentingNewLine]", "\t\t", 
     RowBox[{"{", "   ", 
      RowBox[{
       RowBox[{"-", "0.08"}], ",", "     ", "0.04", ",", "      ", "0.06", 
       ",", "       ", 
       RowBox[{"-", "0.02"}], ",", "       ", "1", ",", "            ", 
       "0.11"}], "}"}], ",", "\[IndentingNewLine]", "\t\t", 
     RowBox[{"{", "     ", 
      RowBox[{"0.04", ",", "   ", 
       RowBox[{"-", "0.06"}], ",", "      ", "0.01", ",", "          ", 
       "0.04", ",", "       ", "0.11", ",", "      ", "1"}], "}"}]}], "}"}]}],
   ";"}]}], "Input",
 CellChangeTimes->{{3.510920259404728*^9, 3.51092026020033*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LEP II data", "Subsection",
 CellChangeTimes->{{3.510916209567413*^9, 3.510916215089823*^9}}],

Cell[CellGroupData[{

Cell["Total cross-sections and assymmetries ", "Subsubsection",
 CellChangeTimes->{{3.510920190359007*^9, 3.5109202092350397`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "from", " ", "LEP", " ", "II", " ", "combined", " ", "data", " ", "from", 
     " ", "hep"}], "-", 
    RowBox[{
     RowBox[{"ex", "/", "0612034"}], "v2", " ", 
     RowBox[{"(", "2007", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Center", " ", "of", " ", "mass", " ", "energy"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"RSLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "130.25", ",", "136.22", ",", "161.34", ",", "172.12", ",", "182.69", 
       ",", "188.635", ",", "191.590", ",", "195.526", ",", "199.522", ",", 
       "201.636", ",", "204.881", ",", "206.561"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Measured", "  ", "hadronic", " ", "cross"}], "-", "sections", 
     "  ", "-", " ", 
     RowBox[{"From", " ", "Table", " ", "3.2"}]}], "  ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sigmahadLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "82.1", ",", "66.7", ",", "37.0", ",", "29.23", ",", "24.59", ",", 
       "22.47", ",", "22.05", ",", "20.53", ",", "19.25", ",", "19.07", ",", 
       "18.17", ",", "17.49"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Experimental", " ", "errors"}], " ", "-", " ", 
     RowBox[{"From", " ", "Table", " ", "3.2"}]}], "  ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"errsigmahadLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "2.2", ",", "2.0", ",", "1.1", ",", "0.99", ",", "0.42", ",", "0.24", 
       ",", "0.53", ",", "0.34", ",", "0.32", ",", "0.44", ",", "0.31", ",", 
       "0.26"}], "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"SM", " ", "predictions"}], " ", "-", " ", 
     RowBox[{"From", " ", "Table", " ", "3.2"}]}], "  ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sigmahadSMLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "82.8", ",", "66.6", ",", "35.2", ",", "28.74", ",", "24.20", ",", 
       "22.156", ",", "21.24", ",", "20.13", ",", "19.09", ",", "18.57", ",", 
       "17.81", ",", "17.42"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"correlation", " ", "matrix"}], " ", "-", " ", 
     RowBox[{"From", " ", "Table", " ", "3.3"}]}], "  ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"crsigmahadLEP", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0.071", ",", "0.080", ",", "0.072", ",", "0.114", ",", 
         "0.146", ",", "0.077", ",", "0.105", ",", "0.120", ",", "0.086", ",",
          "0.117", ",", "0.138"}], "}"}], ",", "\[IndentingNewLine]", 
       "\t\t\t", 
       RowBox[{"{", 
        RowBox[{
        "0.071", ",", "1", ",", "0.075", ",", "0.067", ",", "0.106", ",", 
         "0.135", ",", "0.071", ",", "0.097", ",", "0.110", ",", "0.079", ",",
          "0.109", ",", "0.128"}], "}"}], ",", "\[IndentingNewLine]", 
       "\t\t\t", 
       RowBox[{"{", 
        RowBox[{
        "0.080", ",", "0.075", ",", "1", ",", "0.077", ",", "0.120", ",", 
         "0.153", ",", "0.080", ",", "0.110", ",", "0.125", ",", "0.090", ",",
          "0.124", ",", "0.145"}], "}"}], ",", "\[IndentingNewLine]", 
       "\t\t\t", 
       RowBox[{"{", 
        RowBox[{
        "0.072", ",", "0.067", ",", "0.077", ",", "1", ",", "0.108", ",", 
         "0.137", ",", "0.072", ",", "0.099", ",", "0.112", ",", "0.081", ",",
          "0.111", ",", "0.130"}], "}"}], ",", "\[IndentingNewLine]", 
       "\t\t\t", 
       RowBox[{"{", 
        RowBox[{
        "0.114", ",", "0.106", ",", "0.120", ",", "0.108", ",", "1", ",", 
         "0.223", ",", "0.117", ",", "0.158", ",", "0.182", ",", "0.129", ",",
          "0.176", ",", "0.208"}], "}"}], ",", "\[IndentingNewLine]", 
       "\t\t\t", 
       RowBox[{"{", 
        RowBox[{
        "0.146", ",", "0.135", ",", "0.153", ",", "0.137", ",", "0.223", ",", 
         "1", ",", "0.151", ",", "0.206", ",", "0.235", ",", "0.168", ",", 
         "0.226", ",", "0.268"}], "}"}], ",", "\[IndentingNewLine]", "\t\t\t", 
       RowBox[{"{", 
        RowBox[{
        "0.077", ",", "0.071", ",", "0.080", ",", "0.072", ",", "0.117", ",", 
         "0.151", ",", "1", ",", "0.109", ",", "0.126", ",", "0.090", ",", 
         "0.118", ",", "0.138"}], "}"}], ",", "\[IndentingNewLine]", "\t\t\t", 
       RowBox[{"{", 
        RowBox[{
        "0.105", ",", "0.097", ",", "0.110", ",", "0.099", ",", "0.158", ",", 
         "0.206", ",", "0.109", ",", "1", ",", "0.169", ",", "0.122", ",", 
         "0.162", ",", "0.190"}], "}"}], ",", "\[IndentingNewLine]", "\t\t\t", 
       RowBox[{"{", 
        RowBox[{
        "0.120", ",", "0.110", ",", "0.125", ",", "0.112", ",", "0.182", ",", 
         "0.235", ",", "0.126", ",", "0.169", ",", "1", ",", "0.140", ",", 
         "0.184", ",", "0.215"}], "}"}], ",", "\[IndentingNewLine]", "\t\t\t", 
       RowBox[{"{", 
        RowBox[{
        "0.086", ",", "0.079", ",", "0.090", ",", "0.081", ",", "0.129", ",", 
         "0.168", ",", "0.090", ",", "0.122", ",", "0.140", ",", "1", ",", 
         "0.132", ",", "0.153"}], "}"}], ",", "\[IndentingNewLine]", "\t\t\t", 
       RowBox[{"{", 
        RowBox[{
        "0.117", ",", "0.109", ",", "0.124", ",", "0.111", ",", "0.176", ",", 
         "0.226", ",", "0.118", ",", "0.162", ",", "0.184", ",", "0.132", ",",
          "1", ",", "0.213"}], "}"}], ",", "\[IndentingNewLine]", "\t\t\t", 
       RowBox[{"{", 
        RowBox[{
        "0.138", ",", "0.128", ",", "0.145", ",", "0.130", ",", "0.208", ",", 
         "0.268", ",", "0.138", ",", "0.190", ",", "0.215", ",", "0.153", ",",
          "0.213", ",", "1"}], "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]",
    "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Measured", " ", "muon", " ", "pair", " ", "cross"}], "-", 
     "sections", " ", "-", " ", 
     RowBox[{"From", " ", "Table", " ", "3.2"}]}], "  ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sigmamuLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "8.62", ",", "8.27", ",", "4.61", ",", "3.57", ",", "3.49", ",", 
       "3.123", ",", "2.92", ",", "2.94", ",", "3.02", ",", "2.58", ",", 
       "2.45", ",", "2.595"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"SM", " ", "predicted", " ", "cross"}], "-", "sections", " ", 
     "-", " ", 
     RowBox[{"From", " ", "Table", " ", "3.2"}]}], "  ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sigmamuSMLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "8.44", ",", "7.28", ",", "4.61", ",", "3.95", ",", "3.45", ",", 
       "3.207", ",", "3.10", ",", "2.96", ",", "2.83", ",", "2.77", ",", 
       "2.67", ",", "2.623"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Experimental", " ", "errors"}], " ", "-", " ", 
     RowBox[{"From", " ", "Table", " ", "3.2"}]}], "  ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"errsigmamuLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "0.68", ",", "0.67", ",", "0.36", ",", "0.32", ",", "0.15", ",", 
       "0.076", ",", "0.18", ",", "0.11", ",", "0.11", ",", "0.14", ",", 
       "0.10", ",", "0.088"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Measured", " ", "forward"}], "-", 
     RowBox[{"backward", " ", "asymmetries"}], " ", "-", " ", 
     RowBox[{"From", " ", "Table", " ", "3.2"}]}], "  ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"afbmuLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "0.694", ",", "0.708", ",", "0.538", ",", "0.675", ",", "0.559", ",", 
       "0.569", ",", "0.553", ",", "0.581", ",", "0.524", ",", "0.547", ",", 
       "0.565", ",", "0.542"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"SM", " ", "predicted", " ", "asymmetries"}], " ", "-", " ", 
     RowBox[{"From", " ", "Table", " ", "3.2"}]}], "  ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"afbmuSMLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "0.705", ",", "0.684", ",", "0.609", ",", "0.591", ",", "0.576", ",", 
       "0.569", ",", "0.566", ",", "0.562", ",", "0.558", ",", "0.556", ",", 
       "0.553", ",", "0.552"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Experimental", " ", "errors"}], " ", "-", " ", 
     RowBox[{"From", " ", "Table", " ", "3.2"}]}], "  ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"errafbmuLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "0.060", ",", "0.060", ",", "0.067", ",", "0.077", ",", "0.035", ",", 
       "0.021", ",", "0.051", ",", "0.031", ",", "0.031", ",", "0.047", ",", 
       "0.035", ",", "0.027"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"tau", " ", "pair", " ", "channel"}], " ", "-", " ", 
     RowBox[{"From", " ", "Table", " ", "3.2"}]}], "  ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sigmatauLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "9.02", ",", "7.078", ",", "5.67", ",", "4.01", ",", "3.37", ",", 
       "3.20", ",", "2.81", ",", "2.94", ",", "2.90", ",", "2.79", ",", 
       "2.78", ",", "2.53"}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"sigmatauSMLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "8.44", ",", "7.279", ",", "4.61", ",", "3.95", ",", "3.45", ",", 
       "3.20", ",", "3.10", ",", "2.96", ",", "2.83", ",", "2.77", ",", 
       "2.67", ",", "2.62"}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"errsigmatauLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "0.93", ",", "0.82", ",", "0.54", ",", "0.45", ",", "0.17", ",", "0.10",
        ",", "0.23", ",", "0.14", ",", "0.14", ",", "0.20", ",", "0.14", ",", 
       "0.11"}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"afbtauLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "0.663", ",", "0.753", ",", "0.646", ",", "0.342", ",", "0.608", ",", 
       "0.596", ",", "0.615", ",", "0.505", ",", "0.539", ",", "0.589", ",", 
       "0.571", ",", "0.564"}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"afbtauSMLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "0.704", ",", "0.683", ",", "0.609", ",", "0.591", ",", "0.576", ",", 
       "0.569", ",", "0.566", ",", "0.562", ",", "0.558", ",", "0.556", ",", 
       "0.553", ",", "0.551"}], "}"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"errafbtauLEP", "=", 
     RowBox[{"{", 
      RowBox[{
      "0.076", ",", "0.088", ",", "0.077", ",", "0.094", ",", "0.045", ",", 
       "0.026", ",", "0.069", ",", "0.044", ",", "0.042", ",", "0.059", ",", 
       "0.042", ",", "0.037"}], "}"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.510916203826603*^9, 3.5109162062290072`*^9}, {
  3.5109188933025265`*^9, 3.51091891224096*^9}, {3.5109198723524485`*^9, 
  3.5109199062669077`*^9}, {3.510919957512998*^9, 3.510920031425928*^9}, {
  3.510920069770795*^9, 3.510920070223196*^9}, {3.5109201039192553`*^9, 
  3.510920108380863*^9}, {3.5109201434497247`*^9, 3.510920145337328*^9}, {
  3.51092018085859*^9, 3.5109202139930487`*^9}, {3.529325476909859*^9, 
  3.529325488234507*^9}}],

Cell[BoxData[
 StyleBox[
  RowBox[{"(*", " ", 
   RowBox[{"92", " ", "measurements", " ", "so", " ", "far", " ", 
    RowBox[{"(", 
     RowBox[{"94", " ", "considering", " ", "NuTev"}], ")"}]}], " ", "*)"}],
  Background->RGBColor[0.87, 0.94, 1]]], "Input",
 CellChangeTimes->{{3.5293255527391963`*^9, 3.5293255527831993`*^9}, {
  3.529326309579485*^9, 3.5293263206811204`*^9}, {3.5405396988240595`*^9, 
  3.540539704535386*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ee pair differential cross-sections", "Subsubsection",
 CellChangeTimes->{{3.510920155071745*^9, 3.510920162559758*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Form", " ", "OPAL", " ", "experiment"}], ",", " ", 
    RowBox[{"Eur", ".", " ", "Phys", ".", " ", "J", ".", " ", "C33"}], ",", 
    " ", 
    RowBox[{"173", 
     RowBox[{"(", "2003", ")"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"RSOPAL", "=", 
     RowBox[{"{", 
      RowBox[{
      "188.635", ",", "191.590", ",", "195.526", ",", "199.522", ",", 
       "201.636", ",", "204.881", ",", "206.561"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmaeOPAL", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1.3", ",", "2.1", ",", "2.4", ",", "2.5", ",", "3.8", ",", "4.5", 
         ",", "6.3", ",", "9.2", ",", "12.3", ",", "19.7", ",", "31.9", ",", 
         "51.6", ",", "94.9", ",", "215", ",", "684"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.4", ",", "2.5", ",", "1.5", ",", "2.4", ",", "2.9", ",", "6.5", 
         ",", "6.6", ",", "9.2", ",", "13.7", ",", "21.2", ",", "31.0", ",", 
         "45.2", ",", "91.6", ",", "206", ",", "663"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.3", ",", "1.5", ",", "2.2", ",", "2.9", ",", "3.5", ",", "5.1", 
         ",", "5.6", ",", "8.4", ",", "12.7", ",", "14.9", ",", "26.7", ",", 
         "50.1", ",", "90.5", ",", "199", ",", "640"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.5", ",", "1.8", ",", "2.0", ",", "2.5", ",", "3.9", ",", "5.1", 
         ",", "6.2", ",", "9.7", ",", "10.0", ",", "15.6", ",", "28.8", ",", 
         "48.4", ",", "87.1", ",", "194", ",", "606"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
        "2.2", ",", "1.3", ",", "2.8", ",", "3.8", ",", "2.2", ",", "5.0", 
         ",", "8.2", ",", "8.9", ",", "10.8", ",", "14.6", ",", "24.5", ",", 
         "45.4", ",", "84.4", ",", "184", ",", "606"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.8", ",", "1.7", ",", "2.3", ",", "2.3", ",", "3.8", ",", "5.7", 
         ",", "6.9", ",", "7.2", ",", "11.2", ",", "14.2", ",", "27.2", ",", 
         "43.8", ",", "79.0", ",", "173", ",", "578"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.4", ",", "1.7", ",", "1.7", ",", "2.8", ",", "2.8", ",", "3.9", 
         ",", "6.4", ",", "7.4", ",", "11.9", ",", "17.1", ",", "25.1", ",", 
         "41.9", ",", "77.3", ",", "174", ",", "565"}], "}"}]}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"errdsigmaeOPAL", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.2", ",", "0.3", ",", "0.3", ",", "0.3", ",", "0.4", ",", "0.5", 
         ",", "0.6", ",", "0.8", ",", "0.9", ",", "1.1", ",", "1.4", ",", 
         "1.8", ",", "2.4", ",", "4", ",", "7"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.6", ",", "0.8", ",", "0.6", ",", "0.8", ",", "0.9", ",", "1.8", 
         ",", "1.8", ",", "1.9", ",", "2.3", ",", "2.9", ",", "3.5", ",", 
         "4.3", ",", "5.9", ",", "9", ",", "16"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.4", ",", "0.3", ",", "0.4", ",", "0.5", ",", "0.5", ",", "0.9", 
         ",", "0.9", ",", "1.1", ",", "1.4", ",", "1.5", ",", "2.0", ",", 
         "2.8", ",", "3.6", ",", "6", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.3", ",", "0.4", ",", "0.4", ",", "0.4", ",", "0.5", ",", "0.9", 
         ",", "1.0", ",", "1.2", ",", "1.2", ",", "1.5", ",", "2.1", ",", 
         "2.7", ",", "3.5", ",", "5", ",", "10"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.6", ",", "0.5", ",", "0.8", ",", "0.8", ",", "0.7", ",", "1.4", 
         ",", "1.6", ",", "1.6", ",", "1.8", ",", "2.1", ",", "2.7", ",", 
         "3.8", ",", "5.0", ",", "8", ",", "14"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.2", ",", "0.4", ",", "0.4", ",", "0.4", ",", "0.5", ",", "0.9", 
         ",", "1.0", ",", "1.0", ",", "1.3", ",", "1.4", ",", "2.0", ",", 
         "2.5", ",", "3.3", ",", "5", ",", "9"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.2", ",", "0.3", ",", "0.3", ",", "0.3", ",", "0.4", ",", "0.6", 
         ",", "0.7", ",", "0.8", ",", "1.0", ",", "1.2", ",", "1.5", ",", 
         "1.9", ",", "2.5", ",", "4", ",", "7"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"syserrdsigmaeOPAL", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1.10", ",", "1.16", ",", "1.16", ",", "1.16", ",", "1.16", ",", 
         "1.18", ",", "1.18"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.47", ",", "0.50", ",", "0.50", ",", "0.50", ",", "0.50", ",", 
         "0.52", ",", "0.52"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "0.77", ",", "0.86", ",", "0.86", ",", "0.86", ",", "0.86", ",", 
         "0.89", ",", "0.89"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "SM", " ", "prediction", " ", "calculated", " ", "with", " ", "BHWIDE"}], 
    " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmaeSM", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1.65005749", ",", "1.8185249", ",", "2.152575", ",", "2.7445187", 
         ",", "3.9832157", ",", "5.32403164", ",", "6.93831865", ",", 
         "9.45725257", ",", "13.1912288", ",", "19.4533701", ",", 
         "30.1487427", ",", "50.645226", ",", "95.635255", ",", "212.649716", 
         ",", "685.740814"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.60351512", ",", "1.76129295", ",", "2.05726626", ",", "2.62907102",
          ",", "3.85100997", ",", "5.1417669", ",", "6.73633009", ",", 
         "9.13097235", ",", "12.7397206", ",", "18.8225595", ",", 
         "29.2493243", ",", "49.2154933", ",", "92.7968634", ",", 
         "206.457327", ",", "664.893684"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.51989164", ",", "1.69825997", ",", "1.95936543", ",", "2.51757236",
          ",", "3.64849209", ",", "4.95025859", ",", "6.4470483", ",", 
         "8.69062111", ",", "12.2601369", ",", "18.0195", ",", "27.9748171", 
         ",", "47.2214053", ",", "89.0337371", ",", "198.533629", ",", 
         "638.68866"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.44978566", ",", "1.6273315", ",", "1.88229559", ",", "2.41906209", 
         ",", "3.4931112", ",", "4.70186806", ",", "6.13978293", ",", 
         "8.3580737", ",", "11.8511849", ",", "17.2209144", ",", "26.8961305",
          ",", "45.390833", ",", "85.5337412", ",", "190.536623", ",", 
         "613.868875"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.44099397", ",", "1.58302109", ",", "1.82967316", ",", "2.36644468",
          ",", "3.41623229", ",", "4.67628068", ",", "6.0288236", ",", 
         "8.18298576", ",", "11.5319952", ",", "16.8562431", ",", 
         "26.3321305", ",", "44.443873", ",", "83.7333242", ",", "186.828836",
          ",", "600.980915"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.37674508", ",", "1.52367625", ",", "1.78178534", ",", "2.30632963",
          ",", "3.29027871", ",", "4.4755235", ",", "5.84296294", ",", 
         "7.85494045", ",", "11.1344442", ",", "16.4004574", ",", 
         "25.6003079", ",", "42.9039022", ",", "81.1148228", ",", 
         "181.011367", ",", "582.643808"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "1.36465507", ",", "1.50150607", ",", "1.75689703", ",", "2.28213503",
          ",", "3.22949092", ",", "4.40043436", ",", "5.72943107", ",", 
         "7.7060607", ",", "10.9789199", ",", "16.1137237", ",", "25.2326265",
          ",", "42.2445554", ",", "79.7850985", ",", "178.021953", ",", 
         "573.257286"}], "}"}]}], "}"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.5109201477085323`*^9, 3.5109201535585423`*^9}}],

Cell[BoxData[
 StyleBox[
  RowBox[{"(*", " ", 
   RowBox[{"194", " ", "measurements", " ", "so", " ", "far", " ", 
    RowBox[{"(", 
     RowBox[{"196", " ", "considering", " ", "NuTev"}], ")"}]}], " ", "*)"}],
  Background->RGBColor[0.87, 0.94, 1]]], "Input",
 CellChangeTimes->{
  3.5293255882212257`*^9, {3.5293258624889135`*^9, 3.5293258631619515`*^9}, {
   3.529326370090946*^9, 3.5293263832657003`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["W pair differential cross-sections", "Subsubsection",
 CellChangeTimes->{{3.5109201198156834`*^9, 3.5109201224364877`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"From", " ", "L3", " ", "experiment"}], ",", " ", 
    RowBox[{"(", 
     RowBox[{"hep", "-", 
      RowBox[{"ex", "/", "0409016"}]}], ")"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"RSL3", "=", 
     RowBox[{"{", 
      RowBox[{"182.7", ",", "189.0", ",", "198.3", ",", "205.9"}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmaWL3", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.54", ",", "0.81", ",", "0.22", ",", "0.96", ",", "1.71", ",", 
         "2.27", ",", "3.37", ",", "3.52", ",", "4.24", ",", "5.00"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
        "0.69", ",", "0.88", ",", "1.08", ",", "1.18", ",", "1.34", ",", 
         "1.51", ",", "1.88", ",", "2.95", ",", "4.19", ",", "6.11"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
        "0.68", ",", "0.76", ",", "0.78", ",", "0.80", ",", "1.31", ",", 
         "1.64", ",", "2.21", ",", "2.41", ",", "3.69", ",", "6.26"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
        "0.60", ",", "0.44", ",", "0.77", ",", "0.99", ",", "1.35", ",", 
         "1.72", ",", "1.75", ",", "2.84", ",", "4.80", ",", "7.49"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmaWSM", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.74", ",", "0.84", ",", "1.02", ",", "1.20", ",", "1.44", ",", 
         "1.78", ",", "2.16", ",", "2.86", ",", "3.84", ",", "5.47"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
        "0.64", ",", "0.78", ",", "0.94", ",", "1.14", ",", "1.38", ",", 
         "1.72", ",", "2.22", ",", "2.95", ",", "4.15", ",", "6.24"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
        "0.57", ",", "0.71", ",", "0.85", ",", "1.05", ",", "1.29", ",", 
         "1.65", ",", "2.16", ",", "2.97", ",", "4.38", ",", "7.20"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
        "0.52", ",", "0.64", ",", "0.78", ",", "0.98", ",", "1.21", ",", 
         "1.55", ",", "2.06", ",", "2.92", ",", "4.45", ",", "7.80"}], 
        "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"errdsigmaWL3", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0.23", ",", "0.29", ",", "0.26", ",", "0.33", ",", "0.43", ",", 
         "0.50", ",", "0.62", ",", "0.66", ",", "0.74", ",", "0.83"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
        "0.12", ",", "0.15", ",", "0.17", ",", "0.19", ",", "0.20", ",", 
         "0.22", ",", "0.24", ",", "0.31", ",", "0.37", ",", "0.47"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
        "0.11", ",", "0.13", ",", "0.15", ",", "0.16", ",", "0.20", ",", 
         "0.23", ",", "0.27", ",", "0.29", ",", "0.36", ",", "0.49"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{
        "0.10", ",", "0.11", ",", "0.14", ",", "0.16", ",", "0.20", ",", 
         "0.23", ",", "0.23", ",", "0.30", ",", "0.41", ",", "0.53"}], 
        "}"}]}], "}"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.51092011239007*^9, 3.5109201130920715`*^9}}],

Cell[BoxData[
 StyleBox[
  RowBox[{"(*", " ", 
   RowBox[{"237", " ", "measurements", " ", "so", " ", "far", " ", 
    RowBox[{"(", 
     RowBox[{"239", " ", "considering", " ", "NuTev"}], ")"}]}], " ", "*)"}],
  Background->RGBColor[0.87, 0.94, 1]]], "Input",
 CellChangeTimes->{{3.5293256085463886`*^9, 3.529325609876465*^9}, {
  3.529325867559203*^9, 3.5293258872693305`*^9}, {3.529326408569147*^9, 
  3.529326414609493*^9}, {3.5405397183701773`*^9, 3.540539720904322*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
OPAL ee\[Rule]ee error matrix,obtained using the information from a program \
provided by P.Ward,private communication\
\>", "Subsubsection",
 CellChangeTimes->{
  3.505049584112108*^9, {3.510920090877632*^9, 3.5109200956356406`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DSYS2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "0.0005248089000000001`", ",", "0.000042268900000000005`", ",", 
       "0.000042268900000000005`", ",", "0.000042268900000000005`", ",", 
       "0.000042268900000000005`", ",", "0.000042268900000000005`", ",", 
       "0.000042268900000000005`", ",", "0.000042268900000000005`", ",", 
       "0.000042268900000000005`", ",", "0.000042268900000000005`", ",", 
       "0.000042268900000000005`", ",", "0.000042268900000000005`", ",", 
       "0.000042268900000000005`", ",", "0.00006500890000000001`", ",", 
       "0.00006500890000000001`", ",", "0.00052706`", ",", "0.00004092`", ",",
        "0.00004092`", ",", "0.00004092`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00006726`", ",", 
       "0.00006726`", ",", "0.00052706`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00006726`", ",", 
       "0.00006726`", ",", "0.00052706`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00006726`", ",", 
       "0.00006726`", ",", "0.00052706`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00004092`", ",", 
       "0.00004092`", ",", "0.00004092`", ",", "0.00006726`", ",", 
       "0.00006726`", ",", "0.0005285600000000001`", ",", "0.00004182`", ",", 
       "0.00004182`", ",", "0.00004182`", ",", "0.00004182`", ",", 
       "0.00004182`", ",", "0.00004182`", ",", "0.00004182`", ",", 
       "0.00004182`", ",", "0.00004182`", ",", "0.00004182`", ",", 
       "0.00004182`", ",", "0.00004182`", ",", "0.00006876`", ",", 
       "0.00006876`", ",", "0.0005285600000000001`", ",", "0.00004182`", ",", 
       "0.00004182`", ",", "0.00004182`", ",", "0.00004182`", ",", 
       "0.00004182`", ",", "0.00004182`", ",", "0.00004182`", ",", 
       "0.00004182`", ",", "0.00004182`", ",", "0.00004182`", ",", 
       "0.00004182`", ",", "0.00004182`", ",", "0.00006876`", ",", 
       "0.00006876`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.000042268900000000005`", ",", "0.0004264189`", ",", "0.0004264189`", 
       ",", "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.000042268900000000005`", ",", "0.0004264189`", ",", "0.0004264189`", 
       ",", "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.000042268900000000005`", ",", "0.0004264189`", ",", "0.0004264189`", 
       ",", "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.000042268900000000005`", ",", "0.0004264189`", ",", "0.0004264189`", 
       ",", "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.000042268900000000005`", ",", "0.0004264189`", ",", "0.0004264189`", 
       ",", "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.000042268900000000005`", ",", "0.0004264189`", ",", "0.0004264189`", 
       ",", "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.000042268900000000005`", ",", "0.0004264189`", ",", "0.0004264189`", 
       ",", "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.000042268900000000005`", ",", "0.0004264189`", ",", "0.0004264189`", 
       ",", "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.000042268900000000005`", ",", "0.0004264189`", ",", "0.0004264189`", 
       ",", "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.000042268900000000005`", ",", "0.0004264189`", ",", "0.0004264189`", 
       ",", "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.000042268900000000005`", ",", "0.0004264189`", ",", "0.0004264189`", 
       ",", "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.000042268900000000005`", ",", "0.0004264189`", ",", "0.0004264189`", 
       ",", "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0004264189`", ",", "0.0004264189`", ",", 
       "0.0004264189`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000043440000000000004`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003706`", ",", "0.00003706`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`", ",",
        "0.000044640000000000006`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003826`", ",", "0.00003826`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006500890000000001`", ",", "0.0000358889`", ",", "0.0000358889`", 
       ",", "0.0000358889`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.0000358889`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.0000358889`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.0000358889`", ",", "0.0000888489`", ",", "0.0000888489`", ",", 
       "0.00006726`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00009109999999999999`", ",", 
       "0.00009109999999999999`", ",", "0.00006726`", ",", "0.00003454`", ",",
        "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00009109999999999999`", ",",
        "0.00009109999999999999`", ",", "0.00006726`", ",", "0.00003454`", 
       ",", "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00009109999999999999`", ",",
        "0.00009109999999999999`", ",", "0.00006726`", ",", "0.00003454`", 
       ",", "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00009109999999999999`", ",",
        "0.00009109999999999999`", ",", "0.00006876`", ",", "0.00003544`", 
       ",", "0.00003544`", ",", "0.00003544`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.0000926`", ",", 
       "0.0000926`", ",", "0.00006876`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.0000926`", ",", 
       "0.0000926`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006500890000000001`", ",", "0.0000358889`", ",", "0.0000358889`", 
       ",", "0.0000358889`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.0000358889`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.0000358889`", ",", "0.0000358889`", ",", "0.0000358889`", ",", 
       "0.0000358889`", ",", "0.0000888489`", ",", "0.0000888489`", ",", 
       "0.00006726`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00009109999999999999`", ",", 
       "0.00009109999999999999`", ",", "0.00006726`", ",", "0.00003454`", ",",
        "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00009109999999999999`", ",",
        "0.00009109999999999999`", ",", "0.00006726`", ",", "0.00003454`", 
       ",", "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00009109999999999999`", ",",
        "0.00009109999999999999`", ",", "0.00006726`", ",", "0.00003454`", 
       ",", "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00003454`", ",", 
       "0.00003454`", ",", "0.00003454`", ",", "0.00009109999999999999`", ",",
        "0.00009109999999999999`", ",", "0.00006876`", ",", "0.00003544`", 
       ",", "0.00003544`", ",", "0.00003544`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.0000926`", ",", 
       "0.0000926`", ",", "0.00006876`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.00003544`", ",", 
       "0.00003544`", ",", "0.00003544`", ",", "0.0000926`", ",", 
       "0.0000926`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00052706`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.00006726`", ",", "0.00006726`", 
       ",", "0.000544217`", ",", "0.000054837000000000004`", ",", 
       "0.000054837000000000004`", ",", "0.000054837000000000004`", ",", 
       "0.000054837000000000004`", ",", "0.000054837000000000004`", ",", 
       "0.000054837000000000004`", ",", "0.000054837000000000004`", ",", 
       "0.000054837000000000004`", ",", "0.000054837000000000004`", ",", 
       "0.000054837000000000004`", ",", "0.000054837000000000004`", ",", 
       "0.000054837000000000004`", ",", "0.000084417`", ",", "0.000084417`", 
       ",", "0.000539462`", ",", "0.000050082000000000006`", ",", 
       "0.000050082000000000006`", ",", "0.000050082000000000006`", ",", 
       "0.000050082000000000006`", ",", "0.000050082000000000006`", ",", 
       "0.000050082000000000006`", ",", "0.000050082000000000006`", ",", 
       "0.000050082000000000006`", ",", "0.000050082000000000006`", ",", 
       "0.000050082000000000006`", ",", "0.000050082000000000006`", ",", 
       "0.000050082000000000006`", ",", "0.000079662`", ",", "0.000079662`", 
       ",", "0.0005397418`", ",", "0.0000503618`", ",", "0.0000503618`", ",", 
       "0.0000503618`", ",", "0.0000503618`", ",", "0.0000503618`", ",", 
       "0.0000503618`", ",", "0.0000503618`", ",", "0.0000503618`", ",", 
       "0.0000503618`", ",", "0.0000503618`", ",", "0.0000503618`", ",", 
       "0.0000503618`", ",", "0.00007994180000000001`", ",", 
       "0.00007994180000000001`", ",", "0.0005397824000000001`", ",", 
       "0.000050402400000000004`", ",", "0.000050402400000000004`", ",", 
       "0.000050402400000000004`", ",", "0.000050402400000000004`", ",", 
       "0.000050402400000000004`", ",", "0.000050402400000000004`", ",", 
       "0.000050402400000000004`", ",", "0.000050402400000000004`", ",", 
       "0.000050402400000000004`", ",", "0.000050402400000000004`", ",", 
       "0.000050402400000000004`", ",", "0.000050402400000000004`", ",", 
       "0.0000799824`", ",", "0.0000799824`", ",", "0.0005381`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.0000783`", ",", "0.0000783`", ",", "0.0005381`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.0000783`", ",", "0.0000783`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000054837000000000004`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000050082000000000006`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000054837000000000004`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000050082000000000006`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000054837000000000004`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000050082000000000006`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000054837000000000004`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000050082000000000006`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000054837000000000004`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000050082000000000006`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000054837000000000004`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000050082000000000006`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000054837000000000004`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000050082000000000006`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000054837000000000004`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000050082000000000006`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000054837000000000004`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000050082000000000006`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000054837000000000004`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000050082000000000006`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000054837000000000004`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000050082000000000006`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000054837000000000004`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.00043502700000000005`", ",", 
       "0.00043502700000000005`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000050082000000000006`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006726`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00009109999999999999`", ",", 
       "0.00009109999999999999`", ",", "0.000084417`", ",", 
       "0.000048456999999999994`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000048456999999999994`", ",", 
       "0.000108257`", ",", "0.000108257`", ",", "0.000079662`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.00010350199999999999`", ",", "0.00010350199999999999`", ",", 
       "0.00007994180000000001`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.0000439818`", ",", "0.00010378180000000002`", ",", 
       "0.00010378180000000002`", ",", "0.0000799824`", ",", "0.0000440224`", 
       ",", "0.0000440224`", ",", "0.0000440224`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000440224`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000440224`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000440224`", ",", "0.00010382240000000001`", 
       ",", "0.00010382240000000001`", ",", "0.0000783`", ",", "0.00004138`", 
       ",", "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00010214`", ",", 
       "0.00010214`", ",", "0.0000783`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00010214`", ",", 
       "0.00010214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006726`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00009109999999999999`", ",", 
       "0.00009109999999999999`", ",", "0.000084417`", ",", 
       "0.000048456999999999994`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000048456999999999994`", ",", 
       "0.000048456999999999994`", ",", "0.000048456999999999994`", ",", 
       "0.000108257`", ",", "0.000108257`", ",", "0.000079662`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.00010350199999999999`", ",", "0.00010350199999999999`", ",", 
       "0.00007994180000000001`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.0000439818`", ",", "0.00010378180000000002`", ",", 
       "0.00010378180000000002`", ",", "0.0000799824`", ",", "0.0000440224`", 
       ",", "0.0000440224`", ",", "0.0000440224`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000440224`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000440224`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000440224`", ",", "0.00010382240000000001`", 
       ",", "0.00010382240000000001`", ",", "0.0000783`", ",", "0.00004138`", 
       ",", "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00010214`", ",", 
       "0.00010214`", ",", "0.0000783`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00010214`", ",", 
       "0.00010214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00052706`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.00006726`", ",", "0.00006726`", 
       ",", "0.000539462`", ",", "0.000050082000000000006`", ",", 
       "0.000050082000000000006`", ",", "0.000050082000000000006`", ",", 
       "0.000050082000000000006`", ",", "0.000050082000000000006`", ",", 
       "0.000050082000000000006`", ",", "0.000050082000000000006`", ",", 
       "0.000050082000000000006`", ",", "0.000050082000000000006`", ",", 
       "0.000050082000000000006`", ",", "0.000050082000000000006`", ",", 
       "0.000050082000000000006`", ",", "0.000079662`", ",", "0.000079662`", 
       ",", "0.0005407514`", ",", "0.0000513714`", ",", "0.0000513714`", ",", 
       "0.0000513714`", ",", "0.0000513714`", ",", "0.0000513714`", ",", 
       "0.0000513714`", ",", "0.0000513714`", ",", "0.0000513714`", ",", 
       "0.0000513714`", ",", "0.0000513714`", ",", "0.0000513714`", ",", 
       "0.0000513714`", ",", "0.0000809514`", ",", "0.0000809514`", ",", 
       "0.0005392246`", ",", "0.0000498446`", ",", "0.0000498446`", ",", 
       "0.0000498446`", ",", "0.0000498446`", ",", "0.0000498446`", ",", 
       "0.0000498446`", ",", "0.0000498446`", ",", "0.0000498446`", ",", 
       "0.0000498446`", ",", "0.0000498446`", ",", "0.0000498446`", ",", 
       "0.0000498446`", ",", "0.0000794246`", ",", "0.0000794246`", ",", 
       "0.0005392598`", ",", "0.0000498798`", ",", "0.0000498798`", ",", 
       "0.0000498798`", ",", "0.0000498798`", ",", "0.0000498798`", ",", 
       "0.0000498798`", ",", "0.0000498798`", ",", "0.0000498798`", ",", 
       "0.0000498798`", ",", "0.0000498798`", ",", "0.0000498798`", ",", 
       "0.0000498798`", ",", "0.0000794598`", ",", "0.0000794598`", ",", 
       "0.0005381`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.0000783`", ",", "0.0000783`", ",", 
       "0.0005381`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.0000783`", ",", "0.0000783`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050082000000000006`", ",", "0.000430272`", ",", "0.000430272`", 
       ",", "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.0000513714`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000498446`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000498798`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.000047820000000000006`",
        ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050082000000000006`", ",", "0.000430272`", ",", "0.000430272`", 
       ",", "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.0000513714`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000498446`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000498798`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.000047820000000000006`",
        ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050082000000000006`", ",", "0.000430272`", ",", "0.000430272`", 
       ",", "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.0000513714`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000498446`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000498798`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.000047820000000000006`",
        ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050082000000000006`", ",", "0.000430272`", ",", "0.000430272`", 
       ",", "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.0000513714`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000498446`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000498798`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.000047820000000000006`",
        ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050082000000000006`", ",", "0.000430272`", ",", "0.000430272`", 
       ",", "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.0000513714`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000498446`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000498798`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.000047820000000000006`",
        ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050082000000000006`", ",", "0.000430272`", ",", "0.000430272`", 
       ",", "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.0000513714`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000498446`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000498798`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.000047820000000000006`",
        ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050082000000000006`", ",", "0.000430272`", ",", "0.000430272`", 
       ",", "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.0000513714`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000498446`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000498798`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.000047820000000000006`",
        ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050082000000000006`", ",", "0.000430272`", ",", "0.000430272`", 
       ",", "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.0000513714`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000498446`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000498798`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.000047820000000000006`",
        ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050082000000000006`", ",", "0.000430272`", ",", "0.000430272`", 
       ",", "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.0000513714`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000498446`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000498798`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.000047820000000000006`",
        ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050082000000000006`", ",", "0.000430272`", ",", "0.000430272`", 
       ",", "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.0000513714`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000498446`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000498798`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.000047820000000000006`",
        ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050082000000000006`", ",", "0.000430272`", ",", "0.000430272`", 
       ",", "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.0000513714`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000498446`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000498798`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.000047820000000000006`",
        ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050082000000000006`", ",", "0.000430272`", ",", "0.000430272`", 
       ",", "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000430272`", ",", "0.000430272`", ",", 
       "0.000430272`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.0000513714`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.00043156140000000004`", ",", "0.00043156140000000004`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000498446`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000498798`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.000047820000000000006`",
        ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006726`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00009109999999999999`", ",", 
       "0.00009109999999999999`", ",", "0.000079662`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.00010350199999999999`", ",", "0.00010350199999999999`", ",", 
       "0.0000809514`", ",", "0.0000449914`", ",", "0.0000449914`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000449914`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000449914`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000449914`", ",", 
       "0.0000449914`", ",", "0.00010479140000000001`", ",", 
       "0.00010479140000000001`", ",", "0.0000794246`", ",", "0.0000434646`", 
       ",", "0.0000434646`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0001032646`", ",", 
       "0.0001032646`", ",", "0.0000794598`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.00010329980000000002`", 
       ",", "0.00010329980000000002`", ",", "0.0000783`", ",", "0.00004138`", 
       ",", "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00010214`", ",", 
       "0.00010214`", ",", "0.0000783`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00010214`", ",", 
       "0.00010214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006726`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00009109999999999999`", ",", 
       "0.00009109999999999999`", ",", "0.000079662`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.000043701999999999996`", ",", "0.000043701999999999996`", ",", 
       "0.00010350199999999999`", ",", "0.00010350199999999999`", ",", 
       "0.0000809514`", ",", "0.0000449914`", ",", "0.0000449914`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000449914`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000449914`", ",", 
       "0.0000449914`", ",", "0.0000449914`", ",", "0.0000449914`", ",", 
       "0.0000449914`", ",", "0.00010479140000000001`", ",", 
       "0.00010479140000000001`", ",", "0.0000794246`", ",", "0.0000434646`", 
       ",", "0.0000434646`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0001032646`", ",", 
       "0.0001032646`", ",", "0.0000794598`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.00010329980000000002`", 
       ",", "0.00010329980000000002`", ",", "0.0000783`", ",", "0.00004138`", 
       ",", "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00010214`", ",", 
       "0.00010214`", ",", "0.0000783`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00010214`", ",", 
       "0.00010214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00052706`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.00006726`", ",", "0.00006726`", 
       ",", "0.0005397418`", ",", "0.0000503618`", ",", "0.0000503618`", ",", 
       "0.0000503618`", ",", "0.0000503618`", ",", "0.0000503618`", ",", 
       "0.0000503618`", ",", "0.0000503618`", ",", "0.0000503618`", ",", 
       "0.0000503618`", ",", "0.0000503618`", ",", "0.0000503618`", ",", 
       "0.0000503618`", ",", "0.00007994180000000001`", ",", 
       "0.00007994180000000001`", ",", "0.0005392246`", ",", "0.0000498446`", 
       ",", "0.0000498446`", ",", "0.0000498446`", ",", "0.0000498446`", ",", 
       "0.0000498446`", ",", "0.0000498446`", ",", "0.0000498446`", ",", 
       "0.0000498446`", ",", "0.0000498446`", ",", "0.0000498446`", ",", 
       "0.0000498446`", ",", "0.0000498446`", ",", "0.0000794246`", ",", 
       "0.0000794246`", ",", "0.000541282`", ",", "0.000051902000000000006`", 
       ",", "0.000051902000000000006`", ",", "0.000051902000000000006`", ",", 
       "0.000051902000000000006`", ",", "0.000051902000000000006`", ",", 
       "0.000051902000000000006`", ",", "0.000051902000000000006`", ",", 
       "0.000051902000000000006`", ",", "0.000051902000000000006`", ",", 
       "0.000051902000000000006`", ",", "0.000051902000000000006`", ",", 
       "0.000051902000000000006`", ",", "0.000081482`", ",", "0.000081482`", 
       ",", "0.0005395244`", ",", "0.0000501444`", ",", "0.0000501444`", ",", 
       "0.0000501444`", ",", "0.0000501444`", ",", "0.0000501444`", ",", 
       "0.0000501444`", ",", "0.0000501444`", ",", "0.0000501444`", ",", 
       "0.0000501444`", ",", "0.0000501444`", ",", "0.0000501444`", ",", 
       "0.0000501444`", ",", "0.0000797244`", ",", "0.0000797244`", ",", 
       "0.0005381`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.0000783`", ",", "0.0000783`", ",", 
       "0.0005381`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.0000783`", ",", "0.0000783`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000498446`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.000051902000000000006`", ",", "0.000432092`", ",", "0.000432092`", 
       ",", "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.0000501444`", ",", "0.0004303344`",
        ",", "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",",
        "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000498446`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.000051902000000000006`", ",", "0.000432092`", ",", "0.000432092`", 
       ",", "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.0000501444`", ",", "0.0004303344`",
        ",", "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",",
        "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000498446`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.000051902000000000006`", ",", "0.000432092`", ",", "0.000432092`", 
       ",", "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.0000501444`", ",", "0.0004303344`",
        ",", "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",",
        "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000498446`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.000051902000000000006`", ",", "0.000432092`", ",", "0.000432092`", 
       ",", "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.0000501444`", ",", "0.0004303344`",
        ",", "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",",
        "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000498446`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.000051902000000000006`", ",", "0.000432092`", ",", "0.000432092`", 
       ",", "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.0000501444`", ",", "0.0004303344`",
        ",", "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",",
        "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000498446`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.000051902000000000006`", ",", "0.000432092`", ",", "0.000432092`", 
       ",", "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.0000501444`", ",", "0.0004303344`",
        ",", "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",",
        "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000498446`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.000051902000000000006`", ",", "0.000432092`", ",", "0.000432092`", 
       ",", "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.0000501444`", ",", "0.0004303344`",
        ",", "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",",
        "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000498446`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.000051902000000000006`", ",", "0.000432092`", ",", "0.000432092`", 
       ",", "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.0000501444`", ",", "0.0004303344`",
        ",", "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",",
        "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000498446`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.000051902000000000006`", ",", "0.000432092`", ",", "0.000432092`", 
       ",", "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.0000501444`", ",", "0.0004303344`",
        ",", "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",",
        "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000498446`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.000051902000000000006`", ",", "0.000432092`", ",", "0.000432092`", 
       ",", "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.0000501444`", ",", "0.0004303344`",
        ",", "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",",
        "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000498446`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.000051902000000000006`", ",", "0.000432092`", ",", "0.000432092`", 
       ",", "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.0000501444`", ",", "0.0004303344`",
        ",", "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",",
        "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.0000503618`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.00043055180000000005`", ",", 
       "0.00043055180000000005`", ",", "0.0000439818`", ",", "0.0000439818`", 
       ",", "0.0000498446`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0004300346`", ",", "0.0004300346`", ",", 
       "0.0004300346`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.000051902000000000006`", ",", "0.000432092`", ",", "0.000432092`", 
       ",", "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000432092`", ",", "0.000432092`", ",", 
       "0.000432092`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.0000501444`", ",", "0.0004303344`",
        ",", "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",",
        "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.000047820000000000006`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00004144`", ",", 
       "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006726`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00009109999999999999`", ",", 
       "0.00009109999999999999`", ",", "0.00007994180000000001`", ",", 
       "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.00010378180000000002`", ",", "0.00010378180000000002`", ",", 
       "0.0000794246`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0001032646`", ",", "0.0001032646`", ",", 
       "0.000081482`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.000105322`", ",", "0.000105322`", 
       ",", "0.0000797244`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0001035644`", ",", "0.0001035644`", ",", 
       "0.0000783`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00010214`", ",", "0.00010214`", ",", 
       "0.0000783`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00010214`", ",", "0.00010214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006726`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00009109999999999999`", ",", 
       "0.00009109999999999999`", ",", "0.00007994180000000001`", ",", 
       "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.0000439818`", ",", "0.0000439818`", ",", "0.0000439818`", ",", 
       "0.00010378180000000002`", ",", "0.00010378180000000002`", ",", 
       "0.0000794246`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0000434646`", ",", "0.0000434646`", ",", 
       "0.0000434646`", ",", "0.0001032646`", ",", "0.0001032646`", ",", 
       "0.000081482`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.000045521999999999995`", ",", 
       "0.000045521999999999995`", ",", "0.000105322`", ",", "0.000105322`", 
       ",", "0.0000797244`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0001035644`", ",", "0.0001035644`", ",", 
       "0.0000783`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00010214`", ",", "0.00010214`", ",", 
       "0.0000783`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00010214`", ",", "0.00010214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00052706`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.000043440000000000004`", ",", 
       "0.000043440000000000004`", ",", "0.00006726`", ",", "0.00006726`", 
       ",", "0.0005397824000000001`", ",", "0.000050402400000000004`", ",", 
       "0.000050402400000000004`", ",", "0.000050402400000000004`", ",", 
       "0.000050402400000000004`", ",", "0.000050402400000000004`", ",", 
       "0.000050402400000000004`", ",", "0.000050402400000000004`", ",", 
       "0.000050402400000000004`", ",", "0.000050402400000000004`", ",", 
       "0.000050402400000000004`", ",", "0.000050402400000000004`", ",", 
       "0.000050402400000000004`", ",", "0.0000799824`", ",", "0.0000799824`",
        ",", "0.0005392598`", ",", "0.0000498798`", ",", "0.0000498798`", ",",
        "0.0000498798`", ",", "0.0000498798`", ",", "0.0000498798`", ",", 
       "0.0000498798`", ",", "0.0000498798`", ",", "0.0000498798`", ",", 
       "0.0000498798`", ",", "0.0000498798`", ",", "0.0000498798`", ",", 
       "0.0000498798`", ",", "0.0000794598`", ",", "0.0000794598`", ",", 
       "0.0005395244`", ",", "0.0000501444`", ",", "0.0000501444`", ",", 
       "0.0000501444`", ",", "0.0000501444`", ",", "0.0000501444`", ",", 
       "0.0000501444`", ",", "0.0000501444`", ",", "0.0000501444`", ",", 
       "0.0000501444`", ",", "0.0000501444`", ",", "0.0000501444`", ",", 
       "0.0000501444`", ",", "0.0000797244`", ",", "0.0000797244`", ",", 
       "0.0005430972`", ",", "0.0000537172`", ",", "0.0000537172`", ",", 
       "0.0000537172`", ",", "0.0000537172`", ",", "0.0000537172`", ",", 
       "0.0000537172`", ",", "0.0000537172`", ",", "0.0000537172`", ",", 
       "0.0000537172`", ",", "0.0000537172`", ",", "0.0000537172`", ",", 
       "0.0000537172`", ",", "0.0000832972`", ",", "0.0000832972`", ",", 
       "0.0005381`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.0000783`", ",", "0.0000783`", ",", 
       "0.0005381`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.000047760000000000004`", ",", 
       "0.000047760000000000004`", ",", "0.0000783`", ",", "0.0000783`"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000498798`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000501444`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000537172`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.000047337200000000005`",
        ",", "0.000047337200000000005`", ",", "0.000047820000000000006`", ",",
        "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000498798`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000501444`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000537172`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.000047337200000000005`",
        ",", "0.000047337200000000005`", ",", "0.000047820000000000006`", ",",
        "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000498798`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000501444`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000537172`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.000047337200000000005`",
        ",", "0.000047337200000000005`", ",", "0.000047820000000000006`", ",",
        "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000498798`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000501444`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000537172`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.000047337200000000005`",
        ",", "0.000047337200000000005`", ",", "0.000047820000000000006`", ",",
        "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000498798`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000501444`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000537172`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.000047337200000000005`",
        ",", "0.000047337200000000005`", ",", "0.000047820000000000006`", ",",
        "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000498798`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000501444`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000537172`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.000047337200000000005`",
        ",", "0.000047337200000000005`", ",", "0.000047820000000000006`", ",",
        "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000498798`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000501444`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000537172`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.000047337200000000005`",
        ",", "0.000047337200000000005`", ",", "0.000047820000000000006`", ",",
        "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000498798`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000501444`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000537172`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.000047337200000000005`",
        ",", "0.000047337200000000005`", ",", "0.000047820000000000006`", ",",
        "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000498798`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000501444`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000537172`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.000047337200000000005`",
        ",", "0.000047337200000000005`", ",", "0.000047820000000000006`", ",",
        "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000498798`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000501444`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000537172`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.000047337200000000005`",
        ",", "0.000047337200000000005`", ",", "0.000047820000000000006`", ",",
        "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000498798`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000501444`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000537172`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.000047337200000000005`",
        ",", "0.000047337200000000005`", ",", "0.000047820000000000006`", ",",
        "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004092`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00042470999999999996`", ",", 
       "0.00042470999999999996`", ",", "0.00003454`", ",", "0.00003454`", ",",
        "0.000050402400000000004`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0004305924`", ",", 
       "0.0004305924`", ",", "0.0004305924`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000498798`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0004300698`", ",", 
       "0.0004300698`", ",", "0.0004300698`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000501444`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0004303344`", ",", 
       "0.0004303344`", ",", "0.0004303344`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000537172`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.0004339072`", ",", 
       "0.0004339072`", ",", "0.0004339072`", ",", "0.000047337200000000005`",
        ",", "0.000047337200000000005`", ",", "0.000047820000000000006`", ",",
        "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.000047820000000000006`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00004144`", ",", "0.00004144`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006726`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00009109999999999999`", ",", 
       "0.00009109999999999999`", ",", "0.0000799824`", ",", "0.0000440224`", 
       ",", "0.0000440224`", ",", "0.0000440224`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000440224`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000440224`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000440224`", ",", "0.00010382240000000001`", 
       ",", "0.00010382240000000001`", ",", "0.0000794598`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.00010329980000000002`", ",", "0.00010329980000000002`", ",", 
       "0.0000797244`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0001035644`", ",", "0.0001035644`", ",", 
       "0.0000832972`", ",", "0.000047337200000000005`", ",", 
       "0.000047337200000000005`", ",", "0.000047337200000000005`", ",", 
       "0.000047337200000000005`", ",", "0.000047337200000000005`", ",", 
       "0.000047337200000000005`", ",", "0.000047337200000000005`", ",", 
       "0.000047337200000000005`", ",", "0.000047337200000000005`", ",", 
       "0.000047337200000000005`", ",", "0.000047337200000000005`", ",", 
       "0.000047337200000000005`", ",", "0.00010713719999999999`", ",", 
       "0.00010713719999999999`", ",", "0.0000783`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00010214`", ",", 
       "0.00010214`", ",", "0.0000783`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00010214`", ",", 
       "0.00010214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006726`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00003706`", ",", "0.00003706`", ",", 
       "0.00003706`", ",", "0.00009109999999999999`", ",", 
       "0.00009109999999999999`", ",", "0.0000799824`", ",", "0.0000440224`", 
       ",", "0.0000440224`", ",", "0.0000440224`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000440224`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000440224`", ",", "0.0000440224`", ",", 
       "0.0000440224`", ",", "0.0000440224`", ",", "0.00010382240000000001`", 
       ",", "0.00010382240000000001`", ",", "0.0000794598`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.0000434998`", ",", "0.0000434998`", ",", "0.0000434998`", ",", 
       "0.00010329980000000002`", ",", "0.00010329980000000002`", ",", 
       "0.0000797244`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0000437644`", ",", "0.0000437644`", ",", 
       "0.0000437644`", ",", "0.0001035644`", ",", "0.0001035644`", ",", 
       "0.0000832972`", ",", "0.000047337200000000005`", ",", 
       "0.000047337200000000005`", ",", "0.000047337200000000005`", ",", 
       "0.000047337200000000005`", ",", "0.000047337200000000005`", ",", 
       "0.000047337200000000005`", ",", "0.000047337200000000005`", ",", 
       "0.000047337200000000005`", ",", "0.000047337200000000005`", ",", 
       "0.000047337200000000005`", ",", "0.000047337200000000005`", ",", 
       "0.000047337200000000005`", ",", "0.00010713719999999999`", ",", 
       "0.00010713719999999999`", ",", "0.0000783`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00010214`", ",", 
       "0.00010214`", ",", "0.0000783`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00004138`", ",", "0.00004138`", ",", "0.00010214`", ",", 
       "0.00010214`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.0005285600000000001`", ",", "0.000044640000000000006`", ",", 
       "0.000044640000000000006`", ",", "0.000044640000000000006`", ",", 
       "0.000044640000000000006`", ",", "0.000044640000000000006`", ",", 
       "0.000044640000000000006`", ",", "0.000044640000000000006`", ",", 
       "0.000044640000000000006`", ",", "0.000044640000000000006`", ",", 
       "0.000044640000000000006`", ",", "0.000044640000000000006`", ",", 
       "0.000044640000000000006`", ",", "0.00006876`", ",", "0.00006876`", 
       ",", "0.0005381`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.0000783`", ",", "0.0000783`", ",", 
       "0.0005381`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.0000783`", ",", "0.0000783`", ",", 
       "0.0005381`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.0000783`", ",", "0.0000783`", ",", 
       "0.0005381`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.0000783`", ",", "0.0000783`", ",", 
       "0.0005459562000000001`", ",", "0.00005461620000000001`", ",", 
       "0.00005461620000000001`", ",", "0.00005461620000000001`", ",", 
       "0.00005461620000000001`", ",", "0.00005461620000000001`", ",", 
       "0.00005461620000000001`", ",", "0.00005461620000000001`", ",", 
       "0.00005461620000000001`", ",", "0.00005461620000000001`", ",", 
       "0.00005461620000000001`", ",", "0.00005461620000000001`", ",", 
       "0.00005461620000000001`", ",", "0.00008615620000000001`", ",", 
       "0.00008615620000000001`", ",", "0.0005442613`", ",", 
       "0.000052921300000000004`", ",", "0.000052921300000000004`", ",", 
       "0.000052921300000000004`", ",", "0.000052921300000000004`", ",", 
       "0.000052921300000000004`", ",", "0.000052921300000000004`", ",", 
       "0.000052921300000000004`", ",", "0.000052921300000000004`", ",", 
       "0.000052921300000000004`", ",", "0.000052921300000000004`", ",", 
       "0.000052921300000000004`", ",", "0.000052921300000000004`", ",", 
       "0.00008446130000000001`", ",", "0.00008446130000000001`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00005461620000000001`", ",", "0.0004336062`", ",", "0.0004336062`", 
       ",", "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000052921300000000004`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0000465413`", ",", "0.0000465413`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00005461620000000001`", ",", "0.0004336062`", ",", "0.0004336062`", 
       ",", "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000052921300000000004`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0000465413`", ",", "0.0000465413`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00005461620000000001`", ",", "0.0004336062`", ",", "0.0004336062`", 
       ",", "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000052921300000000004`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0000465413`", ",", "0.0000465413`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00005461620000000001`", ",", "0.0004336062`", ",", "0.0004336062`", 
       ",", "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000052921300000000004`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0000465413`", ",", "0.0000465413`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00005461620000000001`", ",", "0.0004336062`", ",", "0.0004336062`", 
       ",", "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000052921300000000004`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0000465413`", ",", "0.0000465413`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00005461620000000001`", ",", "0.0004336062`", ",", "0.0004336062`", 
       ",", "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000052921300000000004`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0000465413`", ",", "0.0000465413`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00005461620000000001`", ",", "0.0004336062`", ",", "0.0004336062`", 
       ",", "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000052921300000000004`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0000465413`", ",", "0.0000465413`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00005461620000000001`", ",", "0.0004336062`", ",", "0.0004336062`", 
       ",", "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000052921300000000004`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0000465413`", ",", "0.0000465413`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00005461620000000001`", ",", "0.0004336062`", ",", "0.0004336062`", 
       ",", "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000052921300000000004`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0000465413`", ",", "0.0000465413`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00005461620000000001`", ",", "0.0004336062`", ",", "0.0004336062`", 
       ",", "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000052921300000000004`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0000465413`", ",", "0.0000465413`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00005461620000000001`", ",", "0.0004336062`", ",", "0.0004336062`", 
       ",", "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000052921300000000004`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0000465413`", ",", "0.0000465413`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.00005461620000000001`", ",", "0.0004336062`", ",", "0.0004336062`", 
       ",", "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.0004336062`", ",", "0.0004336062`", ",", 
       "0.0004336062`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000052921300000000004`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0000465413`", ",", "0.0000465413`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006876`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.0000926`", ",", "0.0000926`", ",", "0.0000783`",
        ",", "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.0000783`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.0000783`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.0000783`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.00008615620000000001`", ",",
        "0.000048236200000000004`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000048236200000000004`", ",", 
       "0.00010999620000000001`", ",", "0.00010999620000000001`", ",", 
       "0.00008446130000000001`", ",", "0.0000465413`", ",", "0.0000465413`", 
       ",", "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000465413`", ",", "0.0001083013`", ",", "0.0001083013`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006876`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.0000926`", ",", "0.0000926`", ",", "0.0000783`",
        ",", "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.0000783`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.0000783`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.0000783`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.00008615620000000001`", ",",
        "0.000048236200000000004`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000048236200000000004`", ",", 
       "0.000048236200000000004`", ",", "0.000048236200000000004`", ",", 
       "0.00010999620000000001`", ",", "0.00010999620000000001`", ",", 
       "0.00008446130000000001`", ",", "0.0000465413`", ",", "0.0000465413`", 
       ",", "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000465413`", ",", "0.0001083013`", ",", "0.0001083013`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
      "0.0005285600000000001`", ",", "0.000044640000000000006`", ",", 
       "0.000044640000000000006`", ",", "0.000044640000000000006`", ",", 
       "0.000044640000000000006`", ",", "0.000044640000000000006`", ",", 
       "0.000044640000000000006`", ",", "0.000044640000000000006`", ",", 
       "0.000044640000000000006`", ",", "0.000044640000000000006`", ",", 
       "0.000044640000000000006`", ",", "0.000044640000000000006`", ",", 
       "0.000044640000000000006`", ",", "0.00006876`", ",", "0.00006876`", 
       ",", "0.0005381`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.0000783`", ",", "0.0000783`", ",", 
       "0.0005381`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.0000783`", ",", "0.0000783`", ",", 
       "0.0005381`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.0000783`", ",", "0.0000783`", ",", 
       "0.0005381`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.000047820000000000006`", ",", 
       "0.000047820000000000006`", ",", "0.0000783`", ",", "0.0000783`", ",", 
       "0.0005442613`", ",", "0.000052921300000000004`", ",", 
       "0.000052921300000000004`", ",", "0.000052921300000000004`", ",", 
       "0.000052921300000000004`", ",", "0.000052921300000000004`", ",", 
       "0.000052921300000000004`", ",", "0.000052921300000000004`", ",", 
       "0.000052921300000000004`", ",", "0.000052921300000000004`", ",", 
       "0.000052921300000000004`", ",", "0.000052921300000000004`", ",", 
       "0.000052921300000000004`", ",", "0.00008446130000000001`", ",", 
       "0.00008446130000000001`", ",", "0.0005452766`", ",", "0.0000539366`", 
       ",", "0.0000539366`", ",", "0.0000539366`", ",", "0.0000539366`", ",", 
       "0.0000539366`", ",", "0.0000539366`", ",", "0.0000539366`", ",", 
       "0.0000539366`", ",", "0.0000539366`", ",", "0.0000539366`", ",", 
       "0.0000539366`", ",", "0.0000539366`", ",", "0.00008547660000000001`", 
       ",", "0.00008547660000000001`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000052921300000000004`", ",", "0.0004319113`", ",", "0.0004319113`",
        ",", "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",",
        "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000539366`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000052921300000000004`", ",", "0.0004319113`", ",", "0.0004319113`",
        ",", "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",",
        "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000539366`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000052921300000000004`", ",", "0.0004319113`", ",", "0.0004319113`",
        ",", "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",",
        "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000539366`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000052921300000000004`", ",", "0.0004319113`", ",", "0.0004319113`",
        ",", "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",",
        "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000539366`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000052921300000000004`", ",", "0.0004319113`", ",", "0.0004319113`",
        ",", "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",",
        "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000539366`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000052921300000000004`", ",", "0.0004319113`", ",", "0.0004319113`",
        ",", "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",",
        "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000539366`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000052921300000000004`", ",", "0.0004319113`", ",", "0.0004319113`",
        ",", "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",",
        "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000539366`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000052921300000000004`", ",", "0.0004319113`", ",", "0.0004319113`",
        ",", "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",",
        "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000539366`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000052921300000000004`", ",", "0.0004319113`", ",", "0.0004319113`",
        ",", "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",",
        "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000539366`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000052921300000000004`", ",", "0.0004319113`", ",", "0.0004319113`",
        ",", "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",",
        "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000539366`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000052921300000000004`", ",", "0.0004319113`", ",", "0.0004319113`",
        ",", "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",",
        "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000539366`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00004182`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00042542999999999997`", ",", 
       "0.00042542999999999997`", ",", "0.00003544`", ",", "0.00003544`", ",",
        "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000047760000000000004`", ",", "0.00042741`", ",", "0.00042741`", 
       ",", "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00042741`", ",", "0.00042741`", ",", 
       "0.00042741`", ",", "0.00004138`", ",", "0.00004138`", ",", 
       "0.000052921300000000004`", ",", "0.0004319113`", ",", "0.0004319113`",
        ",", "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",",
        "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0004319113`", ",", "0.0004319113`", ",", 
       "0.0004319113`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000539366`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.00043292659999999997`", ",", 
       "0.00043292659999999997`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006876`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.0000926`", ",", "0.0000926`", ",", "0.0000783`",
        ",", "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.0000783`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.0000783`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.0000783`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.00008446130000000001`", ",",
        "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0001083013`", ",", "0.0001083013`", ",", "0.00008547660000000001`", 
       ",", "0.000047556600000000005`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`", ",", "0.000047556600000000005`", ",", 
       "0.00010931660000000001`", ",", "0.00010931660000000001`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
      "0.00006876`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.00003826`", ",", "0.00003826`", ",", 
       "0.00003826`", ",", "0.0000926`", ",", "0.0000926`", ",", "0.0000783`",
        ",", "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.0000783`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.0000783`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.0000783`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00004144`", ",", "0.00004144`", ",", "0.00004144`", ",", 
       "0.00010214`", ",", "0.00010214`", ",", "0.00008446130000000001`", ",",
        "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0000465413`", ",", "0.0000465413`", ",", "0.0000465413`", ",", 
       "0.0001083013`", ",", "0.0001083013`", ",", "0.00008547660000000001`", 
       ",", "0.000047556600000000005`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`", ",", "0.000047556600000000005`", ",", 
       "0.000047556600000000005`", ",", "0.000047556600000000005`", ",", 
       "0.00010931660000000001`", ",", "0.00010931660000000001`"}], "}"}]}], 
    "}"}]}], ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["LEP2 heavy flavor measurements", "Subsubsection",
 CellChangeTimes->{3.540539831048622*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RSbLEP", "=", 
   RowBox[{"{", 
    RowBox[{
    "133", ",", "167", ",", "183", ",", "189", ",", "192", ",", "196", ",", 
     "200", ",", "202", ",", "205", ",", "207"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigmahadSM4b", "=", 
   RowBox[{"{", 
    RowBox[{
    "80.3", ",", "43.9", ",", "24.09", ",", "22.055", ",", "21.14", ",", 
     "20.04", ",", "19.00", ",", "18.48", ",", "17.72", ",", "17.34"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RbLEP", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.1822", ",", "0.1494", ",", "0.1646", ",", "0.1565", ",", "0.1551", ",",
      "0.1556", ",", "0.1683", ",", "0.1646", ",", "0.1606", ",", "0.1694"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RbSMLEP", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.1867", ",", "0.1727", ",", "0.1692", ",", "0.1681", ",", "0.1676", ",",
      "0.1670", ",", "0.1664", ",", "0.1661", ",", "0.1657", ",", "0.1654"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"errRbLEP", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.0132", ",", "0.0127", ",", "0.0094", ",", "0.0061", ",", "0.0149", ",",
      "0.0097", ",", "0.0099", ",", "0.0144", ",", "0.0126", ",", "0.0107"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"afbbLEP", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.367", ",", "0.624", ",", "0.515", ",", "0.529", ",", "0.424", ",", 
     "0.535", ",", "0.596", ",", "0.607", ",", "0.715", ",", "0.175"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"afbbSMLEP", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.504", ",", "0.572", ",", "0.588", ",", "0.593", ",", "0.595", ",", 
     "0.598", ",", "0.600", ",", "0.601", ",", "0.603", ",", "0.604"}], 
    "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"errafbbLEP", "=", 
    RowBox[{"{", 
     RowBox[{
     "0.251", ",", "0.254", ",", "0.149", ",", "0.089", ",", "0.267", ",", 
      "0.151", ",", "0.149", ",", "0.241", ",", "0.214", ",", "0.156"}], 
     "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"257", " ", "measurements", " ", "so", " ", "far", " ", 
     RowBox[{"(", 
      RowBox[{"259", " ", "considering", " ", "NuTev"}], ")"}]}], " ", "*)"}],
   Background->RGBColor[0.87, 0.94, 1]], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RScLEP", "=", 
   RowBox[{"{", 
    RowBox[{
    "133", ",", "167", ",", "183", ",", "189", ",", "196", ",", "200", ",", 
     "205", ",", "207"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigmahadSM4c", "=", 
   RowBox[{"{", 
    RowBox[{
    "80.3", ",", "43.9", ",", "24.09", ",", "22.055", ",", "20.04", ",", 
     "19.00", ",", "17.72", ",", "17.34"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RcLEP", "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0.2628", ",", "0.2298", ",", "0.2734", ",", "0.2535",
      ",", "0.2816", ",", "0.2890"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RcSMLEP", "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0.2472", ",", "0.2490", ",", "0.2508", ",", "0.2518",
      ",", "0.2530", ",", "0.2533"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"errRcLEP", "=", 
   RowBox[{"{", 
    RowBox[{
    "0", ",", "0", ",", "0.0397", ",", "0.0213", ",", "0.0387", ",", "0.0360",
      ",", "0.0394", ",", "0.0350"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"afbcLEP", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.630", ",", "0.980", ",", "0.717", ",", "0.542", ",", "0", ",", "0", 
     ",", "0", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"afbcSMLEP", "=", 
   RowBox[{"{", 
    RowBox[{
    "0.684", ",", "0.677", ",", "0.663", ",", "0.656", ",", "0", ",", "0", 
     ",", "0", ",", "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"errafbcLEP", "=", 
    RowBox[{"{", 
     RowBox[{
     "0.313", ",", "0.343", ",", "0.201", ",", "0.143", ",", "0", ",", "0", 
      ",", "0", ",", "0"}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"273", " ", "measurements", " ", "so", " ", "far", " ", 
     RowBox[{"(", 
      RowBox[{"275", " ", "considering", " ", "NuTev"}], ")"}]}], " ", "*)"}],
   Background->RGBColor[0.87, 0.94, 1]]}]}], "Input",
 CellChangeTimes->{
  3.5405397926584263`*^9, {3.540539824578252*^9, 3.5405398370509653`*^9}, {
   3.540539907987023*^9, 3.540539920424734*^9}, {3.540540075581609*^9, 
   3.5405400788477955`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Other observables", "Subsection",
 CellChangeTimes->{3.540540382741177*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Experimental", " ", "data", " ", "for", " ", "the", " ", "other", " ", 
   "observables", " ", "used", " ", "in", " ", "the", " ", "fit", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
     "leptonic", " ", "and", " ", "semileptonic", " ", "tau", " ", "decays"}],
      ",", " ", 
     RowBox[{
     "anomalous", " ", "magnetic", " ", "moment", " ", "of", " ", "tau"}], 
     ",", " ", "\[CapitalDelta]CKM", ",", " ", 
     RowBox[{"leptonic", " ", "W", " ", "decays"}]}], ")"}], " ", "are", " ", 
   "placed", " ", "inside", " ", "the", " ", "subsections", " ", "of", " ", 
   "\"\<Calculate \!\(\*SuperscriptBox[\(\[Chi]\), \(2\)]\) from different \
measurements\>\"", " ", "section"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.540540100136013*^9, 3.540540228629362*^9}}],

Cell[BoxData[
 StyleBox[
  RowBox[{"(*", " ", 
   RowBox[{"278", " ", "measurements", " ", "so", " ", "far", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"280", " ", "considering", " ", "NuTev"}], " ", "-", " ", 
      RowBox[{
      "279", " ", "considering", " ", "NuTev", " ", "but", " ", "not", " ", 
       "leptonic", " ", "W", " ", "decays"}]}], ")"}]}], " ", "*)"}],
  Background->RGBColor[0.87, 0.94, 1]]], "Input",
 CellChangeTimes->{{3.5405404379593353`*^9, 3.540540441973565*^9}, {
  3.5405415845619173`*^9, 3.5405416113834515`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
    "**"}], "**************************************************)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "          ", 
   RowBox[{"Auxiliary", " ", "definitions", " ", "and", " ", "subroutines"}], 
   "                                                      ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
    "**"}], "**************************************************)"}]}]], \
"Section",
 FontSize->14],

Cell[CellGroupData[{

Cell["Operator definition", "Subsection",
 CellChangeTimes->{{3.5109204134237986`*^9, 3.510920440770647*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "following", " ", "characters", 
    RowBox[{"(", " ", 
     RowBox[{"character", " ", "combinations"}], " ", ")"}], " ", "are", " ", 
    "reserved"}], " ", "*)"}], "\n", 
  RowBox[{"(*", "  ", 
   RowBox[{
   "s", ",", "c", ",", "v", ",", " ", "s2", ",", "c2", ",", "v2", ",", "g", 
    ",", "g2", ",", "gp", ",", "gp2", ",", "e", ",", "e0", ",", "S", ",", "R",
     ",", "vv"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "the", " ", "coefficients", " ", "of", " ", "the", " ", "operators"}], " ",
    "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ops", "=", 
     RowBox[{"{", 
      RowBox[{
      "aWB", ",", "ah", ",", "all1", ",", "all3", ",", "alq1", ",", "alq3", 
       ",", "ale", ",", "aqe", ",", "alu", ",", "ald", ",", "aee", ",", "aeu",
        ",", "aed", ",", "ahl1", ",", "ahl3", ",", "ahq1", ",", "ahq3", ",", 
       "ahu", ",", "ahd", ",", "ahe", ",", "aW", ",", "alQ1", ",", "alQ3", 
       ",", "aLq3", ",", "aQe", ",", "alb", ",", "aeb", ",", "ahQ1", ",", 
       "ahQ3", ",", "ahb", ",", "alL1", ",", "alL3", ",", "aLe", ",", "altau",
        ",", "aetau", ",", "ahL1", ",", "ahL3", ",", "ahtau", ",", "atauWt", 
       ",", "atauBt"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"number", " ", "of", " ", "operators"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"opnum", "=", 
     RowBox[{"Length", "[", "ops", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
      "tags", " ", "used", " ", "to", " ", "select", " ", "operators", " ", 
       "in", " ", "the", " ", 
       RowBox[{"fit", ".", " ", "1"}]}], "=", "selected"}], ";", " ", 
     RowBox[{"0", "=", 
      RowBox[{"not", " ", "selected"}]}]}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"optags", "=", 
     RowBox[{"Table", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "opnum"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Operator", " ", "relations"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Example", ":", " ", "operalations"}], "=", 
     RowBox[{"{", 
      RowBox[{"ahu", "\[Rule]", "ahd"}], "}"}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"oprelations", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"inittag", "[", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", 
       RowBox[{"optags", "=", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "opnum"}], "}"}]}], "]"}]}]}], "]"}]}],
     ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"setlist", "[", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", "i", "}"}], ",", "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{"droplist", "=", 
         RowBox[{"{", "}"}]}], ";", "     ", "\[IndentingNewLine]", " ", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"i", "=", "1"}], ",", 
          RowBox[{"i", "\[LessEqual]", "opnum"}], ",", 
          RowBox[{"i", "++"}], ",", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"optags", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "0"}], ",", 
            RowBox[{"droplist", "=", 
             RowBox[{"Append", "[", 
              RowBox[{"droplist", ",", 
               RowBox[{
                RowBox[{"ops", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", "0"}]}], 
              "]"}]}]}], "]"}]}], "]"}], ";", "droplist"}]}], "]"}]}], ";"}]}]
   }]], "Input",
 CellChangeTimes->{{3.5060802558180046`*^9, 3.5060802648515215`*^9}, 
   3.5060811453728848`*^9, {3.5060811872022767`*^9, 3.5060811906504745`*^9}, {
   3.506165290790553*^9, 3.506165294090742*^9}, {3.50616569827886*^9, 
   3.5061657009240117`*^9}, {3.5061659521613817`*^9, 3.506165981573064*^9}, {
   3.506166053817196*^9, 3.5061660783595996`*^9}, {3.5061667221834245`*^9, 
   3.5061667304158955`*^9}, {3.5061685985657473`*^9, 3.5061686024499693`*^9}, 
   3.5061707133430266`*^9, 3.506170758130705*^9, {3.5061708414660516`*^9, 
   3.5061709145053797`*^9}, {3.506171816046563*^9, 3.5061718191509686`*^9}, {
   3.5061725432106404`*^9, 3.506172552445857*^9}, {3.5068528736018333`*^9, 
   3.5068528950674715`*^9}, 3.5068608404568796`*^9, {3.5154896350325365`*^9, 
   3.515489643628152*^9}, {3.515838010510657*^9, 3.515838128039379*^9}, {
   3.5158382896486225`*^9, 3.515838316777174*^9}, {3.515838355156369*^9, 
   3.515838355925413*^9}, {3.515839200199703*^9, 3.515839327264971*^9}, {
   3.516516726597229*^9, 3.516516732182039*^9}, 3.5165286230084844`*^9, {
   3.5172971730099974`*^9, 3.517297175561143*^9}, {3.5221464181334505`*^9, 
   3.5221464202862544`*^9}, {3.540550562148406*^9, 3.5405505646595497`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
First order and second order functions\
\>", "Subsection",
 CellChangeTimes->{{3.5172972105661454`*^9, 3.517297217571546*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"calculate", " ", "the", " ", "zero", " ", "order", " ", "term", 
    RowBox[{"(", 
     RowBox[{
     "no", " ", "contribution", " ", "from", " ", "the", " ", "operators"}], 
     ")"}], "for", " ", "a", " ", "given", " ", "function"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"zeroorder", "[", "function_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"center", ",", "cc"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"inittag", "[", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"center", "=", 
         RowBox[{"setlist", "[", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"cc", "=", 
         RowBox[{"function", "/.", "center"}]}]}]}], "\[IndentingNewLine]", 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "calculate", " ", "the", " ", "linear", " ", "order", " ", "terms", " ", 
     "for", " ", "a", " ", "given", " ", "function"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"firstorder", "[", "function_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"center", ",", "i"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"inittag", "[", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"center", "=", 
         RowBox[{"setlist", "[", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"cc", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"i", "=", "1"}], ",", 
          RowBox[{"i", "\[LessEqual]", "opnum"}], ",", 
          RowBox[{"i", "++"}], ",", 
          RowBox[{"cc", "=", 
           RowBox[{"cc", "+", 
            RowBox[{
             RowBox[{"ops", "[", 
              RowBox[{"[", "i", "]"}], "]"}], 
             RowBox[{"(", " ", 
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{"function", ",", 
                 RowBox[{"ops", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "/.", "center"}], 
              ")"}]}]}]}]}], "]"}], ";", "\[IndentingNewLine]", "cc"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "calculate", " ", "the", " ", "second", " ", "order", " ", "terms", " ", 
     "for", " ", "a", " ", "given", " ", "function"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"secondorder", "[", "function_", "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"center", ",", "i"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"inittag", "[", "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"center", "=", 
         RowBox[{"setlist", "[", "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"cc", "=", "0"}], ";", "\[IndentingNewLine]", 
        RowBox[{"cc", "=", 
         RowBox[{"cc", "+", 
          RowBox[{
           RowBox[{"1", "/", "2"}], 
           SuperscriptBox["atauWt", "2"], 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{"function", ",", "atauWt"}], "]"}], ",", "atauWt"}], 
              "]"}], "/.", "center"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"1", "/", "2"}], 
           SuperscriptBox["atauBt", "2"], 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{"function", ",", "atauBt"}], "]"}], ",", "atauBt"}], 
              "]"}], "/.", "center"}], ")"}]}], "+", 
          RowBox[{"atauBt", " ", "atauWt", 
           RowBox[{"(", " ", 
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{"function", ",", "atauBt"}], "]"}], ",", "atauWt"}], 
              "]"}], "/.", "center"}], ")"}]}]}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
          RowBox[{
          "If", " ", "you", " ", "want", " ", "the", " ", "second", " ", 
           "order", " ", "with", " ", "respect", " ", "of", " ", "all", " ", 
           RowBox[{"operator", ":", " ", "\[IndentingNewLine]", 
            RowBox[{"For", "[", 
             RowBox[{
              RowBox[{"j", "=", "1"}], ",", 
              RowBox[{"j", "\[LessEqual]", "opnum"}], ",", 
              RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
              RowBox[{"For", "[", 
               RowBox[{
                RowBox[{"i", "=", "1"}], ",", 
                RowBox[{"i", "\[LessEqual]", "opnum"}], ",", 
                RowBox[{"i", "++"}], ",", 
                RowBox[{"cc", "=", 
                 RowBox[{"cc", "+", 
                  RowBox[{
                   RowBox[{"1", "/", "2"}], 
                   RowBox[{"ops", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], 
                   RowBox[{"ops", "[", 
                    RowBox[{"[", "j", "]"}], "]"}], 
                   RowBox[{"(", " ", 
                    RowBox[{
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"D", "[", 
                    RowBox[{"function", ",", 
                    RowBox[{"ops", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
                    RowBox[{"ops", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "/.", "center"}],
                     ")"}]}]}]}]}], "]"}]}], "]"}]}]}], ";"}], " ", "*)"}], 
        "\[IndentingNewLine]", "cc"}]}], "]"}]}], ";"}], " "}]}]], "Input",
 CellChangeTimes->{{3.517297185397706*^9, 3.5172972020856605`*^9}, {
  3.5172972831632977`*^9, 3.5172972982431602`*^9}, {3.5405505718279595`*^9, 
  3.5405506039597974`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
calculate chi2 for correlated measurements\
\>", "Subsection",
 CellChangeTimes->{3.517297195456281*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"chi2corr", "[", 
    RowBox[{
    "exp_", ",", "experr_", ",", "expcorr_", ",", "th_", ",", "therr_", ",", 
     "thcorr_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"i", ",", "j", ",", "imax", ",", "err2", ",", "err2inv"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"exp", "=", 
        RowBox[{"experimental", " ", "values"}]}], ",", " ", 
       RowBox[{"experr", "=", 
        RowBox[{"experimental", " ", "errors"}]}], ",", " ", 
       RowBox[{"expcorr", "=", 
        RowBox[{"experimental", " ", "correlations"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"th", "=", " ", 
        RowBox[{"theoretical", " ", "predictions"}]}], ",", "  ", 
       RowBox[{"therr", "=", 
        RowBox[{"theoretical", " ", "errors"}]}], ",", " ", 
       RowBox[{"thcorr", "=", 
        RowBox[{"theoretical", " ", "correlations"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"imax", "=", 
       RowBox[{"Length", "[", "th", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"err2", "=", 
       RowBox[{"Array", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", 
          RowBox[{"imax", ",", "imax"}], "}"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "1"}], ",", 
        RowBox[{"i", "<", 
         RowBox[{"imax", "+", "1"}]}], ",", 
        RowBox[{"i", "++"}], ",", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"j", "=", "1"}], ",", 
          RowBox[{"j", "<", 
           RowBox[{"imax", "+", "1"}]}], ",", 
          RowBox[{"j", "++"}], ",", 
          RowBox[{
           RowBox[{"err2", "[", 
            RowBox[{"[", 
             RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
           RowBox[{
            RowBox[{
             RowBox[{"experr", "[", 
              RowBox[{"[", "i", "]"}], "]"}], 
             RowBox[{"expcorr", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", 
             RowBox[{"experr", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"therr", "[", 
              RowBox[{"[", "i", "]"}], "]"}], 
             RowBox[{"thcorr", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", 
             RowBox[{"therr", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}]}]}]}], " ", "]"}]}], "]"}], 
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"err2inv", "=", 
       RowBox[{"Inverse", "[", "err2", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"temp", "=", "0"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "1"}], ",", 
        RowBox[{"i", "<", 
         RowBox[{"imax", "+", "1"}]}], ",", 
        RowBox[{"i", "++"}], ",", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"j", "=", "1"}], ",", 
          RowBox[{"j", "<", 
           RowBox[{"imax", "+", "1"}]}], ",", 
          RowBox[{"j", "++"}], ",", 
          RowBox[{"temp", "=", 
           RowBox[{"temp", "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"th", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "-", 
               RowBox[{"exp", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], ")"}], 
             RowBox[{"err2inv", "[", 
              RowBox[{"[", 
               RowBox[{"i", ",", "j"}], "]"}], "]"}], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"th", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "-", 
               RowBox[{"exp", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], ")"}]}]}]}]}], "]"}]}], 
       "]"}], ";", "\[IndentingNewLine]", "temp"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5172971976334057`*^9, 3.517297198348447*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Initial state QED corrections function\
\>", "Subsection",
 CellChangeTimes->{{3.5061657831967173`*^9, 3.5061657904771338`*^9}, {
  3.5172971577181225`*^9, 3.517297158786184*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Initial", " ", "state", " ", "QED", " ", "corrections", " ", "for", " ", 
     "S", " ", "channel", " ", "cross"}], "-", 
    RowBox[{"sections", " ", "and", " ", "asymmetries"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Formula", " ", "and", " ", "notations", " ", "from", "  ", "Zfitter", 
    RowBox[{"(", 
     RowBox[{"hep", "-", 
      RowBox[{"ph", "/", "9908433"}]}], ")"}]}], " ", "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"ElectronMass", "=", "0.00048684727"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"R", "=", 
     RowBox[{"1", "-", "vv"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"cosmax", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"cp", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", "cosmax"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"cm", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", "cosmax"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"gammap", "=", 
     RowBox[{"cp", "+", 
      RowBox[{"R", " ", "cm"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"gammam", "=", 
     RowBox[{"cm", "+", 
      RowBox[{"R", " ", "cp"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"r1", "=", 
     RowBox[{"1", "+", "R"}]}], ";", 
    RowBox[{"r2", "=", 
     RowBox[{"1", "+", 
      RowBox[{"R", "^", "2"}]}]}], ";", 
    RowBox[{"r4", "=", 
     RowBox[{"1", "+", 
      RowBox[{"R", "^", "4"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Le", "=", 
     RowBox[{"Log", "[", 
      RowBox[{"S", "/", 
       RowBox[{"ElectronMass", "^", "2"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"betae", "=", 
     RowBox[{"2", " ", 
      RowBox[{"alphaMZ", "/", "Pi"}], 
      RowBox[{"(", 
       RowBox[{"Le", "-", "1"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Sbini", "=", 
     RowBox[{
      RowBox[{"alphaMZ", "/", "Pi"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"3", "/", "2"}], 
         RowBox[{"(", 
          RowBox[{"Le", "-", "1"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"Pi", "^", "2"}], "/", "3"}], "-", 
        RowBox[{"1", "/", "2"}]}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"CT", "=", "1"}], ";", 
    RowBox[{"CFB", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"vmax", "=", 
     RowBox[{"1", "-", "0.7225"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"HTbini", "=", 
     RowBox[{
      RowBox[{"alphaMZ", "/", "Pi"}], 
      RowBox[{"(", 
       RowBox[{"Le", "-", "1"}], ")"}], 
      RowBox[{"(", 
       RowBox[{"vv", "-", "2"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"HFBbini", "=", 
     RowBox[{"FullSimplify", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"alphaMZ", "/", "Pi"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Le", "-", "1"}], ")"}], "-", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "vv"}], ")"}], "/", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{
                RowBox[{"1", "/", "2"}], "vv"}]}], ")"}], "^", "2"}]}], 
           "]"}]}], ")"}], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "vv"}], ")"}], "^", "2"}]}], ")"}], "/", 
           "vv"}], " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "vv"}], ")"}], "/", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", 
              RowBox[{
               RowBox[{"1", "/", "2"}], "vv"}]}], ")"}], "^", "2"}]}]}], 
         ")"}]}], "-", 
       RowBox[{"2", 
        RowBox[{"alphaMZ", "/", "Pi"}], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Le", "-", "1"}], ")"}], "/", "vv"}]}]}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"RTini", "=", 
     RowBox[{"CT", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "Sbini"}], ")"}], "betae", " ", 
         RowBox[{"vv", "^", 
          RowBox[{"(", 
           RowBox[{"betae", "-", "1"}], ")"}]}]}], "+", "HTbini"}], ")"}]}]}],
     ";"}], "\n", 
   RowBox[{
    RowBox[{"RFBini", "=", 
     RowBox[{"CFB", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", "Sbini"}], ")"}], "betae", " ", 
         RowBox[{"vv", "^", 
          RowBox[{"(", 
           RowBox[{"betae", "-", "1"}], ")"}]}]}], "+", "HFBbini"}], 
       ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"sigmaTini", "[", 
      RowBox[{"sigma0_", ",", "RS_"}], "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", "integrand", "}"}], ",", "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{"integrand", "=", 
         RowBox[{"sigma0", " ", "/.", 
          RowBox[{"{", 
           RowBox[{"S", "\[Rule]", 
            RowBox[{
             RowBox[{"RS", "^", "2"}], "*", 
             RowBox[{"(", 
              RowBox[{"1", "-", "vv"}], ")"}]}]}], "}"}]}]}], ";", 
        "\[IndentingNewLine]", "  ", 
        RowBox[{"integrand", "=", 
         RowBox[{
          RowBox[{"integrand", "*", "RTini"}], "/.", 
          RowBox[{"{", 
           RowBox[{"S", "\[Rule]", 
            RowBox[{"RS", "^", "2"}]}], "}"}]}]}], ";", "\[IndentingNewLine]",
         "  ", 
        RowBox[{"NIntegrate", "[", 
         RowBox[{"integrand", ",", 
          RowBox[{"{", 
           RowBox[{"vv", ",", "0", ",", "vmax"}], "}"}], ",", 
          RowBox[{"MaxRecursion", "\[Rule]", "12"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"sigmaFBini", "[", 
      RowBox[{"sigma0_", ",", "RS_"}], "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", "integrand", "}"}], ",", "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{"integrand", "=", 
         RowBox[{"sigma0", " ", "/.", 
          RowBox[{"{", 
           RowBox[{"S", "\[Rule]", 
            RowBox[{
             RowBox[{"RS", "^", "2"}], "*", 
             RowBox[{"(", 
              RowBox[{"1", "-", "vv"}], ")"}]}]}], "}"}]}]}], ";", 
        "\[IndentingNewLine]", "  ", 
        RowBox[{"integrand", "=", 
         RowBox[{
          RowBox[{"integrand", "*", "RFBini"}], "/.", 
          RowBox[{"{", 
           RowBox[{"S", "\[Rule]", 
            RowBox[{"RS", "^", "2"}]}], "}"}]}]}], ";", "\[IndentingNewLine]",
         "  ", 
        RowBox[{"NIntegrate", "[", 
         RowBox[{"integrand", ",", 
          RowBox[{"{", 
           RowBox[{"vv", ",", "0", ",", "vmax"}], "}"}], ",", 
          RowBox[{"MaxRecursion", "\[Rule]", "12"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"radcorrt", "[", 
      RowBox[{"sigma0_", ",", "RS_"}], "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"aa", ",", "bb", ",", "cc", ",", "i", ",", "sigma1"}], "}"}], 
       ",", "\[IndentingNewLine]", "     ", 
       RowBox[{
        RowBox[{"corrected", "=", "0"}], ";", "\[IndentingNewLine]", "     ", 
        RowBox[{"initdroplist", "[", "]"}], ";", "\[IndentingNewLine]", 
        "     ", 
        RowBox[{"sigma1", "=", 
         RowBox[{"sigma0", "/.", "droplist"}]}], ";", "\[IndentingNewLine]", 
        "     ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"sigma1", "/.", 
             RowBox[{"S", "\[Rule]", "40000"}]}], "]"}], ">", 
           RowBox[{"10", "^", 
            RowBox[{"(", 
             RowBox[{"-", "30"}], ")"}]}]}], ",", " ", 
          RowBox[{"inte0", "=", 
           RowBox[{"sigmaTini", "[", 
            RowBox[{"sigma1", ",", "RS"}], "]"}]}], ",", 
          RowBox[{"inte0", "=", "0"}]}], "]"}], ";", "\[IndentingNewLine]", 
        "     ", 
        RowBox[{"corrected", "=", "inte0"}], ";", "\[IndentingNewLine]", 
        "     ", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"i", "=", "1"}], ",", 
          RowBox[{"i", "<", 
           RowBox[{
            RowBox[{"Length", "[", "ops", "]"}], "+", "1"}]}], ",", 
          RowBox[{"i", "++"}], ",", 
          RowBox[{"Block", "[", 
           RowBox[{
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "             ", 
            RowBox[{
             RowBox[{"sigma1", "=", 
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{"sigma0", ",", 
                 RowBox[{"ops", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "/.", 
               "droplist"}]}], ";", "\[IndentingNewLine]", "             ", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Abs", "[", 
                 RowBox[{"sigma1", "/.", 
                  RowBox[{"S", "\[Rule]", "40000"}]}], "]"}], ">", 
                RowBox[{"10", "^", 
                 RowBox[{"(", 
                  RowBox[{"-", "30"}], ")"}]}]}], ",", " ", 
               RowBox[{"inte1", "=", 
                RowBox[{"sigmaTini", "[", 
                 RowBox[{"sigma1", ",", "RS"}], "]"}]}], ",", 
               RowBox[{"inte1", "=", "0"}]}], "]"}], ";", 
             "\[IndentingNewLine]", "            ", 
             RowBox[{"corrected", "=", 
              RowBox[{"corrected", "+", 
               RowBox[{"inte1", " ", 
                RowBox[{"ops", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}]}]}], ";"}]}], 
           "\[IndentingNewLine]", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        "  ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"SECO", "\[Equal]", "1"}], ",", 
          RowBox[{"Block", "[", 
           RowBox[{
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"ops", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "~", 
                RowBox[{"ops", "[", 
                 RowBox[{"[", "11", "]"}], "]"}]}], " ", "and", " ", 
               RowBox[{
                RowBox[{"ops", "[", 
                 RowBox[{"[", "22", "]"}], "]"}], "~", 
                RowBox[{"ops", "[", 
                 RowBox[{"[", "31", "]"}], "]"}]}], " ", "correspond", " ", 
               "to", " ", "4"}], "-", 
              RowBox[{"fermi", " ", "operators"}]}], " ", "*)"}], 
            "\[IndentingNewLine]", "    ", 
            RowBox[{"For", "[", 
             RowBox[{
              RowBox[{"i", "=", "1"}], ",", 
              RowBox[{"i", "\[LessEqual]", "opnum"}], ",", 
              RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", "  ", 
              RowBox[{"For", "[", 
               RowBox[{
                RowBox[{"j", "=", "1"}], ",", 
                RowBox[{"j", "\[LessEqual]", "opnum"}], ",", 
                RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", "        ", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"i", "\[GreaterEqual]", "3"}], "&&", 
                    RowBox[{"i", "\[LessEqual]", "11"}]}], ")"}], "||", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"i", "\[GreaterEqual]", "22"}], "&&", 
                    RowBox[{"i", "\[LessEqual]", "31"}]}], ")"}]}], ")"}], "&&", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"j", "\[GreaterEqual]", "3"}], "&&", 
                    RowBox[{"j", "\[LessEqual]", "11"}]}], ")"}], "||", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"j", "\[GreaterEqual]", "22"}], "&&", 
                    RowBox[{"j", "\[LessEqual]", "31"}]}], ")"}]}], ")"}]}], 
                  ",", 
                  RowBox[{"Block", "[", 
                   RowBox[{
                    RowBox[{"{", "}"}], ",", "   ", "\[IndentingNewLine]", 
                    "     ", 
                    RowBox[{
                    RowBox[{"sigma1", "=", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", "2"}], 
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"D", "[", 
                    RowBox[{"chi2", ",", 
                    RowBox[{"ops", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
                    RowBox[{"ops", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], "/.", 
                    "droplist"}]}], ";", "\[IndentingNewLine]", "      ", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"sigma1", "/.", 
                    RowBox[{"S", "\[Rule]", "40000"}]}], "]"}], ">", 
                    RowBox[{"10", "^", 
                    RowBox[{"(", 
                    RowBox[{"-", "30"}], ")"}]}]}], ",", 
                    RowBox[{"inte2", "=", 
                    RowBox[{"sigmaTini", "[", 
                    RowBox[{"sigma1", ",", "RS"}], "]"}]}], ",", 
                    RowBox[{"inte2", "=", "0"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", "     ", 
                    RowBox[{"corrected", "=", 
                    RowBox[{"corrected", "+", 
                    RowBox[{"inte2", " ", 
                    RowBox[{"ops", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], " ", 
                    RowBox[{"ops", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}]}]}], ";"}]}], "]"}]}], 
                 "]"}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}], 
           "\[IndentingNewLine]", "  ", "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", " ", "corrected"}]}], "\[IndentingNewLine]", 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"radcorrfb", "[", 
      RowBox[{"sigma0_", ",", "RS_"}], "]"}], ":=", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"aa", ",", "bb", ",", "cc", ",", "i"}], "}"}], ",", 
       "\[IndentingNewLine]", "          ", 
       RowBox[{
        RowBox[{"corrected", "=", "0"}], ";", "\[IndentingNewLine]", 
        "         ", 
        RowBox[{"initdroplist", "[", "]"}], ";", "\[IndentingNewLine]", 
        "         ", 
        RowBox[{"sigma1", "=", 
         RowBox[{"sigma0", "/.", "droplist"}]}], ";", "\[IndentingNewLine]", 
        "         ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"sigma1", "/.", 
             RowBox[{"S", "\[Rule]", "40000"}]}], "]"}], ">", 
           RowBox[{"10", "^", 
            RowBox[{"(", 
             RowBox[{"-", "30"}], ")"}]}]}], ",", " ", 
          RowBox[{"inte0", "=", 
           RowBox[{"sigmaFBini", "[", 
            RowBox[{"sigma1", ",", "RS"}], "]"}]}], ",", 
          RowBox[{"inte0", "=", "0"}]}], "]"}], ";", "\[IndentingNewLine]", 
        "       ", 
        RowBox[{"corrected", "=", "inte0"}], ";", "\[IndentingNewLine]", 
        "       ", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"i", "=", "1"}], ",", 
          RowBox[{"i", "<", 
           RowBox[{
            RowBox[{"Length", "[", "ops", "]"}], "+", "1"}]}], ",", 
          RowBox[{"i", "++"}], ",", 
          RowBox[{"Block", "[", 
           RowBox[{
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "             ", 
            RowBox[{
             RowBox[{"sigma1", "=", 
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{"sigma0", ",", 
                 RowBox[{"ops", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], " ", "]"}], "/.", 
               "droplist"}]}], ";", "\[IndentingNewLine]", "             ", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Abs", "[", 
                 RowBox[{"sigma1", "/.", 
                  RowBox[{"S", "\[Rule]", "40000"}]}], "]"}], ">", 
                RowBox[{"10", "^", 
                 RowBox[{"(", 
                  RowBox[{"-", "30"}], ")"}]}]}], ",", 
               RowBox[{"inte1", "=", 
                RowBox[{"sigmaFBini", "[", 
                 RowBox[{"sigma1", ",", "RS"}], "]"}]}], ",", 
               RowBox[{"inte1", "=", "0"}]}], "]"}], ";", 
             "\[IndentingNewLine]", "            ", 
             RowBox[{"corrected", "=", 
              RowBox[{"corrected", "+", 
               RowBox[{"inte1", " ", 
                RowBox[{"ops", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}]}]}], ";"}]}], 
           "\[IndentingNewLine]", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"SECO", "\[Equal]", "1"}], ",", 
          RowBox[{"Block", "[", 
           RowBox[{
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"ops", "[", 
                 RowBox[{"[", "3", "]"}], "]"}], "~", 
                RowBox[{"ops", "[", 
                 RowBox[{"[", "11", "]"}], "]"}]}], " ", "correspond", " ", 
               "to", " ", "4"}], "-", 
              RowBox[{"fermi", " ", "operators"}]}], " ", "*)"}], 
            "\[IndentingNewLine]", "    ", 
            RowBox[{
             RowBox[{"For", "[", 
              RowBox[{
               RowBox[{"i", "=", "1"}], ",", 
               RowBox[{"i", "\[LessEqual]", "opnum"}], ",", 
               RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", "  ", 
               RowBox[{"For", "[", 
                RowBox[{
                 RowBox[{"j", "=", "1"}], ",", 
                 RowBox[{"j", "\[LessEqual]", "opnum"}], ",", 
                 RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", "        ", 
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"i", "\[GreaterEqual]", "3"}], "&&", 
                    RowBox[{"i", "\[LessEqual]", "11"}]}], ")"}], "||", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"i", "\[GreaterEqual]", "22"}], "&&", 
                    RowBox[{"i", "\[LessEqual]", "26"}]}], ")"}], "||", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"i", "\[GreaterEqual]", "30"}], "&&", 
                    RowBox[{"i", "\[LessEqual]", "34"}]}], ")"}]}], ")"}], "&&", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"j", "\[GreaterEqual]", "3"}], "&&", 
                    RowBox[{"j", "\[LessEqual]", "11"}]}], ")"}], "||", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"j", "\[GreaterEqual]", "22"}], "&&", 
                    RowBox[{"j", "\[LessEqual]", "26"}]}], ")"}], "||", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"j", "\[GreaterEqual]", "30"}], "&&", 
                    RowBox[{"j", "\[LessEqual]", "34"}]}], ")"}]}], ")"}]}], 
                   ",", 
                   RowBox[{"Block", "[", 
                    RowBox[{
                    RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
                    "         ", 
                    RowBox[{
                    RowBox[{"sigma1", "=", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"1", "/", "2"}], 
                    RowBox[{"D", "[", 
                    RowBox[{
                    RowBox[{"D", "[", 
                    RowBox[{"chi2", ",", 
                    RowBox[{"ops", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
                    RowBox[{"ops", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], "/.", 
                    "droplist"}]}], ";", "\[IndentingNewLine]", "        ", 
                    RowBox[{"If", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Abs", "[", 
                    RowBox[{"sigma1", "/.", 
                    RowBox[{"S", "\[Rule]", "40000"}]}], "]"}], ">", 
                    RowBox[{"10", "^", 
                    RowBox[{"(", 
                    RowBox[{"-", "30"}], ")"}]}]}], ",", " ", 
                    RowBox[{"inte2", "=", 
                    RowBox[{"sigmaFBini", "[", 
                    RowBox[{"sigma1", ",", "RS"}], "]"}]}], ",", 
                    RowBox[{"inte2", "=", "0"}]}], "]"}], ";", 
                    "\[IndentingNewLine]", "       ", 
                    RowBox[{"corrected", "=", 
                    RowBox[{"corrected", "+", 
                    RowBox[{"inte2", " ", 
                    RowBox[{"ops", "[", 
                    RowBox[{"[", "i", "]"}], "]"}], " ", 
                    RowBox[{"ops", "[", 
                    RowBox[{"[", "j", "]"}], "]"}]}]}]}], ";"}]}], "]"}]}], 
                  "]"}]}], "\[IndentingNewLine]", "    ", "]"}]}], "]"}], 
             ";"}]}], "\[IndentingNewLine]", "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", " ", "corrected"}]}], "\[IndentingNewLine]", 
      "]"}]}], ";"}], "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.506165799081626*^9, 3.506165857791984*^9}, 
   3.50617267379847*^9, {3.50617294723575*^9, 3.5061729798866076`*^9}, {
   3.506173860248118*^9, 3.5061738604197187`*^9}, {3.510922382974058*^9, 
   3.51092238394126*^9}, {3.5292639923151693`*^9, 3.5292640971161532`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Define droplist", "Subsection",
 CellChangeTimes->{{3.506172988591423*^9, 3.506172995502235*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"setdroplist", "[", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"droplist", "=", 
       RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagah", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ah", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaWB", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aWB", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagall1", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"all1", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagall3", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"all3", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagale", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ale", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaee", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aee", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagalq1", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"alq1", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagalq3", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"alq3", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagalu", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"alu", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagald", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ald", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaqe", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aqe", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaeu", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aeu", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaed", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aed", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahl1", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahl1", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahl3", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahl3", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahe", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahe", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahq1", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahq1", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahq3", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahq3", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahu", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahu", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahd", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahd", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaW", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aW", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagalQ1", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"alQ1", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagalQ3", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"alQ3", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaLq3", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aLq3", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaQe", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aQe", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagalb", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"alb", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaeb", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aeb", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahQ1", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahQ1", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahQ3", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahQ3", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahb", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahb", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagalL1", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"alL1", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagalL3", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"alL3", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaLe", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aLe", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaltau", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"altau", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaetau", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aetau", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahL1", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahL1", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahL3", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahL3", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagahtau", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"ahtau", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaeWt", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aeWt", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagaeBt", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"aeBt", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagatauWt", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"atauWt", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"tagatauBt", "\[Equal]", "0"}], ",", 
        RowBox[{"droplist", "=", 
         RowBox[{"Append", "[", 
          RowBox[{"droplist", ",", 
           RowBox[{"atauBt", "\[Rule]", "0"}]}], "]"}]}]}], "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"initdroplist", "[", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"tagah", "=", "0"}], ";", 
      RowBox[{"tagaWB", "=", "0"}], ";", 
      RowBox[{"tagall1", "=", "0"}], ";", 
      RowBox[{"tagall3", "=", "0"}], ";", 
      RowBox[{"tagale", "=", "0"}], ";", 
      RowBox[{"tagaee", "=", "0"}], ";", 
      RowBox[{"tagalq1", "=", "0"}], ";", 
      RowBox[{"tagalq3", "=", "0"}], ";", 
      RowBox[{"tagalu", "=", "0"}], ";", 
      RowBox[{"tagald", "=", "0"}], ";", 
      RowBox[{"tagaqe", "=", "0"}], ";", 
      RowBox[{"tagaeu", "=", "0"}], ";", 
      RowBox[{"tagaed", "=", "0"}], ";", 
      RowBox[{"tagahl1", "=", "0"}], ";", 
      RowBox[{"tagahl3", "=", "0"}], ";", 
      RowBox[{"tagahe", "=", "0"}], ";", 
      RowBox[{"tagahq1", "=", "0"}], ";", 
      RowBox[{"tagahq3", "=", "0"}], ";", 
      RowBox[{"tagahu", "=", "0"}], ";", 
      RowBox[{"tagahd", "=", "0"}], ";", 
      RowBox[{"tagaW", "=", "0"}], ";", 
      RowBox[{"tagalQ1", "=", "0"}], ";", 
      RowBox[{"tagalQ3", "=", "0"}], ";", 
      RowBox[{"tagaLq3", "=", "0"}], ";", 
      RowBox[{"tagaQe", "=", "0"}], ";", 
      RowBox[{"tagalb", "=", "0"}], ";", 
      RowBox[{"tagaeb", "=", "0"}], ";", 
      RowBox[{"tagahQ1", "=", "0"}], ";", 
      RowBox[{"tagahQ3", "=", "0"}], ";", 
      RowBox[{"tagahb", "=", "0"}], ";", 
      RowBox[{"tagalL1", "=", "0"}], ";", 
      RowBox[{"tagalL3", "=", "0"}], ";", 
      RowBox[{"tagaLe", "=", "0"}], ";", 
      RowBox[{"tagaltau", "=", "0"}], ";", 
      RowBox[{"tagaetau", "=", "0"}], ";", 
      RowBox[{"tagahL1", "=", "0"}], ";", 
      RowBox[{"tagahL3", "=", "0"}], ";", 
      RowBox[{"tagahtau", "=", "0"}], ";", 
      RowBox[{"tagaeWt", "=", "0"}], ";", 
      RowBox[{"tagaeBt", "=", "0"}], ";", 
      RowBox[{"tagatauWt", "=", "0"}], ";", 
      RowBox[{"tagatauBt", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"setdroplist", "[", "]"}], ";"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5061738836793594`*^9, 3.506173893678977*^9}, 
   3.5061740568396635`*^9, {3.5068529141151047`*^9, 3.5068529901340384`*^9}, {
   3.5068530208348923`*^9, 3.506853022145294*^9}, {3.5221560537734194`*^9, 
   3.5221560802219324`*^9}, {3.5221561242804527`*^9, 3.522156125439519*^9}, {
   3.540550611092205*^9, 3.5405506319263973`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\[CloseCurlyDoubleQuote]real\[CloseCurlyDoubleQuote] function", \
"Subsection",
 CellChangeTimes->{{3.506173001851446*^9, 3.5061730201034784`*^9}, {
  3.517297133979765*^9, 3.517297140780154*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"real", "[", "value_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "x1", ",", "x2"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"tp", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"initdroplist", "[", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"tp", "=", 
        RowBox[{"Re", "[", 
         RowBox[{
          RowBox[{"tp", "+", "value"}], "/.", "droplist"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", "opnum"}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x1", "=", 
           RowBox[{"D", "[", 
            RowBox[{"value", ",", 
             RowBox[{"ops", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"x2", "=", 
           RowBox[{"Re", "[", 
            RowBox[{"x1", "/.", "droplist"}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", "x2", "]"}], ">", 
             RowBox[{"10", "^", 
              RowBox[{"(", 
               RowBox[{"-", "40"}], ")"}]}]}], ",", 
            RowBox[{"tp", "=", 
             RowBox[{"tp", "+", 
              RowBox[{"x2", " ", 
               RowBox[{"ops", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}]}]}]}], "]"}], ";"}]}], 
        "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", "opnum"}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{"For", "[", 
          RowBox[{
           RowBox[{"j", "=", "1"}], ",", 
           RowBox[{"j", "\[LessEqual]", "opnum"}], ",", 
           RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"x1", "=", 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{"value", ",", 
                 RowBox[{"ops", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
               RowBox[{"ops", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"x2", "=", 
             RowBox[{"Re", "[", 
              RowBox[{"x1", "/.", "droplist"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Abs", "[", "x2", "]"}], ">", 
               RowBox[{"10", "^", 
                RowBox[{"(", 
                 RowBox[{"-", "40"}], ")"}]}]}], ",", 
              RowBox[{"tp", "=", 
               RowBox[{"tp", "+", 
                RowBox[{
                 RowBox[{"1", "/", "2"}], " ", "x2", " ", 
                 RowBox[{"ops", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], " ", 
                 RowBox[{"ops", "[", 
                  RowBox[{"[", "j", "]"}], "]"}]}]}]}]}], "]"}], ";"}]}], 
          "\[IndentingNewLine]", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
       "tp"}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{3.5061738566757116`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["GetResults Function: it gives Matrix U and vectors vi and ai", \
"Subsection",
 CellChangeTimes->{{3.5061657103365498`*^9, 3.5061657193060627`*^9}, {
  3.517297106776209*^9, 3.5172971237511797`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "obtain", " ", "the", " ", "matrix", " ", "U", " ", "and", " ", "the", " ",
     "vectors", " ", "vi", " ", "and", " ", "ai"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GetResults", "[", "chi2_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"i", ",", "j", ",", "min", ",", "opnum"}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"FLSY", "\[Equal]", "0"}], ",", 
         RowBox[{"opnum", "=", "21"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"FLSY", "\[Equal]", "1"}], ",", 
         RowBox[{"opnum", "=", "37"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"U", "=", 
        RowBox[{"Array", "[", 
         RowBox[{"1", ",", 
          RowBox[{"{", 
           RowBox[{"opnum", ",", "opnum"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", "opnum"}], ",", 
         RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
         RowBox[{"For", "[", 
          RowBox[{
           RowBox[{"j", "=", "1"}], ",", 
           RowBox[{"j", "\[LessEqual]", "opnum"}], ",", 
           RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"U", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
            RowBox[{
             RowBox[{"1", "/", "2"}], 
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"D", "[", 
                RowBox[{"chi2", ",", 
                 RowBox[{"ops", "[", 
                  RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
               RowBox[{"ops", "[", 
                RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}]}]}], "]"}]}], "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "\"\<Matrix U in \\!\\(TeV\\^4\\)\>\"", "]"}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
         RowBox[{"U", "/", 
          RowBox[{"10", "^", "12"}]}], "//", "MatrixForm"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"FLSY", "\[Equal]", "0"}], ",", 
         RowBox[{"Block", "[", 
          RowBox[{
           RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
            "Print", "[", 
             "\"\<\\!\\(\\(a\\_i\\)\\&^\\) in \\!\\(TeV\\^\\(-2\\)\\)\>\"", 
             "]"}], ";", "\[IndentingNewLine]", 
            RowBox[{"min", "=", 
             RowBox[{"Solve", "[", 
              RowBox[{
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"D", "[", 
                   RowBox[{"chi2", ",", 
                    RowBox[{"ops", "[", 
                    RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "\[Equal]", 
                  "0"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "1", ",", "21"}], "}"}]}], "]"}], ",", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"ops", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"i", ",", "1", ",", "21"}], "}"}]}], "]"}]}], 
              "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"ahat", "=", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"First", "[", 
                RowBox[{
                 RowBox[{"ops", "[", 
                  RowBox[{"[", "i", "]"}], "]"}], "/.", "min"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"i", ",", "1", ",", "opnum"}], "}"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Print", "[", 
             RowBox[{"ahat", "*", "1000000"}], "]"}], ";"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
         "Print", "[", 
          "\"\<For FLSY=1, ahat not unique because there are flat \
directions\>\"", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", "\"\<\\!\\(v\\&^\\_i\\) in TeV\>\"", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"vhat", "=", 
        RowBox[{"Array", "[", 
         RowBox[{"0", ",", "opnum"}], "]"}]}], ";", "\[IndentingNewLine]", 
       " ", 
       RowBox[{"initdroplist", "[", "]"}], ";", "\[IndentingNewLine]", " ", 
       RowBox[{"temp", "=", 
        RowBox[{"chi2", "/.", "droplist"}]}], ";", "\[IndentingNewLine]", " ", 
       RowBox[{"chi21", "=", 
        RowBox[{"chi2", "-", "temp"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", "opnum"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{"Block", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"temp", ",", "temp1", ",", "temp2"}], "}"}], ",", 
           "\[IndentingNewLine]", "    ", 
           RowBox[{
            RowBox[{"inittag", "[", "]"}], ";", "\[IndentingNewLine]", "    ", 
            RowBox[{
             RowBox[{"optags", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "=", "1"}], ";", 
            "\[IndentingNewLine]", "    ", 
            RowBox[{"setlist", "[", "]"}], ";", "\[IndentingNewLine]", "    ", 
            RowBox[{"droplist", "=", 
             RowBox[{"Append", "[", 
              RowBox[{"droplist", ",", 
               RowBox[{
                RowBox[{"ops", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", "1"}]}], "]"}]}], 
            ";", "\[IndentingNewLine]", "    ", 
            RowBox[{"temp1", "=", 
             RowBox[{"chi21", "/.", "droplist"}]}], ";", 
            "\[IndentingNewLine]", "    ", 
            RowBox[{"setlist", "[", "]"}], ";", "\[IndentingNewLine]", "    ", 
            RowBox[{"droplist", "=", 
             RowBox[{"Append", "[", 
              RowBox[{"droplist", ",", 
               RowBox[{
                RowBox[{"ops", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
                RowBox[{"-", "1"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            "     ", 
            RowBox[{"temp2", "=", 
             RowBox[{"chi21", "/.", "droplist"}]}], ";", 
            "\[IndentingNewLine]", "     ", 
            RowBox[{
             RowBox[{"vhat", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "=", 
             RowBox[{
              RowBox[{"1", "/", "2"}], 
              RowBox[{"(", 
               RowBox[{"temp1", "-", "temp2"}], ")"}]}]}], ";"}]}], 
          "\[IndentingNewLine]", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"vhat", "/", "1000000"}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{
       "Print", "[", "\"\<fourth roots of eigenvalues of U in GeV\>\"", "]"}],
        ";", "\[IndentingNewLine]", 
       RowBox[{"eigens", "=", 
        RowBox[{"Eigensystem", "[", "U", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"eigenvalues", "=", 
        RowBox[{"eigens", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"eigenvalues", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "^", 
           RowBox[{"(", 
            RowBox[{"1", "/", "4"}], ")"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", "opnum"}], "}"}]}], "]"}], "]"}], 
       ";"}]}], "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{
         RowBox[{"eigens", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "//", "MatrixForm"}], "]"}], ";"}], 
      "*)"}], "\[IndentingNewLine]", "]"}]}], ";"}]}]], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
    "**"}], "**************************************************)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "          ", 
   RowBox[{
   "Calculate", " ", "new", " ", "physics", " ", "predictions", " ", "to", 
    " ", "observables"}], "                                           ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "          ", 
   RowBox[{
    RowBox[{"theoretical", " ", "value"}], "=", 
    RowBox[{
     RowBox[{"SM", " ", "prediction"}], "+", 
     RowBox[{"NP", " ", "tree", " ", "level", " ", "correction"}]}]}], 
   "                                   ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
    "**"}], "**************************************************)"}]}]], \
"Section",
 FontSize->14],

Cell[CellGroupData[{

Cell["NP contributions to the basic parameters", "Subsection",
 CellChangeTimes->{{3.510920642525801*^9, 3.5109206511838164`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"PiZZ0", "=", 
   RowBox[{"ah", "*", 
    RowBox[{"v2", "^", "2"}], "*", 
    RowBox[{"g2", "/", 
     RowBox[{"(", 
      RowBox[{"8", "c2"}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PiZZp", "=", 
   RowBox[{"2", "aWB", "*", "v2", "*", "s", "*", "c"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PiAZp", "=", 
   RowBox[{
    RowBox[{"-", "2"}], "aWB", "*", 
    RowBox[{"v2", "/", "2"}], 
    RowBox[{"(", 
     RowBox[{"c2", "-", "s2"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PiAAp", "=", 
    RowBox[{
     RowBox[{"-", "2"}], "aWB", "*", "v2", "*", "s", "*", "c"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Z", " ", "field", " ", "redefinition"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Zredf", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "+", "PiZZp"}], ")"}], "^", 
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Shift", " ", "to", " ", "Z", " ", "mass"}], " ", "*)"}], 
  " "}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DMZ2", "=", 
    RowBox[{"PiZZ0", "+", 
     RowBox[{
      RowBox[{"MZ", "^", "2"}], "PiZZp"}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"shift", " ", "to", " ", "alpha"}], "  ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Dalpha", "=", 
   RowBox[{"alphaMZ", " ", "PiAAp"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ds2", "=", 
   RowBox[{"s2", " ", 
    RowBox[{"c2", "/", 
     RowBox[{"(", 
      RowBox[{"c2", "-", "s2"}], ")"}]}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Dalpha", "/", "alphaMZ"}], "-", 
      RowBox[{"DMZ2", "/", 
       RowBox[{"MZ", "^", "2"}]}], "-", 
      RowBox[{"DGF", "/", "GF"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alphaMZ0", "=", 
    RowBox[{"alphaMZ", "-", "Dalpha"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"shift", " ", "to", " ", "Fermi", " ", "constant"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DGF", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], "/", "2"}], " ", 
     RowBox[{"(", 
      RowBox[{"-", "all3"}], ")"}]}], "+", 
    RowBox[{"GF", " ", "2", " ", "ahl3", " ", "v2"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GF0", "=", 
    RowBox[{"GF", "-", "DGF"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"e", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"4", "Pi", " ", "alphaMZ"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"e0", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"4", "Pi", " ", "alphaMZ0"}], ")"}], "^", 
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s02", "=", 
   RowBox[{"s2", "-", "Ds2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c02", "=", 
    RowBox[{"1", "-", "s02"}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Fermion", " ", "charges"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Qe", "=", 
   RowBox[{"-", "1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Qu", "=", 
   RowBox[{"2", "/", "3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Qd", "=", 
   RowBox[{
    RowBox[{"-", "1"}], "/", "3"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Qt", "=", "Qu"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Qb", "=", "Qd"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Qnu", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5068520088767147`*^9, 3.5068520114195194`*^9}, {
   3.506852261815559*^9, 3.506852262735961*^9}, {3.5068524133698254`*^9, 
   3.5068525803681183`*^9}, 3.5068612801280518`*^9, {3.506864000028576*^9, 
   3.5068640681694956`*^9}, {3.506864099837551*^9, 3.506864109493968*^9}, {
   3.5068641431588273`*^9, 3.506864183952899*^9}, {3.5068642569766273`*^9, 
   3.506864334415163*^9}, {3.5068644280123806`*^9, 3.5068644742196617`*^9}, {
   3.5068645119249277`*^9, 3.5068645262769527`*^9}, {3.5069429310115366`*^9, 
   3.5069429519837365`*^9}, {3.5069443079562936`*^9, 3.506944684713843*^9}, {
   3.5069447162696476`*^9, 3.506944723438058*^9}, {3.5069447686066413`*^9, 
   3.5069447893248262`*^9}, {3.5069448305351834`*^9, 
   3.5069448734616385`*^9}, {3.5069452900204644`*^9, 
   3.5069456141680045`*^9}, {3.5069458349096303`*^9, 
   3.5069458475013504`*^9}, {3.506948057326745*^9, 3.5069480710175285`*^9}, {
   3.506948416505289*^9, 3.506948437658499*^9}, {3.5072974264269714`*^9, 
   3.507297445209404*^9}, {3.50729753943357*^9, 3.5072975435207767`*^9}, {
   3.5073779911500883`*^9, 3.5073780126313257`*^9}, {3.507378045703384*^9, 
   3.5073780875114574`*^9}, {3.507378122580319*^9, 3.507378148881965*^9}, {
   3.507378252822384*^9, 3.50737862087383*^9}, {3.507378673898323*^9, 
   3.507378812504567*^9}, {3.5073793417666965`*^9, 3.5073793424686975`*^9}, {
   3.510903079880372*^9, 3.510903092531995*^9}, {3.510903882877183*^9, 
   3.5109039205356493`*^9}, {3.5109045296855187`*^9, 
   3.5109045367991314`*^9}, {3.5109094266414795`*^9, 
   3.5109094584811354`*^9}, {3.510909583499755*^9, 3.5109096673031025`*^9}, {
   3.5109204552474723`*^9, 3.5109204719083014`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Effective couplings between Z boson and fermions", "Subsection",
 CellChangeTimes->{{3.510920622994567*^9, 3.510920625974172*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "The", " ", "quantities", " ", "with", " ", "a", " ", "\"\<0\>\"", " ", 
     "in", " ", "the", " ", "end", " ", "are", " ", "SM", " ", "values"}], 
    ",", " ", 
    RowBox[{
    "without", " ", "a", " ", "\"\<0\>\"", " ", "are", " ", "new", " ", 
     "values"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"gvf0", "=", 
    RowBox[{"t3", "-", 
     RowBox[{"2", "Qf", " ", "s02"}]}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"gaf0", "=", "t3"}], "          ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"gvnu0", "=", 
     RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ganu0", "=", 
     RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gve0", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}], "+", 
      RowBox[{"2", "s02"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gae0", "=", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gvu0", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], "-", 
      RowBox[{
       RowBox[{"4", "/", "3"}], "s02"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gau0", "=", 
     RowBox[{"1", "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gvd0", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}], "+", 
      RowBox[{
       RowBox[{"2", "/", "3"}], "s02"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gad0", "=", 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gvb0", "=", "gvd0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gab0", "=", "gad0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gvt0", "=", "gvu0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gat0", "=", "gau0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Dgvf", "=", 
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s02", " ", "c02"}], "]"}], "*", "PiAZp", "*", "Qf"}]}], 
     ";"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dgve", "=", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s02", " ", "c02"}], "]"}], "*", "PiAZp", "*", "Qe"}], "-", 
      RowBox[{"ahl1", " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahl3", " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahe", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dgae", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "ahl1"}], " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahl3", " ", 
       RowBox[{"v2", "/", "2"}]}], " ", "+", 
      RowBox[{"ahe", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dgvnu", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "ahl1"}], " ", 
       RowBox[{"v2", "/", "2"}]}], "+", 
      RowBox[{"ahl3", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dganu", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "ahl1"}], " ", 
       RowBox[{"v2", "/", "2"}]}], "+", 
      RowBox[{"ahl3", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dgvtau", "=", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s02", " ", "c02"}], "]"}], "*", "PiAZp", "*", "Qe"}], "-", 
      RowBox[{"ahL1", " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahL3", " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahtau", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dgatau", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "ahL1"}], " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahL3", " ", 
       RowBox[{"v2", "/", "2"}]}], " ", "+", 
      RowBox[{"ahtau", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dgvnutau", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "ahL1"}], " ", 
       RowBox[{"v2", "/", "2"}]}], "+", 
      RowBox[{"ahL3", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dganutau", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "ahL1"}], " ", 
       RowBox[{"v2", "/", "2"}]}], "+", 
      RowBox[{"ahL3", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dgvu", "=", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s02", " ", "c02"}], "]"}], "*", "PiAZp", "*", "Qu"}], "-", 
      RowBox[{"ahq1", " ", 
       RowBox[{"v2", "/", "2"}]}], "+", 
      RowBox[{"ahq3", " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahu", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dgau", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "ahq1"}], " ", 
       RowBox[{"v2", "/", "2"}]}], "+", 
      RowBox[{"ahq3", " ", 
       RowBox[{"v2", "/", "2"}]}], "+", 
      RowBox[{"ahu", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dgvd", "=", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s02", " ", "c02"}], "]"}], "*", "PiAZp", "*", "Qd"}], "-", 
      RowBox[{"ahq1", " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahq3", " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahd", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dgad", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "ahq1"}], " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahq3", " ", 
       RowBox[{"v2", "/", "2"}]}], "+", 
      RowBox[{"ahd", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Dgvt", "=", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s02", " ", "c02"}], "]"}], "*", "PiAZp", "*", "Qt"}], "-", 
      RowBox[{"ahQ1", " ", 
       RowBox[{"v2", "/", "2"}]}], "+", 
      RowBox[{"ahQ3", " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"aht", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Dgat", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "ahQ1"}], " ", 
       RowBox[{"v2", "/", "2"}]}], "+", 
      RowBox[{"ahQ3", " ", 
       RowBox[{"v2", "/", "2"}]}], "+", 
      RowBox[{"aht", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Dgvb", "=", 
     RowBox[{
      RowBox[{"2", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"s02", " ", "c02"}], "]"}], "*", "PiAZp", "*", "Qb"}], "-", 
      RowBox[{"ahQ1", " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahQ3", " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahb", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Dgab", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "ahQ1"}], " ", 
       RowBox[{"v2", "/", "2"}]}], "-", 
      RowBox[{"ahQ3", " ", 
       RowBox[{"v2", "/", "2"}]}], "+", 
      RowBox[{"ahb", " ", 
       RowBox[{"v2", "/", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gve", "=", 
     RowBox[{"gve0", "+", "Dgve"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gae", "=", 
     RowBox[{"gae0", "+", "Dgae"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gvtau", "=", 
     RowBox[{"gve0", "+", "Dgvtau"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gatau", "=", 
     RowBox[{"gae0", "+", "Dgatau"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gvnu", "=", 
     RowBox[{"gvnu0", "+", "Dgvnu"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ganu", "=", 
     RowBox[{"ganu0", "+", "Dganu"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gvnutau", "=", 
     RowBox[{"gvnu0", "+", "Dgvnutau"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ganutau", "=", 
     RowBox[{"ganu0", "+", "Dganutau"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gvu", "=", 
     RowBox[{"gvu0", "+", "Dgvu"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"gau", "=", 
     RowBox[{"gau0", "+", "Dgau"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gvd", "=", 
     RowBox[{"gvd0", "+", "Dgvd"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"gad", "=", 
     RowBox[{"gad0", "+", "Dgad"}]}], ";"}], " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gvt", "=", 
     RowBox[{"gvt0", "+", "Dgvt"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gat", "=", 
     RowBox[{"gat0", "+", "Dgat"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gvb", "=", 
     RowBox[{"gvb0", "+", "Dgvb"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gab", "=", 
     RowBox[{"gab0", "+", "Dgab"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gle", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"gve", "+", "gae"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gle0", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"gve0", "+", "gae0"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"gre", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"gve", "-", "gae"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gre0", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"gve0", "-", "gae0"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"glu", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"gvu", "+", "gau"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"glu0", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"gvu0", "+", "gau0"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"gru", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"gvu", "-", "gau"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gru0", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"gvu0", "-", "gau0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gld", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"gvd", "+", "gad"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gld0", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"gvd0", "+", "gad0"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"grd", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"gvd", "-", "gad"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"grd0", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"gvd0", "-", "gad0"}], ")"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.51092048810113*^9, 3.5109204901291337`*^9}, {
   3.5109205964589205`*^9, 3.510920620872963*^9}, 3.512123479748954*^9, {
   3.512123826787163*^9, 3.5121238305467696`*^9}, {3.51229443600616*^9, 
   3.512294436630161*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Z pole measurements", "Subsection",
 CellChangeTimes->{3.510920609375743*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"tr", "=", 
     RowBox[{"tree", " ", "level"}]}], ",", " ", 
    RowBox[{"th", "=", 
     RowBox[{"NP", " ", "predictions"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Decaly", " ", "rates"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Gammaetr", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], "alphaMZ0", " ", 
      RowBox[{"MZ", "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", "c02", "*", "s02"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", "gve", ")"}], "^", "2"}], "+", 
        RowBox[{"gae", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Gammatautr", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], "alphaMZ0", " ", 
      RowBox[{"MZ", "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", "c02", "*", "s02"}], ")"}]}], 
      SqrtBox[
       RowBox[{"1", "-", 
        RowBox[{"4", 
         FractionBox[
          SuperscriptBox["mtau", "2"], 
          SuperscriptBox["MZ", "2"]]}]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["gvtau", "2"], "+", 
            SuperscriptBox["gatau", "2"]}], ")"}], " ", "+", 
          RowBox[{"2", 
           FractionBox[
            SuperscriptBox["mtau", "2"], 
            SuperscriptBox["MZ", "2"]], 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["gvtau", "2"], "-", 
             RowBox[{"2", 
              SuperscriptBox["gatau", "2"]}]}], ")"}]}]}], ")"}], "-", " ", 
        RowBox[{"3", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", 
            SqrtBox["2"], 
            FractionBox["mtau", "MZ"], 
            RowBox[{"(", 
             FractionBox[
              RowBox[{"gle0", "+", "gre0"}], "2"], ")"}], 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"c", " ", "atauWt", " ", 
               FractionBox[
                SuperscriptBox["v", "2"], "2"]}], "+", 
              RowBox[{"s", " ", "atauBt", 
               FractionBox[
                SuperscriptBox["v", "2"], "2"]}]}], ")"}]}], "-", 
           RowBox[{
            FractionBox["4", "3"], 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"8", 
               FractionBox[
                SuperscriptBox["mtau", "2"], 
                SuperscriptBox["MZ", "2"]]}]}], ")"}], 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"c", " ", "atauWt", 
                FractionBox[
                 SuperscriptBox["v", "2"], "2"]}], "+", 
               RowBox[{"s", " ", "atauBt", 
                FractionBox[
                 SuperscriptBox["v", "2"], "2"]}]}], ")"}], "2"]}]}], 
          ")"}]}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Gammaftr", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], " ", "alphaMZ0", " ", 
      RowBox[{"MZ", "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", "c02", "*", "s02"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", "gvf", ")"}], "^", "2"}], "+", 
        RowBox[{"gaf", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Gammautr", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], "alphaMZ0", " ", 
      RowBox[{"MZ", "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", "c02", "*", "s02"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"gvu", "^", "2"}], "+", 
        RowBox[{"gau", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Gammadtr", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], "alphaMZ0", " ", 
      RowBox[{"MZ", "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", "c02", "*", "s02"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", "gvd", ")"}], "^", "2"}], "+", 
        RowBox[{"gad", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Gammattr", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], "alphaMZ0", " ", 
      RowBox[{"MZ", "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", "c02", "*", "s02"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"gvt", "^", "2"}], "+", 
        RowBox[{"gat", "^", "2"}]}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Gammabtr", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], "alphaMZ0", " ", 
      RowBox[{"MZ", "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", "c02", "*", "s02"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", "gvb", ")"}], "^", "2"}], "+", 
        RowBox[{"gab", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Gammanutr", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], "alphaMZ0", " ", 
      RowBox[{"MZ", "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", "c02", "*", "s02"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", "gvnu", ")"}], "^", "2"}], "+", 
        RowBox[{"ganu", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Gammanutautr", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], "alphaMZ0", " ", 
      RowBox[{"MZ", "/", 
       RowBox[{"(", 
        RowBox[{"12", " ", "c02", "*", "s02"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", "gvnutau", ")"}], "^", "2"}], "+", 
        RowBox[{"ganutau", "^", "2"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Gammahadtr", "=", 
     RowBox[{
      RowBox[{"2", "Nf", " ", "Gammautr"}], "+", 
      RowBox[{"2", "Nf", " ", "Gammadtr"}], "+", 
      RowBox[{"Nf", " ", "Gammabtr"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Gammahadth", "=", 
     RowBox[{
      RowBox[{"firstorder", "[", "Gammahadtr", "]"}], "+", "GammahadSM"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.5109206052261353`*^9, 3.510920606676938*^9}, {
   3.5110894744774137`*^9, 3.5110894887202387`*^9}, {3.512123868907237*^9, 
   3.5121238809660583`*^9}, {3.512123991835453*^9, 3.5121240573867683`*^9}, {
   3.512291906068017*^9, 3.5122919767800617`*^9}, {3.512293953952896*^9, 
   3.512293963983714*^9}, {3.512294359441225*^9, 3.512294362608031*^9}, {
   3.512294401108898*^9, 3.5122944019981003`*^9}, {3.5136008762647367`*^9, 
   3.5136009076145296`*^9}, {3.5136010956162825`*^9, 3.51360109906548*^9}, {
   3.515838471292012*^9, 3.515838538291844*^9}, {3.515839729822996*^9, 
   3.5158397410236363`*^9}, {3.5159111678501005`*^9, 3.515911188707337*^9}, {
   3.515911265350271*^9, 3.5159113264399786`*^9}, {3.5160117363470664`*^9, 
   3.5160117738651323`*^9}, 3.516012178623443*^9, 3.5160122507423697`*^9, {
   3.5160123195228906`*^9, 3.5160123845126047`*^9}, {3.516012421016669*^9, 
   3.5160124590027356`*^9}, {3.5165167466432643`*^9, 
   3.5165167888101387`*^9}, {3.5165286010280457`*^9, 3.516528605817254*^9}, {
   3.5165324986633177`*^9, 3.5165325029265614`*^9}, {3.516966539598906*^9, 
   3.5169665593017406`*^9}, {3.5172365212683287`*^9, 
   3.5172365221913815`*^9}, {3.540550644084092*^9, 3.5405506500654345`*^9}}],

Cell[CellGroupData[{

Cell["\<\
Tensorial contribution to Z -> tau tau\
\>", "Subsubsection",
 CellChangeTimes->{{3.5169665696133585`*^9, 3.5169665830917826`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
      "I", " ", "take", " ", "the", " ", "formulas", " ", "for", " ", 
       "tensorial", " ", "contribution", " ", "e"}], "+", "e", "-"}], " ", 
     "\[Rule]", " ", 
     RowBox[{"tau", "+", " ", "tau", "-", " ", 
      RowBox[{"cross", " ", "section"}]}]}], ",", " ", 
    RowBox[{
    "except", " ", "for", " ", "the", " ", "definition", " ", "of", " ", 
     "\[Xi]\[Gamma]", " ", "and", " ", "\[Xi]Z"}], ",", " ", 
    RowBox[{
     RowBox[{"from", " ", 
      RowBox[{"Nucl", ".", "Phys", ".", "B"}], " ", "582"}], "-", "3"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "factor", " ", 
    RowBox[{
     SuperscriptBox["v", "2"], "/", "2"}], " ", "in", " ", "the", " ", 
    "definition", " ", "of", " ", "\[Xi]\[Gamma]", " ", "and", " ", "\[Xi]Z", 
    " ", "gives", " ", "to", " ", "atauWt", " ", "and", " ", "atauBt", " ", 
    "a", " ", "structure", " ", "compatible", " ", "with", " ", "the", " ", 
    "others", " ", "flavour", " ", "matrices", " ", "used", " ", "in", " ", 
    "this", " ", "program"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Xi]\[Gamma]", "=", 
     RowBox[{
      FractionBox[
       SqrtBox["2"], 
       RowBox[{"s", " ", "c"}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"s", " ", "atauWt"}], " ", "-", 
        RowBox[{"c", " ", "atauBt"}]}], ")"}], "*", 
      FractionBox[
       SuperscriptBox["v", "2"], "2"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Xi]Z", "=", 
     RowBox[{
      SqrtBox["2"], 
      RowBox[{"(", " ", 
       RowBox[{
        RowBox[{"c", " ", "atauWt"}], " ", "+", " ", 
        RowBox[{"s", " ", "atauBt"}]}], ")"}], "*", 
      FractionBox[
       SuperscriptBox["v", "2"], "2"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalPi]ZRe", "=", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "s", " ", "c"}], ")"}], "2"]], 
      FractionBox[
       RowBox[{"S", 
        RowBox[{"(", 
         RowBox[{"S", "-", 
          SuperscriptBox["MZ", "2"]}], ")"}]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"S", "-", 
           SuperscriptBox["MZ", "2"]}], ")"}], "2"], "+", 
        RowBox[{
         SuperscriptBox["\[CapitalGamma]Z", "2"], 
         SuperscriptBox["MZ", "2"]}]}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalPi]Zsq", "=", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"2", "s", " ", "c"}], ")"}], "4"]], 
      FractionBox[
       SuperscriptBox["S", "2"], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"S", "-", 
           SuperscriptBox["MZ", "2"]}], ")"}], "2"], "+", 
        RowBox[{
         SuperscriptBox["\[CapitalGamma]Z", "2"], 
         SuperscriptBox["MZ", "2"]}]}]]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RZ", "=", 
     FractionBox["mtau", "MZ"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Beta]eta", "=", 
     SqrtBox[
      RowBox[{"1", "-", 
       RowBox[{"4", 
        FractionBox[
         SuperscriptBox["mtau", "2"], "S"]}]}]]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vE", "=", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "2"]}], "+", 
      RowBox[{"2", " ", "s2"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vTau", "=", "vE"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"aE", "=", 
     RowBox[{"-", 
      FractionBox["1", "2"]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"aTau", "=", "aE"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmatauSM0", "=", 
     RowBox[{
      FractionBox[
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox["alphaMZ", "2"]}], "S"], " ", "\[Beta]eta", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", "vTau", " ", "vE", " ", "\[CapitalPi]ZRe"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["aE", "2"], "+", 
           SuperscriptBox["vE", "2"]}], ")"}], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vTau", "2"], "+", 
           RowBox[{
            SuperscriptBox["aTau", "2"], 
            SuperscriptBox["\[Beta]eta", "2"]}]}], ")"}], 
         "\[CapitalPi]Zsq"}]}], " ", ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmatauSMm", "=", 
     RowBox[{
      FractionBox[
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox["alphaMZ", "2"]}], "S"], " ", "\[Beta]eta", " ", "4", 
      FractionBox[
       SuperscriptBox["mtau", "2"], "S"], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", "vTau", " ", "vE", " ", "\[CapitalPi]ZRe"}], "+", 
        RowBox[{
         SuperscriptBox["vTau", "2"], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vE", "2"], "+", 
           SuperscriptBox["aE", "2"]}], ")"}], "\[CapitalPi]Zsq"}]}], " ", 
       ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmatauSMFB", "=", 
     RowBox[{
      FractionBox[
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox["alphaMZ", "2"]}], "S"], " ", 
      SuperscriptBox["\[Beta]eta", "2"], " ", "2", " ", "aTau", " ", "aE", 
      " ", 
      RowBox[{"(", 
       RowBox[{"\[CapitalPi]ZRe", "+", 
        RowBox[{"2", " ", "vTau", " ", "vE", " ", "\[CapitalPi]Zsq"}]}], 
       ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmatauSM", "=", 
     RowBox[{"gev2pbarn", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], "dsigmatauSM0", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["cos", "2"]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], "dsigmatauSMm", "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["cos", "2"]}], ")"}]}], "+", 
        RowBox[{"dsigmatauSMFB", " ", "*", "cos"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmatautensorial0", "=", 
     RowBox[{
      FractionBox[
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox["alphaMZ", "2"]}], "S"], " ", "\[Beta]eta", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "RZ", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"vE", " ", "vTau", " ", "\[CapitalPi]ZRe"}]}], ")"}], 
         "\[Xi]\[Gamma]"}], "-", 
        RowBox[{"8", " ", "RZ", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"vE", " ", "\[CapitalPi]ZRe"}], "+", 
           RowBox[{"vTau", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vE", "2"], "+", 
              SuperscriptBox["aE", "2"]}], ")"}], "\[CapitalPi]Zsq"}]}], 
          ")"}], "\[Xi]Z"}], "+", 
        RowBox[{"4", 
         SuperscriptBox["RZ", "2"], 
         SuperscriptBox["\[Xi]\[Gamma]", "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "RZ"}], ")"}], "2"], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vE", "2"], "+", 
           SuperscriptBox["aE", "2"]}], ")"}], "\[CapitalPi]Zsq", " ", 
         SuperscriptBox["\[Xi]Z", "2"]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"4", "RZ"}], ")"}], "2"], "vE", " ", "\[CapitalPi]ZRe", 
         " ", "\[Xi]Z", " ", "\[Xi]\[Gamma]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmatautensorialm", "=", 
     RowBox[{
      FractionBox[
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox["alphaMZ", "2"]}], "S"], " ", "\[Beta]eta", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", "RZ", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"vE", " ", "vTau", " ", "\[CapitalPi]ZRe"}]}], ")"}], 
         "\[Xi]\[Gamma]"}], "-", 
        RowBox[{"8", " ", "RZ", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"vE", " ", "\[CapitalPi]ZRe"}], "+", 
           RowBox[{"vTau", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["vE", "2"], "+", 
              SuperscriptBox["aE", "2"]}], ")"}], "\[CapitalPi]Zsq"}]}], 
          ")"}], "\[Xi]Z"}], "+", 
        RowBox[{
         FractionBox["S", 
          SuperscriptBox["MZ", "2"]], 
         SuperscriptBox["\[Xi]\[Gamma]", "2"]}], "+", 
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", "S"}], 
          SuperscriptBox["MZ", "2"]], 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["vE", "2"], "+", 
           SuperscriptBox["aE", "2"]}], ")"}], "\[CapitalPi]Zsq", " ", 
         SuperscriptBox["\[Xi]Z", "2"]}], "-", 
        RowBox[{
         FractionBox[
          RowBox[{"4", " ", "S"}], 
          SuperscriptBox["MZ", "2"]], "vTau", " ", "\[CapitalPi]ZRe", " ", 
         "\[Xi]Z", " ", "\[Xi]\[Gamma]"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmatautensorialFB", "=", 
     RowBox[{
      FractionBox[
       RowBox[{"\[Pi]", " ", 
        SuperscriptBox["alphaMZ", "2"]}], "S"], " ", 
      SuperscriptBox["\[Beta]eta", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
        "4", " ", "RZ", " ", "aTau", " ", "aE", " ", "\[CapitalPi]ZRe", " ", 
         "\[Xi]\[Gamma]"}], " ", "-", " ", 
        RowBox[{
        "16", " ", "RZ", " ", "aTau", " ", "aE", " ", "vE", " ", 
         "\[CapitalPi]Zsq", " ", "\[Xi]Z"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmatautensorial", "=", 
     RowBox[{"gev2pbarn", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "2"], "dsigmatautensorial0", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["cos", "2"]}], ")"}]}], "+", 
        RowBox[{
         FractionBox["1", "2"], "dsigmatautensorialm", "*", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           SuperscriptBox["cos", "2"]}], ")"}]}], "+", 
        RowBox[{"dsigmatautensorialFB", " ", "*", "cos"}]}], ")"}]}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.5169665951506033`*^9, 3.5169665963518057`*^9}, {
  3.5172993933279924`*^9, 3.5172994272669334`*^9}, {3.54055065523073*^9, 
  3.5405506679164553`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Universality ratios", "Subsubsection",
 CellChangeTimes->{{3.5169666013906145`*^9, 3.5169666055402217`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Reth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", 
     RowBox[{"Gammahadtr", "/", "Gammaetr"}], "]"}], "+", "ReSM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rmuth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", 
     RowBox[{"Gammahadtr", "/", "Gammaetr"}], "]"}], "+", "RmuSM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rtauth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", 
     RowBox[{"Gammahadtr", "/", "Gammatautr"}], "]"}], "+", "RtauSM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rbth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", 
     RowBox[{"Nf", " ", 
      RowBox[{"Gammabtr", "/", "Gammahadtr"}]}], "]"}], "+", "RbSM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Rcth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", 
     RowBox[{"Nf", " ", 
      RowBox[{"Gammautr", "/", "Gammahadtr"}]}], "]"}], "+", "RcSM"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.516966615103039*^9, 3.51696661588304*^9}, {
  3.516966752164879*^9, 3.5169667530228806`*^9}, {3.540539284359353*^9, 
  3.540539291016734*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Z width", "Subsubsection",
 CellChangeTimes->{{3.516966756142886*^9, 3.51696675826449*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"GammaZtr", "=", 
   RowBox[{
    RowBox[{"2", "Gammaetr"}], "+", 
    RowBox[{"2", "Gammanutr"}], "+", "Gammatautr", "+", "Gammanutautr", "+", 
    RowBox[{"2", "Nf", " ", "Gammautr"}], "+", 
    RowBox[{"2", "Nf", " ", "Gammadtr"}], "+", 
    RowBox[{"Nf", " ", "Gammabtr"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GammaZth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", "GammaZtr", "]"}], "+", "GammaZSM"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.516966787935742*^9, 3.516966788934144*^9}, {
  3.5405392969530735`*^9, 3.5405393037244606`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Hadronic Z cross section", "Subsubsection",
 CellChangeTimes->{{3.5169667935673523`*^9, 3.516966801382966*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"sigmah0th", "=", 
   RowBox[{
    RowBox[{"gev2pbarn", "*", 
     RowBox[{"firstorder", "[", 
      RowBox[{"12", " ", 
       RowBox[{"Pi", "/", "MZ2"}], " ", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"Gammaetr", " ", "Gammahadtr"}], ")"}], "/", 
        RowBox[{"GammaZtr", "^", "2"}]}]}], "]"}]}], "+", "sigmah0SM"}]}], 
  ";"}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Asymmetries", "Subsubsection",
 CellChangeTimes->{{3.51696662154585*^9, 3.516966624993456*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Ae", "=", 
   RowBox[{"2", 
    RowBox[{"gve", "/", 
     RowBox[{"(", 
      RowBox[{"gae", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"gve", "/", "gae"}], ")"}], "^", "2"}]}], ")"}]}], 
      ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Atau", "=", 
   RowBox[{"2", 
    RowBox[{"gvtau", "/", 
     RowBox[{"(", 
      RowBox[{"gatau", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"gvtau", "/", "gatau"}], ")"}], "^", "2"}]}], ")"}]}], 
      ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Aeth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", "Ae", "]"}], "+", "AeSM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Amuth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", "Ae", "]"}], "+", "AmuSM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Atauth", "=", 
    RowBox[{
     RowBox[{"firstorder", "[", "Atau", "]"}], "+", "AtauSM"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Alth", "=", 
     RowBox[{
      RowBox[{"firstorder", "[", "Ae", "]"}], "+", "AlSM"}]}], ";"}], "*)"}], 
  " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "If", " ", "assuming", " ", "lepton", " ", "universality", " ", "and", " ",
     "given", " ", "the", " ", "SM", " ", "value", " ", "AlSM"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"As", "=", 
   RowBox[{"2", 
    RowBox[{"gvd", "/", 
     RowBox[{"(", 
      RowBox[{"gad", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"gvd", "/", "gad"}], ")"}], "^", "2"}]}], ")"}]}], 
      ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ab", "=", 
   RowBox[{"2", 
    RowBox[{"gvb", "/", 
     RowBox[{"(", 
      RowBox[{"gab", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"gvb", "/", "gab"}], ")"}], "^", "2"}]}], ")"}]}], 
      ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Abth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", "Ab", "]"}], "+", "AbSM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Asth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", "As", "]"}], "+", "AsSM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ac", "=", 
   RowBox[{"2", 
    RowBox[{"gvu", "/", 
     RowBox[{"(", 
      RowBox[{"gau", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"gvu", "/", "gau"}], ")"}], "^", "2"}]}], ")"}]}], 
      ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Acth", "=", 
    RowBox[{
     RowBox[{"firstorder", "[", "Ac", "]"}], "+", "AcSM"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AFB0eth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", 
     RowBox[{
      RowBox[{"3", "/", "4"}], "Ae", " ", "Ae"}], "]"}], "+", "AFB0eSM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AFB0muth", "=", 
    RowBox[{
     RowBox[{"firstorder", "[", 
      RowBox[{
       RowBox[{"3", "/", "4"}], "Ae", " ", "Ae"}], "]"}], "+", "AFB0muSM"}]}],
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "I", " ", "calculate", " ", "the", " ", "tensorial", " ", "operators", " ",
     "contribution", " ", "to", " ", "the", " ", "asymmetry", " ", "in", " ", 
    "Z", " ", "decays", " ", "to", " ", "tau", " ", "tau", " ", "at", " ", 
    "the", " ", "Z", " ", "pole"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigmatauFBtensorial", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{"dsigmatautensorial", 
       RowBox[{"\[DifferentialD]", "cos"}]}]}], "-", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "0"], 
      RowBox[{"dsigmatautensorial", 
       RowBox[{"\[DifferentialD]", "cos"}]}]}]}], " ", "/.", 
    RowBox[{"S", "\[Rule]", 
     SuperscriptBox["MZ", "2"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigmatautensorial", "=", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "1"}], "1"], 
     RowBox[{"dsigmatautensorial", 
      RowBox[{"\[DifferentialD]", "cos"}]}]}], " ", "/.", 
    RowBox[{"S", "\[Rule]", 
     SuperscriptBox["MZ", "2"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigmatauFBSM", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{"dsigmatauSM", 
       RowBox[{"\[DifferentialD]", "cos"}]}]}], "-", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", 
       RowBox[{"-", "1"}], "0"], 
      RowBox[{"dsigmatauSM", 
       RowBox[{"\[DifferentialD]", "cos"}]}]}]}], "/.", 
    RowBox[{"S", "\[Rule]", 
     SuperscriptBox["MZ", "2"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigmatauSM", "=", 
   RowBox[{
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "1"}], "1"], 
     RowBox[{"dsigmatauSM", 
      RowBox[{"\[DifferentialD]", "cos"}]}]}], "/.", 
    RowBox[{"S", "\[Rule]", 
     SuperscriptBox["MZ", "2"]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AFB0tautensorial", "=", 
    RowBox[{
     RowBox[{"sigmatauFBtensorial", "/", "sigmatauSM"}], " ", "-", " ", 
     RowBox[{"AFB0tauSM", "*", 
      RowBox[{"sigmatautensorial", "/", "sigmatauSM"}]}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AFB0tauth", "=", 
    RowBox[{
     RowBox[{"firstorder", "[", 
      RowBox[{
       RowBox[{"3", "/", "4"}], "Ae", " ", "Atau"}], "]"}], "+", 
     RowBox[{"firstorder", "[", "AFB0tautensorial", "]"}], "+", 
     "AFB0tauSM"}]}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AFB0bth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", 
     RowBox[{
      RowBox[{"3", "/", "4"}], "Ae", " ", "Ab"}], "]"}], "+", "AFB0bSM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AFB0cth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", 
     RowBox[{
      RowBox[{"3", "/", "4"}], "Ae", " ", "Ac"}], "]"}], "+", "AFB0cSM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AFB0sth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", 
     RowBox[{
      RowBox[{"3", "/", "4"}], "Ae", " ", "As"}], "]"}], "+", "AFB0sSM"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sin2effth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", 
     RowBox[{
      RowBox[{"1", "/", "4"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"gve", "/", "gae"}]}], ")"}]}], "]"}], "+", "sin2effSM"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.516966642559087*^9, 3.5169666453358917`*^9}, {
  3.516966716019616*^9, 3.5169667164096165`*^9}, {3.5169668202433987`*^9, 
  3.516966897494735*^9}, {3.5169669520948305`*^9, 3.5169670085357294`*^9}, {
  3.5169670801554556`*^9, 3.5169671804324317`*^9}, {3.516967298711839*^9, 
  3.516967313968666*^9}, {3.5169673564007406`*^9, 3.516967423933259*^9}, {
  3.5169678169291496`*^9, 3.5169679774690313`*^9}, {3.516968021585909*^9, 
  3.516968037014336*^9}, {3.517295878029332*^9, 3.5172958809621377`*^9}, {
  3.5172973969248047`*^9, 3.517297416845944*^9}, {3.517308628936904*^9, 
  3.5173086294409323`*^9}, {3.5405392417609167`*^9, 3.540539248514303*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["W mass", "Subsubsection",
 CellChangeTimes->{{3.5169666470206947`*^9, 3.5169666512639017`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MZ02", "=", 
   RowBox[{
    RowBox[{"MZ", "^", "2"}], "-", "DMZ2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MW2", "=", 
   RowBox[{"MZ02", " ", "c02"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MW", "=", 
   SqrtBox["MW2"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MWth", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", 
     RowBox[{"Sqrt", "[", "MW2", "]"}], "]"}], "+", "MWSM"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.516966661029519*^9, 3.516966675599945*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Deep inelastic scattering", "Subsubsection",
 CellChangeTimes->{3.516966670685936*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"gveeff", "=", 
   RowBox[{
    RowBox[{"Zredf", "^", "2"}], " ", 
    RowBox[{"MZ02", "/", 
     RowBox[{"MZ", "^", "2"}]}], " ", 
    RowBox[{"GF0", "/", "GF"}], " ", "2", "gvnu", 
    RowBox[{"(", 
     RowBox[{"gve", "-", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          RowBox[{"2", "^", 
           RowBox[{"(", 
            RowBox[{"1", "/", "2"}], ")"}]}], "GF"}], ")"}]}], 
       RowBox[{"(", 
        RowBox[{"all1", "-", "all3", "+", "ale"}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"gaeeff", "=", 
   RowBox[{
    RowBox[{"Zredf", "^", "2"}], " ", 
    RowBox[{"MZ02", "/", 
     RowBox[{"MZ", "^", "2"}]}], " ", 
    RowBox[{"GF0", "/", "GF"}], " ", "2", "gvnu", 
    RowBox[{"(", 
     RowBox[{"gae", "-", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", "2", "]"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "GF"}], ")"}]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"1", "/", "2"}], "all1"}], "-", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "all3"}], "-", 
         RowBox[{
          RowBox[{"1", "/", "2"}], "ale"}]}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"glueff2old", "=", 
   RowBox[{
    RowBox[{"Zredf", "^", "4"}], "  ", 
    RowBox[{"MZ02", "/", 
     RowBox[{"MZ", "^", "2"}]}], " ", "*", "4", "*", " ", 
    RowBox[{"gvnu", "^", "2"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"glu", "-", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"4", "GF"}], ")"}]}], 
         RowBox[{"(", 
          RowBox[{"alq1", "+", "alq3"}], ")"}]}]}], ")"}], "^", "2"}], "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"ahl3", " ", "v2"}], "+", 
        RowBox[{"ahq3", " ", "v2"}], "-", 
        RowBox[{"alq3", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}]}], "GF"}], ")"}]}]}], ")"}], "^", 
      "2"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"gldeff2old", "=", 
   RowBox[{
    RowBox[{"Zredf", "^", "4"}], "  ", 
    RowBox[{"MZ02", "/", 
     RowBox[{"MZ", "^", "2"}]}], " ", "*", "4", "*", " ", 
    RowBox[{"gvnu", "^", "2"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"gld", "-", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"4", "GF"}], ")"}]}], 
         RowBox[{"(", 
          RowBox[{"alq1", "-", "alq3"}], ")"}]}]}], ")"}], "^", "2"}], "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"ahl3", " ", "v2"}], "+", 
        RowBox[{"ahq3", " ", "v2"}], "-", 
        RowBox[{"alq3", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}]}], "GF"}], ")"}]}]}], ")"}], "^", 
      "2"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"grueff2old", "=", 
   RowBox[{
    RowBox[{"Zredf", "^", "4"}], "  ", 
    RowBox[{"MZ02", "/", 
     RowBox[{"MZ", "^", "2"}]}], " ", "*", "4", "*", " ", 
    RowBox[{"gvnu", "^", "2"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"gru", "-", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"4", "GF"}], ")"}]}], "alu"}]}], ")"}], "^", "2"}], "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"ahl3", " ", "v2"}], "+", 
        RowBox[{"ahq3", " ", "v2"}], "-", 
        RowBox[{"alq3", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}]}], "GF"}], ")"}]}]}], ")"}], "^", 
      "2"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"grdeff2old", "=", 
   RowBox[{
    RowBox[{"Zredf", "^", "4"}], "  ", 
    RowBox[{"MZ02", "/", 
     RowBox[{"MZ", "^", "2"}]}], " ", "*", "4", "*", " ", 
    RowBox[{"gvnu", "^", "2"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"grd", "-", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"4", "GF"}], ")"}]}], "ald"}]}], ")"}], "^", "2"}], "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"ahl3", " ", "v2"}], "+", 
        RowBox[{"ahq3", " ", "v2"}], "-", 
        RowBox[{"alq3", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}]}], "GF"}], ")"}]}]}], ")"}], "^", 
      "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"glueff2", "=", 
   RowBox[{
    RowBox[{"Zredf", "^", "4"}], 
    RowBox[{
     RowBox[{"(", "  ", 
      RowBox[{"MZ02", "/", 
       RowBox[{"MZ", "^", "2"}]}], " ", ")"}], "^", "2"}], "*", "4", "*", " ", 
    RowBox[{"gvnu", "^", "2"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"glu", "-", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"4", "GF"}], ")"}]}], 
         RowBox[{"(", 
          RowBox[{"alq1", "+", "alq3"}], ")"}]}]}], ")"}], "^", "2"}], "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"ahl3", " ", "v2"}], "+", 
        RowBox[{"ahq3", " ", "v2"}], "-", 
        RowBox[{"alq3", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}]}], "GF"}], ")"}]}]}], ")"}], "^", 
      "2"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"gldeff2", "=", 
   RowBox[{
    RowBox[{"Zredf", "^", "4"}], " ", 
    RowBox[{
     RowBox[{"(", " ", 
      RowBox[{"MZ02", "/", 
       RowBox[{"MZ", "^", "2"}]}], " ", ")"}], "^", "2"}], "*", "4", "*", " ", 
    RowBox[{"gvnu", "^", "2"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"gld", "-", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"4", "GF"}], ")"}]}], 
         RowBox[{"(", 
          RowBox[{"alq1", "-", "alq3"}], ")"}]}]}], ")"}], "^", "2"}], "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"ahl3", " ", "v2"}], "+", 
        RowBox[{"ahq3", " ", "v2"}], "-", 
        RowBox[{"alq3", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}]}], "GF"}], ")"}]}]}], ")"}], "^", 
      "2"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"grueff2", "=", 
   RowBox[{
    RowBox[{"Zredf", "^", "4"}], "  ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"MZ02", "/", 
       RowBox[{"MZ", "^", "2"}]}], " ", ")"}], "^", "2"}], "*", "4", "*", " ", 
    RowBox[{"gvnu", "^", "2"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"gru", "-", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"4", "GF"}], ")"}]}], "alu"}]}], ")"}], "^", "2"}], "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"ahl3", " ", "v2"}], "+", 
        RowBox[{"ahq3", " ", "v2"}], "-", 
        RowBox[{"alq3", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}]}], "GF"}], ")"}]}]}], ")"}], "^", 
      "2"}]}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"grdeff2", "=", 
   RowBox[{
    RowBox[{"Zredf", "^", "4"}], "  ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"MZ02", "/", 
       RowBox[{"MZ", "^", "2"}]}], " ", ")"}], "^", "2"}], "*", "4", "*", " ", 
    RowBox[{"gvnu", "^", "2"}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"grd", "-", 
        RowBox[{
         RowBox[{
          RowBox[{"Sqrt", "[", "2", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"4", "GF"}], ")"}]}], "ald"}]}], ")"}], "^", "2"}], "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"ahl3", " ", "v2"}], "+", 
        RowBox[{"ahq3", " ", "v2"}], "-", 
        RowBox[{"alq3", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}]}], "GF"}], ")"}]}]}], ")"}], "^", 
      "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deltaLeff2", "=", 
   RowBox[{"glueff2", "-", "gldeff2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"deltaReff2", "=", 
   RowBox[{"grueff2", "-", "grdeff2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gLeff2", "=", 
   RowBox[{"glueff2", "+", "gldeff2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"gReff2", "=", 
   RowBox[{"grueff2", "+", "grdeff2"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5169666700619354`*^9, 3.516966682838358*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Other Z pole observables", "Subsubsection",
 CellChangeTimes->{{3.516966684803961*^9, 3.5169667017767906`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "CDHS", " ", "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"RnuthCDHS", "=", 
     RowBox[{
      RowBox[{"firstorder", "[", 
       RowBox[{"gLeff2", "+", 
        RowBox[{"rCDHS", " ", "gReff2"}]}], "]"}], "+", "RnuSM"}]}], ";"}], 
   "\n", "\n", 
   RowBox[{"(*", " ", "CHARM", " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"RnuthCHARM", "=", 
     RowBox[{
      RowBox[{"firstorder", "[", 
       RowBox[{"gLeff2", "+", 
        RowBox[{"rCHARM", " ", "gReff2"}]}], "]"}], "+", "RnuSM"}]}], ";"}], 
   "\n", "\n", 
   RowBox[{"(*", " ", "NuTeV", " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"gL2th", "=", 
     RowBox[{
      RowBox[{"firstorder", "[", 
       RowBox[{"glueff2", "+", "gldeff2"}], "]"}], "+", "gL2SM"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"gR2th", "=", 
     RowBox[{
      RowBox[{"firstorder", "[", 
       RowBox[{"grueff2", "+", "grdeff2"}], "]"}], "+", "gR2SM"}]}], ";"}], 
   "\n", "\n", 
   RowBox[{"(*", " ", "CCFR", " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"kappath", "=", 
     RowBox[{
      RowBox[{"firstorder", "[", 
       RowBox[{
        RowBox[{"1.7897", " ", "gLeff2"}], "+", 
        RowBox[{"1.1479", "gReff2"}], "-", 
        RowBox[{"0.0916", "deltaLeff2"}], "-", 
        RowBox[{"0.0782", "deltaReff2"}]}], "]"}], "+", "kappaSM"}]}], ";"}], 
   "\n", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"CHARM", " ", "II"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"gVeth", "=", 
     RowBox[{
      RowBox[{"firstorder", "[", "gveeff", "]"}], "+", "gVeSM"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"gAeth", "=", 
     RowBox[{
      RowBox[{"firstorder", "[", "gaeeff", "]"}], "+", "gAeSM"}]}], ";"}], 
   "\n", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Atomic", " ", "parity", " ", "violation"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"C1u0", "=", 
     RowBox[{"2", "gae", " ", "gvu"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"C1d0", "=", 
     RowBox[{"2", "gae", " ", "gvd"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"C2u0", "=", 
     RowBox[{"2", "gve", " ", "gau"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"C2d0", "=", 
     RowBox[{"2", " ", "gve", " ", "gad"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DC1u", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "/", "GF"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"-", "1"}], "/", "4"}], 
         RowBox[{"(", 
          RowBox[{"alq1", "-", "alq3"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"1", "/", "4"}], "alu"}], "+", 
        RowBox[{
         RowBox[{"1", "/", "4"}], "aqe"}], "+", 
        RowBox[{
         RowBox[{"1", "/", "4"}], "aeu"}]}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DC2u", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "/", "GF"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"-", "1"}], "/", "4"}], 
         RowBox[{"(", 
          RowBox[{"alq1", "-", "alq3"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"1", "/", "4"}], "alu"}], "-", 
        RowBox[{
         RowBox[{"1", "/", "4"}], "aqe"}], "+", 
        RowBox[{
         RowBox[{"1", "/", "4"}], "aeu"}]}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DC1d", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "/", "GF"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"-", "1"}], "/", "4"}], 
         RowBox[{"(", 
          RowBox[{"alq1", "+", "alq3"}], ")"}]}], "-", 
        RowBox[{
         RowBox[{"1", "/", "4"}], "ald"}], "+", 
        RowBox[{
         RowBox[{"1", "/", "4"}], "aqe"}], "+", 
        RowBox[{
         RowBox[{"1", "/", "4"}], "aed"}]}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"DC2d", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Sqrt", "[", "2", "]"}], "/", "GF"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"-", "1"}], "/", "4"}], 
         RowBox[{"(", 
          RowBox[{"alq1", "+", "alq3"}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"1", "/", "4"}], "ald"}], "-", 
        RowBox[{
         RowBox[{"1", "/", "4"}], "aqe"}], "+", 
        RowBox[{
         RowBox[{"1", "/", "4"}], "aed"}]}], ")"}]}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"C1ueff", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], " ", 
      RowBox[{"MW2", "/", 
       RowBox[{"(", 
        RowBox[{"MZ2", " ", "c02"}], ")"}]}], 
      RowBox[{"GF0", "/", "GF"}], " ", 
      RowBox[{"(", 
       RowBox[{"C1u0", "+", "DC1u"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"C1deff", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], " ", 
      RowBox[{"MW2", "/", 
       RowBox[{"(", 
        RowBox[{"MZ2", " ", "c02"}], ")"}]}], 
      RowBox[{"GF0", "/", "GF"}], " ", 
      RowBox[{"(", 
       RowBox[{"C1d0", "+", "DC1d"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"C2ueff", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], " ", 
      RowBox[{"MW2", "/", 
       RowBox[{"(", 
        RowBox[{"MZ2", " ", "c02"}], ")"}]}], 
      RowBox[{"GF0", "/", "GF"}], " ", 
      RowBox[{"(", 
       RowBox[{"C2u0", "+", "DC2u"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"C2deff", "=", 
     RowBox[{
      RowBox[{"Zredf", "^", "2"}], " ", 
      RowBox[{"MW2", "/", 
       RowBox[{"(", 
        RowBox[{"MZ2", " ", "c02"}], ")"}]}], 
      RowBox[{"GF0", "/", "GF"}], " ", 
      RowBox[{"(", 
       RowBox[{"C2d0", "+", "DC2d"}], ")"}]}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"QWCsth", "=", 
     RowBox[{
      RowBox[{"firstorder", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "376"}], "C1ueff"}], "-", 
        RowBox[{"422", "C1deff"}]}], "]"}], "+", "QWCsSM"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"QWTlth", "=", 
     RowBox[{
      RowBox[{"firstorder", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "572"}], "C1ueff"}], "-", 
        RowBox[{"658", "C1deff"}]}], "]"}], "+", "QWTlSM"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.516966687097165*^9, 3.516966691277972*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["LEP II", "Subsection",
 CellChangeTimes->{3.510920559533655*^9}],

Cell[CellGroupData[{

Cell["Fermion pair production", "Subsubsection",
 CellChangeTimes->{3.540539972342704*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a1mu", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"all1", "+", "all3", "+", 
      RowBox[{"2", "ale"}], "+", "aee"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a2mu", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "all1"}], "-", "all3", "+", "aee"}], ")"}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"a3mu", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "all1"}], "-", "all3", "+", "aee"}], ")"}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"a4mu", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"all1", "+", "all3", "-", 
      RowBox[{"2", "ale"}], "+", "aee"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a1tau", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"alL1", "+", "alL3", "+", "altau", "+", "aLe", "+", "aetau"}], 
     ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a2tau", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "alL1"}], "-", "alL3", "-", "altau", "+", "aLe", "+", 
      "aetau"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a3tau", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "alL1"}], "-", "alL3", "+", "altau", "-", "aLe", "+", 
      "aetau"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4tau", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"alL1", "+", "alL3", "-", "altau", "-", "aLe", "+", "aetau"}], 
     ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a1u", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"alq1", "-", "alq3", "+", "alu", "+", "aqe", "+", "aeu"}], 
     ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a2u", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "alq1"}], "+", "alq3", "-", "alu", "+", "aqe", "+", 
      "aeu"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a3u", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "alq1"}], "+", "alq3", "+", "alu", "-", "aqe", "+", 
      "aeu"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4u", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"alq1", "-", "alq3", "-", "alu", "-", "aqe", "+", "aeu"}], 
     ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a1d", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"alq1", "+", "alq3", "+", "ald", "+", "aqe", "+", "aed"}], 
     ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a2d", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "alq1"}], "-", "alq3", "-", "ald", "+", "aqe", "+", 
      "aed"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a3d", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "alq1"}], "-", "alq3", "+", "ald", "-", "aqe", "+", 
      "aed"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4d", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"alq1", "+", "alq3", "-", "ald", "-", "aqe", "+", "aed"}], 
     ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a1e", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"all1", "+", "all3", "+", 
      RowBox[{"2", "ale"}], "+", "aee"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a2e", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "all1"}], "-", "all3", "+", "aee"}], ")"}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"a3e", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "all1"}], "-", "all3", "+", "aee"}], ")"}]}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"a4e", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"all1", "+", "all3", "-", 
      RowBox[{"2", "ale"}], "+", "aee"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a1t", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"alQ1", "-", "alQ3", "+", "alt", "+", "aQe", "+", "aet"}], 
     ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a2t", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "alQ1"}], "+", "alQ3", "-", "alt", "+", "aQe", "+", 
      "aet"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a3t", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "alQ1"}], "+", "alQ3", "+", "alt", "-", "aQe", "+", 
      "aet"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a4t", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"alQ1", "-", "alQ3", "-", "alt", "-", "aQe", "+", "aet"}], 
     ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a1b", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{"alQ1", "+", "alQ3", "+", "alb", "+", "aQe", "+", "aeb"}], 
     ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a2b", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "alQ1"}], "-", "alQ3", "-", "alb", "+", "aQe", "+", 
      "aeb"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"a3b", "=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "alQ1"}], "-", "alQ3", "+", "alb", "-", "aQe", "+", 
      "aeb"}], ")"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"a4b", "=", 
    RowBox[{
     RowBox[{"1", "/", "4"}], 
     RowBox[{"(", 
      RowBox[{"alQ1", "+", "alQ3", "-", "alb", "-", "aQe", "+", "aeb"}], 
      ")"}]}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Z", " ", "exchange", " ", "magnitude", " ", "squared", " ", "for", " ", 
     "ee"}], "\[Rule]", 
    RowBox[{"ff", " ", 
     RowBox[{"(", 
      RowBox[{"f", "\[NotEqual]", "e"}], ")"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"S", "=", 
     RowBox[{
      RowBox[{"Mandelstam", " ", "variable"}], "=", 
      RowBox[{"CM", " ", "energy", " ", "squard"}]}]}], ",", " ", 
    RowBox[{"cos", "=", 
     RowBox[{"cos", 
      RowBox[{"(", 
       RowBox[{
       "angle", " ", "between", " ", "electron", " ", "and", " ", "outgoing", 
        " ", "fermion"}], ")"}]}]}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MZZf", "[", 
     RowBox[{"gaf_", ",", "gvf_", ",", "S_", ",", "cos_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["e0", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
         "8", " ", "cos", " ", "gae", " ", "gaf", " ", "gve", " ", "gvf"}], 
         "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["cos", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["gae", "2"], "+", 
            SuperscriptBox["gve", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["gaf", "2"], "+", 
            SuperscriptBox["gvf", "2"]}], ")"}]}]}], ")"}], " ", 
       SuperscriptBox["S", "2"], " ", 
       SuperscriptBox["Zredf", "4"]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"16", " ", 
       RowBox[{"c02", " ", "^", "2"}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["MZ", "2"]}], "+", "S"}], ")"}], "2"], " ", 
       RowBox[{"s02", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Gamma", " ", "exchange", " ", "magnitude", " ", "squared"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Mggf", "[", 
     RowBox[{"Q_", ",", "S_", ",", "cos_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"e", "^", "4"}], " ", 
     RowBox[{"Q", "^", "2"}], 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"cos", "^", "2"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Gamma", "-", 
    RowBox[{"Z", "  ", "interference"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MgZf", "[", 
     RowBox[{"Q_", ",", "gaf_", ",", "gvf_", ",", "S_", ",", "cos_"}], "]"}], 
    ":=", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["e", "2"], " ", 
        SuperscriptBox["e0", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "cos", " ", "gae", " ", "gaf"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["cos", "2"]}], ")"}], " ", "gve", " ", "gvf"}]}], 
         ")"}], " ", "Q", " ", "S", " ", 
        RowBox[{"Zredf", "^", "2"}]}], ")"}]}], "/", 
     RowBox[{"(", 
      RowBox[{"2", " ", "c02", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["MZ", "2"]}], "+", "S"}], ")"}], " ", "s02"}], 
      ")"}]}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Z", "-", 
    RowBox[{"NP", " ", "interference"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MZnf", "[", 
     RowBox[{
     "gaf_", ",", "gvf_", ",", "a1_", ",", "a2_", ",", "a3_", ",", "a4_", ",",
       "S_", ",", "cos_"}], "]"}], ":=", 
    RowBox[{
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["e", "2"], 
       RowBox[{"S", "^", "2"}]}], 
      RowBox[{"c02", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["MZ", "2"]}], "+", "S"}], ")"}], " ", "s02"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        FractionBox["1", "8"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["cos", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a4", " ", "gae", " ", "gaf"}], "-", 
          RowBox[{"a3", " ", "gaf", " ", "gve"}], "-", 
          RowBox[{"a2", " ", "gae", " ", "gvf"}], "+", 
          RowBox[{"a1", " ", "gve", " ", "gvf"}]}], ")"}]}], " ", "+", 
       RowBox[{
        FractionBox["1", "4"], " ", "cos", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a1", " ", "gae", " ", "gaf"}], "-", 
          RowBox[{"a2", " ", "gaf", " ", "gve"}], "-", 
          RowBox[{"a3", " ", "gae", " ", "gvf"}], "+", 
          RowBox[{"a4", " ", "gve", " ", "gvf"}]}], ")"}]}]}], " ", ")"}]}]}],
    ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Gamma", "-", 
    RowBox[{"NP", " ", "interference"}]}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Mgnf", "[", 
     RowBox[{
     "Q_", ",", "a1_", ",", "a2_", ",", "a3_", ",", "a4_", ",", "S_", ",", 
      "cos_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "S"]}], 
     RowBox[{"(", 
      RowBox[{"16", " ", 
       SuperscriptBox["e", "2"], " ", "Q", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox["1", "4"], " ", "a4", " ", "cos", " ", 
          SuperscriptBox["S", "2"]}], "+", 
         RowBox[{
          FractionBox["1", "8"], " ", "a1", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["cos", "2"]}], ")"}], " ", 
          SuperscriptBox["S", "2"]}]}], ")"}]}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "If", " ", "considering", " ", "higher", " ", "order", " ", "terms"}], 
    ",", " ", 
    RowBox[{"NP", " ", "magnitude", " ", "squared"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"Mnnf", "[", 
      RowBox[{
      "a1_", ",", "a2_", ",", "a3_", ",", "a4_", ",", "S_", ",", "cos_"}], 
      "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a1", "^", "2"}], "+", 
         RowBox[{"a2", "^", "2"}], "+", 
         RowBox[{"a3", "^", "2"}], "+", 
         RowBox[{"a4", "^", "2"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"S", "^", "2"}], 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"cos", "^", "2"}]}], ")"}]}], ")"}]}], "+", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a1", " ", "a4"}], "+", 
         RowBox[{"a2", " ", "a3"}]}], ")"}], "2", " ", 
       RowBox[{"S", "^", "2"}], " ", "cos"}]}]}], ";"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"ee", "\[Rule]", 
    RowBox[{"ee", " ", "channel"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MZZe", "[", 
     RowBox[{"S_", ",", "cos_"}], "]"}], ":=", 
    RowBox[{
     FractionBox["1", "4"], 
     FractionBox[
      RowBox[{"e0", "^", "4"}], 
      RowBox[{"16", 
       RowBox[{"c02", "^", "2"}], 
       RowBox[{"s02", "^", "2"}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", "cos"}], ")"}], "2"], "-", "4"}], ")"}], "4", 
           RowBox[{"gae", "^", "2"}], 
           RowBox[{"gve", "^", "2"}], " ", "2", 
           RowBox[{"S", "^", "2"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "+", "cos"}], ")"}], "2"], " ", "+", "4"}], ")"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["gae", "2"], "+", 
              SuperscriptBox["gve", "2"]}], ")"}], "2"], "2", 
           RowBox[{"S", "^", "2"}]}]}], ")"}], "/", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["MZ", "2"]}], "-", 
           RowBox[{
            FractionBox["1", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"1", "-", "cos"}], ")"}], " ", "S"}]}], ")"}], "^", 
         "2"}]}], "+", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["MZ", "2"]}], "+", "S"}], ")"}], "2"], " "}]], 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"8", " ", "cos", " ", "4", " ", 
           SuperscriptBox["gae", "2"], 
           RowBox[{"gve", "^", "2"}], " ", 
           SuperscriptBox["S", "2"]}], "+", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["cos", "2"]}], ")"}], 
           RowBox[{
            RowBox[{"(", " ", 
             RowBox[{
              SuperscriptBox["gve", "2"], "+", 
              RowBox[{"gae", "^", "2"}]}], ")"}], "^", "2"}], " ", 
           SuperscriptBox["S", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", " ", 
          SuperscriptBox["S", "2"], 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "cos"}], ")"}], "^", "2"}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"gve", "^", "2"}], "+", 
               RowBox[{"gae", "^", "2"}]}], ")"}], "^", "2"}], "+", 
            RowBox[{"4", 
             RowBox[{"gve", "^", "2"}], 
             RowBox[{"gae", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
        RowBox[{"(", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["MZ", "2"]}], "-", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", "cos"}], ")"}], " ", "S"}]}], ")"}], 
          RowBox[{"(", 
           RowBox[{"S", "-", 
            RowBox[{"MZ", "^", "2"}]}], ")"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox["Zredf", "4"]}]}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Mgge", "[", 
     RowBox[{"S_", ",", "cos_"}], "]"}], ":=", 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "cos"}], ")"}], "2"], " ", 
        SuperscriptBox["e", "4"]}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", "cos"}]], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["cos", "2"]}], ")"}], " ", 
       SuperscriptBox["e", "4"]}], "+", 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", "cos"}], "+", 
          SuperscriptBox["cos", "2"]}], ")"}], " ", 
        SuperscriptBox["e", "4"]}], 
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "-", "cos"}], ")"}], "2"], " "}]]}], ")"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"MgZe", "[", 
    RowBox[{"S_", ",", "cos_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"1", "/", "4"}], 
    FractionBox["1", 
     RowBox[{"2", " ", "c02", " ", "s02"}]], 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["e", "2"], " ", 
      SuperscriptBox["e0", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"4", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "cos"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["gae", "2"], "+", 
            SuperscriptBox["gve", "2"]}], ")"}], " ", "S"}], 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"1", "-", "cos"}], ")"}]}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["MZ", "2"]}], "+", "S"}], ")"}]}]], "+", 
        FractionBox[
         RowBox[{"2", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", "cos"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["gae", "2"], "+", 
            SuperscriptBox["gve", "2"]}], ")"}], " ", "S"}], 
         RowBox[{" ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["MZ", "2"]}], "-", 
            RowBox[{
             FractionBox["1", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", "cos"}], ")"}], " ", "S"}]}], ")"}]}]], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "cos", " ", 
              SuperscriptBox["gae", "2"], " ", 
              SuperscriptBox["S", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                SuperscriptBox["cos", "2"]}], ")"}], " ", 
              SuperscriptBox["gve", "2"], " ", 
              SuperscriptBox["S", "2"]}]}], ")"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"S", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["MZ", "2"]}], "+", "S"}], ")"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", 
                RowBox[{"2", " ", "cos"}], "+", 
                SuperscriptBox["cos", "2"]}], ")"}], " ", 
              RowBox[{"gae", "^", "2"}], " ", 
              SuperscriptBox["S", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"5", "+", 
                RowBox[{"2", " ", "cos"}], "+", 
                SuperscriptBox["cos", "2"]}], ")"}], " ", 
              SuperscriptBox["gve", "2"], " ", 
              SuperscriptBox["S", "2"]}]}], ")"}]}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{"1", "-", "cos"}], ")"}]}], " ", "S", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["MZ", "2"]}], "-", 
             RowBox[{
              FractionBox["1", "2"], " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", "cos"}], ")"}], " ", "S"}]}], ")"}]}], 
          ")"}]}]}], ")"}], " ", 
      SuperscriptBox["Zredf", "2"]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MZne", "[", 
    RowBox[{"S_", ",", "cos_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"4", 
       RowBox[{"e0", "^", "2"}], 
       RowBox[{"S", "^", "2"}]}], 
      RowBox[{"c02", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["MZ", "2"]}], "+", "S"}], ")"}], " ", "s02"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "8"]}], " ", 
        RowBox[{"(", 
         RowBox[{"a2e", "+", "a3e"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "cos"}], ")"}], "2"], " ", "gae", " ", "gve"}], 
       " ", "+", 
       RowBox[{
        FractionBox["1", "8"], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          SuperscriptBox["cos", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a4e", " ", 
           SuperscriptBox["gae", "2"]}], "+", 
          RowBox[{"a1e", " ", 
           SuperscriptBox["gve", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "4"], " ", "cos", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a1e", " ", 
           SuperscriptBox["gae", "2"]}], "+", 
          RowBox[{"a4e", " ", 
           SuperscriptBox["gve", "2"]}]}], ")"}]}], " ", "+", 
       RowBox[{
        FractionBox["1", "16"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "cos"}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"(", 
            RowBox[{"a2e", "+", "a3e"}], ")"}], " ", "gae", " ", "gve"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a1e", "+", "a4e"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"gae", "^", "2"}], "+", 
             SuperscriptBox["gve", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"4", 
       RowBox[{"e0", "^", "2"}], 
       RowBox[{"S", "^", "2"}]}], 
      RowBox[{"c02", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["MZ", "2"]}], "-", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "-", "cos"}], ")"}], " ", "S"}]}], ")"}], " ", 
       "s02"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "8"]}], " ", 
        RowBox[{"(", 
         RowBox[{"a2e", "+", "a3e"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "cos"}], ")"}], "2"], " ", "gae", " ", "gve"}], 
       " ", "+", 
       RowBox[{
        FractionBox["1", "16"], " ", 
        RowBox[{"(", 
         RowBox[{"5", "+", 
          RowBox[{"2", " ", "cos"}], "+", 
          SuperscriptBox["cos", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a4e", " ", 
           SuperscriptBox["gae", "2"]}], "+", 
          RowBox[{"a1e", " ", 
           SuperscriptBox["gve", "2"]}]}], ")"}]}], "+", 
       "\[IndentingNewLine]", 
       RowBox[{
        FractionBox["1", "16"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", "cos"}], "+", 
          SuperscriptBox["cos", "2"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a1e", " ", 
           SuperscriptBox["gae", "2"]}], "+", 
          RowBox[{"a4e", " ", 
           SuperscriptBox["gve", "2"]}]}], ")"}]}], "+", 
       RowBox[{
        FractionBox["1", "16"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "cos"}], ")"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"(", 
            RowBox[{"a2e", "+", "a3e"}], ")"}], " ", "gae", " ", "gve"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a1e", "+", "a4e"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["gae", "2"], "+", 
             SuperscriptBox["gve", "2"]}], ")"}]}]}], ")"}]}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Mgne", "[", 
     RowBox[{"S_", ",", "cos_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"S", 
      RowBox[{"(", 
       RowBox[{"16", " ", 
        SuperscriptBox["e", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           FractionBox["1", "4"], " ", "a4e", " ", "cos"}], " ", "+", 
          RowBox[{
           FractionBox["1", "16"], " ", 
           RowBox[{"(", 
            RowBox[{"a1e", "+", "a4e"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"1", "+", "cos"}], ")"}], "2"]}], " ", "+", 
          RowBox[{
           FractionBox["1", "8"], " ", "a1e", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             SuperscriptBox["cos", "2"]}], ")"}]}]}], ")"}]}], ")"}]}], "+", 
     RowBox[{
      FractionBox["S", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"1", "-", "cos"}], ")"}]}], " "}]], "32", " ", 
      SuperscriptBox["e", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox["1", "16"], " ", 
         RowBox[{"(", 
          RowBox[{"a1e", "+", "a4e"}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", "cos"}], ")"}], "2"]}], " ", "+", 
        RowBox[{
         FractionBox["1", "16"], " ", "a4e", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "+", 
           RowBox[{"2", " ", "cos"}], "+", 
           SuperscriptBox["cos", "2"]}], ")"}]}], " ", "+", 
        RowBox[{
         FractionBox["1", "16"], " ", "a1e", " ", 
         RowBox[{"(", 
          RowBox[{"5", "+", 
           RowBox[{"2", " ", "cos"}], "+", 
           SuperscriptBox["cos", "2"]}], ")"}]}]}], " ", ")"}]}]}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "second", " ", "order", " ", "contribution", " ", "from", " ", "contact", 
    " ", "terms"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"Mnne", "[", 
      RowBox[{"S_", ",", "cos_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a1e", "^", "2"}], "+", 
         RowBox[{"a2e", "^", "2"}], "+", 
         RowBox[{"a3e", "^", "2"}], "+", 
         RowBox[{"a4e", "^", "2"}]}], ")"}], 
       RowBox[{"S", "^", "2"}], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"cos", "^", "2"}]}], ")"}]}], "+", 
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a1e", " ", "a4e"}], "+", 
         RowBox[{"a3e", " ", "a2e"}]}], ")"}], 
       RowBox[{"S", "^", "2"}], " ", "2", "cos"}], "+", 
      RowBox[{
       RowBox[{"1", "/", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a1e", "^", "2"}], "+", 
         RowBox[{"a2e", "^", "2"}], "+", 
         RowBox[{"a3e", "^", "2"}], "+", 
         RowBox[{"a4e", "^", "2"}]}], ")"}], 
       RowBox[{"S", "^", "2"}], 
       RowBox[{"(", 
        RowBox[{"5", "+", 
         RowBox[{"2", "cos"}], "+", 
         RowBox[{"cos", "^", "2"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a1e", " ", "a4e"}], "+", 
         RowBox[{"a2e", " ", "a3e"}]}], ")"}], 
       RowBox[{"S", "^", "2"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", 
         RowBox[{"2", "cos"}], "+", 
         RowBox[{"cos", "^", "2"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a1e", "^", "2"}], "+", 
         RowBox[{"a4e", "^", "2"}], "+", 
         RowBox[{"2", "a1e", " ", "a4e"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"S", "^", "2"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "cos"}], ")"}], "^", "2"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a2e", "^", "2"}], "+", 
         RowBox[{"a3e", "^", "2"}], "+", 
         RowBox[{"2", "a2e", " ", "a3e"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"S", "^", "2"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "cos"}], ")"}], "^", "2"}]}], ")"}]}]}]}], ";"}],
    "*)"}]}]}], "Input",
 CellChangeTimes->{{3.5109205024531555`*^9, 3.5109205617020593`*^9}, {
  3.5405399747898436`*^9, 3.5405399783570476`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Differential cross-sections", "Subsubsection"]], \
"Subsubsection",
 CellChangeTimes->{{3.5109207861084538`*^9, 3.510920789306459*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"dsigmamu", "=", 
   RowBox[{"gev2pbarn", "  ", 
    RowBox[{"1", "/", 
     RowBox[{"(", 
      RowBox[{"32", " ", "Pi", " ", "S"}], ")"}]}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"MZnf", "[", 
       RowBox[{
       "gae", ",", "gve", ",", "a1mu", ",", "a2mu", ",", "a3mu", ",", "a4mu", 
        ",", "S", ",", "cos"}], "]"}], "+", 
      RowBox[{"Mgnf", "[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "a1mu", ",", "a2mu", ",", "a3mu", ",", 
        "a4mu", ",", "S", ",", "cos"}], "]"}], "+", 
      RowBox[{"MZZf", "[", 
       RowBox[{"gae", ",", "gve", ",", "S", ",", "cos"}], "]"}], "+", 
      RowBox[{"Mggf", "[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "S", ",", "cos"}], "]"}], "+", 
      RowBox[{"MgZf", "[", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "gae", ",", "gve", ",", "S", ",", "cos"}], 
       "]"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsigmamutr", "=", 
    RowBox[{"firstorder", "[", "dsigmamu", "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"SECO", "\[Equal]", "1"}], ",", 
      RowBox[{"dsigmamutr", "=", 
       RowBox[{"dsigmamutr", "+", 
        RowBox[{"gev2pbarn", " ", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"32", " ", "Pi", " ", "S"}], ")"}]}], 
         RowBox[{"Mnnf", "[", 
          RowBox[{
          "a1mu", ",", "a2mu", ",", "a3mu", ",", "a4mu", ",", "S", ",", 
           "cos"}], "]"}]}]}]}]}], "]"}], ";"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsigmatau", "=", 
    RowBox[{"gev2pbarn", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"32", " ", "Pi", " ", "S"}], ")"}]}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"MZnf", "[", 
          RowBox[{
          "gatau", ",", "gvtau", ",", "a1tau", ",", "a2tau", ",", "a3tau", 
           ",", "a4tau", ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"Mgnf", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "a1tau", ",", "a2tau", ",", "a3tau", ",", 
           "a4tau", ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"MZZf", "[", 
          RowBox[{"gatau", ",", "gvtau", ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"Mggf", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"MgZf", "[", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "gatau", ",", "gvtau", ",", "S", ",", 
           "cos"}], "]"}]}], ")"}]}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsigmatautr", "=", 
    RowBox[{
     RowBox[{"firstorder", "[", "dsigmatau", "]"}], "+", 
     RowBox[{"firstorder", "[", "dsigmatautensorial", "]"}]}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"SECO", "\[Equal]", "1"}], ",", 
      RowBox[{"dsigmatautr", "=", 
       RowBox[{"dsigmatautr", "+", 
        RowBox[{"gev2pbarn", " ", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"32", " ", "Pi", " ", "S"}], ")"}]}], 
         RowBox[{"Mnnf", "[", 
          RowBox[{
          "a1tau", ",", "a2tau", ",", "a3tau", ",", "a4tau", ",", "S", ",", 
           "cos"}], "]"}]}]}]}]}], "]"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsigmahad", "=", 
   RowBox[{"gev2pbarn", "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"32", " ", "Pi", " ", "S"}], ")"}]}], "2", " ", "Nf", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"MZnf", "[", 
          RowBox[{
          "gau", ",", "gvu", ",", "a1u", ",", "a2u", ",", "a3u", ",", "a4u", 
           ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"Mgnf", "[", 
          RowBox[{
           RowBox[{"2", "/", "3"}], ",", "a1u", ",", "a2u", ",", "a3u", ",", 
           "a4u", ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"MZZf", "[", 
          RowBox[{"gau", ",", "gvu", ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"Mggf", "[", 
          RowBox[{
           RowBox[{"2", "/", "3"}], ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"MgZf", "[", 
          RowBox[{
           RowBox[{"2", "/", "3"}], ",", "gau", ",", "gvu", ",", "S", ",", 
           "cos"}], "]"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"32", " ", "Pi", " ", "S"}], ")"}]}], "2", "Nf", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"MZnf", "[", 
          RowBox[{
          "gad", ",", "gvd", ",", "a1d", ",", "a2d", ",", "a3d", ",", "a4d", 
           ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"Mgnf", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "/", "3"}], ",", "a1d", ",", "a2d", ",", 
           "a3d", ",", "a4d", ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"MZZf", "[", 
          RowBox[{"gad", ",", "gvd", ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"Mggf", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "/", "3"}], ",", "S", ",", "cos"}], "]"}], 
         "+", 
         RowBox[{"MgZf", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "/", "3"}], ",", "gad", ",", "gvd", ",", "S", 
           ",", "cos"}], "]"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{"32", " ", "Pi", " ", "S"}], ")"}]}], "Nf", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"MZnf", "[", 
          RowBox[{
          "gab", ",", "gvb", ",", "a1b", ",", "a2b", ",", "a3b", ",", "a4b", 
           ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"Mgnf", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "/", "3"}], ",", "a1b", ",", "a2b", ",", 
           "a3b", ",", "a4b", ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"MZZf", "[", 
          RowBox[{"gab", ",", "gvb", ",", "S", ",", "cos"}], "]"}], "+", 
         RowBox[{"Mggf", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "/", "3"}], ",", "S", ",", "cos"}], "]"}], 
         "+", 
         RowBox[{"MgZf", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "1"}], "/", "3"}], ",", "gab", ",", "gvb", ",", "S", 
           ",", "cos"}], "]"}]}], ")"}]}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsigmahadtr", "=", 
   RowBox[{"firstorder", "[", "dsigmahad", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsigmab", "=", 
   RowBox[{"gev2pbarn", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"32", " ", "Pi", " ", "S"}], ")"}]}], "Nf", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"MZnf", "[", 
         RowBox[{
         "gab", ",", "gvb", ",", "a1b", ",", "a2b", ",", "a3b", ",", "a4b", 
          ",", "S", ",", "cos"}], "]"}], "+", 
        RowBox[{"Mgnf", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1"}], "/", "3"}], ",", "a1b", ",", "a2b", ",", "a3b",
           ",", "a4b", ",", "S", ",", "cos"}], "]"}], "+", 
        RowBox[{"MZZf", "[", 
         RowBox[{"gab", ",", "gvb", ",", "S", ",", "cos"}], "]"}], "+", 
        RowBox[{"Mggf", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1"}], "/", "3"}], ",", "S", ",", "cos"}], "]"}], "+", 
        RowBox[{"MgZf", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "1"}], "/", "3"}], ",", "gab", ",", "gvb", ",", "S", 
          ",", "cos"}], "]"}]}], ")"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsigmabtr", "=", 
   RowBox[{"firstorder", "[", "dsigmab", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsigmac", "=", 
   RowBox[{"gev2pbarn", "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"32", " ", "Pi", " ", "S"}], ")"}]}], "Nf", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"MZnf", "[", 
         RowBox[{
         "gau", ",", "gvu", ",", "a1u", ",", "a2u", ",", "a3u", ",", "a4u", 
          ",", "S", ",", "cos"}], "]"}], "+", 
        RowBox[{"Mgnf", "[", 
         RowBox[{
          RowBox[{"2", "/", "3"}], ",", "a1u", ",", "a2u", ",", "a3u", ",", 
          "a4u", ",", "S", ",", "cos"}], "]"}], "+", 
        RowBox[{"MZZf", "[", 
         RowBox[{"gau", ",", "gvu", ",", "S", ",", "cos"}], "]"}], "+", 
        RowBox[{"Mggf", "[", 
         RowBox[{
          RowBox[{"2", "/", "3"}], ",", "S", ",", "cos"}], "]"}], "+", 
        RowBox[{"MgZf", "[", 
         RowBox[{
          RowBox[{"2", "/", "3"}], ",", "gau", ",", "gvu", ",", "S", ",", 
          "cos"}], "]"}]}], ")"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dsigmactr", "=", 
    RowBox[{"firstorder", "[", "dsigmac", "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"SECO", "\[Equal]", "1"}], ",", " ", 
      RowBox[{"dsigmahadtr", "=", 
       RowBox[{"dsigmahadtr", "+", 
        RowBox[{"gev2pbarn", " ", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"32", " ", "Pi", " ", "S"}], ")"}]}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "Nf", " ", 
            RowBox[{"Mnnf", "[", 
             RowBox[{
             "a1u", ",", "a2u", ",", "a3u", ",", "a4u", ",", "S", ",", 
              "cos"}], "]"}]}], "+", 
           RowBox[{"2", " ", "Nf", " ", 
            RowBox[{"Mnnf", "[", 
             RowBox[{
             "a1d", ",", "a2d", ",", "a3d", ",", "a4d", ",", "S", ",", 
              "cos"}], "]"}]}], "+", 
           RowBox[{"Nf", " ", 
            RowBox[{"Mnnf", "[", 
             RowBox[{
             "a1b", ",", "a2b", ",", "a3b", ",", "a4b", ",", "S", ",", 
              "cos"}], "]"}]}]}], ")"}]}]}]}]}], "]"}], ";"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsigmae", "=", 
   RowBox[{"gev2pbarn", 
    RowBox[{"(", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"32", " ", "Pi", " ", "S"}], ")"}]}], ")"}], 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"MZne", "[", 
       RowBox[{"S", ",", "cos"}], "]"}], "+", 
      RowBox[{"Mgne", "[", 
       RowBox[{"S", ",", "cos"}], "]"}], "+", 
      RowBox[{"Mgge", "[", 
       RowBox[{"S", ",", "cos"}], "]"}], "+", 
      RowBox[{"MZZe", "[", 
       RowBox[{"S", ",", "cos"}], "]"}], "+", 
      RowBox[{"MgZe", "[", 
       RowBox[{"S", ",", "cos"}], "]"}]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dsigmaetr", "=", 
   RowBox[{"firstorder", "[", "dsigmae", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"SECO", "\[Equal]", "1"}], ",", 
      RowBox[{"dsigmaetr", "=", 
       RowBox[{"dsigmaetr", "+", 
        RowBox[{"gev2pbarn", " ", 
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"32", " ", "Pi", " ", "S"}], ")"}]}], 
         RowBox[{"Mnne", "[", 
          RowBox[{"S", ",", "cos"}], "]"}]}]}]}]}], "]"}], ";"}], 
   "*)"}]}]}], "Input",
 CellChangeTimes->{{3.5122826239288216`*^9, 3.512282646751662*^9}, {
   3.512286007438635*^9, 3.5122860665120134`*^9}, {3.512286108441412*^9, 
   3.5122861191520243`*^9}, {3.512286216560596*^9, 3.51228649373545*^9}, {
   3.5122917086767273`*^9, 3.512291864031613*^9}, {3.513600691221153*^9, 
   3.513600747545374*^9}, {3.513600783422426*^9, 3.513600847817109*^9}, 
   3.514804464974123*^9, {3.515911666052575*^9, 3.5159119074005995`*^9}, {
   3.515911988629942*^9, 3.5159120864889135`*^9}, {3.515912330691743*^9, 
   3.515912343156164*^9}, {3.516011622279666*^9, 3.5160116566621265`*^9}, {
   3.5160117064574137`*^9, 3.5160117096866193`*^9}, {3.5167134308694057`*^9, 
   3.5167137171611085`*^9}, {3.5169665196620708`*^9, 
   3.5169665223296757`*^9}, {3.5405393100668235`*^9, 3.540539319896386*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["W pair production", "Subsubsection"]], "Subsubsection",
 CellChangeTimes->{{3.5109208146253033`*^9, 3.5109208182913103`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Formulas", " ", "and", " ", "notations", " ", "taken", " ", "from", " ", 
     RowBox[{"Nucl", ".", " ", "Phys", ".", " ", "B282"}]}], ",", 
    RowBox[{"253", 
     RowBox[{"(", "1987", ")"}]}]}], " ", "*)"}], " ", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"lambdaZ", "=", 
     RowBox[{"6", 
      RowBox[{"aW", "/", 
       RowBox[{"Sqrt", "[", "g2", "]"}]}], " ", 
      RowBox[{"MWth", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"lambdag", "=", 
     RowBox[{"6", " ", 
      RowBox[{"aW", "/", 
       RowBox[{"Sqrt", "[", "g2", "]"}]}], " ", 
      RowBox[{"MWth", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kappaZ", "=", 
     RowBox[{"1", "-", 
      RowBox[{"aWB", " ", "v2", " ", 
       RowBox[{"s", "/", "c"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"kappag", "=", 
     RowBox[{"1", "+", 
      RowBox[{"aWB", " ", "v2", " ", 
       RowBox[{"c", "/", "s"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"f1g", "=", 
     RowBox[{"1", "+", 
      RowBox[{
       RowBox[{"S", "/", 
        RowBox[{"(", 
         RowBox[{"2", 
          RowBox[{"MWth", "^", "2"}]}], ")"}]}], "lambdag"}]}]}], ";", 
    RowBox[{"f2g", "=", "lambdag"}], ";", 
    RowBox[{"f3g", "=", 
     RowBox[{"1", "+", "kappag", "+", "lambdag"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"f1Z", "=", 
     RowBox[{"1", "+", 
      RowBox[{
       RowBox[{"S", "/", 
        RowBox[{"(", 
         RowBox[{"2", 
          RowBox[{"MWth", "^", "2"}]}], ")"}]}], "lambdaZ"}]}]}], ";", 
    RowBox[{"f2Z", "=", "lambdaZ"}], ";", 
    RowBox[{"f3Z", "=", 
     RowBox[{"1", "+", "kappaZ", "+", "lambdaZ"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"beta", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"4", 
         RowBox[{
          RowBox[{"MWth", "^", "2"}], "/", "S"}]}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"gamma", "=", 
     RowBox[{
      RowBox[{"Sqrt", "[", "S", "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"2", "MWth"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"sin", "=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"cos", "^", "2"}]}], ")"}], "^", 
      RowBox[{"(", 
       RowBox[{"1", "/", "2"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"For", " ", "simplicity"}], ",", " ", 
     RowBox[{
     "in", " ", "the", " ", "following", " ", "i", " ", "means", " ", 
      "\"\<-1\>\""}], ",", " ", 
     RowBox[{"z", " ", "means", " ", "\"\<-2\>\""}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d122", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", "cos"}], ")"}], "sin"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"diz2", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", "cos"}], ")"}], "sin"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d1z2", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "1"}], "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", "cos"}], ")"}], "sin"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"di22", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", "cos"}], ")"}], "sin"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d111", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", "cos"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dii1", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", "cos"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d1i1", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", "cos"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"di11", "=", 
     RowBox[{
      RowBox[{"1", "/", "2"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", "cos"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"d101", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "/", "2"}], "]"}]}], "sin"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"di01", "=", 
     RowBox[{
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "/", "2"}], "]"}], "sin"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tM1i1i", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tM1ii1", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMi11i", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], "/", "s02"}], " ", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"beta", "^", "2"}], "-", 
         RowBox[{"2", "beta", " ", "cos"}]}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", "ahl3", " ", "v2"}]}], ")"}], 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMi1i1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Sqrt", "[", "2", "]"}]}], "/", "s02"}], " ", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"beta", "^", "2"}], "-", 
         RowBox[{"2", "beta", " ", "cos"}]}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", "ahl3", " ", "v2"}]}], ")"}], 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AZ10", "=", 
     RowBox[{"gamma", " ", "f3Z"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AZ0i", "=", 
     RowBox[{"gamma", " ", "f3Z"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AZ01", "=", 
     RowBox[{"gamma", " ", "f3Z"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AZi0", "=", 
     RowBox[{"gamma", " ", "f3Z"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AZ11", "=", "f1Z"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AZii", "=", "f1Z"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"AZ00", "=", 
     RowBox[{
      RowBox[{"gamma", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"beta", "^", "2"}]}], ")"}]}], "f1Z"}], "+", 
        RowBox[{"4", 
         RowBox[{"gamma", "^", "2"}], " ", 
         RowBox[{"beta", "^", "2"}], " ", "f2Z"}], "+", 
        RowBox[{"2", " ", "f3Z"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Ag10", "=", 
     RowBox[{"gamma", " ", "f3g"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Ag0i", "=", 
     RowBox[{"gamma", " ", "f3g"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Ag01", "=", 
     RowBox[{"gamma", " ", "f3g"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Agi0", "=", 
     RowBox[{"gamma", " ", "f3g"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Ag11", "=", "f1g"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Agii", "=", "f1g"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Ag00", "=", 
     RowBox[{
      RowBox[{"gamma", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"beta", "^", "2"}]}], ")"}]}], "f1g"}], "+", 
        RowBox[{"4", 
         RowBox[{"gamma", "^", "2"}], " ", 
         RowBox[{"beta", "^", "2"}], " ", "f2g"}], "+", 
        RowBox[{"2", " ", "f3g"}]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"B10", "=", 
     RowBox[{"2", "gamma"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"B0i", "=", 
     RowBox[{"2", "gamma"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"B01", "=", 
     RowBox[{"2", "gamma"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Bi0", "=", 
     RowBox[{"2", "gamma"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"B11", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Bii", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"B00", "=", 
     RowBox[{"2", 
      RowBox[{"gamma", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"C10", "=", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "beta"}], ")"}], "/", "gamma"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"C0i", "=", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "beta"}], ")"}], "/", "gamma"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"C01", "=", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "beta"}], ")"}], "/", "gamma"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Ci0", "=", 
     RowBox[{"2", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", "beta"}], ")"}], "/", "gamma"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"C11", "=", 
     RowBox[{"1", "/", 
      RowBox[{"gamma", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Cii", "=", 
     RowBox[{"1", "/", 
      RowBox[{"gamma", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"C00", "=", 
     RowBox[{"2", "/", 
      RowBox[{"gamma", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMg1i10", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Ag10"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMg1i0i", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Ag0i"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMg1i01", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Ag01"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMg1ii0", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Agi0"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMg1i11", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Ag11"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMg1iii", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Agii"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMg1i00", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Ag00"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMgi110", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Ag10"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMgi10i", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Ag0i"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMgi101", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Ag01"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMgi1i0", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Agi0"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMgi111", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Ag11"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMgi1ii", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Agii"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMgi100", "=", 
     RowBox[{
      RowBox[{"-", "beta"}], " ", "Ag00"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZ1i10", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZ10", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gre", "/", "gre0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZ1i0i", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZ0i", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gre", "/", "gre0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZ1i01", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZ01", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gre", "/", "gre0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZ1ii0", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZi0", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gre", "/", "gre0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZ1i11", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZ11", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gre", "/", "gre0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZ1iii", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZii", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gre", "/", "gre0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZ1i00", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZ00", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gre", "/", "gre0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZi110", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "s02"}], ")"}]}]}], ")"}], 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZ10", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gle", "/", "gle0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZi10i", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "s02"}], ")"}]}]}], ")"}], 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZ0i", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gle", "/", "gle0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZi101", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "s02"}], ")"}]}]}], ")"}], 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZ01", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gle", "/", "gle0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZi1i0", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "s02"}], ")"}]}]}], ")"}], 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZi0", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gle", "/", "gle0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZi111", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "s02"}], ")"}]}]}], ")"}], 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZ11", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gle", "/", "gle0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZi1ii", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "s02"}], ")"}]}]}], ")"}], 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZii", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gle", "/", "gle0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMZi100", "=", 
     RowBox[{"beta", " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{"2", "s02"}], ")"}]}]}], ")"}], 
      RowBox[{"S", "/", 
       RowBox[{"(", 
        RowBox[{"S", "-", 
         RowBox[{"MZ", "^", "2"}]}], ")"}]}], " ", "AZ00", " ", 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}], " ", 
      RowBox[{"Zredf", "^", "2"}], 
      RowBox[{"(", 
       RowBox[{"gle", "/", "gle0"}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMnui110", "=", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"2", "s02", " ", "beta"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{"B10", "-", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"beta", "^", "2"}], "-", 
            RowBox[{"2", "beta", " ", "cos"}]}], ")"}]}], "C10"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", "ahl3", " ", "v2"}]}], ")"}], 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMnui10i", "=", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"2", "s02", " ", "beta"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{"B0i", "-", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"beta", "^", "2"}], "-", 
            RowBox[{"2", "beta", " ", "cos"}]}], ")"}]}], "C0i"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", "ahl3", " ", "v2"}]}], ")"}], 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMnui101", "=", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"2", "s02", " ", "beta"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{"B01", "-", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"beta", "^", "2"}], "-", 
            RowBox[{"2", "beta", " ", "cos"}]}], ")"}]}], "C01"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", "ahl3", " ", "v2"}]}], ")"}], 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMnui1i0", "=", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"2", "s02", " ", "beta"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{"Bi0", "-", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"beta", "^", "2"}], "-", 
            RowBox[{"2", "beta", " ", "cos"}]}], ")"}]}], "Ci0"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", "ahl3", " ", "v2"}]}], ")"}], 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMnui111", "=", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"2", "s02", " ", "beta"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{"B11", "-", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"beta", "^", "2"}], "-", 
            RowBox[{"2", "beta", " ", "cos"}]}], ")"}]}], "C11"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", "ahl3", " ", "v2"}]}], ")"}], 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMnui1ii", "=", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"2", "s02", " ", "beta"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{"Bii", "-", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"beta", "^", "2"}], "-", 
            RowBox[{"2", "beta", " ", "cos"}]}], ")"}]}], "Cii"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", "ahl3", " ", "v2"}]}], ")"}], 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMnui100", "=", 
     RowBox[{
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{"2", "s02", " ", "beta"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{"B00", "-", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"beta", "^", "2"}], "-", 
            RowBox[{"2", "beta", " ", "cos"}]}], ")"}]}], "C00"}]}], ")"}], 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", "ahl3", " ", "v2"}]}], ")"}], 
      RowBox[{
       RowBox[{"e0", "^", "2"}], "/", 
       RowBox[{"e", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMnu1i10", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMnu1i0i", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMnu1i01", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMnu1ii0", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMnu1i11", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMnu1iii", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMnu1i00", "=", "0"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tM1i10", "=", 
     RowBox[{"tMg1i10", "+", "tMZ1i10", "+", "tMnu1i10"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tM1i0i", "=", 
     RowBox[{"tMg1i0i", "+", "tMZ1i0i", "+", "tMnu1i0i"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tM1i01", "=", 
     RowBox[{"tMg1i01", "+", "tMZ1i01", "+", "tMnu1i01"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tM1ii0", "=", 
     RowBox[{"tMg1ii0", "+", "tMZ1ii0", "+", "tMnu1ii0"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tM1i11", "=", 
     RowBox[{"tMg1i11", "+", "tMZ1i11", "+", "tMnu1i11"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tM1i00", "=", 
     RowBox[{"tMg1i00", "+", "tMZ1i00", "+", "tMnu1i00"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tM1iii", "=", 
     RowBox[{"tMg1iii", "+", "tMZ1iii", "+", "tMnu1iii"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"tMi110", "=", 
     RowBox[{"tMgi110", "+", "tMZi110", "+", "tMnui110"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMi10i", "=", 
     RowBox[{"tMgi10i", "+", "tMZi10i", "+", "tMnui10i"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMi101", "=", 
     RowBox[{"tMgi101", "+", "tMZi101", "+", "tMnui101"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMi1i0", "=", 
     RowBox[{"tMgi1i0", "+", "tMZi1i0", "+", "tMnui1i0"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMi111", "=", 
     RowBox[{"tMgi111", "+", "tMZi111", "+", "tMnui111"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMi100", "=", 
     RowBox[{"tMgi100", "+", "tMZi100", "+", "tMnui100"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tMi1ii", "=", 
     RowBox[{"tMgi1ii", "+", "tMZi1ii", "+", "tMnui1ii"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"M1i1i", "=", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tM1i1i", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "d122"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"M1ii1", "=", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tM1ii1", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "d1z2"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"M1i10", "=", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tM1i10", " ", 
      RowBox[{"(", 
       RowBox[{"+", "1"}], ")"}], " ", "d111"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"M1i0i", "=", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tM1i0i", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "d111"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"M1i01", "=", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tM1i01", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "d1i1"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"M1ii0", "=", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tM1ii0", " ", 
      RowBox[{"(", 
       RowBox[{"+", "1"}], ")"}], " ", "d1i1"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"M1i11", "=", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tM1i11", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "d101"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"M1iii", "=", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tM1iii", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "d101"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"M1i00", "=", 
     RowBox[{
      RowBox[{"Sqrt", "[", "2", "]"}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tM1i00", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "d101"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Mi11i", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", "2", "]"}]}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tMi11i", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "di22"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Mi1i1", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", "2", "]"}]}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tMi1i1", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "diz2"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Mi110", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", "2", "]"}]}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tMi110", " ", 
      RowBox[{"(", 
       RowBox[{"+", "1"}], ")"}], " ", "di11"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Mi10i", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", "2", "]"}]}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tMi10i", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "di11"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Mi101", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", "2", "]"}]}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tMi101", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "dii1"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Mi1i0", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", "2", "]"}]}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tMi1i0", " ", 
      RowBox[{"(", 
       RowBox[{"+", "1"}], ")"}], " ", "dii1"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Mi111", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", "2", "]"}]}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tMi111", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "di01"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Mi1ii", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", "2", "]"}]}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tMi1ii", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "di01"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Mi100", "=", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Sqrt", "[", "2", "]"}]}], " ", 
      RowBox[{"e", "^", "2"}], " ", "tMi100", " ", 
      RowBox[{"(", 
       RowBox[{"-", "1"}], ")"}], " ", "di01"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"temp", "=", 
     RowBox[{
      RowBox[{"1", "/", "4"}], "gev2pbarn", " ", 
      RowBox[{"S", "^", 
       RowBox[{"(", 
        RowBox[{"1", "/", "2"}], ")"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"S", "/", "4"}], "-", "MW2"}], ")"}], "^", 
        RowBox[{"(", 
         RowBox[{"1", "/", "2"}], ")"}]}], "/", 
       RowBox[{"(", 
        RowBox[{"16", " ", "Pi", " ", 
         RowBox[{"S", "^", "2"}]}], ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmai1", "=", 
     RowBox[{"temp", " ", 
      RowBox[{"Mi1i1", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigma1i", "=", 
     RowBox[{"temp", " ", 
      RowBox[{"Mi11i", "^", "2"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigma10", "=", 
     RowBox[{"temp", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Mi110", "^", "2"}], "+", 
        RowBox[{"M1i10", "^", "2"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigma0i", "=", 
     RowBox[{"temp", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Mi10i", "^", "2"}], "+", 
        RowBox[{"M1i0i", "^", "2"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmai0", "=", 
     RowBox[{"temp", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Mi1i0", "^", "2"}], "+", 
        RowBox[{"M1ii0", "^", "2"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigma01", "=", 
     RowBox[{"temp", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Mi101", "^", "2"}], "+", 
        RowBox[{"M1i01", "^", "2"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigma11", "=", 
     RowBox[{"temp", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Mi111", "^", "2"}], "+", 
        RowBox[{"M1i11", "^", "2"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmaii", "=", 
     RowBox[{"temp", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Mi1ii", "^", "2"}], "+", 
        RowBox[{"M1iii", "^", "2"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigma00", "=", 
     RowBox[{"temp", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Mi100", "^", "2"}], "+", 
        RowBox[{"M1i00", "^", "2"}]}], ")"}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmaW", "=", 
     RowBox[{
     "dsigmai1", "+", "dsigma1i", "+", "dsigma10", "+", "dsigma0i", "+", 
      "dsigmai0", "+", "dsigma01", "+", "dsigma11", "+", "dsigmaii", "+", 
      "dsigma00"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"dsigmaWtr", "=", 
     RowBox[{"firstorder", "[", "dsigmaW", "]"}]}], ";"}], 
   "\[IndentingNewLine]"}]}]], "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
    "**"}], "**************************************************)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "          ", 
   RowBox[{"Calculate", " ", 
    SuperscriptBox["\[Chi]", "2"], " ", "from", " ", "different", " ", 
    "measurements"}], "                                                   ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
    "**"}], "**************************************************)"}]}]], \
"Section",
 FontSize->14],

Cell[CellGroupData[{

Cell["chi2: Z pole observables", "Subsection",
 CellChangeTimes->{{3.5109208706294017`*^9, 3.510920896385047*^9}}],

Cell[CellGroupData[{

Cell["chi2MW: W mass ", "Subsubsection",
 CellChangeTimes->{3.5106639051949615`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"chi2MW", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"MWth", "-", "MWexp1"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errMW1", "^", "2"}], "+", 
       RowBox[{"therrMW", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"MWth", "-", "MWexp2"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errMW2", "^", "2"}], "+", 
       RowBox[{"therrMW", "^", "2"}]}], ")"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5106639011857543`*^9, 3.5106639093601685`*^9}, {
   3.522579459865943*^9, 3.522579471628363*^9}, {3.5292567455398407`*^9, 
   3.529256753090254*^9}, {3.5292609107939568`*^9, 3.529260913165161*^9}, {
   3.5387458594624605`*^9, 3.5387458681489577`*^9}, 3.5405385505303807`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["chi2Zline: Z line shape and lepton FB asymmetries", "Subsubsection",
 CellChangeTimes->{
  3.510663937206218*^9, {3.535374798816877*^9, 3.5353748108925676`*^9}, {
   3.5353752018709297`*^9, 3.535375210278411*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"thsZline", "=", 
   RowBox[{"{", 
    RowBox[{
    "GammaZth", ",", "sigmah0th", ",", "Reth", ",", "Rmuth", ",", "Rtauth", 
     ",", "AFB0eth", ",", "AFB0muth", ",", "AFB0tauth"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"therrsZline", "=", 
   RowBox[{"{", 
    RowBox[{
    "therrGammaZ", ",", "therrsigmah0", ",", "therrRe", ",", "therrRmu", ",", 
     "therrRtau", ",", "therrAFB0e", ",", "therrAFB0mu", ",", 
     "therrAFB0tau"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"thcorrZline", "=", 
   RowBox[{"IdentityMatrix", "[", "8", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi2Zline", "=", 
   RowBox[{"chi2corr", "[", 
    RowBox[{
    "expsZline", ",", "errsZline", ",", "corrsZline", ",", "thsZline", ",", 
     "therrsZline", ",", "thcorrZline"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.510663930669806*^9, 3.510663932463809*^9}, 
   3.5106639680474715`*^9, {3.5353747979768286`*^9, 3.5353748083774233`*^9}, 
   3.535375094327779*^9, {3.5353752043250704`*^9, 3.5353752393330727`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
chi2bc: Z pole hadronic observables\
\>", "Subsubsection",
 CellChangeTimes->{{3.510663954803048*^9, 3.510663960715459*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"thsbc", "=", 
   RowBox[{"{", 
    RowBox[{
    "Rbth", ",", "Rcth", ",", "AFB0bth", ",", "AFB0cth", ",", "Abth", ",", 
     "Acth"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"therrsbc", "=", 
   RowBox[{"{", 
    RowBox[{
    "therrRb", ",", "therrRc", ",", "therrAFB0b", ",", "therrAFB0c", ",", 
     "therrAb", ",", "therrAc"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"thcorrbc", "=", 
   RowBox[{"IdentityMatrix", "[", "6", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi2bc", "=", 
   RowBox[{"chi2corr", "[", 
    RowBox[{
    "expsbc", ",", "errsbc", ",", "corrsbc", ",", "thsbc", ",", "therrsbc", 
     ",", "thcorrbc"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5106639522134438`*^9, 3.5106639661130686`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
chi2QFB: Effective weak angle from inclusive hadronic charge asymmetry QFB\
\>", "Subsubsection",
 CellChangeTimes->{3.5106639810578947`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"chi2QFB", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"sin2effth", "-", "sin2effexp"}], ")"}], "^", "2"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"errsin2eff", "^", "2"}], "+", 
      RowBox[{"therrsin2eff", "^", "2"}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.510663976845887*^9, 3.5106639790610914`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
chi2pol: Polarization asymmetries\
\>", "Subsubsection",
 CellChangeTimes->{{3.5106639957843204`*^9, 3.5106639980931244`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi2pol", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Aeth", "-", "Aeexp1"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errAe1", "^", "2"}], "+", 
       RowBox[{"therrAe", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Aeth", "-", "Aeexp2"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errAe2", "^", "2"}], "+", 
       RowBox[{"therrAe", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Aeth", "-", "Aeexp3"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errAe3", "^", "2"}], "+", 
       RowBox[{"therrAe", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Amuth", "-", "Amuexp"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errAmu", "^", "2"}], "+", 
       RowBox[{"therrAmu", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Atauth", "-", "Atauexp1"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errAtau1", "^", "2"}], "+", 
       RowBox[{"therrAtau", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Atauth", "-", "Atauexp2"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errAtau2", "^", "2"}], "+", 
       RowBox[{"therrAtau", "^", "2"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi2As", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Asth", "-", "Asexp"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errAs", "^", "2"}], "+", 
       RowBox[{"therrAs", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"AFB0sth", "-", "AFB0sexp"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errAFB0s", "^", "2"}], "+", 
       RowBox[{"therrAFB0s", "^", "2"}]}], ")"}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.510922536213127*^9, 3.5109225432331395`*^9}, {
  3.5292567719506874`*^9, 3.529256782059505*^9}, {3.5292617307781973`*^9, 
  3.5292617362850065`*^9}, {3.536058417226071*^9, 3.536058425137336*^9}, {
  3.5360596157458677`*^9, 3.536059622773432*^9}, {3.536059735827467*^9, 
  3.5360597621568933`*^9}, {3.5387434265223045`*^9, 3.5387434420051904`*^9}, {
  3.5387458874130597`*^9, 3.538745910511381*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["chi2DIS: DIS", "Subsubsection",
 CellChangeTimes->{{3.5106640132407513`*^9, 3.5106640190439615`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi2DIS", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"gVeth", "-", "gVeexp"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errgVe", "^", "2"}], "+", 
       RowBox[{"therrgVe", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"gAeth", "-", "gAeexp"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errgAe", "^", "2"}], "+", 
       RowBox[{"therrgAe", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"RnuthCDHS", "-", "RnuexpCDHS"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"therrRnu", "^", "2"}], "+", 
       RowBox[{"errRnuCDHS", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"RnuthCHARM", "-", "RnuexpCHARM"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"therrRnu", "^", "2"}], "+", 
       RowBox[{"errRnuCHARM", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"kappath", "-", "kappaexp"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errkappa", "^", "2"}], "+", 
       RowBox[{"therrkappa", "^", "2"}]}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"NUTE", "\[Equal]", "1"}], ",", 
    RowBox[{"chi2DIS", "=", 
     RowBox[{"chi2DIS", "+", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gL2th", "-", "gL2exp"}], ")"}], "^", "2"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"errgL2", "^", "2"}], "+", 
         RowBox[{"therrgL2", "^", "2"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"gR2th", "-", "gR2exp"}], ")"}], "^", "2"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"errgR2", "^", "2"}], "+", 
         RowBox[{"therrgR2", "^", "2"}]}], ")"}]}]}]}]}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5106640106823463`*^9, 3.5106640115715485`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
chi2QW: Atomic parity violation\
\>", "Subsubsection",
 CellChangeTimes->{3.5106640533172216`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"chi2QW", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"QWCsth", "-", "QWCsexp"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errQWCs", "^", "2"}], "+", 
       RowBox[{"therrQWCs", "^", "2"}]}], ")"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"QWTlth", "-", "QWTlexp"}], ")"}], "^", "2"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"errQWTl", "^", "2"}], "+", 
       RowBox[{"therrQWTl", "^", "2"}]}], ")"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.510664029043579*^9, 3.5106640303851814`*^9}, 
   3.5106670572869687`*^9}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["chi2: fermion pair production at LEP II", "Subsection",
 CellChangeTimes->{{3.5106670595957727`*^9, 3.5106670724657955`*^9}}],

Cell[CellGroupData[{

Cell["\<\
chi2hadLEP: Hadronic cross-sections\
\>", "Subsubsection",
 CellChangeTimes->{{3.510667065430183*^9, 3.510667068487788*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"imax", "=", 
   RowBox[{"Length", "[", "sigmahadLEP", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigmath", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"0", ",", "imax"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"sigma0", "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", 
      RowBox[{"-", "1"}], "1"], 
     RowBox[{"dsigmahadtr", 
      RowBox[{"\[DifferentialD]", "cos"}]}]}]}], ";"}]}], "\n", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "  ", 
      RowBox[{
       RowBox[{"RS", "=", 
        RowBox[{"RSLEP", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", "  ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"RADI", "==", "1"}], ",", 
         RowBox[{"temp", "=", 
          RowBox[{"radcorrt", "[", 
           RowBox[{"sigma0", ",", "RS"}], "]"}]}], ",", 
         RowBox[{"temp", "=", 
          RowBox[{"sigma0", "/.", 
           RowBox[{"S", "\[Rule]", 
            RowBox[{"RS", "^", "2"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "  ", 
       RowBox[{
        RowBox[{"sigmath", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "=", 
        RowBox[{
         RowBox[{"sigmahadSMLEP", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "+", "temp"}]}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"therrsigmahadLEP", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"0", ",", "imax"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "<", 
      RowBox[{"imax", "+", "1"}]}], ",", 
     RowBox[{"i", "++"}], ",", " ", 
     RowBox[{
      RowBox[{"therrsigmahadLEP", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "=", "0"}]}], "]"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"theoretical", " ", "errors", " ", "negligible"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"thcorrsigmahadLEP", "=", 
   RowBox[{"IdentityMatrix", "[", "imax", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi2hadLEP", "=", 
   RowBox[{"chi2corr", "[", 
    RowBox[{
    "sigmahadLEP", ",", "errsigmahadLEP", ",", "crsigmahadLEP", ",", 
     "sigmath", ",", "therrsigmahadLEP", ",", "thcorrsigmahadLEP"}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{3.5106670839942155`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["chi2muLEP: Muon pair cross-sections and asymmetries", "Subsubsection",
 CellChangeTimes->{{3.5106671183610764`*^9, 3.510667121184681*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi2muLEP", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"imax", "=", 
   RowBox[{"Length", "[", "sigmamuLEP", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"errmatrix", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"imax", ",", "imax"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigmadev", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"1", ",", "imax"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"afbdev", "=", 
    RowBox[{"Array", "[", 
     RowBox[{"1", ",", "imax"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "<", 
      RowBox[{"imax", "+", "1"}]}], ",", 
     RowBox[{"i", "++"}], ",", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "     ", 
       RowBox[{
        RowBox[{"RS", "=", 
         RowBox[{"RSLEP", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        "      ", 
        RowBox[{"sigma0", "=", 
         RowBox[{
          SubsuperscriptBox["\[Integral]", 
           RowBox[{"-", "1"}], "1"], 
          RowBox[{"dsigmamutr", 
           RowBox[{"\[DifferentialD]", "cos"}]}]}]}], ";", 
        "\[IndentingNewLine]", "      ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"RADI", "==", "1"}], ",", 
          RowBox[{"sigmatr", "=", 
           RowBox[{"radcorrt", "[", 
            RowBox[{"sigma0", ",", "RS"}], "]"}]}], ",", 
          RowBox[{"sigmatr", "=", 
           RowBox[{"sigma0", "/.", 
            RowBox[{"S", "\[Rule]", 
             RowBox[{"RS", "^", "2"}]}]}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", "      ", 
        RowBox[{"sigmath", "=", 
         RowBox[{
          RowBox[{"sigmamuSMLEP", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", "sigmatr"}]}], ";", 
        "\[IndentingNewLine]", "      ", 
        RowBox[{
         RowBox[{"sigmadev", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "=", 
         RowBox[{"sigmath", "-", 
          RowBox[{"sigmamuLEP", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
        "      ", 
        RowBox[{"sigma0", "=", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Integral]", "0", "1"], 
           RowBox[{"dsigmamutr", 
            RowBox[{"\[DifferentialD]", "cos"}]}]}], "-", 
          RowBox[{
           SubsuperscriptBox["\[Integral]", 
            RowBox[{"-", "1"}], "0"], 
           RowBox[{"dsigmamutr", 
            RowBox[{"\[DifferentialD]", "cos"}]}]}]}]}], ";", 
        "\[IndentingNewLine]", "      ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"RADI", "==", "1"}], ",", 
          RowBox[{"sigmafbtr", "=", 
           RowBox[{"radcorrfb", "[", 
            RowBox[{"sigma0", ",", "RS"}], "]"}]}], ",", 
          RowBox[{"sigmafbtr", "=", 
           RowBox[{"sigma0", "/.", 
            RowBox[{"S", "\[Rule]", 
             RowBox[{"RS", "^", "2"}]}]}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", "      ", 
        RowBox[{"afbth", "=", 
         RowBox[{
          RowBox[{"afbmuSMLEP", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", 
          FractionBox["sigmafbtr", 
           RowBox[{"sigmamuSMLEP", "[", 
            RowBox[{"[", "i", "]"}], "]"}]], "-", 
          RowBox[{
           RowBox[{"afbmuSMLEP", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "*", 
           FractionBox["sigmatr", 
            RowBox[{"sigmamuSMLEP", "[", 
             RowBox[{"[", "i", "]"}], "]"}]]}]}]}], ";", 
        "\[IndentingNewLine]", "      ", 
        RowBox[{
         RowBox[{"afbdev", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "=", 
         RowBox[{"afbth", "-", 
          RowBox[{"afbmuLEP", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}]}], ";"}]}], "\[IndentingNewLine]",
       "   ", "]"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "<", 
       RowBox[{"imax", "+", "1"}]}], ",", 
      RowBox[{"j", "++"}], ",", 
      RowBox[{
       RowBox[{"errmatrix", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"0.004", "^", "2"}], "  ", 
        RowBox[{"sigmamuLEP", "[", 
         RowBox[{"[", "i", "]"}], "]"}], " ", 
        RowBox[{"sigmamuLEP", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}]}]}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{
     RowBox[{"errmatrix", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "i"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"errmatrix", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "i"}], "]"}], "]"}], "+", 
      RowBox[{
       RowBox[{"errsigmamuLEP", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "^", "2"}]}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"errmatrixinv", "=", 
   RowBox[{"Inverse", "[", "errmatrix", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "<", 
      RowBox[{"imax", "+", "1"}]}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"j", "<", 
        RowBox[{"imax", "+", "1"}]}], ",", 
       RowBox[{"j", "++"}], ",", 
       RowBox[{"chi2muLEP", "=", 
        RowBox[{"chi2muLEP", "+", 
         RowBox[{
          RowBox[{"sigmadev", "[", 
           RowBox[{"[", "i", "]"}], "]"}], 
          RowBox[{"errmatrixinv", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", 
          RowBox[{"sigmadev", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}]}]}]}], "]"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "<", 
       RowBox[{"imax", "+", "1"}]}], ",", 
      RowBox[{"j", "++"}], ",", 
      RowBox[{
       RowBox[{"errmatrix", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"0.004", "^", "2"}], "  ", 
        RowBox[{"afbmuLEP", "[", 
         RowBox[{"[", "i", "]"}], "]"}], " ", 
        RowBox[{"afbmuLEP", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}]}]}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{
     RowBox[{"errmatrix", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "i"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"errmatrix", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "i"}], "]"}], "]"}], "+", 
      RowBox[{
       RowBox[{"errafbmuLEP", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "^", "2"}]}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"errmatrixinv", "=", 
   RowBox[{"Inverse", "[", "errmatrix", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "<", 
       RowBox[{"imax", "+", "1"}]}], ",", 
      RowBox[{"j", "++"}], ",", 
      RowBox[{"chi2muLEP", "=", 
       RowBox[{"chi2muLEP", "+", 
        RowBox[{
         RowBox[{"afbdev", "[", 
          RowBox[{"[", "i", "]"}], "]"}], 
         RowBox[{"errmatrixinv", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", 
         RowBox[{"afbdev", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}]}]}]}], "]"}]}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.510667094820635*^9, 3.5106671112786636`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["chi2tauLEP: Tau pair cross-sections and asymmetries", "Subsubsection",
 CellChangeTimes->{{3.510667132728701*^9, 3.510667135318306*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi2tauLEP", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"imax", "=", 
   RowBox[{"Length", "[", "sigmatauLEP", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"errmatrix", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{"imax", ",", "imax"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigmadev", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"1", ",", "imax"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"afbdev", "=", 
    RowBox[{"Array", "[", 
     RowBox[{"1", ",", "imax"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "<", 
      RowBox[{"imax", "+", "1"}]}], ",", 
     RowBox[{"i", "++"}], ",", 
     RowBox[{"Block", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "     ", 
       RowBox[{
        RowBox[{"RS", "=", 
         RowBox[{"RSLEP", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        "      ", 
        RowBox[{"sigma0", "=", 
         RowBox[{
          SubsuperscriptBox["\[Integral]", 
           RowBox[{"-", "1"}], "1"], 
          RowBox[{"dsigmatautr", 
           RowBox[{"\[DifferentialD]", "cos"}]}]}]}], ";", 
        "\[IndentingNewLine]", "      ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"RADI", "==", "1"}], ",", 
          RowBox[{"sigmatr", "=", 
           RowBox[{"radcorrt", "[", 
            RowBox[{"sigma0", ",", "RS"}], "]"}]}], ",", 
          RowBox[{"sigmatr", "=", 
           RowBox[{"sigma0", "/.", 
            RowBox[{"S", "\[Rule]", 
             RowBox[{"RS", "^", "2"}]}]}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", "      ", 
        RowBox[{"sigmath", "=", 
         RowBox[{
          RowBox[{"sigmatauSMLEP", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "+", "sigmatr"}]}], ";", 
        "\[IndentingNewLine]", "     ", 
        RowBox[{
         RowBox[{"sigmadev", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "=", 
         RowBox[{"sigmath", "-", 
          RowBox[{"sigmatauLEP", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
        "      ", 
        RowBox[{"sigma0", "=", 
         RowBox[{
          RowBox[{
           SubsuperscriptBox["\[Integral]", "0", "1"], 
           RowBox[{"dsigmatautr", 
            RowBox[{"\[DifferentialD]", "cos"}]}]}], "-", 
          RowBox[{
           SubsuperscriptBox["\[Integral]", 
            RowBox[{"-", "1"}], "0"], 
           RowBox[{"dsigmatautr", 
            RowBox[{"\[DifferentialD]", "cos"}]}]}]}]}], ";", 
        "\[IndentingNewLine]", "      ", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"RADI", "==", "1"}], ",", 
          RowBox[{"sigmafbtr", "=", 
           RowBox[{"radcorrfb", "[", 
            RowBox[{"sigma0", ",", "RS"}], "]"}]}], ",", 
          RowBox[{"sigmafbtr", "=", 
           RowBox[{"sigma0", "/.", 
            RowBox[{"S", "\[Rule]", 
             RowBox[{"RS", "^", "2"}]}]}]}]}], "]"}], ";", 
        "\[IndentingNewLine]", "      ", 
        RowBox[{"afbth", "=", 
         RowBox[{
          RowBox[{
           RowBox[{"afbtauSMLEP", "[", 
            RowBox[{"[", "i", "]"}], "]"}], 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             FractionBox["sigmatr", 
              RowBox[{"sigmatauSMLEP", "[", 
               RowBox[{"[", "i", "]"}], "]"}]]}], ")"}]}], "+", 
          FractionBox["sigmafbtr", 
           RowBox[{"sigmatauSMLEP", "[", 
            RowBox[{"[", "i", "]"}], "]"}]]}]}], ";", "\[IndentingNewLine]", 
        "      ", 
        RowBox[{
         RowBox[{"afbdev", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "=", " ", 
         RowBox[{"afbth", "-", 
          RowBox[{"afbtauLEP", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}]}], ";"}]}], "\[IndentingNewLine]",
       "   ", "]"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "<", 
       RowBox[{"imax", "+", "1"}]}], ",", 
      RowBox[{"j", "++"}], ",", 
      RowBox[{
       RowBox[{"errmatrix", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"\[Delta]SMerrsigmatau", "^", "2"}], "  ", 
        RowBox[{"sigmatauSMLEP", "[", 
         RowBox[{"[", "i", "]"}], "]"}], " ", 
        RowBox[{"sigmatauSMLEP", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}]}]}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{
     RowBox[{"errmatrix", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "i"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"errmatrix", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "i"}], "]"}], "]"}], "+", 
      RowBox[{
       RowBox[{"errsigmatauLEP", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "^", "2"}]}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"errmatrixinv", "=", 
   RowBox[{"Inverse", "[", "errmatrix", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "<", 
      RowBox[{"imax", "+", "1"}]}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"j", "=", "1"}], ",", 
       RowBox[{"j", "<", 
        RowBox[{"imax", "+", "1"}]}], ",", 
       RowBox[{"j", "++"}], ",", 
       RowBox[{"chi2tauLEP", "=", 
        RowBox[{"chi2tauLEP", "+", 
         RowBox[{
          RowBox[{"sigmadev", "[", 
           RowBox[{"[", "i", "]"}], "]"}], 
          RowBox[{"errmatrixinv", "[", 
           RowBox[{"[", 
            RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", 
          RowBox[{"sigmadev", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}]}]}]}], "]"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "<", 
       RowBox[{"imax", "+", "1"}]}], ",", 
      RowBox[{"j", "++"}], ",", 
      RowBox[{
       RowBox[{"errmatrix", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"\[Delta]SMerrfbtau", "^", "2"}], "  ", 
        RowBox[{"afbtauSMLEP", "[", 
         RowBox[{"[", "i", "]"}], "]"}], " ", 
        RowBox[{"afbtauSMLEP", "[", 
         RowBox[{"[", "j", "]"}], "]"}]}]}]}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{
     RowBox[{"errmatrix", "[", 
      RowBox[{"[", 
       RowBox[{"i", ",", "i"}], "]"}], "]"}], "=", 
     RowBox[{
      RowBox[{"errmatrix", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "i"}], "]"}], "]"}], "+", 
      RowBox[{
       RowBox[{"errafbtauLEP", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "^", "2"}]}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"errmatrixinv", "=", 
   RowBox[{"Inverse", "[", "errmatrix", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "<", 
       RowBox[{"imax", "+", "1"}]}], ",", 
      RowBox[{"j", "++"}], ",", 
      RowBox[{"chi2tauLEP", "=", 
       RowBox[{"chi2tauLEP", "+", 
        RowBox[{
         RowBox[{"afbdev", "[", 
          RowBox[{"[", "i", "]"}], "]"}], 
         RowBox[{"errmatrixinv", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}], " ", 
         RowBox[{"afbdev", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}]}]}]}], "]"}]}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{
  3.515912190884297*^9, 3.515912298945687*^9, 3.516012501980811*^9, 
   3.516012860890641*^9, 3.516707179781782*^9, {3.5287422930525*^9, 
   3.528742300088112*^9}, {3.5287431548760133`*^9, 3.5287431618648252`*^9}, {
   3.5287434887321997`*^9, 3.5287435053462286`*^9}, {3.5287440788968363`*^9, 
   3.5287440891928544`*^9}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
chi2eOPAL: Electron pair differential cross-sections\
\>", "Subsection",
 CellChangeTimes->{{3.5106671674075623`*^9, 3.5106671698255663`*^9}}],

Cell[CellGroupData[{

Cell["OPAL data", "Subsubsection",
 CellChangeTimes->{{3.510667182180788*^9, 3.510667184333592*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi2e", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"dev", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"0", ",", "105"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"errmatrix2", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", 
      RowBox[{"105", ",", "105"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"jj", "=", "1"}], ",", 
    RowBox[{"jj", "<", "8"}], ",", 
    RowBox[{"jj", "++"}], ",", "\[IndentingNewLine]", "    ", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"kk", "=", "1"}], ",", 
      RowBox[{"kk", "<", "8"}], ",", 
      RowBox[{"kk", "++"}], ",", "\[IndentingNewLine]", "    ", 
      RowBox[{"For", " ", "[", 
       RowBox[{
        RowBox[{"j", "=", "1"}], ",", 
        RowBox[{"j", "<", "16"}], ",", 
        RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", "      ", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"k", "=", "1"}], ",", 
          RowBox[{"k", "<", "16"}], ",", 
          RowBox[{"k", "++"}], ",", " ", 
          RowBox[{"Block", "[", 
           RowBox[{
            RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "     ", 
            RowBox[{"(*", 
             RowBox[{
              RowBox[{
               RowBox[{"errmatrix2", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"15", 
                    RowBox[{"(", 
                    RowBox[{"jj", "-", "1"}], ")"}]}], "+", "j"}], ",", 
                  RowBox[{
                   RowBox[{"15", 
                    RowBox[{"(", 
                    RowBox[{"kk", "-", "1"}], ")"}]}], "+", "k"}]}], "]"}], 
                "]"}], "=", 
               RowBox[{
                RowBox[{"DSYS2", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"15", 
                    RowBox[{"(", 
                    RowBox[{"jj", "-", "1"}], ")"}]}], "+", "j"}], ",", 
                   RowBox[{
                    RowBox[{"15", 
                    RowBox[{"(", 
                    RowBox[{"kk", "-", "1"}], ")"}]}], "+", "k"}]}], "]"}], 
                 "]"}], "*", 
                RowBox[{"dsigmaeOPAL", "[", 
                 RowBox[{"[", 
                  RowBox[{"jj", ",", "j"}], "]"}], "]"}], "*", 
                RowBox[{"dsigmaeOPAL", "[", 
                 RowBox[{"[", 
                  RowBox[{"kk", ",", "k"}], "]"}], "]"}]}]}], ";"}], "*)"}], 
            "\[IndentingNewLine]", "      ", 
            RowBox[{
             RowBox[{
              RowBox[{"errmatrix2", "[", 
               RowBox[{"[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"15", 
                   RowBox[{"(", 
                    RowBox[{"jj", "-", "1"}], ")"}]}], "+", "j"}], ",", 
                 RowBox[{
                  RowBox[{"15", 
                   RowBox[{"(", 
                    RowBox[{"kk", "-", "1"}], ")"}]}], "+", "k"}]}], "]"}], 
               "]"}], "=", 
              RowBox[{
               RowBox[{"DSYS2", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"15", 
                    RowBox[{"(", 
                    RowBox[{"jj", "-", "1"}], ")"}]}], "+", "j"}], ",", 
                  RowBox[{
                   RowBox[{"15", 
                    RowBox[{"(", 
                    RowBox[{"kk", "-", "1"}], ")"}]}], "+", "k"}]}], "]"}], 
                "]"}], "*", 
               RowBox[{"dsigmaeSM", "[", 
                RowBox[{"[", 
                 RowBox[{"jj", ",", "j"}], "]"}], "]"}], "*", 
               RowBox[{"dsigmaeSM", "[", 
                RowBox[{"[", 
                 RowBox[{"kk", ",", "k"}], "]"}], "]"}]}]}], ";", 
             "\[IndentingNewLine]", "       ", 
             RowBox[{"If", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"j", "\[Equal]", "k"}], "&&", 
                RowBox[{"jj", "==", "kk"}]}], ",", 
               RowBox[{
                RowBox[{"errmatrix2", "[", 
                 RowBox[{"[", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"15", 
                    RowBox[{"(", 
                    RowBox[{"jj", "-", "1"}], ")"}]}], "+", "j"}], ",", 
                   RowBox[{
                    RowBox[{"15", 
                    RowBox[{"(", 
                    RowBox[{"kk", "-", "1"}], ")"}]}], "+", "k"}]}], "]"}], 
                 "]"}], "=", 
                RowBox[{
                 RowBox[{"errmatrix2", "[", 
                  RowBox[{"[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"15", 
                    RowBox[{"(", 
                    RowBox[{"jj", "-", "1"}], ")"}]}], "+", "j"}], ",", 
                    RowBox[{
                    RowBox[{"15", 
                    RowBox[{"(", 
                    RowBox[{"kk", "-", "1"}], ")"}]}], "+", "k"}]}], "]"}], 
                  "]"}], "+", 
                 RowBox[{
                  RowBox[{"errdsigmaeOPAL", "[", 
                   RowBox[{"[", 
                    RowBox[{"jj", ",", "j"}], "]"}], "]"}], "^", "2"}]}]}]}], 
              "]"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}], 
       "]"}]}], "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5106671807143855`*^9, 3.5106671896688013`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Error matrices", "Subsubsection",
 CellChangeTimes->{{3.510667206485631*^9, 3.5106672083420343`*^9}, {
  3.5109209530755463`*^9, 3.510920956710353*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"errmatrix", "//", "MatrixForm"}], "]"}], ";"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"errmatrixinv2", "=", 
     RowBox[{"Inverse", "[", "errmatrix2", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "<", "8"}], ",", 
      RowBox[{"i", "++"}], ",", 
      RowBox[{"Block", "[", 
       RowBox[{
        RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "  ", 
        RowBox[{
         RowBox[{"RS", "=", 
          RowBox[{"RSOPAL", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
         "    ", 
         RowBox[{"For", "[", 
          RowBox[{
           RowBox[{"j", "=", "1"}], ",", 
           RowBox[{"j", "<", "16"}], ",", 
           RowBox[{"j", "++"}], ",", 
           RowBox[{"Block", "[", 
            RowBox[{
             RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "        ", 
             RowBox[{
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"j", "\[LessEqual]", "5"}], ",", 
                RowBox[{
                 RowBox[{"cos0", "=", 
                  RowBox[{
                   RowBox[{"-", "0.99"}], "+", 
                   RowBox[{"0.18", "*", "j"}]}]}], ";", 
                 RowBox[{"cos1", "=", 
                  RowBox[{"cos0", "-", "0.09"}]}], ";", 
                 RowBox[{"cos2", "=", 
                  RowBox[{"cos0", "+", "0.09"}]}]}], ",", 
                RowBox[{
                 RowBox[{"cos0", "=", 
                  RowBox[{"0.045", "+", 
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"j", "-", "6"}], ")"}], "*", "0.09"}]}]}], ";", 
                 RowBox[{"cos1", "=", 
                  RowBox[{"cos0", "-", "0.045"}]}], ";", 
                 RowBox[{"cos2", "=", 
                  RowBox[{"cos0", "+", "0.045"}]}]}]}], "]"}], ";", 
              "\[IndentingNewLine]", "        ", 
              RowBox[{"tempdsigma", "=", 
               RowBox[{"dsigmaetr", "/.", 
                RowBox[{"S", "\[Rule]", 
                 RowBox[{"RS", "^", "2"}]}]}]}], ";", "\[IndentingNewLine]", 
              "        ", 
              RowBox[{"(*", 
               RowBox[{
                RowBox[{"sigmath", "=", 
                 RowBox[{
                  RowBox[{"dsigmaeSM", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}], "+", 
                  RowBox[{"real", "[", 
                   RowBox[{
                    RowBox[{"Integrate", "[", 
                    RowBox[{"tempdsigma", ",", 
                    RowBox[{"{", 
                    RowBox[{"cos", ",", "cos1", ",", "cos2"}], "}"}]}], "]"}],
                     "/", 
                    RowBox[{"(", 
                    RowBox[{"cos2", "-", "cos1"}], ")"}]}], "]"}]}]}], ";"}], 
               "*)"}], "\[IndentingNewLine]", "       ", 
              RowBox[{"sigmath", "=", 
               RowBox[{
                RowBox[{
                 RowBox[{"dsigmaeSM", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "j"}], "]"}], "]"}], "+", "dsigmaetr"}], 
                "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"S", "\[Rule]", 
                   RowBox[{"RS", "^", "2"}]}], ",", 
                  RowBox[{"cos", "\[Rule]", "cos0"}]}], "}"}]}]}], ";", 
              "\[IndentingNewLine]", "      ", 
              RowBox[{
               RowBox[{"dev", "[", 
                RowBox[{"[", 
                 RowBox[{
                  RowBox[{"15", 
                   RowBox[{"(", 
                    RowBox[{"i", "-", "1"}], ")"}]}], "+", "j"}], "]"}], 
                "]"}], "=", 
               RowBox[{"sigmath", "-", 
                RowBox[{"dsigmaeOPAL", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], ";"}]}], 
            "\[IndentingNewLine]", "  ", "]"}]}], "]"}], ";"}]}], "   ", 
       "\[IndentingNewLine]", "   ", "]"}]}], "\[IndentingNewLine]", " ", 
     "]"}], ";"}], "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Print", "[", 
      RowBox[{"errmatrixinv", "//", "MatrixForm"}], "]"}], ";"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "<", "106"}], ",", 
      RowBox[{"j", "++"}], ",", 
      RowBox[{"Block", "[", 
       RowBox[{
        RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"k", "=", "1"}], ",", 
          RowBox[{"k", "<", "106"}], ",", 
          RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", "     ", 
          RowBox[{
           RowBox[{"chi2e", "=", 
            RowBox[{"chi2e", "+", 
             RowBox[{"Expand", "[", 
              RowBox[{
               RowBox[{"dev", "[", 
                RowBox[{"[", "j", "]"}], "]"}], "*", 
               RowBox[{"errmatrixinv2", "[", 
                RowBox[{"[", 
                 RowBox[{"j", ",", "k"}], "]"}], "]"}], "*", 
               RowBox[{"dev", "[", 
                RowBox[{"[", "k", "]"}], "]"}]}], "]"}]}]}], ";"}]}], 
         "\[IndentingNewLine]", "]"}]}], "]"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"chi2eOPAL", "=", "chi2e"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.5106672434576955`*^9, 3.510667243613696*^9}, {
  3.510920950345542*^9, 3.510920958831957*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["chi2WL3: W pair production differential cross-sections", "Subsection",
 CellChangeTimes->{{3.510667224644063*^9, 3.510667253410513*^9}}],

Cell[CellGroupData[{

Cell["L3 data", "Subsubsection",
 CellChangeTimes->{3.5106672600405245`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi2WL3", "=", "0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"imax", "=", 
   RowBox[{"Length", "[", "RSL3", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"jmax", "=", 
   RowBox[{"Length", "[", 
    RowBox[{"dsigmaWL3", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "  ", 
      RowBox[{
       RowBox[{"RS", "=", 
        RowBox[{"RSL3", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", " ", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"j", "=", "1"}], ",", 
         RowBox[{"j", "<", 
          RowBox[{"jmax", "+", "1"}]}], ",", 
         RowBox[{"j", "++"}], ",", 
         RowBox[{"Block", "[", 
          RowBox[{
           RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "    ", 
           RowBox[{
            RowBox[{"ang", "=", 
             RowBox[{
              RowBox[{"-", "0.9"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"j", "-", "1"}], ")"}], "*", "0.2"}]}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{
             "The", " ", "branching", " ", "fractions", " ", "for", " ", "W", 
              " ", "decay", " ", "are", " ", "affected", " ", "by", " ", 
              "operators", " ", "ahq3", " ", "and", " ", "ahl3"}], " ", 
             "*)"}], "\[IndentingNewLine]", "   ", 
            RowBox[{"dGammahad", "=", 
             RowBox[{"2", " ", "v2", " ", "ahq3"}]}], ";", 
            RowBox[{"dGammalep", "=", 
             RowBox[{"2", " ", "v2", " ", "ahl3"}]}], ";", 
            "\[IndentingNewLine]", "    ", 
            RowBox[{"dsigmath", "=", " ", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"dsigmaWSM", "[", 
                 RowBox[{"[", 
                  RowBox[{"i", ",", "j"}], "]"}], "]"}], 
                RowBox[{"(", 
                 RowBox[{"1", "+", 
                  RowBox[{
                   RowBox[{"1", "/", "3"}], " ", "dGammalep"}], "-", 
                  RowBox[{
                   RowBox[{"1", "/", "3"}], "dGammahad"}]}], ")"}]}], "+", 
               RowBox[{"0.29245", "dsigmaWtr"}]}], "/.", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"S", "\[Rule]", 
                 RowBox[{"RS", "^", "2"}]}], ",", 
                RowBox[{"cos", "\[Rule]", "ang"}]}], "}"}]}]}], ";", 
            "\[IndentingNewLine]", "   ", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"dsigmath", "=", " ", 
               RowBox[{
                RowBox[{
                 RowBox[{"dsigmaWSM", "[", 
                  RowBox[{"[", 
                   RowBox[{"i", ",", "j"}], "]"}], "]"}], "+", 
                 RowBox[{"0.29245", "dsigmaWtr"}]}], "/.", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"S", "\[Rule]", 
                   RowBox[{"RS", "^", "2"}]}], ",", 
                  RowBox[{"cos", "\[Rule]", "ang"}]}], "}"}]}]}], ";"}], 
             "*)"}], "\[IndentingNewLine]", " ", 
            RowBox[{"(*", 
             RowBox[{"0.29245", "=", 
              RowBox[{"SM", " ", "branching", " ", "ratio", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"WW", "\[Rule]", 
                  RowBox[{"qqe", " ", "nu"}]}], ",", 
                 RowBox[{"qq", " ", "mu", " ", "nu"}]}], ")"}]}]}], " ", 
             "*)"}], "\[IndentingNewLine]", "  ", 
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{
              "as", " ", "suggested", " ", "in", " ", "the", " ", "paper"}], 
              ",", " ", 
              RowBox[{
              "we", " ", "take", " ", "the", " ", "theoretical", " ", "error",
                " ", "to", " ", "be", " ", "2", "%"}]}], " ", "*)"}], "   ", 
            "\[IndentingNewLine]", "   ", 
            RowBox[{"chi2WL3", "=", 
             RowBox[{"chi2WL3", "+", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"dsigmath", "-", 
                  RowBox[{"dsigmaWL3", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ")"}], "^", 
                "2"}], "/", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"errdsigmaWL3", "[", 
                   RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}], "^", "2"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"dsigmaWSM", "[", 
                    RowBox[{"[", 
                    RowBox[{"i", ",", "j"}], "]"}], "]"}], "*", "0.02"}], 
                   ")"}], "^", "2"}]}], ")"}]}]}]}], ";"}]}], 
          "\[IndentingNewLine]", "   ", "]"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "]"}], ";"}]}], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["chi2: Heavy flavor at LEP2", "Subsection",
 CellChangeTimes->{
  3.510667281474962*^9, {3.510920988144408*^9, 3.5109209896264105`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"chi2bLEP", "=", "0."}], ";"}], "\n", 
 RowBox[{
  RowBox[{"imax", "=", 
   RowBox[{"Length", "[", "RSbLEP", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sigmabSMLEP", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sigmahadSM4b", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "*", 
      RowBox[{"RbSMLEP", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "     ", 
      RowBox[{
       RowBox[{"RS", "=", 
        RowBox[{"RSbLEP", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       "      ", 
       RowBox[{"sigma0", "=", 
        RowBox[{
         SubsuperscriptBox["\[Integral]", 
          RowBox[{"-", "1"}], "1"], 
         RowBox[{"dsigmabtr", 
          RowBox[{"\[DifferentialD]", "cos"}]}]}]}], ";", 
       "\[IndentingNewLine]", "      ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"RADI", "==", "1"}], ",", 
         RowBox[{"sigmatr", "=", 
          RowBox[{"radcorrt", "[", 
           RowBox[{"sigma0", ",", "RS"}], "]"}]}], ",", 
         RowBox[{"sigmatr", "=", 
          RowBox[{"sigma0", "/.", 
           RowBox[{"S", "\[Rule]", 
            RowBox[{"RS", "^", "2"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "      ", 
       RowBox[{"sigma0had", "=", 
        RowBox[{
         SubsuperscriptBox["\[Integral]", 
          RowBox[{"-", "1"}], "1"], 
         RowBox[{"dsigmahadtr", 
          RowBox[{"\[DifferentialD]", "cos"}]}]}]}], ";", 
       "\[IndentingNewLine]", "       ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"RADI", "==", "1"}], ",", 
         RowBox[{"sigmahadtr", "=", 
          RowBox[{"radcorrt", "[", 
           RowBox[{"sigma0had", ",", "RS"}], "]"}]}], ",", 
         RowBox[{"sigmahadtr", "=", 
          RowBox[{"sigma0had", "/.", 
           RowBox[{"S", "\[Rule]", 
            RowBox[{"RS", "^", "2"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "      ", 
       RowBox[{"Rbthtemp", "=", 
        RowBox[{
         RowBox[{"RbSMLEP", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "+", 
         RowBox[{"sigmatr", "/", 
          RowBox[{"sigmahadSM4b", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"RbSMLEP", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "*", 
          RowBox[{"sigmahadtr", "/", 
           RowBox[{"sigmahadSM4b", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}]}]}]}], ";", 
       "\[IndentingNewLine]", "      ", 
       RowBox[{"chi2bLEP", "=", 
        RowBox[{"chi2bLEP", "+", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Rbthtemp", "-", 
             RowBox[{"RbLEP", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], ")"}], "^", "2"}], "/", 
          RowBox[{
           RowBox[{"errRbLEP", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "^", "2"}]}]}]}], ";", 
       "\[IndentingNewLine]", "      ", 
       RowBox[{"sigma0", "=", 
        RowBox[{
         RowBox[{
          SubsuperscriptBox["\[Integral]", "0", "1"], 
          RowBox[{"dsigmabtr", 
           RowBox[{"\[DifferentialD]", "cos"}]}]}], "-", 
         RowBox[{
          SubsuperscriptBox["\[Integral]", 
           RowBox[{"-", "1"}], "0"], 
          RowBox[{"dsigmabtr", 
           RowBox[{"\[DifferentialD]", "cos"}]}]}]}]}], ";", 
       "\[IndentingNewLine]", "      ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"RADI", "==", "1"}], ",", 
         RowBox[{"sigmafbtr", "=", 
          RowBox[{"radcorrfb", "[", 
           RowBox[{"sigma0", ",", "RS"}], "]"}]}], ",", 
         RowBox[{"sigmafbtr", "=", 
          RowBox[{"sigma0", "/.", 
           RowBox[{"S", "\[Rule]", 
            RowBox[{"RS", "^", "2"}]}]}]}]}], "]"}], ";", 
       "\[IndentingNewLine]", "      ", 
       RowBox[{"afbth", "=", 
        RowBox[{
         RowBox[{"afbbSMLEP", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "+", 
         FractionBox["sigmafbtr", 
          RowBox[{"sigmabSMLEP", "[", 
           RowBox[{"[", "i", "]"}], "]"}]], "-", 
         RowBox[{
          RowBox[{"afbbSMLEP", "[", 
           RowBox[{"[", "i", "]"}], "]"}], "*", 
          FractionBox["sigmatr", 
           RowBox[{"sigmabSMLEP", "[", 
            RowBox[{"[", "i", "]"}], "]"}]]}]}]}], ";", "\[IndentingNewLine]",
        "      ", 
       RowBox[{"chi2bLEP", "=", 
        RowBox[{"chi2bLEP", "+", 
         RowBox[{
          RowBox[{
           RowBox[{"(", " ", 
            RowBox[{"afbth", "-", 
             RowBox[{"afbbLEP", "[", 
              RowBox[{"[", "i", "]"}], "]"}]}], ")"}], "^", "2"}], "/", 
          RowBox[{
           RowBox[{"errafbbLEP", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "^", "2"}]}]}]}], ";"}]}], 
     "\[IndentingNewLine]", "   ", "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"chi2cLEP", "=", "0."}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"imax", "=", 
   RowBox[{"Length", "[", "RScLEP", "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"sigmacSMLEP", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"sigmahadSM4c", "[", 
       RowBox[{"[", "i", "]"}], "]"}], "*", 
      RowBox[{"RcSMLEP", "[", 
       RowBox[{"[", "i", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "3", ",", "8"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<", 
     RowBox[{"imax", "+", "1"}]}], ",", 
    RowBox[{"i", "++"}], ",", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "     ", 
      RowBox[{
       RowBox[{"RS", "=", 
        RowBox[{"RScLEP", "[", 
         RowBox[{"[", "i", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       "      ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"i", ">", "2"}], ",", 
         RowBox[{"Block", "[", 
          RowBox[{
           RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "      ", 
           RowBox[{
            RowBox[{"sigma0", "=", 
             RowBox[{
              SubsuperscriptBox["\[Integral]", 
               RowBox[{"-", "1"}], "1"], 
              RowBox[{"dsigmactr", 
               RowBox[{"\[DifferentialD]", "cos"}]}]}]}], ";", 
            "\[IndentingNewLine]", "      ", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"RADI", "==", "1"}], ",", 
              RowBox[{"sigmatr", "=", 
               RowBox[{"radcorrt", "[", 
                RowBox[{"sigma0", ",", "RS"}], "]"}]}], ",", 
              RowBox[{"sigmatr", "=", 
               RowBox[{"sigma0", "/.", 
                RowBox[{"S", "\[Rule]", 
                 RowBox[{"RS", "^", "2"}]}]}]}]}], "]"}], ";", 
            "\[IndentingNewLine]", "      ", 
            RowBox[{"sigma0had", "=", 
             RowBox[{
              SubsuperscriptBox["\[Integral]", 
               RowBox[{"-", "1"}], "1"], 
              RowBox[{"dsigmahadtr", 
               RowBox[{"\[DifferentialD]", "cos"}]}]}]}], ";", 
            "\[IndentingNewLine]", "       ", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"RADI", "==", "1"}], ",", 
              RowBox[{"sigmahadtr", "=", 
               RowBox[{"radcorrt", "[", 
                RowBox[{"sigma0had", ",", "RS"}], "]"}]}], ",", 
              RowBox[{"sigmahadtr", "=", 
               RowBox[{"sigma0had", "/.", 
                RowBox[{"S", "\[Rule]", 
                 RowBox[{"RS", "^", "2"}]}]}]}]}], "]"}], ";", 
            "\[IndentingNewLine]", "      ", 
            RowBox[{"Rcthtemp", "=", 
             RowBox[{
              RowBox[{"RcSMLEP", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "+", 
              RowBox[{"sigmatr", "/", 
               RowBox[{"sigmahadSM4c", "[", 
                RowBox[{"[", "i", "]"}], "]"}]}], "-", 
              RowBox[{
               RowBox[{"RcSMLEP", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "*", 
               RowBox[{"sigmahadtr", "/", 
                RowBox[{"sigmahadSM4c", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}]}]}]}], ";", "\n", 
            "                 ", 
            RowBox[{"chi2cLEP", "=", 
             RowBox[{"chi2cLEP", "+", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Rcthtemp", "-", 
                  RowBox[{"RcLEP", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}], ")"}], "^", "2"}], "/", 
               RowBox[{
                RowBox[{"errRcLEP", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "^", "2"}]}]}]}], ";"}]}], 
          "]"}]}], "]"}], ";", "\[IndentingNewLine]", "      ", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"i", "<", "5"}], ",", 
         RowBox[{"Block", "[", 
          RowBox[{
           RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "      ", 
           RowBox[{
            RowBox[{"sigma0", "=", 
             RowBox[{
              RowBox[{
               SubsuperscriptBox["\[Integral]", "0", "1"], 
               RowBox[{"dsigmactr", 
                RowBox[{"\[DifferentialD]", "cos"}]}]}], "-", 
              RowBox[{
               SubsuperscriptBox["\[Integral]", 
                RowBox[{"-", "1"}], "0"], 
               RowBox[{"dsigmactr", 
                RowBox[{"\[DifferentialD]", "cos"}]}]}]}]}], ";", 
            "\[IndentingNewLine]", "      ", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"RADI", "==", "1"}], ",", 
              RowBox[{"sigmafbtr", "=", 
               RowBox[{"radcorrfb", "[", 
                RowBox[{"sigma0", ",", "RS"}], "]"}]}], ",", 
              RowBox[{"sigmafbtr", "=", 
               RowBox[{"sigma0", "/.", 
                RowBox[{"S", "\[Rule]", 
                 RowBox[{"RS", "^", "2"}]}]}]}]}], "]"}], ";", 
            "\[IndentingNewLine]", "      ", 
            RowBox[{"afbth", "=", 
             RowBox[{
              RowBox[{"afbcSMLEP", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "+", 
              FractionBox["sigmafbtr", 
               RowBox[{"sigmacSMLEP", "[", 
                RowBox[{"[", "i", "]"}], "]"}]], "-", 
              RowBox[{
               RowBox[{"afbcSMLEP", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "*", 
               FractionBox["sigmatr", 
                RowBox[{"sigmacSMLEP", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]]}]}]}], ";", 
            "\[IndentingNewLine]", "      ", 
            RowBox[{"chi2cLEP", "=", 
             RowBox[{"chi2cLEP", "+", 
              RowBox[{
               RowBox[{
                RowBox[{"(", " ", 
                 RowBox[{"afbth", "-", 
                  RowBox[{"afbcLEP", "[", 
                   RowBox[{"[", "i", "]"}], "]"}]}], ")"}], "^", "2"}], "/", 
               RowBox[{
                RowBox[{"errafbcLEP", "[", 
                 RowBox[{"[", "i", "]"}], "]"}], "^", "2"}]}]}]}], ";"}]}], 
          "]"}]}], "]"}]}]}], "\[IndentingNewLine]", "   ", "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"On", "[", 
   RowBox[{"General", "::", "spell"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"On", "[", 
   RowBox[{"General", "::", "spell1"}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.510667280726161*^9, 3.510667283502966*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
chi2: \[Tau] -> \[Nu] \[Mu] \[Vee] and \[Tau] -> \[Nu] e \[Vee]\
\>", "Subsection",
 CellChangeTimes->{{3.5215385368718657`*^9, 3.5215385571207013`*^9}, 
   3.5219744199961987`*^9, {3.5224956430003786`*^9, 3.522495643187579*^9}, {
   3.53598184348178*^9, 3.5359818523338594`*^9}, {3.5384803515803814`*^9, 
   3.5384803518443966`*^9}, {3.5405425198624134`*^9, 3.540542522705576*^9}}],

Cell[CellGroupData[{

Cell["Experimental data", "Subsubsection",
 CellChangeTimes->{
  3.4833414523888493`*^9, 3.529429765176746*^9, {3.5299347026793165`*^9, 
   3.5299347071235704`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"O\[Tau]2lepexp", "=", "1.0028"}], ";", 
  RowBox[{"errO\[Tau]2lep", "=", "0.0030"}], ";", 
  RowBox[{"O\[Tau]2lepSM", "=", "1.0002"}], ";", 
  RowBox[{"therrO\[Tau]2lep", "=", "0.0000"}], ";"}]], "Input",
 CellChangeTimes->{{3.4833416796656485`*^9, 3.483341702020488*^9}, 
   3.483341938891304*^9, {3.483429532020203*^9, 3.483429537012212*^9}, 
   3.4834296773500586`*^9, {3.5151518484927406`*^9, 3.515151861908764*^9}, {
   3.515153192094993*^9, 3.515153195136998*^9}, 3.5154811220239058`*^9, 
   3.515481332371937*^9, {3.515481388046121*^9, 3.515481389930229*^9}, {
   3.5215385760747347`*^9, 3.521538626275623*^9}, {3.5215389301485567`*^9, 
   3.5215389710830283`*^9}, {3.521543593996532*^9, 3.52154361566497*^9}, {
   3.521543658627445*^9, 3.5215436900771008`*^9}, {3.521545497482671*^9, 
   3.5215455431088147`*^9}, 3.521787136720083*^9, 3.5217986456273794`*^9, {
   3.5224963835336795`*^9, 3.522496402784113*^9}, {3.5287325112822742`*^9, 
   3.5287325185362873`*^9}, {3.5288087168108635`*^9, 3.5288087283704844`*^9}, 
   3.5360705123207965`*^9, 3.5388307505056896`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Theoretical formulas", "Subsubsection",
 CellChangeTimes->{
  3.4833414631528683`*^9, {3.521798956583726*^9, 3.5217989774721627`*^9}, {
   3.528826814155075*^9, 3.528826816354679*^9}, {3.529934712722891*^9, 
   3.529934731855985*^9}, 3.538479729179782*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "We", " ", "need", " ", "to", " ", "multiply", " ", "the", " ", "NP", " ", 
   "coefficients", " ", "by", " ", 
   RowBox[{
    SuperscriptBox["v", "2"], "/", "2"}], " ", "to", " ", "match", " ", "the",
    " ", "normalization", " ", "used", " ", "in", " ", "the", " ", "rest", 
   " ", "of", " ", "the", " ", "program"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.528826818663483*^9, 3.5288269150092525`*^9}, 
   3.5388307658561163`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"O\[Tau]2lepth", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{"O\[Tau]2lepSM", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"4", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ahL3", "-", "ahl3"}], ")"}], "-", 
         RowBox[{"(", 
          RowBox[{"alL3", "-", "all3"}], ")"}]}], ")"}], 
       FractionBox[
        SuperscriptBox["v", "2"], "2"]}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.538825721245717*^9, 3.538825766251796*^9}, {
   3.538825884796404*^9, 3.5388259021748343`*^9}, 3.538830763204112*^9}],

Cell[BoxData[
 RowBox[{"1.0002`", "\[VeryThinSpace]", "-", 
  RowBox[{"121273.38709719639`", " ", "ahl3"}], "+", 
  RowBox[{"121273.38709719639`", " ", "ahL3"}], "+", 
  RowBox[{"121273.38709719639`", " ", "all3"}], "-", 
  RowBox[{"121273.38709719639`", " ", "alL3"}]}]], "Output",
 CellChangeTimes->{3.5388314644117436`*^9, 3.5388966328493166`*^9, 
  3.538897104059268*^9, 3.5388983543267794`*^9, 3.539351054399274*^9, 
  3.5393525329406705`*^9, 3.5394165857490067`*^9, 3.5394179345691547`*^9, 
  3.539419098980756*^9, 3.5399430586353226`*^9, 3.540540600165613*^9, 
  3.540541767379374*^9, 3.540542371379921*^9, 3.540550862446582*^9, 
  3.540568627501643*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Chi]", "2"], TraditionalForm]]]], "Subsubsection",
 CellChangeTimes->{
  3.4833418950552273`*^9, {3.5287348728223305`*^9, 3.528734873460367*^9}, {
   3.5299347546192875`*^9, 3.5299347555053377`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Chi]\[Tau]To\[Mu]", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"O\[Tau]2lepth", "-", "O\[Tau]2lepexp"}], ")"}], "^", "2"}], 
    "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"errO\[Tau]2lep", "^", "2"}], "+", 
      RowBox[{"therrO\[Tau]2lep", "^", "2"}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.53883079053636*^9, 3.5388308388184447`*^9}, {
  3.538831238726147*^9, 3.538831256993779*^9}}],

Cell[BoxData[
 RowBox[{"0.751111111111074`", "\[VeryThinSpace]", "+", 
  RowBox[{"7.006906810060063`*^7", " ", "ahl3"}], "+", 
  RowBox[{"1.6341371575584932`*^15", " ", 
   SuperscriptBox["ahl3", "2"]}], "-", 
  RowBox[{"7.006906810060063`*^7", " ", "ahL3"}], "-", 
  RowBox[{"3.2682743151169865`*^15", " ", "ahl3", " ", "ahL3"}], "+", 
  RowBox[{"1.6341371575584932`*^15", " ", 
   SuperscriptBox["ahL3", "2"]}], "-", 
  RowBox[{"7.006906810060063`*^7", " ", "all3"}], "-", 
  RowBox[{"3.2682743151169865`*^15", " ", "ahl3", " ", "all3"}], "+", 
  RowBox[{"3.2682743151169865`*^15", " ", "ahL3", " ", "all3"}], "+", 
  RowBox[{"1.6341371575584932`*^15", " ", 
   SuperscriptBox["all3", "2"]}], "+", 
  RowBox[{"7.006906810060063`*^7", " ", "alL3"}], "+", 
  RowBox[{"3.2682743151169865`*^15", " ", "ahl3", " ", "alL3"}], "-", 
  RowBox[{"3.2682743151169865`*^15", " ", "ahL3", " ", "alL3"}], "-", 
  RowBox[{"3.2682743151169865`*^15", " ", "all3", " ", "alL3"}], "+", 
  RowBox[{"1.6341371575584932`*^15", " ", 
   SuperscriptBox["alL3", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.5388307943271666`*^9, {3.5388308245756197`*^9, 3.538830839551646*^9}, 
   3.5388314644429436`*^9, 3.538896632895319*^9, 3.5388971040842695`*^9, 
   3.53889835434978*^9, 3.5393510544148736`*^9, 3.5393525329406705`*^9, 
   3.539416585782009*^9, 3.5394179345881557`*^9, 3.5394190989987564`*^9, 
   3.5399430586723247`*^9, 3.540540600185614*^9, 3.540541767382374*^9, 
   3.540542371386921*^9, 3.5405508624515824`*^9, 3.5405686275172434`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"chi2", ":", " ", 
    SuperscriptBox["\[Tau]", "-"]}], TraditionalForm]]],
 " -> \[Nu] ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Pi]", "-"], TraditionalForm]]]
}], "Subsection",
 CellChangeTimes->{{3.5215385368718657`*^9, 3.5215385571207013`*^9}, {
   3.521974360060893*^9, 3.5219743613556957`*^9}, 3.521974417812195*^9, {
   3.5221467902877045`*^9, 3.522146796543315*^9}, {3.5384803571527004`*^9, 
   3.5384803575297217`*^9}, {3.5388312183525114`*^9, 3.538831218851712*^9}}],

Cell[CellGroupData[{

Cell["Experimental data", "Subsubsection",
 CellChangeTimes->{
  3.4833414523888493`*^9, {3.5221541143624916`*^9, 3.522154116362606*^9}, 
   3.529934766996995*^9, {3.5388309372546177`*^9, 3.5388309374730177`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"R\[Tau]2\[Pi]exp", "=", "1.002"}], ";", 
  RowBox[{"errR\[Tau]2\[Pi]", "=", "0.007"}], ";", 
  RowBox[{"R\[Tau]2\[Pi]SM", "=", "1.0016"}], ";", 
  RowBox[{"therrR\[Tau]2\[Pi]", "=", "0.0014"}], ";"}]], "Input",
 CellChangeTimes->{{3.4833416796656485`*^9, 3.483341702020488*^9}, 
   3.483341938891304*^9, {3.483429532020203*^9, 3.483429537012212*^9}, 
   3.4834296773500586`*^9, {3.5151518484927406`*^9, 3.515151861908764*^9}, {
   3.515153192094993*^9, 3.515153195136998*^9}, 3.5154811220239058`*^9, 
   3.515481332371937*^9, {3.515481388046121*^9, 3.515481389930229*^9}, {
   3.5215385760747347`*^9, 3.521538626275623*^9}, {3.5215389301485567`*^9, 
   3.5215389710830283`*^9}, {3.521543593996532*^9, 3.52154361566497*^9}, {
   3.521543658627445*^9, 3.5215436900771008`*^9}, {3.521545497482671*^9, 
   3.5215455431088147`*^9}, 3.521787136720083*^9, 3.5217986456273794`*^9, {
   3.5221464986607924`*^9, 3.5221465297672462`*^9}, {3.522150583559167*^9, 
   3.5221506300784483`*^9}, {3.522151222161888*^9, 3.522151356509324*^9}, {
   3.5221514112186203`*^9, 3.5221514212026377`*^9}, {3.5221515034147825`*^9, 
   3.522151505037185*^9}, {3.52215410139775*^9, 3.5221541056729946`*^9}, 
   3.5287325284891043`*^9, {3.5288089742269154`*^9, 3.528808989171742*^9}, {
   3.528809262720801*^9, 3.52880929640126*^9}, {3.52880960952601*^9, 
   3.528809644345271*^9}, {3.5288097228758087`*^9, 3.5288097840123167`*^9}, {
   3.5288098690168657`*^9, 3.5288098716220703`*^9}, {3.528829064583828*^9, 
   3.528829074458645*^9}, 3.5291750743636723`*^9, {3.529175275715189*^9, 
   3.5291752780363216`*^9}, 3.538830930453006*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell["Theoretical formulas", "Subsubsection",
 CellChangeTimes->{
  3.4833414631528683`*^9, {3.521798956583726*^9, 3.5217989774721627`*^9}, {
   3.5221464542163143`*^9, 3.5221464578355207`*^9}, {3.528828141031006*^9, 
   3.528828144619012*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "We", " ", "need", " ", "to", " ", "multiply", " ", "the", " ", "NP", " ", 
   "coefficients", " ", "by", " ", 
   RowBox[{
    SuperscriptBox["v", "2"], "/", "2"}], " ", "to", " ", "match", " ", "the",
    " ", "normalization", " ", "used", " ", "in", " ", "the", " ", "rest", 
   " ", "of", " ", "the", " ", "program"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.5291748868349466`*^9, 3.529174907808146*^9}, {
  3.5388309492510386`*^9, 3.538830949485039*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"R\[Tau]2\[Pi]th", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{"R\[Tau]2\[Pi]SM", 
     RowBox[{"(", 
      RowBox[{"1", "+", 
       RowBox[{"4", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ahL3", "-", "ahl3"}], ")"}], "-", 
          RowBox[{"(", 
           RowBox[{"aLq3", "-", "alq3"}], ")"}]}], ")"}], 
        FractionBox[
         SuperscriptBox["v", "2"], "2"]}]}], ")"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.483341552868626*^9, 3.4833416394955783`*^9}, {
   3.511256124433941*^9, 3.511256143247574*^9}, {3.5151508588314857`*^9, 
   3.5151508804007196`*^9}, {3.515150961202341*^9, 3.51515096153436*^9}, {
   3.5151518019266586`*^9, 3.515151815311482*^9}, {3.515152174146405*^9, 
   3.515152179029214*^9}, {3.515152231648106*^9, 3.5151522511325407`*^9}, {
   3.515152849471591*^9, 3.515152850469993*^9}, 3.51515305952596*^9, {
   3.515155322088146*^9, 3.515155362651466*^9}, {3.515480622983362*^9, 
   3.515480634435017*^9}, {3.5154806981536617`*^9, 3.515480699398733*^9}, {
   3.515481099298606*^9, 3.5154811121993437`*^9}, {3.5154811523576407`*^9, 
   3.515481152936674*^9}, {3.515481352809106*^9, 3.515481359863509*^9}, {
   3.515481436294881*^9, 3.51548146670162*^9}, {3.51548260067048*^9, 
   3.5154826190765324`*^9}, {3.5154826778818955`*^9, 
   3.5154826805450478`*^9}, {3.5154827479369025`*^9, 3.515482748510936*^9}, {
   3.51584020684828*^9, 3.5158402266284113`*^9}, {3.521538680080117*^9, 
   3.5215388452688074`*^9}, {3.5215389924550657`*^9, 
   3.5215389931570673`*^9}, {3.521543471068316*^9, 3.521543505138776*^9}, {
   3.5215438374505596`*^9, 3.5215439074478827`*^9}, {3.521543942033143*^9, 
   3.521543952297961*^9}, {3.5215455856323586`*^9, 3.5215456382244987`*^9}, {
   3.521546721863533*^9, 3.5215467220735335`*^9}, {3.521787161165326*^9, 
   3.5217871887773747`*^9}, {3.52178734554205*^9, 3.5217873768045053`*^9}, {
   3.5217874361782093`*^9, 3.521787470201869*^9}, {3.521788030462253*^9, 
   3.5217880494630866`*^9}, {3.5217882113757706`*^9, 
   3.5217882305638046`*^9}, {3.5217882937127156`*^9, 3.521788372118453*^9}, {
   3.5217887328222866`*^9, 3.521788733586688*^9}, {3.5217984338258076`*^9, 
   3.521798457303849*^9}, 3.5217987604445815`*^9, {3.5221453402495575`*^9, 
   3.5221454768901973`*^9}, {3.5221459421142144`*^9, 
   3.5221459466538224`*^9}, {3.5221460820932603`*^9, 
   3.5221461423873663`*^9}, {3.5221465888601503`*^9, 3.522146599577369*^9}, {
   3.522146718948779*^9, 3.522146719135979*^9}, {3.5221505055434294`*^9, 
   3.5221505092250357`*^9}, {3.522150618550028*^9, 3.522150641544469*^9}, {
   3.5221507817419147`*^9, 3.522150783473518*^9}, {3.5221508550620437`*^9, 
   3.522150855701645*^9}, {3.522150961953431*^9, 3.52215097270185*^9}, 
   3.522153217967221*^9, {3.5221539661110125`*^9, 3.522153998123843*^9}, {
   3.5221541959581585`*^9, 3.5221542471810884`*^9}, {3.5221542856212873`*^9, 
   3.522154290200549*^9}, 3.5221543229434223`*^9, {3.522154576039898*^9, 
   3.5221546945326757`*^9}, {3.522154757909301*^9, 3.522154759181373*^9}, {
   3.522154796248493*^9, 3.5221548066880903`*^9}, {3.522154885786615*^9, 
   3.5221548935640593`*^9}, {3.522154992573723*^9, 3.522155009694702*^9}, {
   3.5221556082299356`*^9, 3.522155613053212*^9}, {3.5221556440889874`*^9, 
   3.522155648209223*^9}, {3.522738073909055*^9, 3.522738087329074*^9}, {
   3.5287328751529136`*^9, 3.5287329542450523`*^9}, {3.52873307233726*^9, 
   3.5287330896688905`*^9}, 3.528734947590607*^9, {3.528741370357679*^9, 
   3.5287413803416967`*^9}, {3.528826933994486*^9, 3.5288269642897387`*^9}, {
   3.528828177067069*^9, 3.5288281892818904`*^9}, {3.528828269965232*^9, 
   3.52882829154007*^9}, {3.528828744003265*^9, 3.528828800724964*^9}, {
   3.5288288546230593`*^9, 3.528828876556698*^9}, {3.528828911422759*^9, 
   3.528828921531577*^9}, {3.5288290306849685`*^9, 3.528829057033415*^9}, {
   3.5288290876250687`*^9, 3.528829096517084*^9}, {3.5291744943144956`*^9, 
   3.5291744960065928`*^9}, {3.5291750407287483`*^9, 
   3.5291750425198507`*^9}, {3.529175094885846*^9, 3.529175161267643*^9}, {
   3.5291752636735*^9, 3.529175265563608*^9}, {3.538479399982953*^9, 
   3.5384794002789702`*^9}, {3.538479444816518*^9, 3.538479450602848*^9}, {
   3.5388309471918354`*^9, 3.5388309553662496`*^9}, 3.538831048109412*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Chi]", "2"], TraditionalForm]]]], "Subsubsection",
 CellChangeTimes->{
  3.4833418950552273`*^9, {3.522496304597541*^9, 3.5224963658744483`*^9}, {
   3.5299347773705883`*^9, 3.5299347778586164`*^9}, {3.5388246841538954`*^9, 
   3.538824684575096*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Chi]\[Tau]ToPiNu", "=", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"R\[Tau]2\[Pi]th", "-", "R\[Tau]2\[Pi]exp"}], ")"}], "^", "2"}],
     "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"errR\[Tau]2\[Pi]", "^", "2"}], "+", 
      RowBox[{"therrR\[Tau]2\[Pi]", "^", "2"}]}], ")"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.483341898487233*^9, 3.4833419336340947`*^9}, {
   3.4834296695656447`*^9, 3.4834296963664923`*^9}, 3.515151824343898*^9, {
   3.515151871565181*^9, 3.5151518791467943`*^9}, {3.515155381696555*^9, 
   3.5151553853297634`*^9}, 3.515480625237491*^9, 3.515481455285967*^9, 
   3.515482605554759*^9, 3.515482668463357*^9, 3.5154879193486905`*^9, 
   3.5154879824322987`*^9, 3.521538903004509*^9, 3.5215389824086485`*^9, {
   3.5215435219400053`*^9, 3.5215435298648195`*^9}, 3.521543919662704*^9, {
   3.521545470027727*^9, 3.521545472907731*^9}, {3.5221466988247433`*^9, 
   3.522146707810359*^9}, {3.522155039416402*^9, 3.522155049466977*^9}, 
   3.5288291212899275`*^9, 3.531509270375779*^9, {3.5315975959570456`*^9, 
   3.53159759854665*^9}, {3.538479485916868*^9, 3.5384794987426023`*^9}, {
   3.5388230574389086`*^9, 3.538823105455793*^9}, {3.538823260145664*^9, 
   3.5388232619864674`*^9}, {3.5388232926405215`*^9, 
   3.5388233233735757`*^9}, {3.538823535892749*^9, 3.53882354256956*^9}, {
   3.5388236172624917`*^9, 3.538823617980093*^9}, {3.53882475527442*^9, 
   3.538824776755658*^9}, 3.5388248165045276`*^9, {3.5388309661146684`*^9, 
   3.5388309800766926`*^9}, {3.5388310248965716`*^9, 
   3.5388310383437953`*^9}, {3.5388313164142838`*^9, 3.538831321156692*^9}}],

Cell[BoxData[
 RowBox[{"0.003139717425431019`", "\[VeryThinSpace]", "+", 
  RowBox[{"1.9064856497544844`*^6", " ", "ahl3"}], "+", 
  RowBox[{"2.894119947928761`*^14", " ", 
   SuperscriptBox["ahl3", "2"]}], "-", 
  RowBox[{"1.9064856497544844`*^6", " ", "ahL3"}], "-", 
  RowBox[{"5.788239895857522`*^14", " ", "ahl3", " ", "ahL3"}], "+", 
  RowBox[{"2.894119947928761`*^14", " ", 
   SuperscriptBox["ahL3", "2"]}], "-", 
  RowBox[{"1.9064856497544844`*^6", " ", "alq3"}], "-", 
  RowBox[{"5.788239895857522`*^14", " ", "ahl3", " ", "alq3"}], "+", 
  RowBox[{"5.788239895857522`*^14", " ", "ahL3", " ", "alq3"}], "+", 
  RowBox[{"2.894119947928761`*^14", " ", 
   SuperscriptBox["alq3", "2"]}], "+", 
  RowBox[{"1.9064856497544844`*^6", " ", "aLq3"}], "+", 
  RowBox[{"5.788239895857522`*^14", " ", "ahl3", " ", "aLq3"}], "-", 
  RowBox[{"5.788239895857522`*^14", " ", "ahL3", " ", "aLq3"}], "-", 
  RowBox[{"5.788239895857522`*^14", " ", "alq3", " ", "aLq3"}], "+", 
  RowBox[{"2.894119947928761`*^14", " ", 
   SuperscriptBox["aLq3", "2"]}]}]], "Output",
 CellChangeTimes->{{3.5388310272053757`*^9, 3.538831050808217*^9}, 
   3.5388313223890944`*^9, 3.5388314644741435`*^9, 3.5388966329823236`*^9, 
   3.5388971041382723`*^9, 3.538898354375782*^9, 3.5393510544460735`*^9, 
   3.5393525329562707`*^9, 3.5394165861360292`*^9, 3.5394179346121573`*^9, 
   3.5394190990347586`*^9, 3.539943058754329*^9, 3.5405406002106156`*^9, 
   3.5405417673893747`*^9, 3.540542371412923*^9, 3.540550862465583*^9, 
   3.5405686275796432`*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
chi2: anomalous magnetic moment of \[Tau] (a\[Tau]) \
\>", "Subsection",
 CellChangeTimes->{{3.510921002933234*^9, 3.510921015522456*^9}, {
   3.5111732442896385`*^9, 3.511173247087799*^9}, {3.528735012660329*^9, 
   3.528735014187416*^9}, 3.5316743697251654`*^9, {3.5388312079628935`*^9, 
   3.538831208477694*^9}}],

Cell[CellGroupData[{

Cell["Experimental data", "Subsubsection",
 CellChangeTimes->{
  3.483768391845375*^9, {3.5111732163490405`*^9, 3.511173219295209*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a\[Tau]Exp", "=", 
   RowBox[{"-", "0.018"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]a\[Tau]Exp", "=", "0.017"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a\[Tau]SM", "=", 
   RowBox[{"11773", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "7"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]a\[Tau]SM", "=", 
   RowBox[{"3", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "7"}]]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4837684011897917`*^9, 3.4837684315006447`*^9}, {
   3.483768933712327*^9, 3.4837689344923277`*^9}, 3.4837689877040215`*^9, {
   3.5073842915574675`*^9, 3.507384329153618*^9}, {3.50738441556356*^9, 
   3.507384420890865*^9}, 3.5148060758173523`*^9, {3.53167432673149*^9, 
   3.531674327667492*^9}, {3.531675090430832*^9, 3.531675108481063*^9}, 
   3.531675418454608*^9, 3.5388964662007847`*^9, {3.538896949657437*^9, 
   3.5388969506984963`*^9}, 3.538898209808513*^9, {3.539417791128951*^9, 
   3.539417794939169*^9}, {3.539418945318967*^9, 3.5394189458919992`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Theoretical formulas ", "Subsubsection",
 CellChangeTimes->{
  3.4837684419526625`*^9, {3.4887986510098014`*^9, 3.488798651826848*^9}, {
   3.511173221720348*^9, 3.511173228245721*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"a\[Tau]", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"2", 
      SqrtBox["2"]}], "s"], 
    FractionBox["mtau", "MW"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"atauBt", " ", "c"}], " ", "-", " ", 
      RowBox[{"atauWt", " ", "s"}]}], ")"}], 
    FractionBox[
     SuperscriptBox["v", "2"], "2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a\[Tau]tr", "=", 
   RowBox[{"firstorder", "[", "a\[Tau]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4837684486918745`*^9, 3.4837684522642813`*^9}, {
   3.4837685141339893`*^9, 3.483768552541257*^9}, {3.483775059141821*^9, 
   3.4837750613882246`*^9}, 3.4875090196916966`*^9, {3.488008632503498*^9, 
   3.4880086645927544`*^9}, 3.488631704496044*^9, {3.5073009002024612`*^9, 
   3.507300905319271*^9}, {3.5074687047732005`*^9, 3.507468715564818*^9}, {
   3.5109031045128155`*^9, 3.510903109114824*^9}, {3.5109034306157885`*^9, 
   3.510903431099389*^9}, {3.5110894618881917`*^9, 3.5110894626369925`*^9}, {
   3.5110895957988267`*^9, 3.5110896014460363`*^9}, {3.5110896481057186`*^9, 
   3.511089676372968*^9}, {3.5110897458242903`*^9, 3.5110897497086973`*^9}, {
   3.515483347036169*^9, 3.5154833475691996`*^9}, {3.515484096432032*^9, 
   3.5154840978551135`*^9}, {3.515840171235243*^9, 3.515840185799076*^9}, {
   3.5165166916063676`*^9, 3.516516713914407*^9}, {3.5316746860937214`*^9, 
   3.5316746929733334`*^9}, {3.540550673256761*^9, 3.5405506749988604`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]]],
 "a\[Tau]"
}], "Subsubsection",
 CellChangeTimes->{
  3.483768559218069*^9, {3.511173231438904*^9, 3.511173240732435*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]a\[Tau]", "=", 
   RowBox[{"Expand", "[", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"a\[Tau]Exp", "-", "a\[Tau]tr"}], ")"}], "2"], 
     RowBox[{
      SuperscriptBox["\[Sigma]a\[Tau]Exp", "2"], "+", 
      SuperscriptBox["\[Sigma]a\[Tau]SM", "2"]}]], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4837685635236764`*^9, 3.483768587781719*^9}, {
   3.4837689928208303`*^9, 3.4837689945992336`*^9}, {3.5062599141141524`*^9, 
   3.5062599172185583`*^9}, {3.5073844456582813`*^9, 
   3.5073844475623903`*^9}, {3.5110896827221794`*^9, 3.5110896828625793`*^9}, 
   3.5154840179695444`*^9, {3.515484056460746*^9, 3.5154840620130634`*^9}, 
   3.5154878679677515`*^9, {3.5316746982617426`*^9, 3.5316747017717485`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["chi2: \[CapitalDelta]CKM", "Subsection",
 CellChangeTimes->{{3.5109210286576796`*^9, 3.5109210347884903`*^9}, {
   3.52873500988317*^9, 3.5287350121683006`*^9}, 3.538741456147606*^9}],

Cell[CellGroupData[{

Cell["Experimental data", "Subsubsection",
 CellChangeTimes->{{3.5074688667794666`*^9, 3.5074688708126974`*^9}, 
   3.5111732558002973`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalDelta]CKMExp", " ", "=", " ", 
   RowBox[{"-", "0.0001"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]\[CapitalDelta]CKMExp", " ", "=", " ", "0.0006"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.5074688841134586`*^9, 3.5074689046946354`*^9}, {
  3.5148060498277063`*^9, 3.514806072276146*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Theoretical formulas ", "Subsubsection",
 CellChangeTimes->{{3.5074689076658053`*^9, 3.5074689098029275`*^9}, 
   3.511173259440505*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalDelta]CKM", " ", "=", 
   RowBox[{"4", "*", 
    FractionBox[
     SuperscriptBox["v", "2"], "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"ahq3", "-", "ahl3"}], ")"}], "-", 
      RowBox[{"(", 
       RowBox[{"alq3", "-", "all3"}], ")"}]}], ")"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5074689213975906`*^9, 3.507468933740297*^9}, {
  3.5074690209752865`*^9, 3.5074690382832766`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]]],
 "\[CapitalDelta]CKM"
}], "Subsubsection",
 CellChangeTimes->{
  3.5074689414827394`*^9, {3.5111732633497286`*^9, 3.5111732698090982`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]\[CapitalDelta]CKM", "=", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"\[CapitalDelta]CKMExp", " ", "-", " ", "\[CapitalDelta]CKM"}], 
      ")"}], "2"], 
    SuperscriptBox["\[Sigma]\[CapitalDelta]CKMExp", "2"]]}], ";"}]], "Input",
 CellChangeTimes->{{3.5074689538574476`*^9, 3.507469012366794*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["chi2: W-> \[Tau] \[Nu]", "Subsection",
 CellChangeTimes->{{3.4833414296908092`*^9, 3.4833414426076326`*^9}, {
   3.5104805501715093`*^9, 3.510480564734342*^9}, {3.5148997191426535`*^9, 
   3.514899725562021*^9}, {3.5287349754682016`*^9, 3.5287350058409386`*^9}, {
   3.538835507897251*^9, 3.538835510034455*^9}, 3.5405425271498303`*^9}],

Cell[CellGroupData[{

Cell["Experimental data", "Subsubsection",
 CellChangeTimes->{{3.539942274521629*^9, 3.5399422799816384`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Mcorr", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.00", ",", "0.08", ",", 
       RowBox[{"-", "0.21"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.08", ",", "1.00", ",", 
       RowBox[{"-", "0.14"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "0.21"}], ",", 
       RowBox[{"-", "0.14"}], " ", ",", "1.00"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BWe", "=", 
   RowBox[{"10.75", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]BWe", "=", 
   RowBox[{"0.13", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BW\[Mu]", "=", 
   RowBox[{"10.57", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]BW\[Mu]", "=", 
   RowBox[{"0.15", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BW\[Tau]", "=", 
   RowBox[{"11.25", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]BW\[Tau]", "=", 
   RowBox[{"0.20", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BW", "=", 
   RowBox[{"{", 
    RowBox[{"BWe", ",", "BW\[Mu]", ",", "BW\[Tau]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BWtmp", "=", 
   RowBox[{"{", 
    RowBox[{"We", ",", "W\[Mu]", ",", "W\[Tau]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]BW", "=", 
   RowBox[{"{", 
    RowBox[{"\[Sigma]BWe", ",", "\[Sigma]BW\[Mu]", ",", "\[Sigma]BW\[Tau]"}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5383969745900373`*^9, 3.538397076856887*^9}, {
  3.538397126835746*^9, 3.538397217162912*^9}, {3.5383978780367117`*^9, 
  3.5383978852491245`*^9}, {3.538399618630268*^9, 3.538399620711387*^9}, {
  3.5384014543032627`*^9, 3.5384014733413515`*^9}, {3.53883691221541*^9, 
  3.538836912761411*^9}, {3.5399422948640647`*^9, 3.539942296252467*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Merr", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Sigma]BW", "[", 
       RowBox[{"[", "i", "]"}], "]"}], 
      RowBox[{"Mcorr", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}], 
      RowBox[{"\[Sigma]BW", "[", 
       RowBox[{"[", "j", "]"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.538399506295843*^9, {3.5384014751084523`*^9, 3.5384014771355686`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["R\[Tau]l - experimental and SM data", "Subsubsection",
 CellChangeTimes->{
  3.5388368416079397`*^9, {3.540538617585216*^9, 3.5405386279668097`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RW\[Tau]lSM", "=", "0.99929"}], ";"}]], "Input",
 CellChangeTimes->{{3.5383996230475206`*^9, 3.5383996350672083`*^9}, 
   3.5399426024810047`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RW\[Tau]ltmp", "=", 
   RowBox[{"2", 
    RowBox[{"W\[Tau]", "/", 
     RowBox[{"(", 
      RowBox[{"We", "+", "W\[Mu]"}], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RW\[Tau]lExp", "=", 
   RowBox[{"RW\[Tau]ltmp", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"We", "\[Rule]", "BWe"}], ",", 
      RowBox[{"W\[Mu]", "\[Rule]", "BW\[Mu]"}], ",", 
      RowBox[{"W\[Tau]", "\[Rule]", "BW\[Tau]"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]RW\[Tau]lExp", "=", 
   RowBox[{
    SqrtBox[
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"RW\[Tau]ltmp", ",", 
          RowBox[{"BWtmp", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "*", 
        RowBox[{"D", "[", 
         RowBox[{"RW\[Tau]ltmp", ",", 
          RowBox[{"BWtmp", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], "]"}], "*", 
        RowBox[{"Merr", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}]], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"We", "\[Rule]", "BWe"}], ",", 
      RowBox[{"W\[Mu]", "\[Rule]", "BW\[Mu]"}], ",", 
      RowBox[{"W\[Tau]", "\[Rule]", "BW\[Tau]"}]}], "}"}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.538397221421156*^9, 3.5383972238342934`*^9}, {
  3.5383977125052443`*^9, 3.538397747975273*^9}, {3.538399368739975*^9, 
  3.5383994608042407`*^9}, {3.538399516327417*^9, 3.5383995351184916`*^9}, {
  3.5384014836759424`*^9, 3.538401487224146*^9}, {3.5388368987525864`*^9, 
  3.538836901576192*^9}, {3.5399423294649253`*^9, 3.5399423296677256`*^9}, {
  3.53994260547621*^9, 3.5399426152262273`*^9}, {3.5405385901156445`*^9, 
  3.540538592546784*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Theoretical formulas", "Subsubsection",
 CellChangeTimes->{
  3.4833414631528683`*^9, {3.5405385985091248`*^9, 3.540538603718423*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalGamma]Wl\[Nu]SM", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"GF", " ", 
      SuperscriptBox["MW", "3"]}], 
     RowBox[{"6", 
      SqrtBox["2"], "\[Pi]"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["m", "2"], 
        SuperscriptBox["MW", "2"]]}], ")"}], "2"], 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["m", "2"], 
       RowBox[{"2", 
        SuperscriptBox["MW", "2"]}]]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]Wl\[Nu]hl3", "=", 
   RowBox[{"\[CapitalGamma]Wl\[Nu]SM", "  ", "4", " ", "ahL3", 
    FractionBox[
     SuperscriptBox["v", "2"], "2"]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalGamma]Wl\[Nu]EWt", "=", 
    RowBox[{
     FractionBox["GF", "\[Pi]"], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox[
         SuperscriptBox["m", "2"], 
         SuperscriptBox["MW", "2"]]}], ")"}], "2"], 
     SuperscriptBox["MW", "2"], "m", " ", "atauWt", 
     FractionBox[
      SuperscriptBox["v", "2"], "2"]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]W\[Tau]\[Nu]th", "=", 
   RowBox[{
    RowBox[{
    "\[CapitalGamma]Wl\[Nu]SM", "+", "\[CapitalGamma]Wl\[Nu]EWt", "+", 
     "\[CapitalGamma]Wl\[Nu]hl3"}], "/.", 
    RowBox[{"{", 
     RowBox[{"m", "\[Rule]", "mtau"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]W\[Mu]\[Nu]th", "=", 
   RowBox[{
    RowBox[{
    "\[CapitalGamma]Wl\[Nu]SM", "+", "\[CapitalGamma]Wl\[Nu]EWt", "+", 
     "\[CapitalGamma]Wl\[Nu]hl3"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "\[Rule]", "mmu"}], ",", 
      RowBox[{"ahL3", "\[Rule]", "ahl3"}]}], "}"}]}]}], ";", 
  RowBox[{"\[CapitalGamma]We\[Nu]th", "=", 
   RowBox[{
    RowBox[{
    "\[CapitalGamma]Wl\[Nu]SM", "+", "\[CapitalGamma]Wl\[Nu]EWt", "+", 
     "\[CapitalGamma]Wl\[Nu]hl3"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "\[Rule]", "me"}], ",", 
      RowBox[{"ahL3", "\[Rule]", "ahl3"}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.483341552868626*^9, 3.4833416394955783`*^9}, {
   3.511256124433941*^9, 3.511256143247574*^9}, {3.5151508588314857`*^9, 
   3.5151508804007196`*^9}, {3.515150961202341*^9, 3.51515096153436*^9}, {
   3.5151518019266586`*^9, 3.515151815311482*^9}, {3.515152174146405*^9, 
   3.515152179029214*^9}, {3.515152231648106*^9, 3.5151522511325407`*^9}, {
   3.515152849471591*^9, 3.515152850469993*^9}, 3.51515305952596*^9, {
   3.515155322088146*^9, 3.515155362651466*^9}, {3.515480622983362*^9, 
   3.515480634435017*^9}, {3.5154806981536617`*^9, 3.515480699398733*^9}, {
   3.515481099298606*^9, 3.5154811121993437`*^9}, {3.5154811523576407`*^9, 
   3.515481152936674*^9}, {3.515481352809106*^9, 3.515481359863509*^9}, {
   3.515481436294881*^9, 3.51548146670162*^9}, {3.51548260067048*^9, 
   3.5154826190765324`*^9}, {3.5154826778818955`*^9, 
   3.5154826805450478`*^9}, {3.5154827479369025`*^9, 3.515482748510936*^9}, {
   3.51584020684828*^9, 3.5158402266284113`*^9}, 3.5388355229980774`*^9, {
   3.538835691431573*^9, 3.538835765859304*^9}, {3.538835957021605*^9, 
   3.5388360014816833`*^9}, {3.5388361122674007`*^9, 
   3.5388361208006163`*^9}, {3.5388361848231287`*^9, 3.538836246084436*^9}, {
   3.5388363574686317`*^9, 3.538836384519079*^9}, {3.5399423846422224`*^9, 
   3.5399423881834283`*^9}, {3.539942476557584*^9, 3.539942501720428*^9}, {
   3.5405506787960777`*^9, 3.540550678958087*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RW\[Tau]lth", "=", 
   RowBox[{"RW\[Tau]lSM", "+", 
    RowBox[{"firstorder", "[", 
     FractionBox[
      RowBox[{"2", "\[CapitalGamma]W\[Tau]\[Nu]th"}], 
      RowBox[{
      "\[CapitalGamma]We\[Nu]th", "+", "\[CapitalGamma]W\[Mu]\[Nu]th"}]], 
     "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5388361274462276`*^9, 3.538836173045108*^9}, {
   3.5388363389825993`*^9, 3.5388363460806117`*^9}, {3.538836391788692*^9, 
   3.53883640770072*^9}, {3.5399424674627676`*^9, 3.5399424679463687`*^9}, 
   3.5405386097607684`*^9}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  SuperscriptBox["\[Chi]", "2"], TraditionalForm]]]], "Subsubsection",
 CellChangeTimes->{
  3.4833418950552273`*^9, {3.5405386397764854`*^9, 3.5405386402655134`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Chi]Wl\[Nu]", "=", 
  RowBox[{"Expand", "[", 
   FractionBox[
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"RW\[Tau]lExp", "-", "RW\[Tau]lth"}], ")"}], "2"], 
    SuperscriptBox["\[Sigma]RW\[Tau]lExp", "2"]], "]"}]}]], "Input",
 CellChangeTimes->{{3.483341898487233*^9, 3.4833419336340947`*^9}, {
   3.4834296695656447`*^9, 3.4834296963664923`*^9}, 3.515151824343898*^9, {
   3.515151871565181*^9, 3.5151518791467943`*^9}, {3.515155381696555*^9, 
   3.5151553853297634`*^9}, 3.515480625237491*^9, 3.515481455285967*^9, 
   3.515482605554759*^9, 3.515482668463357*^9, 3.5154879193486905`*^9, 
   3.5154879824322987`*^9, {3.538835526664084*^9, 3.538835536226901*^9}, {
   3.538835571576563*^9, 3.5388355720601635`*^9}, {3.538835605101022*^9, 
   3.53883562116905*^9}, {3.538836414611532*^9, 3.5388364183322144`*^9}, {
   3.538836944647867*^9, 3.5388369787339272`*^9}, {3.5399425541989202`*^9, 
   3.5399425687849455`*^9}}],

Cell[BoxData[
 RowBox[{"5.756340656853227`", "\[VeryThinSpace]", "+", 
  RowBox[{"6580.373250978359`", " ", "ah"}], "+", 
  RowBox[{"1.8805919725511293`*^6", " ", 
   SuperscriptBox["ah", "2"]}], "+", 
  RowBox[{"2.489094560542175`*^7", " ", "ahl3"}], "+", 
  RowBox[{"1.4227069106696453`*^10", " ", "ah", " ", "ahl3"}], "+", 
  RowBox[{"2.690768363380504`*^13", " ", 
   SuperscriptBox["ahl3", "2"]}], "-", 
  RowBox[{"2.4883035327885285`*^7", " ", "ahL3"}], "-", 
  RowBox[{"1.4222547781273607`*^10", " ", "ah", " ", "ahL3"}], "-", 
  RowBox[{"5.379826488437555`*^13", " ", "ahl3", " ", "ahL3"}], "+", 
  RowBox[{"2.6890583968116883`*^13", " ", 
   SuperscriptBox["ahL3", "2"]}], "-", 
  RowBox[{"3955.138768237066`", " ", "all3"}], "-", 
  RowBox[{"2.2606627114249235`*^6", " ", "ah", " ", "all3"}], "-", 
  RowBox[{"8.55119161727139`*^9", " ", "ahl3", " ", "all3"}], "+", 
  RowBox[{"8.5484740708980055`*^9", " ", "ahL3", " ", "all3"}], "+", 
  RowBox[{"679386.593346758`", " ", 
   SuperscriptBox["all3", "2"]}], "-", 
  RowBox[{"1.1376098552105592`*^6", " ", "atauWt"}], "-", 
  RowBox[{"6.502305811561527`*^8", " ", "ah", " ", "atauWt"}], "-", 
  RowBox[{"2.459564740363814`*^12", " ", "ahl3", " ", "atauWt"}], "+", 
  RowBox[{"2.458783097109933`*^12", " ", "ahL3", " ", "atauWt"}], "+", 
  RowBox[{"3.9082162694063795`*^8", " ", "all3", " ", "atauWt"}], "+", 
  RowBox[{"5.620568082308629`*^10", " ", 
   SuperscriptBox["atauWt", "2"]}], "+", 
  RowBox[{"14429.494614678595`", " ", "aWB"}], "+", 
  RowBox[{"8.247553962474632`*^6", " ", "ah", " ", "aWB"}], "+", 
  RowBox[{"3.1197229887714138`*^10", " ", "ahl3", " ", "aWB"}], "-", 
  RowBox[{"3.118731548949509`*^10", " ", "ahL3", " ", "aWB"}], "-", 
  RowBox[{"4.957199109527825`*^6", " ", "all3", " ", "aWB"}], "-", 
  RowBox[{"1.4258307714835272`*^9", " ", "atauWt", " ", "aWB"}], "+", 
  RowBox[{"9.042650845687583`*^6", " ", 
   SuperscriptBox["aWB", "2"]}]}]], "Output",
 CellChangeTimes->{{3.5388355282240868`*^9, 3.5388355725905647`*^9}, {
   3.5388356093130293`*^9, 3.5388356215122504`*^9}, 3.5388359737292347`*^9, {
   3.538836937690255*^9, 3.5388369794671288`*^9}, 3.539942261230406*^9, {
   3.5399423577009745`*^9, 3.5399423746894045`*^9}, 3.539942591389385*^9, 
   3.5399430589693413`*^9, 3.540540600371625*^9, 3.5405417674763794`*^9, 
   3.5405423715479307`*^9, 3.540550862572589*^9, 3.5405686278292437`*^9}]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
   "**********************************************************)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "          ", 
   RowBox[{"Total", " ", 
    SuperscriptBox["\[Chi]", "2"]}], 
   "                                                                          \
         ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**"}], 
   "******************************************************************************)"}\
]}]], "Section",
 FontSize->14],

Cell[CellGroupData[{

Cell["Sum all the chi2", "Subsection",
 CellChangeTimes->{{3.5109210780785666`*^9, 3.5109210833981757`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"FLSY", "\[Equal]", "0"}], ",", 
     RowBox[{"replacement", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"alQ1", "\[Rule]", "alq1"}], ",", 
        RowBox[{"alQ3", "\[Rule]", "alq3"}], ",", 
        RowBox[{"aQe", "\[Rule]", "aqe"}], ",", 
        RowBox[{"alb", "\[Rule]", "ald"}], ",", 
        RowBox[{"aeb", "\[Rule]", "aed"}], ",", 
        RowBox[{"ahQ1", "\[Rule]", "ahq1"}], ",", 
        RowBox[{"ahQ3", "\[Rule]", "ahq3"}], ",", 
        RowBox[{"ahb", "\[Rule]", "ahd"}], ",", 
        RowBox[{"alL1", "\[Rule]", "all1"}], ",", 
        RowBox[{"alL3", "\[Rule]", "all3"}], ",", 
        RowBox[{"aLe", "\[Rule]", "ale"}], ",", 
        RowBox[{"altau", "\[Rule]", "ale"}], ",", 
        RowBox[{"aetau", "\[Rule]", "aee"}], ",", " ", "\n", 
        RowBox[{"ahL1", "\[Rule]", "ahl1"}], ",", 
        RowBox[{"ahL3", "\[Rule]", "ahl3"}], ",", 
        RowBox[{"ahtau", "\[Rule]", "ahe"}]}], "}"}]}]}], "]"}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "note", " ", "that", " ", "there", " ", "is", " ", "no", " ", "light", " ",
     "flavour", " ", "operators", " ", "equivalent", " ", "to", " ", "atauBt",
     " ", "and", " ", "atauWt"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"FLSY", "\[Equal]", "0"}], ",", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"chi2MW", "=", 
        RowBox[{"chi2MW", "/.", "replacement"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"chi2Zline", "=", 
        RowBox[{"chi2Zline", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"chi2bc", "=", 
        RowBox[{"chi2bc", "/.", "replacement"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"chi2QFB", "=", 
        RowBox[{"chi2QFB", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"chi2pol", "=", 
        RowBox[{"chi2pol", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"chi2DIS", "=", 
        RowBox[{"chi2DIS", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"chi2QW", "=", 
        RowBox[{"chi2QW", "/.", "replacement"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"chi2hadLEP", "=", 
        RowBox[{"chi2hadLEP", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"chi2muLEP", "=", 
        RowBox[{"chi2muLEP", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"chi2tauLEP", "=", 
        RowBox[{"chi2tauLEP", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"chi2eOPAL", "=", 
        RowBox[{"chi2eOPAL", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"chi2WL3", "=", 
        RowBox[{"chi2WL3", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"chi2As", "=", 
        RowBox[{"chi2As", "/.", "replacement"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"chi2bLEP", "=", 
        RowBox[{"chi2bLEP", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"chi2cLEP", "=", 
        RowBox[{"chi2cLEP", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Chi]\[Tau]To\[Mu]", "=", 
        RowBox[{"\[Chi]\[Tau]To\[Mu]", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Chi]\[Tau]ToPiNu", "=", 
        RowBox[{"\[Chi]\[Tau]ToPiNu", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Chi]a\[Tau]", "=", 
        RowBox[{"\[Chi]a\[Tau]", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Chi]\[CapitalDelta]CKM", "=", 
        RowBox[{"\[Chi]\[CapitalDelta]CKM", "/.", "replacement"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"\[Chi]Wl\[Nu]", "=", 
        RowBox[{"\[Chi]Wl\[Nu]", "/.", "replacement"}]}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5061661462984858`*^9, 3.5061661473295445`*^9}, {
  3.5063375686489544`*^9, 3.5063375912221937`*^9}, {3.5147181968678074`*^9, 
  3.5147182661757717`*^9}, {3.5147183018018093`*^9, 3.514718323810068*^9}, {
  3.5288056301603746`*^9, 3.5288057355404024`*^9}, {3.529934812491597*^9, 
  3.5299348130726304`*^9}, {3.5299348469295673`*^9, 3.5299348490376873`*^9}, {
  3.531674379506383*^9, 3.531674386838396*^9}, {3.5387414801119766`*^9, 
  3.5387414890454874`*^9}, {3.540538675090505*^9, 3.540538681178853*^9}, {
  3.540550691792821*^9, 3.540550694695987*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"chi2total", "=", 
   RowBox[{"Expand", "[", 
    RowBox[{
    "chi2MW", "+", "chi2Zline", "+", "chi2bc", "+", "chi2QFB", "+", "chi2DIS",
      "+", "chi2QW", "+", "chi2hadLEP", "+", "chi2As", "+", "chi2pol", "+", 
     "chi2muLEP", "+", "chi2tauLEP", "+", "chi2eOPAL", "+", "chi2WL3", "+", 
     "chi2bLEP", "+", "chi2cLEP", "+", "\[Chi]\[Tau]To\[Mu]", "+", 
     "\[Chi]\[Tau]ToPiNu", "+", "\[Chi]a\[Tau]", "+", 
     "\[Chi]\[CapitalDelta]CKM", "+", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"Wdecays", "==", "1"}], ",", "\[Chi]Wl\[Nu]", ",", "0"}], 
      "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5061661392460823`*^9, 3.506166155835031*^9}, 
   3.5061675773703384`*^9, {3.506170674826559*^9, 3.506170675044959*^9}, {
   3.5061711175085363`*^9, 3.5061711192401395`*^9}, 3.506171231045536*^9, {
   3.506171709279976*^9, 3.5061717108555784`*^9}, {3.5061726893204975`*^9, 
   3.506172719007349*^9}, {3.506172922338106*^9, 3.5061729273613153`*^9}, 
   3.5062386734074755`*^9, {3.506254257341417*^9, 3.506254261428624*^9}, {
   3.506254987313499*^9, 3.506254995971514*^9}, 3.506259612971224*^9, {
   3.5074690562243023`*^9, 3.5074690894252014`*^9}, {3.5147160767314944`*^9, 
   3.5147161689744563`*^9}, {3.5148036574699044`*^9, 
   3.5148037026631837`*^9}, {3.5148037673408976`*^9, 3.514803771771305*^9}, {
   3.5148038400994253`*^9, 3.5148039339179897`*^9}, {3.514899847818013*^9, 
   3.514899849066085*^9}, {3.515149308796728*^9, 3.5151493328987703`*^9}, 
   3.515149731603012*^9, 3.515149823066243*^9, {3.516519009216921*^9, 
   3.5165190101489744`*^9}, {3.5165277989516373`*^9, 3.516527810308457*^9}, {
   3.5165357744642878`*^9, 3.5165357891595135`*^9}, {3.5215440080524592`*^9, 
   3.5215440107200637`*^9}, {3.522155662274027*^9, 3.5221556646581635`*^9}, {
   3.5224749463569803`*^9, 3.5224749479960737`*^9}, {3.5224964379933753`*^9, 
   3.522496439678178*^9}, 3.5287332498187714`*^9, 3.52873330571367*^9, {
   3.5287351205535*^9, 3.5287351472120247`*^9}, {3.5287388547253156`*^9, 
   3.5287388557237177`*^9}, {3.5288053858894033`*^9, 3.528805425430665*^9}, {
   3.52880613108103*^9, 3.5288061664853163`*^9}, 3.5288103802297635`*^9, {
   3.5288305241067915`*^9, 3.5288305248399925`*^9}, {3.528830556991649*^9, 
   3.5288305712812743`*^9}, 3.5288309194114857`*^9, {3.5288311754391356`*^9, 
   3.528831178683941*^9}, 3.529254916370998*^9, 3.5292550450323567`*^9, 
   3.529430954508772*^9, {3.529934817206867*^9, 3.529934833813817*^9}, {
   3.5316743889911995`*^9, 3.531674392189205*^9}, 3.5352834751775513`*^9, {
   3.5353750013934636`*^9, 3.5353750023575187`*^9}, {3.538741492310674*^9, 
   3.5387415014271955`*^9}, 3.5393509011134043`*^9, {3.539352377642398*^9, 
   3.539352379327201*^9}, {3.5394166290474834`*^9, 3.5394166335597415`*^9}, 
   3.539418953814452*^9, {3.53994318115233*^9, 3.5399431872916813`*^9}, 
   3.53994608901165*^9, {3.540538684704055*^9, 3.540538725246374*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Print chi2total", "Subsection",
 CellChangeTimes->{{3.5109210611681366`*^9, 3.5109210680477486`*^9}, {
  3.515151598112301*^9, 3.515151598627102*^9}, {3.5405639811142073`*^9, 
  3.5405639957158327`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"chi2total", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "If", " ", "you", " ", "want", " ", "to", " ", "save", " ", "the", " ", 
     "chi2total", " ", "in", " ", "an", " ", "external", " ", "file"}], ",", 
    " ", 
    RowBox[{
    "insert", " ", "the", " ", "file", " ", "path", " ", "in", " ", "the", 
     " ", "following", " ", "line"}], ",", " ", 
    RowBox[{
    "uncomment", " ", "the", " ", "following", " ", "two", " ", "lines", " ", 
     "and", " ", "compile", " ", 
     RowBox[{"them", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "You", " ", "can", " ", "then", " ", "use", " ", "the", " ", "chi2total", 
    " ", "with", " ", "the", " ", "file", " ", 
    "\"\<Results - Your analysis\>\""}], "                    ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"DataFile", "=", "\"\<Write here the File Path\>\""}], ";"}], 
   "               ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Save", "[", 
     RowBox[{"DataFile", ",", "chi2total"}], "]"}], ";"}], 
   "                          ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.540538734429899*^9, 3.540538752615939*^9}, {
  3.5405627542168355`*^9, 3.540562805216752*^9}, {3.5405635614356384`*^9, 
  3.5405636043845153`*^9}, {3.5405637643603954`*^9, 3.5405638729706073`*^9}, {
  3.5405639391033335`*^9, 3.5405639658885803`*^9}, {3.5405639979310365`*^9, 
  3.540564055597715*^9}, {3.5405641033504467`*^9, 3.540564106399621*^9}, {
  3.540568371380393*^9, 3.5405684421577177`*^9}}],

Cell[BoxData[
 RowBox[{"223.24740688793548`", "\[VeryThinSpace]", "+", 
  RowBox[{"2.0239875590720877`*^7", " ", "aeb"}], "+", 
  RowBox[{"8.00911748096842`*^13", " ", 
   SuperscriptBox["aeb", "2"]}], "-", 
  RowBox[{"4.349506314335923`*^7", " ", "aed"}], "+", 
  RowBox[{"1.4135036882066688`*^13", " ", "aeb", " ", "aed"}], "+", 
  RowBox[{"1.435755272408507`*^15", " ", 
   SuperscriptBox["aed", "2"]}], "+", 
  RowBox[{"4.384489277185181`*^7", " ", "aee"}], "+", 
  RowBox[{"3.083123039544148`*^14", " ", 
   SuperscriptBox["aee", "2"]}], "+", 
  RowBox[{"337613.6123279468`", " ", "aetau"}], "+", 
  RowBox[{"1.7170742201857672`*^14", " ", 
   SuperscriptBox["aetau", "2"]}], "+", 
  RowBox[{"7.895393618959737`*^7", " ", "aeu"}], "-", 
  RowBox[{"2.1446752110130453`*^13", " ", "aeb", " ", "aeu"}], "+", 
  RowBox[{"2.1344323835615932`*^15", " ", "aed", " ", "aeu"}], "+", 
  RowBox[{"1.3807311553058475`*^15", " ", 
   SuperscriptBox["aeu", "2"]}], "+", 
  RowBox[{"2.208121181590436`*^8", " ", "ah"}], "-", 
  RowBox[{"6.560852545853561`*^13", " ", "aeb", " ", "ah"}], "-", 
  RowBox[{"1.1256408929591803`*^14", " ", "aed", " ", "ah"}], "-", 
  RowBox[{"5.2021094473292086`*^13", " ", "aee", " ", "ah"}], "-", 
  RowBox[{"3.1005911415394188`*^13", " ", "aetau", " ", "ah"}], "+", 
  RowBox[{"1.9907809002979947`*^14", " ", "aeu", " ", "ah"}], "+", 
  RowBox[{"1.0739978608848096`*^16", " ", 
   SuperscriptBox["ah", "2"]}], "+", 
  RowBox[{"1.9041033788522568`*^7", " ", "ahb"}], "-", 
  RowBox[{"1.2171140524682098`*^13", " ", "aeb", " ", "ahb"}], "-", 
  RowBox[{"3.829858543820781`*^11", " ", "aed", " ", "ahb"}], "+", 
  RowBox[{"2.7701000421235156`*^11", " ", "aeu", " ", "ahb"}], "+", 
  RowBox[{"1.9104523261309878`*^14", " ", "ah", " ", "ahb"}], "+", 
  RowBox[{"9.602000794426062`*^13", " ", 
   SuperscriptBox["ahb", "2"]}], "+", 
  RowBox[{"515630.3178418055`", " ", "ahd"}], "-", 
  RowBox[{"3.829858543820791`*^11", " ", "aeb", " ", "ahd"}], "+", 
  RowBox[{"2.7108581031593775`*^15", " ", "aed", " ", "ahd"}], "+", 
  RowBox[{"2.4422882959482185`*^15", " ", "aeu", " ", "ahd"}], "+", 
  RowBox[{"7.410566996334462`*^14", " ", "ah", " ", "ahd"}], "+", 
  RowBox[{"1.1889744388855102`*^14", " ", "ahb", " ", "ahd"}], "+", 
  RowBox[{"1.5645450074365615`*^15", " ", 
   SuperscriptBox["ahd", "2"]}], "+", 
  RowBox[{"5.7467076334730685`*^7", " ", "ahe"}], "-", 
  RowBox[{"3.935956685985138`*^13", " ", "aeb", " ", "ahe"}], "-", 
  RowBox[{"1.005503011327925`*^15", " ", "aed", " ", "ahe"}], "-", 
  RowBox[{"1.2456703159413012`*^14", " ", "aee", " ", "ahe"}], "-", 
  RowBox[{"3.3863099434539055`*^13", " ", "aetau", " ", "ahe"}], "-", 
  RowBox[{"7.453565377172824`*^14", " ", "aeu", " ", "ahe"}], "-", 
  RowBox[{"7.822998338227926`*^15", " ", "ah", " ", "ahe"}], "-", 
  RowBox[{"8.928268531176176`*^14", " ", "ahb", " ", "ahe"}], "-", 
  RowBox[{"3.227264004267105`*^15", " ", "ahd", " ", "ahe"}], "+", 
  RowBox[{"3.118831450762775`*^16", " ", 
   SuperscriptBox["ahe", "2"]}], "-", 
  RowBox[{"4.1562218613766927`*^8", " ", "ahl1"}], "+", 
  RowBox[{"1.0260353999668378`*^14", " ", "aeb", " ", "ahl1"}], "+", 
  RowBox[{"1.1099349090824328`*^15", " ", "aed", " ", "ahl1"}], "+", 
  RowBox[{"1.6948600112760488`*^14", " ", "aee", " ", "ahl1"}], "+", 
  RowBox[{"4.900260882597778`*^13", " ", "aetau", " ", "ahl1"}], "+", 
  RowBox[{"5.3769152208844875`*^14", " ", "aeu", " ", "ahl1"}], "-", 
  RowBox[{"8.65741482970543`*^15", " ", "ah", " ", "ahl1"}], "+", 
  RowBox[{"1.8041639033686275`*^15", " ", "ahb", " ", "ahl1"}], "+", 
  RowBox[{"4.249738834448574`*^15", " ", "ahd", " ", "ahl1"}], "-", 
  RowBox[{"4.793926384648572`*^16", " ", "ahe", " ", "ahl1"}], "+", 
  RowBox[{"4.793943957553125`*^16", " ", 
   SuperscriptBox["ahl1", "2"]}], "-", 
  RowBox[{"8.884169576545256`*^7", " ", "ahL1"}], "+", 
  RowBox[{"4.900260882597778`*^13", " ", "aetau", " ", "ahL1"}], "-", 
  RowBox[{"6.923719923527879`*^14", " ", "ah", " ", "ahL1"}], "+", 
  RowBox[{"3.4555416484423306`*^14", " ", "ahb", " ", "ahL1"}], "+", 
  RowBox[{"6.911083296884661`*^14", " ", "ahd", " ", "ahL1"}], "-", 
  RowBox[{"2.2034794264186955`*^15", " ", "ahe", " ", "ahL1"}], "+", 
  RowBox[{"3.757955659811811`*^15", " ", "ahl1", " ", "ahL1"}], "+", 
  RowBox[{"4.3957050471521415`*^15", " ", 
   SuperscriptBox["ahL1", "2"]}], "+", 
  RowBox[{"3.476866897874722`*^8", " ", "ahl3"}], "-", 
  RowBox[{"1.5983056183745875`*^14", " ", "aeb", " ", "ahl3"}], "+", 
  RowBox[{"6.596785518987605`*^14", " ", "aed", " ", "ahl3"}], "-", 
  RowBox[{"3.8598376765563516`*^13", " ", "aee", " ", "ahl3"}], "-", 
  RowBox[{"7.502103683559895`*^13", " ", "aetau", " ", "ahl3"}], "+", 
  RowBox[{"1.3340038822076465`*^15", " ", "aeu", " ", "ahl3"}], "+", 
  RowBox[{"4.409781607429435`*^16", " ", "ah", " ", "ahl3"}], "+", 
  RowBox[{"2.0125768315622812`*^15", " ", "ahb", " ", "ahl3"}], "+", 
  RowBox[{"5.790656821171506`*^15", " ", "ahd", " ", "ahl3"}], "-", 
  RowBox[{"6.3208456625218776`*^16", " ", "ahe", " ", "ahl3"}], "+", 
  RowBox[{"3.1348919549937024`*^16", " ", "ahl1", " ", "ahl3"}], "-", 
  RowBox[{"8.546756440313945`*^14", " ", "ahL1", " ", "ahl3"}], "+", 
  RowBox[{"1.1842776522284514`*^17", " ", 
   SuperscriptBox["ahl3", "2"]}], "-", 
  RowBox[{"5.328349460640782`*^7", " ", "ahL3"}], "+", 
  RowBox[{"4.900260882597778`*^13", " ", "aetau", " ", "ahL3"}], "-", 
  RowBox[{"1.4506293522057212`*^15", " ", "ah", " ", "ahL3"}], "+", 
  RowBox[{"6.7670163714862875`*^13", " ", "ahb", " ", "ahL3"}], "+", 
  RowBox[{"1.3534032742972575`*^14", " ", "ahd", " ", "ahL3"}], "+", 
  RowBox[{"5.836340000180073`*^15", " ", "ahe", " ", "ahL3"}], "-", 
  RowBox[{"8.205276823882471`*^15", " ", "ahl1", " ", "ahL3"}], "+", 
  RowBox[{"7.86983842708826`*^15", " ", "ahL1", " ", "ahL3"}], "-", 
  RowBox[{"1.436079903328853`*^16", " ", "ahl3", " ", "ahL3"}], "+", 
  RowBox[{"6.73199174192539`*^15", " ", 
   SuperscriptBox["ahL3", "2"]}], "-", 
  RowBox[{"2.5754584150487725`*^6", " ", "ahq1"}], "+", 
  RowBox[{"2.0372687440397842`*^12", " ", "aeb", " ", "ahq1"}], "+", 
  RowBox[{"5.156743664181399`*^15", " ", "aed", " ", "ahq1"}], "+", 
  RowBox[{"4.567849922615583`*^15", " ", "aeu", " ", "ahq1"}], "-", 
  RowBox[{"8.871497980042218`*^14", " ", "ah", " ", "ahq1"}], "-", 
  RowBox[{"1.0271850588302447`*^14", " ", "ahb", " ", "ahq1"}], "+", 
  RowBox[{"4.745597262065505`*^15", " ", "ahd", " ", "ahq1"}], "+", 
  RowBox[{"4.595440424305694`*^14", " ", "ahe", " ", "ahq1"}], "-", 
  RowBox[{"1.6788391714026148`*^15", " ", "ahl1", " ", "ahq1"}], "-", 
  RowBox[{"6.911083296884658`*^14", " ", "ahL1", " ", "ahq1"}], "-", 
  RowBox[{"3.289403249704112`*^15", " ", "ahl3", " ", "ahq1"}], "-", 
  RowBox[{"1.3534032742972544`*^14", " ", "ahL3", " ", "ahq1"}], "+", 
  RowBox[{"5.168472876868703`*^15", " ", 
   SuperscriptBox["ahq1", "2"]}], "-", 
  RowBox[{"3.2797497458341435`*^7", " ", "ahQ1"}], "+", 
  RowBox[{"8.057030497989803`*^13", " ", "aeb", " ", "ahQ1"}], "+", 
  RowBox[{"3.036042657413457`*^12", " ", "aed", " ", "ahQ1"}], "-", 
  RowBox[{"2.6934182563811484`*^12", " ", "aeu", " ", "ahQ1"}], "-", 
  RowBox[{"2.1402821252025768`*^15", " ", "ah", " ", "ahQ1"}], "-", 
  RowBox[{"9.128305709747155`*^14", " ", "ahb", " ", "ahQ1"}], "-", 
  RowBox[{"6.338638642294182`*^14", " ", "ahd", " ", "ahQ1"}], "+", 
  RowBox[{"6.644141299450992`*^15", " ", "ahe", " ", "ahQ1"}], "-", 
  RowBox[{"8.393194134328985`*^15", " ", "ahl1", " ", "ahQ1"}], "-", 
  RowBox[{"1.8975272237067`*^15", " ", "ahL1", " ", "ahQ1"}], "-", 
  RowBox[{"1.3902456902812124`*^16", " ", "ahl3", " ", "ahQ1"}], "-", 
  RowBox[{"3.715943575431181`*^14", " ", "ahL3", " ", "ahQ1"}], "+", 
  RowBox[{"5.742245284721588`*^14", " ", "ahq1", " ", "ahQ1"}], "+", 
  RowBox[{"2.628250214466094`*^15", " ", 
   SuperscriptBox["ahQ1", "2"]}], "+", 
  RowBox[{"6.416225171501243`*^7", " ", "ahq3"}], "+", 
  RowBox[{"4.0348165707871875`*^12", " ", "aeb", " ", "ahq3"}], "+", 
  RowBox[{"4.252301651384278`*^14", " ", "aed", " ", "ahq3"}], "+", 
  RowBox[{"1.060048357392475`*^13", " ", "aeu", " ", "ahq3"}], "-", 
  RowBox[{"7.459284542383974`*^15", " ", "ah", " ", "ahq3"}], "-", 
  RowBox[{"1.2031931775227395`*^15", " ", "ahb", " ", "ahq3"}], "-", 
  RowBox[{"3.322714136559955`*^15", " ", "ahd", " ", "ahq3"}], "+", 
  RowBox[{"2.2692996106580944`*^16", " ", "ahe", " ", "ahq3"}], "-", 
  RowBox[{"3.210346796326195`*^16", " ", "ahl1", " ", "ahq3"}], "-", 
  RowBox[{"6.899000565138338`*^15", " ", "ahL1", " ", "ahq3"}], "-", 
  RowBox[{"1.3119455859615094`*^17", " ", "ahl3", " ", "ahq3"}], "-", 
  RowBox[{"1.3510371027427455`*^15", " ", "ahL3", " ", "ahq3"}], "+", 
  RowBox[{"4.306074541861999`*^15", " ", "ahq1", " ", "ahq3"}], "+", 
  RowBox[{"6.388025737403979`*^15", " ", "ahQ1", " ", "ahq3"}], "+", 
  RowBox[{"5.904889193801624`*^16", " ", 
   SuperscriptBox["ahq3", "2"]}], "-", 
  RowBox[{"3.279749745834139`*^7", " ", "ahQ3"}], "+", 
  RowBox[{"8.057030497989803`*^13", " ", "aeb", " ", "ahQ3"}], "+", 
  RowBox[{"3.036042657413457`*^12", " ", "aed", " ", "ahQ3"}], "-", 
  RowBox[{"2.693418256381164`*^12", " ", "aeu", " ", "ahQ3"}], "-", 
  RowBox[{"2.140282125202577`*^15", " ", "ah", " ", "ahQ3"}], "-", 
  RowBox[{"9.128305709747155`*^14", " ", "ahb", " ", "ahQ3"}], "-", 
  RowBox[{"6.338638642294186`*^14", " ", "ahd", " ", "ahQ3"}], "+", 
  RowBox[{"6.644141299450996`*^15", " ", "ahe", " ", "ahQ3"}], "-", 
  RowBox[{"8.393194134328989`*^15", " ", "ahl1", " ", "ahQ3"}], "-", 
  RowBox[{"1.8975272237067005`*^15", " ", "ahL1", " ", "ahQ3"}], "-", 
  RowBox[{"1.3902456902812128`*^16", " ", "ahl3", " ", "ahQ3"}], "-", 
  RowBox[{"3.715943575431175`*^14", " ", "ahL3", " ", "ahQ3"}], "+", 
  RowBox[{"5.74224528472159`*^14", " ", "ahq1", " ", "ahQ3"}], "+", 
  RowBox[{"5.256500428932188`*^15", " ", "ahQ1", " ", "ahQ3"}], "+", 
  RowBox[{"6.388025737403982`*^15", " ", "ahq3", " ", "ahQ3"}], "+", 
  RowBox[{"2.628250214466094`*^15", " ", 
   SuperscriptBox["ahQ3", "2"]}], "+", 
  RowBox[{"6.810033485953651`*^7", " ", "ahtau"}], "-", 
  RowBox[{"3.3863099434539055`*^13", " ", "aetau", " ", "ahtau"}], "-", 
  RowBox[{"1.324860916579109`*^15", " ", "ah", " ", "ahtau"}], "-", 
  RowBox[{"1.7685134636183466`*^14", " ", "ahb", " ", "ahtau"}], "-", 
  RowBox[{"3.537026927236693`*^14", " ", "ahd", " ", "ahtau"}], "-", 
  RowBox[{"1.328374251481275`*^15", " ", "ahe", " ", "ahtau"}], "+", 
  RowBox[{"2.0962544683928232`*^15", " ", "ahl1", " ", "ahtau"}], "-", 
  RowBox[{"4.190667592862638`*^15", " ", "ahL1", " ", "ahtau"}], "-", 
  RowBox[{"3.910614458925259`*^15", " ", "ahl3", " ", "ahtau"}], "-", 
  RowBox[{"4.544380223363462`*^15", " ", "ahL3", " ", "ahtau"}], "+", 
  RowBox[{"3.5370269272366906`*^14", " ", "ahq1", " ", "ahtau"}], "+", 
  RowBox[{"9.711364480935575`*^14", " ", "ahQ1", " ", "ahtau"}], "+", 
  RowBox[{"3.530843099650562`*^15", " ", "ahq3", " ", "ahtau"}], "+", 
  RowBox[{"9.711364480935575`*^14", " ", "ahQ3", " ", "ahtau"}], "+", 
  RowBox[{"3.585980245069024`*^15", " ", 
   SuperscriptBox["ahtau", "2"]}], "-", 
  RowBox[{"1.6834146594492268`*^7", " ", "ahu"}], "+", 
  RowBox[{"7.511764709358203`*^10", " ", "aeb", " ", "ahu"}], "+", 
  RowBox[{"2.4422882959482185`*^15", " ", "aed", " ", "ahu"}], "+", 
  RowBox[{"2.1169052621539788`*^15", " ", "aeu", " ", "ahu"}], "-", 
  RowBox[{"1.4459378453578215`*^15", " ", "ah", " ", "ahu"}], "-", 
  RowBox[{"2.4529395750479375`*^14", " ", "ahb", " ", "ahu"}], "+", 
  RowBox[{"1.622015579001695`*^15", " ", "ahd", " ", "ahu"}], "+", 
  RowBox[{"3.642885369836704`*^15", " ", "ahe", " ", "ahu"}], "-", 
  RowBox[{"5.783659502862419`*^15", " ", "ahl1", " ", "ahu"}], "-", 
  RowBox[{"1.3822166593769322`*^15", " ", "ahL1", " ", "ahu"}], "-", 
  RowBox[{"8.756640313524998`*^15", " ", "ahl3", " ", "ahu"}], "-", 
  RowBox[{"2.706806548594515`*^14", " ", "ahL3", " ", "ahu"}], "+", 
  RowBox[{"5.330032497634082`*^15", " ", "ahq1", " ", "ahu"}], "+", 
  RowBox[{"1.33237386388075`*^15", " ", "ahQ1", " ", "ahu"}], "+", 
  RowBox[{"7.41589114629551`*^15", " ", "ahq3", " ", "ahu"}], "+", 
  RowBox[{"1.3323738638807508`*^15", " ", "ahQ3", " ", "ahu"}], "+", 
  RowBox[{"7.074053854473386`*^14", " ", "ahtau", " ", "ahu"}], "+", 
  RowBox[{"1.907590782280312`*^15", " ", 
   SuperscriptBox["ahu", "2"]}], "-", 
  RowBox[{"192403.46147908084`", " ", "alb"}], "+", 
  RowBox[{"6.085172669538543`*^13", " ", "aeb", " ", "alb"}], "+", 
  RowBox[{"6.125263732542641`*^12", " ", "aed", " ", "alb"}], "-", 
  RowBox[{"9.539422916283875`*^12", " ", "aeu", " ", "alb"}], "-", 
  RowBox[{"2.417837289442884`*^13", " ", "ah", " ", "alb"}], "-", 
  RowBox[{"3.0218883610286846`*^12", " ", "ahb", " ", "alb"}], "-", 
  RowBox[{"1.3165356497882251`*^11", " ", "ahd", " ", "alb"}], "-", 
  RowBox[{"1.9402935936127008`*^13", " ", "ahe", " ", "alb"}], "+", 
  RowBox[{"3.780737015955102`*^13", " ", "ahl1", " ", "alb"}], "-", 
  RowBox[{"5.890612141816439`*^13", " ", "ahl3", " ", "alb"}], "+", 
  RowBox[{"7.894498083931576`*^11", " ", "ahq1", " ", "alb"}], "+", 
  RowBox[{"3.2715734458335574`*^13", " ", "ahQ1", " ", "alb"}], "+", 
  RowBox[{"1.408655505315588`*^12", " ", "ahq3", " ", "alb"}], "+", 
  RowBox[{"3.2715734458335574`*^13", " ", "ahQ3", " ", "alb"}], "-", 
  RowBox[{"1.2837754101527832`*^10", " ", "ahu", " ", "alb"}], "+", 
  RowBox[{"1.638382679351637`*^13", " ", 
   SuperscriptBox["alb", "2"]}], "-", 
  RowBox[{"5.856706503743095`*^6", " ", "ald"}], "+", 
  RowBox[{"6.125263732542645`*^12", " ", "aeb", " ", "ald"}], "-", 
  RowBox[{"2.6605719485615515`*^15", " ", "aed", " ", "ald"}], "-", 
  RowBox[{"2.5388013497103085`*^15", " ", "aeu", " ", "ald"}], "+", 
  RowBox[{"1.194095507854957`*^13", " ", "ah", " ", "ald"}], "-", 
  RowBox[{"1.3165356497882202`*^11", " ", "ahb", " ", "ald"}], "-", 
  RowBox[{"2.6833355928454`*^15", " ", "ahd", " ", "ald"}], "+", 
  RowBox[{"9.326441193281002`*^14", " ", "ahe", " ", "ald"}], "-", 
  RowBox[{"7.879330894709462`*^14", " ", "ahl1", " ", "ald"}], "-", 
  RowBox[{"1.0519420764501195`*^15", " ", "ahl3", " ", "ald"}], "-", 
  RowBox[{"5.151216221370414`*^15", " ", "ahq1", " ", "ald"}], "+", 
  RowBox[{"1.0990526568543633`*^12", " ", "ahQ1", " ", "ald"}], "-", 
  RowBox[{"2.3765217318688284`*^14", " ", "ahq3", " ", "ald"}], "+", 
  RowBox[{"1.0990526568543672`*^12", " ", "ahQ3", " ", "ald"}], "-", 
  RowBox[{"2.4976170969080485`*^15", " ", "ahu", " ", "ald"}], "+", 
  RowBox[{"2.6827793367693203`*^12", " ", "alb", " ", "ald"}], "+", 
  RowBox[{"1.393350356029763`*^15", " ", 
   SuperscriptBox["ald", "2"]}], "+", 
  RowBox[{"1.0311804266835611`*^7", " ", "ale"}], "+", 
  RowBox[{"3.553741373785771`*^14", " ", "aee", " ", "ale"}], "-", 
  RowBox[{"2.2039859172382957`*^13", " ", "ah", " ", "ale"}], "-", 
  RowBox[{"1.7580728911598281`*^13", " ", "ahe", " ", "ale"}], "+", 
  RowBox[{"6.900844818853858`*^13", " ", "ahl1", " ", "ale"}], "-", 
  RowBox[{"3.66660317898353`*^13", " ", "ahl3", " ", "ale"}], "+", 
  RowBox[{"9.049273706901985`*^14", " ", 
   SuperscriptBox["ale", "2"]}], "+", 
  RowBox[{"9.502041503634686`*^6", " ", "aLe"}], "+", 
  RowBox[{"8.443103961582047`*^13", " ", "aetau", " ", "aLe"}], "+", 
  RowBox[{"1.351762166497414`*^12", " ", "ah", " ", "aLe"}], "+", 
  RowBox[{"1.5876915210644443`*^13", " ", "ahe", " ", "aLe"}], "-", 
  RowBox[{"8.791738661009371`*^12", " ", "ahl1", " ", "aLe"}], "-", 
  RowBox[{"8.791738661009371`*^12", " ", "ahL1", " ", "aLe"}], "-", 
  RowBox[{"3.384689995019715`*^12", " ", "ahl3", " ", "aLe"}], "-", 
  RowBox[{"8.791738661009371`*^12", " ", "ahL3", " ", "aLe"}], "+", 
  RowBox[{"1.5876915210644443`*^13", " ", "ahtau", " ", "aLe"}], "+", 
  RowBox[{"8.70680753898095`*^13", " ", 
   SuperscriptBox["aLe", "2"]}], "+", 
  RowBox[{"4.8261401657548055`*^7", " ", "all1"}], "+", 
  RowBox[{"6.736467757633442`*^14", " ", "aee", " ", "all1"}], "-", 
  RowBox[{"6.743976403257781`*^13", " ", "ah", " ", "all1"}], "-", 
  RowBox[{"1.3688425304055383`*^14", " ", "ahe", " ", "all1"}], "+", 
  RowBox[{"1.9298162091121022`*^14", " ", "ahl1", " ", "all1"}], "-", 
  RowBox[{"5.6790939584784414`*^13", " ", "ahl3", " ", "all1"}], "+", 
  RowBox[{"3.818643849250764`*^14", " ", "ale", " ", "all1"}], "+", 
  RowBox[{"3.768831806536246`*^14", " ", 
   SuperscriptBox["all1", "2"]}], "+", 
  RowBox[{"308954.0247701262`", " ", "alL1"}], "+", 
  RowBox[{"3.774938479819471`*^14", " ", "aetau", " ", "alL1"}], "-", 
  RowBox[{"3.411276789989748`*^13", " ", "ah", " ", "alL1"}], "-", 
  RowBox[{"3.7257027383433125`*^13", " ", "ahe", " ", "alL1"}], "+", 
  RowBox[{"5.391312995008917`*^13", " ", "ahl1", " ", "alL1"}], "+", 
  RowBox[{"5.391312995008917`*^13", " ", "ahL1", " ", "alL1"}], "-", 
  RowBox[{"8.253794164950073`*^13", " ", "ahl3", " ", "alL1"}], "+", 
  RowBox[{"5.391312995008917`*^13", " ", "ahL3", " ", "alL1"}], "-", 
  RowBox[{"3.7257027383433125`*^13", " ", "ahtau", " ", "alL1"}], "+", 
  RowBox[{"9.280026498759084`*^13", " ", "aLe", " ", "alL1"}], "+", 
  RowBox[{"2.0747954578455994`*^14", " ", 
   SuperscriptBox["alL1", "2"]}], "-", 
  RowBox[{"1.7568740576149642`*^8", " ", "all3"}], "+", 
  RowBox[{"1.3121705091707125`*^14", " ", "aeb", " ", "all3"}], "+", 
  RowBox[{"2.2512817859183647`*^14", " ", "aed", " ", "all3"}], "+", 
  RowBox[{"7.776889647099285`*^14", " ", "aee", " ", "all3"}], "+", 
  RowBox[{"6.201182283078837`*^13", " ", "aetau", " ", "all3"}], "-", 
  RowBox[{"3.9815618005959856`*^14", " ", "aeu", " ", "all3"}], "-", 
  RowBox[{"2.7904429668322276`*^16", " ", "ah", " ", "all3"}], "-", 
  RowBox[{"3.820904652261975`*^14", " ", "ahb", " ", "all3"}], "-", 
  RowBox[{"1.3781891301691015`*^15", " ", "ahd", " ", "all3"}], "+", 
  RowBox[{"1.5512230090596338`*^16", " ", "ahe", " ", "all3"}], "+", 
  RowBox[{"1.946016882579861`*^16", " ", "ahl1", " ", "all3"}], "+", 
  RowBox[{"1.3847439847055782`*^15", " ", "ahL1", " ", "all3"}], "-", 
  RowBox[{"1.552762700944818`*^17", " ", "ahl3", " ", "all3"}], "+", 
  RowBox[{"6.169533019528428`*^15", " ", "ahL3", " ", "all3"}], "+", 
  RowBox[{"1.4987998929424748`*^15", " ", "ahq1", " ", "all3"}], "+", 
  RowBox[{"4.2805642504051525`*^15", " ", "ahQ1", " ", "all3"}], "+", 
  RowBox[{"9.61239070331951`*^16", " ", "ahq3", " ", "all3"}], "+", 
  RowBox[{"4.2805642504051525`*^15", " ", "ahQ3", " ", "all3"}], "+", 
  RowBox[{"2.6497218331582175`*^15", " ", "ahtau", " ", "all3"}], "+", 
  RowBox[{"2.6959761701377285`*^15", " ", "ahu", " ", "all3"}], "+", 
  RowBox[{"4.835674578885769`*^13", " ", "alb", " ", "all3"}], "+", 
  RowBox[{"8.004235894069095`*^13", " ", "ald", " ", "all3"}], "+", 
  RowBox[{"4.28366567066291`*^14", " ", "ale", " ", "all3"}], "-", 
  RowBox[{"2.703524332994832`*^12", " ", "aLe", " ", "all3"}], "+", 
  RowBox[{"8.53566814245695`*^14", " ", "all1", " ", "all3"}], "+", 
  RowBox[{"6.822553579979495`*^13", " ", "alL1", " ", "all3"}], "+", 
  RowBox[{"6.634720994415955`*^16", " ", 
   SuperscriptBox["all3", "2"]}], "+", 
  RowBox[{"7.037802212537076`*^7", " ", "alL3"}], "+", 
  RowBox[{"3.774938479819471`*^14", " ", "aetau", " ", "alL3"}], "-", 
  RowBox[{"3.411276789989748`*^13", " ", "ah", " ", "alL3"}], "-", 
  RowBox[{"3.7257027383433125`*^13", " ", "ahe", " ", "alL3"}], "+", 
  RowBox[{"5.391312995008917`*^13", " ", "ahl1", " ", "alL3"}], "+", 
  RowBox[{"5.391312995008917`*^13", " ", "ahL1", " ", "alL3"}], "+", 
  RowBox[{"3.1857363734674855`*^15", " ", "ahl3", " ", "alL3"}], "-", 
  RowBox[{"3.214361185166897`*^15", " ", "ahL3", " ", "alL3"}], "-", 
  RowBox[{"3.7257027383433125`*^13", " ", "ahtau", " ", "alL3"}], "+", 
  RowBox[{"9.280026498759084`*^13", " ", "aLe", " ", "alL3"}], "+", 
  RowBox[{"4.149590915691199`*^14", " ", "alL1", " ", "alL3"}], "-", 
  RowBox[{"3.2000487793171915`*^15", " ", "all3", " ", "alL3"}], "+", 
  RowBox[{"1.841616703343053`*^15", " ", 
   SuperscriptBox["alL3", "2"]}], "+", 
  RowBox[{"3.7951057068982795`*^7", " ", "alq1"}], "+", 
  RowBox[{"3.8224058266110703`*^12", " ", "aeb", " ", "alq1"}], "-", 
  RowBox[{"5.186159430056217`*^15", " ", "aed", " ", "alq1"}], "-", 
  RowBox[{"4.4268463485685625`*^15", " ", "aeu", " ", "alq1"}], "-", 
  RowBox[{"1.3310174444930334`*^14", " ", "ah", " ", "alq1"}], "-", 
  RowBox[{"5.81111602026802`*^11", " ", "ahb", " ", "alq1"}], "-", 
  RowBox[{"5.153598313846216`*^15", " ", "ahd", " ", "alq1"}], "+", 
  RowBox[{"1.817070184224006`*^15", " ", "ahe", " ", "alq1"}], "-", 
  RowBox[{"2.1317147601931148`*^15", " ", "ahl1", " ", "alq1"}], "-", 
  RowBox[{"1.8376226287924218`*^15", " ", "ahl3", " ", "alq1"}], "-", 
  RowBox[{"9.6710510181164`*^15", " ", "ahq1", " ", "alq1"}], "+", 
  RowBox[{"3.82608935770809`*^12", " ", "ahQ1", " ", "alq1"}], "-", 
  RowBox[{"5.446402920937528`*^14", " ", "ahq3", " ", "alq1"}], "+", 
  RowBox[{"3.82608935770809`*^12", " ", "ahQ3", " ", "alq1"}], "-", 
  RowBox[{"4.569855494059898`*^15", " ", "ahu", " ", "alq1"}], "+", 
  RowBox[{"1.2698264827340762`*^12", " ", "alb", " ", "alq1"}], "+", 
  RowBox[{"5.1147200545571`*^15", " ", "ald", " ", "alq1"}], "-", 
  RowBox[{"9.296214167362875`*^12", " ", "all3", " ", "alq1"}], "+", 
  RowBox[{"4.942006451543632`*^15", " ", 
   SuperscriptBox["alq1", "2"]}], "+", 
  RowBox[{"5.1779316650454596`*^7", " ", "alQ1"}], "+", 
  RowBox[{"4.014951423188297`*^14", " ", "aeb", " ", "alQ1"}], "+", 
  RowBox[{"3.408945183237825`*^13", " ", "aed", " ", "alQ1"}], "-", 
  RowBox[{"5.111098644591706`*^13", " ", "aeu", " ", "alQ1"}], "-", 
  RowBox[{"1.657088673718984`*^14", " ", "ah", " ", "alQ1"}], "-", 
  RowBox[{"3.0745163164423406`*^13", " ", "ahb", " ", "alQ1"}], "-", 
  RowBox[{"1.0091195412596348`*^12", " ", "ahd", " ", "alQ1"}], "-", 
  RowBox[{"9.99470166473554`*^13", " ", "ahe", " ", "alQ1"}], "+", 
  RowBox[{"2.5919134937166006`*^14", " ", "ahl1", " ", "alQ1"}], "-", 
  RowBox[{"4.036441201159336`*^14", " ", "ahl3", " ", "alQ1"}], "+", 
  RowBox[{"5.145908197359189`*^12", " ", "ahq1", " ", "alQ1"}], "+", 
  RowBox[{"2.0342067053078356`*^14", " ", "ahQ1", " ", "alQ1"}], "+", 
  RowBox[{"1.0577262486360406`*^13", " ", "ahq3", " ", "alQ1"}], "+", 
  RowBox[{"2.0342067053078356`*^14", " ", "ahQ3", " ", "alQ1"}], "+", 
  RowBox[{"2.942372825444961`*^11", " ", "ahu", " ", "alQ1"}], "+", 
  RowBox[{"1.5232474266722403`*^14", " ", "alb", " ", "alQ1"}], "+", 
  RowBox[{"1.470138203338557`*^13", " ", "ald", " ", "alQ1"}], "+", 
  RowBox[{"3.314177347437969`*^14", " ", "all3", " ", "alQ1"}], "+", 
  RowBox[{"1.018154065733254`*^13", " ", "alq1", " ", "alQ1"}], "+", 
  RowBox[{"5.0341408536384444`*^14", " ", 
   SuperscriptBox["alQ1", "2"]}], "-", 
  RowBox[{"3.021247687546405`*^8", " ", "alq3"}], "+", 
  RowBox[{"6.435649783814569`*^13", " ", "aeb", " ", "alq3"}], "+", 
  RowBox[{"4.9509473389936175`*^14", " ", "aed", " ", "alq3"}], "-", 
  RowBox[{"1.8580592799219802`*^15", " ", "aeu", " ", "alq3"}], "-", 
  RowBox[{"2.3226477994412622`*^14", " ", "ah", " ", "alq3"}], "-", 
  RowBox[{"1.4371274804924785`*^12", " ", "ahb", " ", "alq3"}], "-", 
  RowBox[{"3.625383066127617`*^14", " ", "ahd", " ", "alq3"}], "-", 
  RowBox[{"1.811801430972457`*^14", " ", "ahe", " ", "alq3"}], "+", 
  RowBox[{"1.204457832441302`*^15", " ", "ahl1", " ", "alq3"}], "+", 
  RowBox[{"7.999629150496963`*^16", " ", "ahl3", " ", "alq3"}], "+", 
  RowBox[{"5.788239895857522`*^14", " ", "ahL3", " ", "alq3"}], "-", 
  RowBox[{"5.792102865537499`*^14", " ", "ahq1", " ", "alq3"}], "+", 
  RowBox[{"1.1897081326011469`*^13", " ", "ahQ1", " ", "alq3"}], "-", 
  RowBox[{"8.115607105647286`*^16", " ", "ahq3", " ", "alq3"}], "+", 
  RowBox[{"1.1897081326011516`*^13", " ", "ahQ3", " ", "alq3"}], "-", 
  RowBox[{"1.3195088788694938`*^14", " ", "ahu", " ", "alq3"}], "+", 
  RowBox[{"2.813293758403711`*^13", " ", "alb", " ", "alq3"}], "+", 
  RowBox[{"6.040544762982685`*^14", " ", "ald", " ", "alq3"}], "-", 
  RowBox[{"8.075149932539696`*^16", " ", "all3", " ", "alq3"}], "+", 
  RowBox[{"1.6806265810869594`*^14", " ", "alq1", " ", "alq3"}], "+", 
  RowBox[{"1.5459874799863138`*^14", " ", "alQ1", " ", "alq3"}], "+", 
  RowBox[{"4.3356025580512424`*^16", " ", 
   SuperscriptBox["alq3", "2"]}], "+", 
  RowBox[{"5.1779316650454596`*^7", " ", "alQ3"}], "+", 
  RowBox[{"4.014951423188297`*^14", " ", "aeb", " ", "alQ3"}], "+", 
  RowBox[{"3.408945183237825`*^13", " ", "aed", " ", "alQ3"}], "-", 
  RowBox[{"5.111098644591706`*^13", " ", "aeu", " ", "alQ3"}], "-", 
  RowBox[{"1.657088673718984`*^14", " ", "ah", " ", "alQ3"}], "-", 
  RowBox[{"3.0745163164423406`*^13", " ", "ahb", " ", "alQ3"}], "-", 
  RowBox[{"1.0091195412596348`*^12", " ", "ahd", " ", "alQ3"}], "-", 
  RowBox[{"9.99470166473554`*^13", " ", "ahe", " ", "alQ3"}], "+", 
  RowBox[{"2.5919134937166006`*^14", " ", "ahl1", " ", "alQ3"}], "-", 
  RowBox[{"4.036441201159336`*^14", " ", "ahl3", " ", "alQ3"}], "+", 
  RowBox[{"5.145908197359189`*^12", " ", "ahq1", " ", "alQ3"}], "+", 
  RowBox[{"2.0342067053078356`*^14", " ", "ahQ1", " ", "alQ3"}], "+", 
  RowBox[{"1.0577262486360406`*^13", " ", "ahq3", " ", "alQ3"}], "+", 
  RowBox[{"2.0342067053078356`*^14", " ", "ahQ3", " ", "alQ3"}], "+", 
  RowBox[{"2.942372825444961`*^11", " ", "ahu", " ", "alQ3"}], "+", 
  RowBox[{"1.5232474266722403`*^14", " ", "alb", " ", "alQ3"}], "+", 
  RowBox[{"1.470138203338557`*^13", " ", "ald", " ", "alQ3"}], "+", 
  RowBox[{"3.314177347437969`*^14", " ", "all3", " ", "alQ3"}], "+", 
  RowBox[{"1.018154065733254`*^13", " ", "alq1", " ", "alQ3"}], "+", 
  RowBox[{"1.0068281707276889`*^15", " ", "alQ1", " ", "alQ3"}], "+", 
  RowBox[{"1.5459874799863138`*^14", " ", "alq3", " ", "alQ3"}], "+", 
  RowBox[{"5.0341408536384444`*^14", " ", 
   SuperscriptBox["alQ3", "2"]}], "+", 
  RowBox[{"1.9064856497544844`*^6", " ", "aLq3"}], "+", 
  RowBox[{"5.788239895857522`*^14", " ", "ahl3", " ", "aLq3"}], "-", 
  RowBox[{"5.788239895857522`*^14", " ", "ahL3", " ", "aLq3"}], "-", 
  RowBox[{"5.788239895857522`*^14", " ", "alq3", " ", "aLq3"}], "+", 
  RowBox[{"2.894119947928761`*^14", " ", 
   SuperscriptBox["aLq3", "2"]}], "+", 
  RowBox[{"9.502041503634695`*^6", " ", "altau"}], "+", 
  RowBox[{"8.44310396158205`*^13", " ", "aetau", " ", "altau"}], "+", 
  RowBox[{"1.351762166497414`*^12", " ", "ah", " ", "altau"}], "+", 
  RowBox[{"1.587691521064445`*^13", " ", "ahe", " ", "altau"}], "-", 
  RowBox[{"8.791738661009379`*^12", " ", "ahl1", " ", "altau"}], "-", 
  RowBox[{"8.791738661009379`*^12", " ", "ahL1", " ", "altau"}], "-", 
  RowBox[{"3.384689995019715`*^12", " ", "ahl3", " ", "altau"}], "-", 
  RowBox[{"8.791738661009379`*^12", " ", "ahL3", " ", "altau"}], "+", 
  RowBox[{"1.587691521064445`*^13", " ", "ahtau", " ", "altau"}], "+", 
  RowBox[{"1.7413615077961906`*^14", " ", "aLe", " ", "altau"}], "+", 
  RowBox[{"9.280026498759088`*^13", " ", "alL1", " ", "altau"}], "-", 
  RowBox[{"2.703524332994836`*^12", " ", "all3", " ", "altau"}], "+", 
  RowBox[{"9.280026498759088`*^13", " ", "alL3", " ", "altau"}], "+", 
  RowBox[{"8.706807538980958`*^13", " ", 
   SuperscriptBox["altau", "2"]}], "+", 
  RowBox[{"2.869769529438737`*^7", " ", "alu"}], "-", 
  RowBox[{"9.914363277408836`*^12", " ", "aeb", " ", "alu"}], "-", 
  RowBox[{"2.5388013497103085`*^15", " ", "aed", " ", "alu"}], "-", 
  RowBox[{"1.9174198066812172`*^15", " ", "aeu", " ", "alu"}], "+", 
  RowBox[{"6.342190466831371`*^12", " ", "ah", " ", "alu"}], "+", 
  RowBox[{"9.27039796503335`*^10", " ", "ahb", " ", "alu"}], "-", 
  RowBox[{"2.4976170969080485`*^15", " ", "ahd", " ", "alu"}], "+", 
  RowBox[{"8.870160838436832`*^14", " ", "ahe", " ", "alu"}], "-", 
  RowBox[{"1.163203531804118`*^15", " ", "ahl1", " ", "alu"}], "-", 
  RowBox[{"5.501362082030484`*^14", " ", "ahl3", " ", "alu"}], "-", 
  RowBox[{"4.564466478403017`*^15", " ", "ahq1", " ", "alu"}], "-", 
  RowBox[{"1.0202415880089023`*^12", " ", "ahQ1", " ", "alu"}], "-", 
  RowBox[{"3.873212087371646`*^14", " ", "ahq3", " ", "alu"}], "-", 
  RowBox[{"1.0202415880089102`*^12", " ", "ahQ3", " ", "alu"}], "-", 
  RowBox[{"2.0103878772546582`*^15", " ", "ahu", " ", "alu"}], "-", 
  RowBox[{"4.440913500027293`*^12", " ", "alb", " ", "alu"}], "+", 
  RowBox[{"2.294469447872356`*^15", " ", "ald", " ", "alu"}], "-", 
  RowBox[{"2.0858390151157775`*^14", " ", "all3", " ", "alu"}], "+", 
  RowBox[{"4.662684414579747`*^15", " ", "alq1", " ", "alu"}], "-", 
  RowBox[{"2.355014122376072`*^13", " ", "alQ1", " ", "alu"}], "-", 
  RowBox[{"3.4521271510282594`*^14", " ", "alq3", " ", "alu"}], "-", 
  RowBox[{"2.355014122376072`*^13", " ", "alQ3", " ", "alu"}], "+", 
  RowBox[{"1.2102960213857765`*^15", " ", 
   SuperscriptBox["alu", "2"]}], "+", 
  RowBox[{"3.050815688872363`*^7", " ", "aqe"}], "-", 
  RowBox[{"1.348860831565668`*^13", " ", "aeb", " ", "aqe"}], "+", 
  RowBox[{"4.994588396669287`*^15", " ", "aed", " ", "aqe"}], "+", 
  RowBox[{"4.871928492230591`*^15", " ", "aeu", " ", "aqe"}], "+", 
  RowBox[{"8.848667082013212`*^13", " ", "ah", " ", "aqe"}], "+", 
  RowBox[{"3.376071988645054`*^11", " ", "ahb", " ", "aqe"}], "+", 
  RowBox[{"5.153972303329955`*^15", " ", "ahd", " ", "aqe"}], "-", 
  RowBox[{"1.7484340135139142`*^15", " ", "ahe", " ", "aqe"}], "+", 
  RowBox[{"1.6441290816325578`*^15", " ", "ahl1", " ", "aqe"}], "+", 
  RowBox[{"1.9980757649130865`*^15", " ", "ahl3", " ", "aqe"}], "+", 
  RowBox[{"9.713289166299598`*^15", " ", "ahq1", " ", "aqe"}], "-", 
  RowBox[{"2.722171691225535`*^12", " ", "ahQ1", " ", "aqe"}], "+", 
  RowBox[{"4.357289518948087`*^14", " ", "ahq3", " ", "aqe"}], "-", 
  RowBox[{"2.722171691225535`*^12", " ", "ahQ3", " ", "aqe"}], "+", 
  RowBox[{"4.561579619272565`*^15", " ", "ahu", " ", "aqe"}], "-", 
  RowBox[{"5.867378336874113`*^12", " ", "alb", " ", "aqe"}], "-", 
  RowBox[{"5.203871135182003`*^15", " ", "ald", " ", "aqe"}], "-", 
  RowBox[{"1.769733416402635`*^14", " ", "all3", " ", "aqe"}], "-", 
  RowBox[{"9.676314621440736`*^15", " ", "alq1", " ", "aqe"}], "-", 
  RowBox[{"3.2475061813084094`*^13", " ", "alQ1", " ", "aqe"}], "-", 
  RowBox[{"1.356528364184512`*^15", " ", "alq3", " ", "aqe"}], "-", 
  RowBox[{"3.2475061813084094`*^13", " ", "alQ3", " ", "aqe"}], "-", 
  RowBox[{"4.4636354854989855`*^15", " ", "alu", " ", "aqe"}], "+", 
  RowBox[{"4.936869655920088`*^15", " ", 
   SuperscriptBox["aqe", "2"]}], "-", 
  RowBox[{"1.8425468435484823`*^6", " ", "aQe"}], "-", 
  RowBox[{"1.2527608596881042`*^14", " ", "aeb", " ", "aQe"}], "-", 
  RowBox[{"9.89428256650546`*^12", " ", "aed", " ", "aQe"}], "+", 
  RowBox[{"1.427523547140925`*^13", " ", "aeu", " ", "aQe"}], "+", 
  RowBox[{"5.227236644996075`*^13", " ", "ah", " ", "aQe"}], "+", 
  RowBox[{"6.650034151303512`*^12", " ", "ahb", " ", "aQe"}], "+", 
  RowBox[{"3.710110138276909`*^11", " ", "ahd", " ", "aQe"}], "+", 
  RowBox[{"4.287057616623075`*^13", " ", "ahe", " ", "aQe"}], "-", 
  RowBox[{"8.183752660932195`*^13", " ", "ahl1", " ", "aQe"}], "+", 
  RowBox[{"1.272519391905211`*^14", " ", "ahl3", " ", "aQe"}], "-", 
  RowBox[{"1.706188062900095`*^12", " ", "ahq1", " ", "aQe"}], "-", 
  RowBox[{"7.045585604902897`*^13", " ", "ahQ1", " ", "aQe"}], "-", 
  RowBox[{"3.8436666256275703`*^12", " ", "ahq3", " ", "aQe"}], "-", 
  RowBox[{"7.045585604902897`*^13", " ", "ahQ3", " ", "aQe"}], "-", 
  RowBox[{"1.8874855649174902`*^11", " ", "ahu", " ", "aQe"}], "-", 
  RowBox[{"6.710775877642345`*^13", " ", "alb", " ", "aQe"}], "-", 
  RowBox[{"4.202189454777332`*^12", " ", "ald", " ", "aQe"}], "-", 
  RowBox[{"1.0454473289992153`*^14", " ", "all3", " ", "aQe"}], "-", 
  RowBox[{"3.835332205019926`*^12", " ", "alq1", " ", "aQe"}], "-", 
  RowBox[{"3.1455374745956556`*^14", " ", "alQ1", " ", "aQe"}], "-", 
  RowBox[{"4.431418292417978`*^13", " ", "alq3", " ", "aQe"}], "-", 
  RowBox[{"3.1455374745956556`*^14", " ", "alQ3", " ", "aQe"}], "+", 
  RowBox[{"6.505986054735789`*^12", " ", "alu", " ", "aQe"}], "+", 
  RowBox[{"9.375081620691008`*^12", " ", "aqe", " ", "aQe"}], "+", 
  RowBox[{"6.985443196423621`*^13", " ", 
   SuperscriptBox["aQe", "2"]}], "-", 
  RowBox[{"1.1473148825510636`*^6", " ", "atauBt"}], "-", 
  RowBox[{"1.142040077958136`*^13", " ", "aetau", " ", "atauBt"}], "-", 
  RowBox[{"7.296362996565589`*^12", " ", "ah", " ", "atauBt"}], "+", 
  RowBox[{"3.0639656756370764`*^11", " ", "ahb", " ", "atauBt"}], "+", 
  RowBox[{"6.127931351274153`*^11", " ", "ahd", " ", "atauBt"}], "+", 
  RowBox[{"9.23094355906656`*^12", " ", "ahe", " ", "atauBt"}], "+", 
  RowBox[{"9.996170813025078`*^11", " ", "ahl1", " ", "atauBt"}], "+", 
  RowBox[{"1.5051324325010793`*^13", " ", "ahL1", " ", "atauBt"}], "-", 
  RowBox[{"2.698507235788399`*^13", " ", "ahl3", " ", "atauBt"}], "+", 
  RowBox[{"1.5651705598548725`*^13", " ", "ahL3", " ", "atauBt"}], "-", 
  RowBox[{"6.127931351274143`*^11", " ", "ahq1", " ", "atauBt"}], "-", 
  RowBox[{"1.6825027372033052`*^12", " ", "ahQ1", " ", "atauBt"}], "-", 
  RowBox[{"6.117217813685804`*^12", " ", "ahq3", " ", "atauBt"}], "-", 
  RowBox[{"1.6825027372033052`*^12", " ", "ahQ3", " ", "atauBt"}], "-", 
  RowBox[{"1.5224158170376814`*^12", " ", "ahtau", " ", "atauBt"}], "-", 
  RowBox[{"1.2255862702548306`*^12", " ", "ahu", " ", "atauBt"}], "-", 
  RowBox[{"7.996543268656081`*^12", " ", "aLe", " ", "atauBt"}], "-", 
  RowBox[{"1.2558965744101021`*^13", " ", "alL1", " ", "atauBt"}], "+", 
  RowBox[{"1.459272599313118`*^13", " ", "all3", " ", "atauBt"}], "-", 
  RowBox[{"1.2558965744101021`*^13", " ", "alL3", " ", "atauBt"}], "-", 
  RowBox[{"7.996543268656084`*^12", " ", "altau", " ", "atauBt"}], "+", 
  RowBox[{"5.0318067175019556`*^11", " ", 
   SuperscriptBox["atauBt", "2"]}], "-", 
  RowBox[{"2.5355520620515104`*^6", " ", "atauWt"}], "+", 
  RowBox[{"7.628520571143122`*^12", " ", "aetau", " ", "atauWt"}], "-", 
  RowBox[{"1.5178212462845416`*^13", " ", "ah", " ", "atauWt"}], "+", 
  RowBox[{"5.588526960266877`*^11", " ", "ahb", " ", "atauWt"}], "+", 
  RowBox[{"1.1177053920533755`*^12", " ", "ahd", " ", "atauWt"}], "+", 
  RowBox[{"1.5982545244141059`*^13", " ", "ahe", " ", "atauWt"}], "+", 
  RowBox[{"4.2307537386197676`*^12", " ", "ahl1", " ", "atauWt"}], "+", 
  RowBox[{"2.985907535916393`*^13", " ", "ahL1", " ", "atauWt"}], "-", 
  RowBox[{"5.429188661243289`*^13", " ", "ahl3", " ", "atauWt"}], "+", 
  RowBox[{"3.095418010932846`*^13", " ", "ahL3", " ", "atauWt"}], "-", 
  RowBox[{"1.1177053920533745`*^12", " ", "ahq1", " ", "atauWt"}], "-", 
  RowBox[{"3.0688045830110117`*^12", " ", "ahQ1", " ", "atauWt"}], "-", 
  RowBox[{"1.1157512939990672`*^13", " ", "ahq3", " ", "atauWt"}], "-", 
  RowBox[{"3.0688045830110107`*^12", " ", "ahQ3", " ", "atauWt"}], "-", 
  RowBox[{"3.633512296856827`*^12", " ", "ahtau", " ", "atauWt"}], "-", 
  RowBox[{"2.235410784106751`*^12", " ", "ahu", " ", "atauWt"}], "+", 
  RowBox[{"5.21792656449468`*^12", " ", "aLe", " ", "atauWt"}], "+", 
  RowBox[{"8.389732646656066`*^12", " ", "alL1", " ", "atauWt"}], "+", 
  RowBox[{"3.0356424925690836`*^13", " ", "all3", " ", "atauWt"}], "+", 
  RowBox[{"8.389732646656066`*^12", " ", "alL3", " ", "atauWt"}], "+", 
  RowBox[{"5.217926564494682`*^12", " ", "altau", " ", "atauWt"}], "+", 
  RowBox[{"2.275942036094067`*^11", " ", "atauBt", " ", "atauWt"}], "+", 
  RowBox[{"7.275566542211517`*^11", " ", 
   SuperscriptBox["atauWt", "2"]}], "+", 
  RowBox[{"1.0166032315579371`*^6", " ", "aW"}], "+", 
  RowBox[{"8.956941612206582`*^12", " ", "ah", " ", "aW"}], "+", 
  RowBox[{"2.853318384427856`*^12", " ", "ahe", " ", "aW"}], "+", 
  RowBox[{"1.2622695247677342`*^13", " ", "ahl1", " ", "aW"}], "-", 
  RowBox[{"3.457984606996489`*^12", " ", "ahl3", " ", "aW"}], "+", 
  RowBox[{"1.6024436419425403`*^12", " ", "ahq3", " ", "aW"}], "-", 
  RowBox[{"8.35816270993225`*^12", " ", "all3", " ", "aW"}], "+", 
  RowBox[{"2.621086924689996`*^12", " ", 
   SuperscriptBox["aW", "2"]}], "+", 
  RowBox[{"5.96365661234771`*^8", " ", "aWB"}], "-", 
  RowBox[{"1.3722212406589`*^14", " ", "aeb", " ", "aWB"}], "+", 
  RowBox[{"1.9845691859366382`*^15", " ", "aed", " ", "aWB"}], "-", 
  RowBox[{"7.040904280619256`*^13", " ", "aee", " ", "aWB"}], "-", 
  RowBox[{"4.7461389959633234`*^13", " ", "aetau", " ", "aWB"}], "+", 
  RowBox[{"2.447840382518223`*^15", " ", "aeu", " ", "aWB"}], "+", 
  RowBox[{"6.031777398139479`*^16", " ", "ah", " ", "aWB"}], "-", 
  RowBox[{"6.526199182559486`*^13", " ", "ahb", " ", "aWB"}], "+", 
  RowBox[{"3.5925064394245095`*^15", " ", "ahd", " ", "aWB"}], "-", 
  RowBox[{"5.112932688540952`*^16", " ", "ahe", " ", "aWB"}], "-", 
  RowBox[{"3.1609083266970416`*^16", " ", "ahl1", " ", "aWB"}], "-", 
  RowBox[{"3.2494683832894505`*^15", " ", "ahL1", " ", "aWB"}], "+", 
  RowBox[{"1.4117353739120723`*^17", " ", "ahl3", " ", "aWB"}], "-", 
  RowBox[{"4.778251628465609`*^15", " ", "ahL3", " ", "aWB"}], "+", 
  RowBox[{"2.655144532372248`*^15", " ", "ahq1", " ", "aWB"}], "-", 
  RowBox[{"4.796635517323774`*^15", " ", "ahQ1", " ", "aWB"}], "-", 
  RowBox[{"1.469541804208894`*^16", " ", "ahq3", " ", "aWB"}], "-", 
  RowBox[{"4.796635517323774`*^15", " ", "ahQ3", " ", "aWB"}], "-", 
  RowBox[{"7.210873491187712`*^15", " ", "ahtau", " ", "aWB"}], "-", 
  RowBox[{"5.0903858020093975`*^14", " ", "ahu", " ", "aWB"}], "-", 
  RowBox[{"4.520547590356466`*^13", " ", "alb", " ", "aWB"}], "-", 
  RowBox[{"2.350402298800511`*^15", " ", "ald", " ", "aWB"}], "-", 
  RowBox[{"6.6884165038955125`*^13", " ", "ale", " ", "aWB"}], "-", 
  RowBox[{"2.2211573602592246`*^13", " ", "aLe", " ", "aWB"}], "-", 
  RowBox[{"1.0359491852508227`*^14", " ", "all1", " ", "aWB"}], "-", 
  RowBox[{"5.2215812196050695`*^13", " ", "alL1", " ", "aWB"}], "-", 
  RowBox[{"8.887501709518275`*^16", " ", "all3", " ", "aWB"}], "-", 
  RowBox[{"5.2215812196050695`*^13", " ", "alL3", " ", "aWB"}], "-", 
  RowBox[{"4.3386140743700735`*^15", " ", "alq1", " ", "aWB"}], "-", 
  RowBox[{"3.459421774799329`*^14", " ", "alQ1", " ", "aWB"}], "-", 
  RowBox[{"1.0380452826435332`*^15", " ", "alq3", " ", "aWB"}], "-", 
  RowBox[{"3.459421774799329`*^14", " ", "alQ3", " ", "aWB"}], "-", 
  RowBox[{"2.2211573602592254`*^13", " ", "altau", " ", "aWB"}], "-", 
  RowBox[{"1.711919494265401`*^15", " ", "alu", " ", "aWB"}], "+", 
  RowBox[{"4.4346474988870705`*^15", " ", "aqe", " ", "aWB"}], "+", 
  RowBox[{"9.65928951831769`*^13", " ", "aQe", " ", "aWB"}], "-", 
  RowBox[{"3.4901528932742414`*^13", " ", "atauBt", " ", "aWB"}], "-", 
  RowBox[{"6.852223324548234`*^13", " ", "atauWt", " ", "aWB"}], "+", 
  RowBox[{"1.5283353123283645`*^13", " ", "aW", " ", "aWB"}], "+", 
  RowBox[{"1.0665373042875603`*^17", " ", 
   SuperscriptBox["aWB", "2"]}]}]], "Output",
 CellChangeTimes->{3.538896633458351*^9, 3.5388971045552964`*^9, 
  3.538898354748803*^9, 3.539351055163675*^9, 3.5393525334086714`*^9, 
  3.539416590930303*^9, 3.539416638133003*^9, 3.539417935154188*^9, 
  3.53941909940878*^9, 3.5399430595063725`*^9, 3.5399431900088367`*^9, 
  3.540540600704644*^9, 3.5405408849499016`*^9, 3.5405417677943974`*^9, 
  3.540542371873949*^9, 3.5405508629296093`*^9, 3.5405511457757874`*^9, 
  3.5405686283284445`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1350, 611},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 82, 1, 69, "Title"],
Cell[CellGroupData[{
Cell[674, 27, 2867, 64, 224, "Section"],
Cell[3544, 93, 2983, 56, 529, "Subsection"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6564, 154, 8154, 198, 604, "Section"],
Cell[14721, 354, 222, 6, 52, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[14980, 365, 686, 17, 74, "Section"],
Cell[15669, 384, 5824, 135, 492, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[21530, 524, 779, 18, 74, "Section"],
Cell[CellGroupData[{
Cell[22334, 546, 145, 1, 28, "Subsubsection"],
Cell[22482, 549, 2082, 59, 188, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[24601, 613, 111, 1, 27, "Subsubsection"],
Cell[24715, 616, 1566, 38, 92, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26318, 659, 153, 2, 28, "Subsubsection"],
Cell[26474, 663, 1897, 36, 92, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[28408, 704, 103, 1, 21, "Subsubsection"],
Cell[28514, 707, 632, 15, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29183, 727, 107, 1, 27, "Subsubsection"],
Cell[29293, 730, 264, 6, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[29594, 741, 129, 1, 27, "Subsubsection"],
Cell[29726, 744, 626, 10, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30389, 759, 103, 1, 27, "Subsubsection"],
Cell[30495, 762, 327, 7, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30859, 774, 109, 1, 27, "Subsubsection"],
Cell[30971, 777, 314, 7, 92, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31322, 789, 143, 1, 28, "Subsubsection"],
Cell[31468, 792, 2973, 81, 348, "Input"],
Cell[34444, 875, 486, 13, 52, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[34979, 894, 772, 18, 74, "Section"],
Cell[CellGroupData[{
Cell[35776, 916, 150, 2, 36, "Subsection"],
Cell[35929, 920, 476, 9, 31, "Input"],
Cell[36408, 931, 29458, 899, 1192, "Input"],
Cell[65869, 1832, 373, 9, 31, "Input"],
Cell[CellGroupData[{
Cell[66267, 1845, 175, 3, 27, "Subsubsection"],
Cell[66445, 1850, 17358, 446, 1052, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[83852, 2302, 99, 1, 28, "Subsection"],
Cell[CellGroupData[{
Cell[83976, 2307, 131, 1, 27, "Subsubsection"],
Cell[84110, 2310, 11662, 271, 1092, "Input"],
Cell[95775, 2583, 430, 9, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[96242, 2597, 126, 1, 27, "Subsubsection"],
Cell[96371, 2600, 8040, 172, 492, "Input"],
Cell[104414, 2774, 409, 9, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[104860, 2788, 129, 1, 21, "Subsubsection"],
Cell[104992, 2791, 3283, 87, 172, "Input"],
Cell[108278, 2880, 476, 9, 31, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[108791, 2894, 244, 5, 27, "Subsubsection"],
Cell[109038, 2901, 310606, 4513, 26712, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[419681, 7419, 97, 1, 21, "Subsubsection"],
Cell[419781, 7422, 4691, 126, 432, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[424521, 7554, 81, 1, 28, "Subsection"],
Cell[424605, 7557, 829, 17, 52, "Input"],
Cell[425437, 7576, 552, 12, 31, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[426038, 7594, 801, 18, 74, "Section"],
Cell[CellGroupData[{
Cell[426864, 7616, 109, 1, 36, "Subsection"],
Cell[426976, 7619, 5076, 116, 352, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[432089, 7740, 136, 3, 28, "Subsection"],
Cell[432228, 7745, 5981, 144, 537, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[438246, 7894, 114, 3, 28, "Subsection"],
Cell[438363, 7899, 4122, 109, 272, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[442522, 8013, 189, 4, 28, "Subsection"],
Cell[442714, 8019, 22279, 566, 1532, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[465030, 8590, 103, 1, 28, "Subsection"],
Cell[465136, 8593, 15238, 401, 1052, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[480411, 8999, 202, 3, 28, "Subsection"],
Cell[480616, 9004, 3511, 90, 372, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[484164, 9099, 205, 3, 28, "Subsection"],
Cell[484372, 9104, 8018, 195, 792, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[492439, 9305, 1120, 26, 94, "Section"],
Cell[CellGroupData[{
Cell[493584, 9335, 130, 1, 36, "Subsection"],
Cell[493717, 9338, 5630, 151, 652, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[499384, 9494, 136, 1, 28, "Subsection"],
Cell[499523, 9497, 11674, 357, 1252, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[511234, 9859, 83, 1, 28, "Subsection"],
Cell[511320, 9862, 7399, 201, 400, "Input"],
Cell[CellGroupData[{
Cell[518744, 10067, 141, 3, 27, "Subsubsection"],
Cell[518888, 10072, 10515, 299, 808, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[529440, 10376, 114, 1, 21, "Subsubsection"],
Cell[529557, 10379, 1140, 35, 112, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[530734, 10419, 97, 1, 21, "Subsubsection"],
Cell[530834, 10422, 608, 15, 52, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[531479, 10442, 117, 1, 21, "Subsubsection"],
Cell[531599, 10445, 391, 12, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[532027, 10462, 101, 1, 21, "Subsubsection"],
Cell[532131, 10465, 7584, 231, 649, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[539752, 10701, 101, 1, 21, "Subsubsection"],
Cell[539856, 10704, 550, 17, 95, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[540443, 10726, 92, 1, 21, "Subsubsection"],
Cell[540538, 10729, 9100, 295, 292, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[549675, 11029, 117, 1, 21, "Subsubsection"],
Cell[549795, 11032, 6168, 198, 692, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[556012, 11236, 70, 1, 28, "Subsection"],
Cell[CellGroupData[{
Cell[556107, 11241, 90, 1, 27, "Subsubsection"],
Cell[556200, 11244, 29574, 936, 1703, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[585811, 12185, 159, 2, 21, "Subsubsection"],
Cell[585973, 12189, 12187, 331, 672, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[598197, 12525, 149, 1, 21, "Subsubsection"],
Cell[598349, 12528, 33309, 1039, 3192, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[631719, 13574, 841, 19, 74, "Section"],
Cell[CellGroupData[{
Cell[632585, 13597, 114, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[632724, 13602, 84, 1, 27, "Subsubsection"],
Cell[632811, 13605, 862, 23, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[633710, 13633, 219, 3, 21, "Subsubsection"],
Cell[633932, 13638, 1103, 26, 92, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[635072, 13669, 134, 3, 21, "Subsubsection"],
Cell[635209, 13674, 820, 22, 92, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[636066, 13701, 151, 3, 21, "Subsubsection"],
Cell[636220, 13706, 385, 11, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[636642, 13722, 136, 3, 21, "Subsubsection"],
Cell[636781, 13727, 2558, 77, 72, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[639376, 13809, 107, 1, 21, "Subsubsection"],
Cell[639486, 13812, 2130, 68, 72, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[641653, 13885, 108, 3, 21, "Subsubsection"],
Cell[641764, 13890, 672, 21, 31, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[642485, 13917, 131, 1, 28, "Subsection"],
Cell[CellGroupData[{
Cell[642641, 13922, 134, 3, 27, "Subsubsection"],
Cell[642778, 13927, 2672, 79, 287, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[645487, 14011, 144, 1, 27, "Subsubsection"],
Cell[645634, 14014, 8737, 255, 694, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[654408, 14274, 142, 1, 21, "Subsubsection"],
Cell[654553, 14277, 9056, 261, 694, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[663658, 14544, 152, 3, 28, "Subsection"],
Cell[CellGroupData[{
Cell[663835, 14551, 100, 1, 27, "Subsubsection"],
Cell[663938, 14554, 5465, 143, 232, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[669440, 14702, 158, 2, 21, "Subsubsection"],
Cell[669601, 14706, 5587, 142, 392, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[675237, 14854, 142, 1, 28, "Subsection"],
Cell[CellGroupData[{
Cell[675404, 14859, 76, 1, 27, "Subsubsection"],
Cell[675483, 14862, 5252, 130, 332, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[680784, 14998, 141, 2, 28, "Subsection"],
Cell[680928, 15002, 11730, 307, 912, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[692695, 15314, 392, 6, 28, "Subsection"],
Cell[CellGroupData[{
Cell[693112, 15324, 165, 3, 27, "Subsubsection"],
Cell[693280, 15329, 1110, 17, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[694427, 15351, 262, 4, 21, "Subsubsection"],
Cell[694692, 15357, 489, 10, 33, "Input"],
Cell[CellGroupData[{
Cell[695206, 15371, 590, 16, 54, "Input"],
Cell[695799, 15389, 661, 11, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[696509, 15406, 257, 5, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[696791, 15415, 481, 13, 31, "Input"],
Cell[697275, 15430, 1521, 26, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[698857, 15463, 537, 13, 28, "Subsection"],
Cell[CellGroupData[{
Cell[699419, 15480, 213, 3, 27, "Subsubsection"],
Cell[699635, 15485, 1639, 24, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[701311, 15514, 244, 4, 21, "Subsubsection"],
Cell[701558, 15520, 512, 10, 33, "Input"],
Cell[702073, 15532, 4328, 68, 54, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[706438, 15605, 309, 6, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[706772, 15615, 1667, 29, 31, "Input"],
Cell[708442, 15646, 1524, 26, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[710027, 15679, 326, 6, 28, "Subsection"],
Cell[CellGroupData[{
Cell[710378, 15689, 135, 2, 27, "Subsubsection"],
Cell[710516, 15693, 1086, 23, 92, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[711639, 15721, 191, 3, 21, "Subsubsection"],
Cell[711833, 15726, 1472, 29, 75, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[713342, 15760, 218, 7, 21, "Subsubsection"],
Cell[713563, 15769, 784, 16, 52, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[714396, 15791, 189, 2, 28, "Subsection"],
Cell[CellGroupData[{
Cell[714610, 15797, 140, 2, 27, "Subsubsection"],
Cell[714753, 15801, 358, 8, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[715148, 15814, 142, 2, 27, "Subsubsection"],
Cell[715293, 15818, 462, 13, 50, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[715792, 15836, 235, 7, 27, "Subsubsection"],
Cell[716030, 15845, 367, 9, 52, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[716446, 15860, 342, 4, 28, "Subsection"],
Cell[CellGroupData[{
Cell[716813, 15868, 110, 1, 27, "Subsubsection"],
Cell[716926, 15871, 2200, 65, 212, "Input"],
Cell[719129, 15938, 616, 18, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[719782, 15961, 155, 2, 21, "Subsubsection"],
Cell[719940, 15965, 181, 4, 31, "Input"],
Cell[720124, 15971, 1918, 51, 74, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[722079, 16027, 140, 2, 21, "Subsubsection"],
Cell[722222, 16031, 3646, 89, 224, "Input"],
Cell[725871, 16122, 563, 13, 49, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[726471, 16140, 205, 4, 21, "Subsubsection"],
Cell[CellGroupData[{
Cell[726701, 16148, 954, 17, 52, "Input"],
Cell[727658, 16167, 2381, 40, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[730112, 16215, 735, 18, 74, "Section"],
Cell[CellGroupData[{
Cell[730872, 16237, 108, 1, 36, "Subsection"],
Cell[730983, 16240, 4618, 101, 492, "Input"],
Cell[735604, 16343, 2975, 45, 72, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[738616, 16393, 209, 3, 28, "Subsection"],
Cell[CellGroupData[{
Cell[738850, 16400, 1637, 36, 112, "Input"],
Cell[740490, 16438, 38897, 600, 1475, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
