(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    535674,      10056]
NotebookOptionsPosition[    525366,       9718]
NotebookOutlinePosition[    525701,       9733]
CellTagsIndexPosition[    525658,       9730]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["U(2)^5 flavor symmetry and lepton universality \
violation in W -> tau nu_tau ",
 FontFamily->"Arial",
 FontSize->22,
 FontWeight->"Bold",
 FontSlant->"Italic"]], "Subsubtitle",
 CellChangeTimes->{3.5405484731599226`*^9}],

Cell[TextData[{
 "____________________________________________________________________________\
__________________________________________________________________\n",
 StyleBox["RESULT SUMMARY - ",
  FontFamily->"Arial",
  FontSize->22,
  FontWeight->"Bold"],
 StyleBox["[U(2)xU(1)]^5 flavor symmetry case",
  FontFamily->"Arial",
  FontSize->22,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 StyleBox[" and ",
  FontFamily->"Arial",
  FontSize->22,
  FontWeight->"Bold"],
 StyleBox["Single operators analysis\n\n",
  FontFamily->"Arial",
  FontSize->22,
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 0]],
 "Authors:   Alberto Filipuzzi and Mart\[IAcute]n Gonz\[AAcute]lez-Alonso \
(March 2012)\nPlease refer to arXiv:1203.2092 for the analysis of these \
results."
}], "Subsubtitle",
 CellChangeTimes->{{3.5227357992395215`*^9, 3.5227359077221127`*^9}, {
   3.5227359476737823`*^9, 3.522735996845069*^9}, {3.529326526190875*^9, 
   3.529326566725193*^9}, {3.529952212750554*^9, 3.5299522142215953`*^9}, 
   3.5316768405853057`*^9, {3.5405404902363253`*^9, 3.5405404908113585`*^9}, {
   3.540541039370734*^9, 3.540541041989884*^9}, {3.540541412889098*^9, 
   3.5405414585237083`*^9}, {3.540541562680666*^9, 3.540541562834675*^9}, {
   3.540543388480096*^9, 3.540543443440239*^9}, {3.540543507460901*^9, 
   3.5405435088669815`*^9}, {3.5405481807331967`*^9, 3.540548239412553*^9}, {
   3.5405482727354593`*^9, 3.5405482881253395`*^9}, 3.540548336601112*^9, {
   3.5405485034046526`*^9, 3.5405485053087616`*^9}, {3.540555020921831*^9, 
   3.540555031144486*^9}}],

Cell[TextData[{
 "What is this file?\n",
 StyleBox["In sections a, b and c you can find the results we explained in \
section IV.B of arXiv:1203.2092.\nIn particular, for each particular choice \
of the operator set, we calculated:\n\ta) the error matrix\n\tb) limits on \
the operators\n\tc) prediction for the universality ratio R\[Tau]l\n\nIf you \
want to use this file to analyze the constraints on a different set of \
operators, please refer to the file \[OpenCurlyDoubleQuote]Results - Your \
analys\[CloseCurlyDoubleQuote].",
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Plain"]
}], "Section",
 CellChangeTimes->{{3.5405485096230083`*^9, 3.540548510063033*^9}, {
  3.540548984296158*^9, 3.540549314356036*^9}, {3.5405507579406047`*^9, 
  3.540551069890447*^9}, {3.540551671354849*^9, 3.5405516903699365`*^9}, {
  3.5405518990048695`*^9, 3.540552080736264*^9}}],

Cell[CellGroupData[{

Cell["Global definitions", "Section",
 CellChangeTimes->{{3.54054852538791*^9, 3.5405485438069634`*^9}, {
   3.5405488547487483`*^9, 3.5405488625161924`*^9}, 3.5405489675001974`*^9}],

Cell[CellGroupData[{

Cell["Operator definition", "Subsection",
 CellChangeTimes->{{3.5098760004104085`*^9, 3.509876005823618*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Ops", "=", 
   RowBox[{"{", 
    RowBox[{
    "aWB", ",", "ah", ",", "all1", ",", "all3", ",", "alq1", ",", "alq3", ",",
      "ale", ",", "aqe", ",", "alu", ",", "ald", ",", "aee", ",", "aeu", ",", 
     "aed", ",", "ahl1", ",", "ahl3", ",", "ahq1", ",", "ahq3", ",", "ahu", 
     ",", "ahd", ",", "ahe", ",", "aW", ",", "alQ1", ",", "alQ3", ",", "aLq3",
      ",", "aQe", ",", "alb", ",", "aeb", ",", "ahQ1", ",", "ahQ3", ",", 
     "ahb", ",", "alL1", ",", "alL3", ",", "aLe", ",", "altau", ",", "aetau", 
     ",", "ahL1", ",", "ahL3", ",", "ahtau", ",", "atauWt", ",", "atauBt"}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5098045015742044`*^9, 3.509804539868395*^9}, 
   3.5098055398695917`*^9, {3.5098761825719285`*^9, 3.5098761852551327`*^9}, 
   3.509880149675496*^9, {3.509880315635002*^9, 3.509880316898604*^9}, 
   3.5099523020183744`*^9, {3.509952377350907*^9, 3.5099523775693073`*^9}, {
   3.509952421920185*^9, 3.5099524468334293`*^9}, {3.510386296800147*^9, 
   3.5103862970891633`*^9}, {3.513946979684264*^9, 3.5139470088407154`*^9}, 
   3.514631111040115*^9, {3.514703333377412*^9, 3.5147034699556513`*^9}, {
   3.5147036825684247`*^9, 3.5147036880752344`*^9}, {3.5147037960742245`*^9, 
   3.514703803437437*^9}, 3.514712541967086*^9, {3.5147125815443554`*^9, 
   3.514712588486367*^9}, {3.514712620840824*^9, 3.5147126360976515`*^9}, {
   3.5147126716969137`*^9, 3.514712685565338*^9}, {3.5147127673094816`*^9, 
   3.514712810989558*^9}, {3.514713426285839*^9, 3.514713427518241*^9}, {
   3.5221557637518315`*^9, 3.522155766803006*^9}, {3.531598588899789*^9, 
   3.5315985951710005`*^9}, 3.5405500598076735`*^9, {3.5405501205011454`*^9, 
   3.5405501317487884`*^9}, {3.5405502380788703`*^9, 
   3.5405502395879564`*^9}, {3.5405512401521854`*^9, 3.540551241525264*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Degrees of freedom", "Subsection",
 CellChangeTimes->{{3.529952197171565*^9, 3.5299522008773985`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"NMeasurements", "=", 
   StyleBox["279",
    FontWeight->"Bold"]}], 
  StyleBox[";",
   FontWeight->"Bold"]}]], "Input",
 CellChangeTimes->{{3.5299521665780716`*^9, 3.5299521730962396`*^9}, {
  3.5316768465757165`*^9, 3.531676846653716*^9}, {3.5405404863001003`*^9, 
  3.540540486425108*^9}, {3.5405433298707433`*^9, 3.54054332998275*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]]],
 " (please provide the path of the file where the chi square is stored)"
}], "Subsection",
 CellChangeTimes->{{3.529952027459799*^9, 3.5299520305960827`*^9}, {
  3.540540917388757*^9, 3.5405409623763304`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Path", " ", "of", " ", "the", " ", "file", " ", "where", " ", "total", 
     " ", "chi"}], "-", 
    RowBox[{"square", " ", "is", " ", "stored"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"DataFile", "=", "\"\<xxx\>\""}], ";"}]}]], "Input",
 CellChangeTimes->{{3.5405409701977777`*^9, 3.5405409734239626`*^9}, {
   3.5405414809029884`*^9, 3.5405414890334535`*^9}, 3.540542323398176*^9, {
   3.5405496959728637`*^9, 3.540549699109043*^9}, {3.5405537001678905`*^9, 
   3.5405537004479065`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Get", "[", "DataFile", "]"}]], "Input",
 CellChangeTimes->{{3.5405409793042984`*^9, 3.5405409810203967`*^9}}],

Cell[BoxData[
 RowBox[{"223.24740688793548`", "\[VeryThinSpace]", "+", 
  RowBox[{"2.0239875590720877`*^7", " ", "aeb"}], "+", 
  RowBox[{"8.00911748096842`*^13", " ", 
   SuperscriptBox["aeb", "2"]}], "-", 
  RowBox[{"4.349506314335923`*^7", " ", "aed"}], "+", 
  RowBox[{"1.4135036882066688`*^13", " ", "aeb", " ", "aed"}], "+", 
  RowBox[{"1.435755272408507`*^15", " ", 
   SuperscriptBox["aed", "2"]}], "+", 
  RowBox[{"4.384489277185181`*^7", " ", "aee"}], "+", 
  RowBox[{"3.083123039544148`*^14", " ", 
   SuperscriptBox["aee", "2"]}], "+", 
  RowBox[{"337613.6123279468`", " ", "aetau"}], "+", 
  RowBox[{"1.7170742201857672`*^14", " ", 
   SuperscriptBox["aetau", "2"]}], "+", 
  RowBox[{"7.895393618959737`*^7", " ", "aeu"}], "-", 
  RowBox[{"2.1446752110130453`*^13", " ", "aeb", " ", "aeu"}], "+", 
  RowBox[{"2.1344323835615932`*^15", " ", "aed", " ", "aeu"}], "+", 
  RowBox[{"1.3807311553058475`*^15", " ", 
   SuperscriptBox["aeu", "2"]}], "+", 
  RowBox[{"2.208121181590436`*^8", " ", "ah"}], "-", 
  RowBox[{"6.560852545853561`*^13", " ", "aeb", " ", "ah"}], "-", 
  RowBox[{"1.1256408929591803`*^14", " ", "aed", " ", "ah"}], "-", 
  RowBox[{"5.2021094473292086`*^13", " ", "aee", " ", "ah"}], "-", 
  RowBox[{"3.1005911415394188`*^13", " ", "aetau", " ", "ah"}], "+", 
  RowBox[{"1.9907809002979947`*^14", " ", "aeu", " ", "ah"}], "+", 
  RowBox[{"1.0739978608848096`*^16", " ", 
   SuperscriptBox["ah", "2"]}], "+", 
  RowBox[{"1.9041033788522568`*^7", " ", "ahb"}], "-", 
  RowBox[{"1.2171140524682098`*^13", " ", "aeb", " ", "ahb"}], "-", 
  RowBox[{"3.829858543820781`*^11", " ", "aed", " ", "ahb"}], "+", 
  RowBox[{"2.7701000421235156`*^11", " ", "aeu", " ", "ahb"}], "+", 
  RowBox[{"1.9104523261309878`*^14", " ", "ah", " ", "ahb"}], "+", 
  RowBox[{"9.602000794426062`*^13", " ", 
   SuperscriptBox["ahb", "2"]}], "+", 
  RowBox[{"515630.3178418055`", " ", "ahd"}], "-", 
  RowBox[{"3.829858543820791`*^11", " ", "aeb", " ", "ahd"}], "+", 
  RowBox[{"2.7108581031593775`*^15", " ", "aed", " ", "ahd"}], "+", 
  RowBox[{"2.4422882959482185`*^15", " ", "aeu", " ", "ahd"}], "+", 
  RowBox[{"7.410566996334462`*^14", " ", "ah", " ", "ahd"}], "+", 
  RowBox[{"1.1889744388855102`*^14", " ", "ahb", " ", "ahd"}], "+", 
  RowBox[{"1.5645450074365615`*^15", " ", 
   SuperscriptBox["ahd", "2"]}], "+", 
  RowBox[{"5.7467076334730685`*^7", " ", "ahe"}], "-", 
  RowBox[{"3.935956685985138`*^13", " ", "aeb", " ", "ahe"}], "-", 
  RowBox[{"1.005503011327925`*^15", " ", "aed", " ", "ahe"}], "-", 
  RowBox[{"1.2456703159413012`*^14", " ", "aee", " ", "ahe"}], "-", 
  RowBox[{"3.3863099434539055`*^13", " ", "aetau", " ", "ahe"}], "-", 
  RowBox[{"7.453565377172824`*^14", " ", "aeu", " ", "ahe"}], "-", 
  RowBox[{"7.822998338227926`*^15", " ", "ah", " ", "ahe"}], "-", 
  RowBox[{"8.928268531176176`*^14", " ", "ahb", " ", "ahe"}], "-", 
  RowBox[{"3.227264004267105`*^15", " ", "ahd", " ", "ahe"}], "+", 
  RowBox[{"3.118831450762775`*^16", " ", 
   SuperscriptBox["ahe", "2"]}], "-", 
  RowBox[{"4.1562218613766927`*^8", " ", "ahl1"}], "+", 
  RowBox[{"1.0260353999668378`*^14", " ", "aeb", " ", "ahl1"}], "+", 
  RowBox[{"1.1099349090824328`*^15", " ", "aed", " ", "ahl1"}], "+", 
  RowBox[{"1.6948600112760488`*^14", " ", "aee", " ", "ahl1"}], "+", 
  RowBox[{"4.900260882597778`*^13", " ", "aetau", " ", "ahl1"}], "+", 
  RowBox[{"5.3769152208844875`*^14", " ", "aeu", " ", "ahl1"}], "-", 
  RowBox[{"8.65741482970543`*^15", " ", "ah", " ", "ahl1"}], "+", 
  RowBox[{"1.8041639033686275`*^15", " ", "ahb", " ", "ahl1"}], "+", 
  RowBox[{"4.249738834448574`*^15", " ", "ahd", " ", "ahl1"}], "-", 
  RowBox[{"4.793926384648572`*^16", " ", "ahe", " ", "ahl1"}], "+", 
  RowBox[{"4.793943957553125`*^16", " ", 
   SuperscriptBox["ahl1", "2"]}], "-", 
  RowBox[{"8.884169576545256`*^7", " ", "ahL1"}], "+", 
  RowBox[{"4.900260882597778`*^13", " ", "aetau", " ", "ahL1"}], "-", 
  RowBox[{"6.923719923527879`*^14", " ", "ah", " ", "ahL1"}], "+", 
  RowBox[{"3.4555416484423306`*^14", " ", "ahb", " ", "ahL1"}], "+", 
  RowBox[{"6.911083296884661`*^14", " ", "ahd", " ", "ahL1"}], "-", 
  RowBox[{"2.2034794264186955`*^15", " ", "ahe", " ", "ahL1"}], "+", 
  RowBox[{"3.757955659811811`*^15", " ", "ahl1", " ", "ahL1"}], "+", 
  RowBox[{"4.3957050471521415`*^15", " ", 
   SuperscriptBox["ahL1", "2"]}], "+", 
  RowBox[{"3.476866897874722`*^8", " ", "ahl3"}], "-", 
  RowBox[{"1.5983056183745875`*^14", " ", "aeb", " ", "ahl3"}], "+", 
  RowBox[{"6.596785518987605`*^14", " ", "aed", " ", "ahl3"}], "-", 
  RowBox[{"3.8598376765563516`*^13", " ", "aee", " ", "ahl3"}], "-", 
  RowBox[{"7.502103683559895`*^13", " ", "aetau", " ", "ahl3"}], "+", 
  RowBox[{"1.3340038822076465`*^15", " ", "aeu", " ", "ahl3"}], "+", 
  RowBox[{"4.409781607429435`*^16", " ", "ah", " ", "ahl3"}], "+", 
  RowBox[{"2.0125768315622812`*^15", " ", "ahb", " ", "ahl3"}], "+", 
  RowBox[{"5.790656821171506`*^15", " ", "ahd", " ", "ahl3"}], "-", 
  RowBox[{"6.3208456625218776`*^16", " ", "ahe", " ", "ahl3"}], "+", 
  RowBox[{"3.1348919549937024`*^16", " ", "ahl1", " ", "ahl3"}], "-", 
  RowBox[{"8.546756440313945`*^14", " ", "ahL1", " ", "ahl3"}], "+", 
  RowBox[{"1.1842776522284514`*^17", " ", 
   SuperscriptBox["ahl3", "2"]}], "-", 
  RowBox[{"5.328349460640782`*^7", " ", "ahL3"}], "+", 
  RowBox[{"4.900260882597778`*^13", " ", "aetau", " ", "ahL3"}], "-", 
  RowBox[{"1.4506293522057212`*^15", " ", "ah", " ", "ahL3"}], "+", 
  RowBox[{"6.7670163714862875`*^13", " ", "ahb", " ", "ahL3"}], "+", 
  RowBox[{"1.3534032742972575`*^14", " ", "ahd", " ", "ahL3"}], "+", 
  RowBox[{"5.836340000180073`*^15", " ", "ahe", " ", "ahL3"}], "-", 
  RowBox[{"8.205276823882471`*^15", " ", "ahl1", " ", "ahL3"}], "+", 
  RowBox[{"7.86983842708826`*^15", " ", "ahL1", " ", "ahL3"}], "-", 
  RowBox[{"1.436079903328853`*^16", " ", "ahl3", " ", "ahL3"}], "+", 
  RowBox[{"6.73199174192539`*^15", " ", 
   SuperscriptBox["ahL3", "2"]}], "-", 
  RowBox[{"2.5754584150487725`*^6", " ", "ahq1"}], "+", 
  RowBox[{"2.0372687440397842`*^12", " ", "aeb", " ", "ahq1"}], "+", 
  RowBox[{"5.156743664181399`*^15", " ", "aed", " ", "ahq1"}], "+", 
  RowBox[{"4.567849922615583`*^15", " ", "aeu", " ", "ahq1"}], "-", 
  RowBox[{"8.871497980042218`*^14", " ", "ah", " ", "ahq1"}], "-", 
  RowBox[{"1.0271850588302447`*^14", " ", "ahb", " ", "ahq1"}], "+", 
  RowBox[{"4.745597262065505`*^15", " ", "ahd", " ", "ahq1"}], "+", 
  RowBox[{"4.595440424305694`*^14", " ", "ahe", " ", "ahq1"}], "-", 
  RowBox[{"1.6788391714026148`*^15", " ", "ahl1", " ", "ahq1"}], "-", 
  RowBox[{"6.911083296884658`*^14", " ", "ahL1", " ", "ahq1"}], "-", 
  RowBox[{"3.289403249704112`*^15", " ", "ahl3", " ", "ahq1"}], "-", 
  RowBox[{"1.3534032742972544`*^14", " ", "ahL3", " ", "ahq1"}], "+", 
  RowBox[{"5.168472876868703`*^15", " ", 
   SuperscriptBox["ahq1", "2"]}], "-", 
  RowBox[{"3.2797497458341435`*^7", " ", "ahQ1"}], "+", 
  RowBox[{"8.057030497989803`*^13", " ", "aeb", " ", "ahQ1"}], "+", 
  RowBox[{"3.036042657413457`*^12", " ", "aed", " ", "ahQ1"}], "-", 
  RowBox[{"2.6934182563811484`*^12", " ", "aeu", " ", "ahQ1"}], "-", 
  RowBox[{"2.1402821252025768`*^15", " ", "ah", " ", "ahQ1"}], "-", 
  RowBox[{"9.128305709747155`*^14", " ", "ahb", " ", "ahQ1"}], "-", 
  RowBox[{"6.338638642294182`*^14", " ", "ahd", " ", "ahQ1"}], "+", 
  RowBox[{"6.644141299450992`*^15", " ", "ahe", " ", "ahQ1"}], "-", 
  RowBox[{"8.393194134328985`*^15", " ", "ahl1", " ", "ahQ1"}], "-", 
  RowBox[{"1.8975272237067`*^15", " ", "ahL1", " ", "ahQ1"}], "-", 
  RowBox[{"1.3902456902812124`*^16", " ", "ahl3", " ", "ahQ1"}], "-", 
  RowBox[{"3.715943575431181`*^14", " ", "ahL3", " ", "ahQ1"}], "+", 
  RowBox[{"5.742245284721588`*^14", " ", "ahq1", " ", "ahQ1"}], "+", 
  RowBox[{"2.628250214466094`*^15", " ", 
   SuperscriptBox["ahQ1", "2"]}], "+", 
  RowBox[{"6.416225171501243`*^7", " ", "ahq3"}], "+", 
  RowBox[{"4.0348165707871875`*^12", " ", "aeb", " ", "ahq3"}], "+", 
  RowBox[{"4.252301651384278`*^14", " ", "aed", " ", "ahq3"}], "+", 
  RowBox[{"1.060048357392475`*^13", " ", "aeu", " ", "ahq3"}], "-", 
  RowBox[{"7.459284542383974`*^15", " ", "ah", " ", "ahq3"}], "-", 
  RowBox[{"1.2031931775227395`*^15", " ", "ahb", " ", "ahq3"}], "-", 
  RowBox[{"3.322714136559955`*^15", " ", "ahd", " ", "ahq3"}], "+", 
  RowBox[{"2.2692996106580944`*^16", " ", "ahe", " ", "ahq3"}], "-", 
  RowBox[{"3.210346796326195`*^16", " ", "ahl1", " ", "ahq3"}], "-", 
  RowBox[{"6.899000565138338`*^15", " ", "ahL1", " ", "ahq3"}], "-", 
  RowBox[{"1.3119455859615094`*^17", " ", "ahl3", " ", "ahq3"}], "-", 
  RowBox[{"1.3510371027427455`*^15", " ", "ahL3", " ", "ahq3"}], "+", 
  RowBox[{"4.306074541861999`*^15", " ", "ahq1", " ", "ahq3"}], "+", 
  RowBox[{"6.388025737403979`*^15", " ", "ahQ1", " ", "ahq3"}], "+", 
  RowBox[{"5.904889193801624`*^16", " ", 
   SuperscriptBox["ahq3", "2"]}], "-", 
  RowBox[{"3.279749745834139`*^7", " ", "ahQ3"}], "+", 
  RowBox[{"8.057030497989803`*^13", " ", "aeb", " ", "ahQ3"}], "+", 
  RowBox[{"3.036042657413457`*^12", " ", "aed", " ", "ahQ3"}], "-", 
  RowBox[{"2.693418256381164`*^12", " ", "aeu", " ", "ahQ3"}], "-", 
  RowBox[{"2.140282125202577`*^15", " ", "ah", " ", "ahQ3"}], "-", 
  RowBox[{"9.128305709747155`*^14", " ", "ahb", " ", "ahQ3"}], "-", 
  RowBox[{"6.338638642294186`*^14", " ", "ahd", " ", "ahQ3"}], "+", 
  RowBox[{"6.644141299450996`*^15", " ", "ahe", " ", "ahQ3"}], "-", 
  RowBox[{"8.393194134328989`*^15", " ", "ahl1", " ", "ahQ3"}], "-", 
  RowBox[{"1.8975272237067005`*^15", " ", "ahL1", " ", "ahQ3"}], "-", 
  RowBox[{"1.3902456902812128`*^16", " ", "ahl3", " ", "ahQ3"}], "-", 
  RowBox[{"3.715943575431175`*^14", " ", "ahL3", " ", "ahQ3"}], "+", 
  RowBox[{"5.74224528472159`*^14", " ", "ahq1", " ", "ahQ3"}], "+", 
  RowBox[{"5.256500428932188`*^15", " ", "ahQ1", " ", "ahQ3"}], "+", 
  RowBox[{"6.388025737403982`*^15", " ", "ahq3", " ", "ahQ3"}], "+", 
  RowBox[{"2.628250214466094`*^15", " ", 
   SuperscriptBox["ahQ3", "2"]}], "+", 
  RowBox[{"6.810033485953651`*^7", " ", "ahtau"}], "-", 
  RowBox[{"3.3863099434539055`*^13", " ", "aetau", " ", "ahtau"}], "-", 
  RowBox[{"1.324860916579109`*^15", " ", "ah", " ", "ahtau"}], "-", 
  RowBox[{"1.7685134636183466`*^14", " ", "ahb", " ", "ahtau"}], "-", 
  RowBox[{"3.537026927236693`*^14", " ", "ahd", " ", "ahtau"}], "-", 
  RowBox[{"1.328374251481275`*^15", " ", "ahe", " ", "ahtau"}], "+", 
  RowBox[{"2.0962544683928232`*^15", " ", "ahl1", " ", "ahtau"}], "-", 
  RowBox[{"4.190667592862638`*^15", " ", "ahL1", " ", "ahtau"}], "-", 
  RowBox[{"3.910614458925259`*^15", " ", "ahl3", " ", "ahtau"}], "-", 
  RowBox[{"4.544380223363462`*^15", " ", "ahL3", " ", "ahtau"}], "+", 
  RowBox[{"3.5370269272366906`*^14", " ", "ahq1", " ", "ahtau"}], "+", 
  RowBox[{"9.711364480935575`*^14", " ", "ahQ1", " ", "ahtau"}], "+", 
  RowBox[{"3.530843099650562`*^15", " ", "ahq3", " ", "ahtau"}], "+", 
  RowBox[{"9.711364480935575`*^14", " ", "ahQ3", " ", "ahtau"}], "+", 
  RowBox[{"3.585980245069024`*^15", " ", 
   SuperscriptBox["ahtau", "2"]}], "-", 
  RowBox[{"1.6834146594492268`*^7", " ", "ahu"}], "+", 
  RowBox[{"7.511764709358301`*^10", " ", "aeb", " ", "ahu"}], "+", 
  RowBox[{"2.4422882959482185`*^15", " ", "aed", " ", "ahu"}], "+", 
  RowBox[{"2.1169052621539788`*^15", " ", "aeu", " ", "ahu"}], "-", 
  RowBox[{"1.4459378453578215`*^15", " ", "ah", " ", "ahu"}], "-", 
  RowBox[{"2.4529395750479375`*^14", " ", "ahb", " ", "ahu"}], "+", 
  RowBox[{"1.622015579001695`*^15", " ", "ahd", " ", "ahu"}], "+", 
  RowBox[{"3.642885369836704`*^15", " ", "ahe", " ", "ahu"}], "-", 
  RowBox[{"5.783659502862419`*^15", " ", "ahl1", " ", "ahu"}], "-", 
  RowBox[{"1.3822166593769322`*^15", " ", "ahL1", " ", "ahu"}], "-", 
  RowBox[{"8.756640313524998`*^15", " ", "ahl3", " ", "ahu"}], "-", 
  RowBox[{"2.706806548594515`*^14", " ", "ahL3", " ", "ahu"}], "+", 
  RowBox[{"5.330032497634082`*^15", " ", "ahq1", " ", "ahu"}], "+", 
  RowBox[{"1.33237386388075`*^15", " ", "ahQ1", " ", "ahu"}], "+", 
  RowBox[{"7.41589114629551`*^15", " ", "ahq3", " ", "ahu"}], "+", 
  RowBox[{"1.3323738638807508`*^15", " ", "ahQ3", " ", "ahu"}], "+", 
  RowBox[{"7.074053854473386`*^14", " ", "ahtau", " ", "ahu"}], "+", 
  RowBox[{"1.907590782280312`*^15", " ", 
   SuperscriptBox["ahu", "2"]}], "-", 
  RowBox[{"192403.46147907898`", " ", "alb"}], "+", 
  RowBox[{"6.085172669538543`*^13", " ", "aeb", " ", "alb"}], "+", 
  RowBox[{"6.125263732542641`*^12", " ", "aed", " ", "alb"}], "-", 
  RowBox[{"9.539422916283875`*^12", " ", "aeu", " ", "alb"}], "-", 
  RowBox[{"2.4178372894428836`*^13", " ", "ah", " ", "alb"}], "-", 
  RowBox[{"3.0218883610286846`*^12", " ", "ahb", " ", "alb"}], "-", 
  RowBox[{"1.3165356497882251`*^11", " ", "ahd", " ", "alb"}], "-", 
  RowBox[{"1.9402935936127004`*^13", " ", "ahe", " ", "alb"}], "+", 
  RowBox[{"3.780737015955102`*^13", " ", "ahl1", " ", "alb"}], "-", 
  RowBox[{"5.890612141816439`*^13", " ", "ahl3", " ", "alb"}], "+", 
  RowBox[{"7.894498083931573`*^11", " ", "ahq1", " ", "alb"}], "+", 
  RowBox[{"3.2715734458335574`*^13", " ", "ahQ1", " ", "alb"}], "+", 
  RowBox[{"1.408655505315584`*^12", " ", "ahq3", " ", "alb"}], "+", 
  RowBox[{"3.2715734458335574`*^13", " ", "ahQ3", " ", "alb"}], "-", 
  RowBox[{"1.2837754101527832`*^10", " ", "ahu", " ", "alb"}], "+", 
  RowBox[{"1.638382679351637`*^13", " ", 
   SuperscriptBox["alb", "2"]}], "-", 
  RowBox[{"5.856706503743095`*^6", " ", "ald"}], "+", 
  RowBox[{"6.125263732542645`*^12", " ", "aeb", " ", "ald"}], "-", 
  RowBox[{"2.6605719485615515`*^15", " ", "aed", " ", "ald"}], "-", 
  RowBox[{"2.5388013497103085`*^15", " ", "aeu", " ", "ald"}], "+", 
  RowBox[{"1.194095507854957`*^13", " ", "ah", " ", "ald"}], "-", 
  RowBox[{"1.3165356497882202`*^11", " ", "ahb", " ", "ald"}], "-", 
  RowBox[{"2.6833355928454`*^15", " ", "ahd", " ", "ald"}], "+", 
  RowBox[{"9.326441193281002`*^14", " ", "ahe", " ", "ald"}], "-", 
  RowBox[{"7.879330894709462`*^14", " ", "ahl1", " ", "ald"}], "-", 
  RowBox[{"1.0519420764501195`*^15", " ", "ahl3", " ", "ald"}], "-", 
  RowBox[{"5.151216221370414`*^15", " ", "ahq1", " ", "ald"}], "+", 
  RowBox[{"1.0990526568543633`*^12", " ", "ahQ1", " ", "ald"}], "-", 
  RowBox[{"2.3765217318688284`*^14", " ", "ahq3", " ", "ald"}], "+", 
  RowBox[{"1.0990526568543672`*^12", " ", "ahQ3", " ", "ald"}], "-", 
  RowBox[{"2.4976170969080485`*^15", " ", "ahu", " ", "ald"}], "+", 
  RowBox[{"2.6827793367693193`*^12", " ", "alb", " ", "ald"}], "+", 
  RowBox[{"1.393350356029763`*^15", " ", 
   SuperscriptBox["ald", "2"]}], "+", 
  RowBox[{"1.0311804266835611`*^7", " ", "ale"}], "+", 
  RowBox[{"3.553741373785771`*^14", " ", "aee", " ", "ale"}], "-", 
  RowBox[{"2.2039859172382957`*^13", " ", "ah", " ", "ale"}], "-", 
  RowBox[{"1.7580728911598281`*^13", " ", "ahe", " ", "ale"}], "+", 
  RowBox[{"6.900844818853858`*^13", " ", "ahl1", " ", "ale"}], "-", 
  RowBox[{"3.66660317898353`*^13", " ", "ahl3", " ", "ale"}], "+", 
  RowBox[{"9.049273706901985`*^14", " ", 
   SuperscriptBox["ale", "2"]}], "+", 
  RowBox[{"9.502041503634686`*^6", " ", "aLe"}], "+", 
  RowBox[{"8.443103961582047`*^13", " ", "aetau", " ", "aLe"}], "+", 
  RowBox[{"1.351762166497414`*^12", " ", "ah", " ", "aLe"}], "+", 
  RowBox[{"1.5876915210644443`*^13", " ", "ahe", " ", "aLe"}], "-", 
  RowBox[{"8.791738661009371`*^12", " ", "ahl1", " ", "aLe"}], "-", 
  RowBox[{"8.791738661009371`*^12", " ", "ahL1", " ", "aLe"}], "-", 
  RowBox[{"3.384689995019715`*^12", " ", "ahl3", " ", "aLe"}], "-", 
  RowBox[{"8.791738661009371`*^12", " ", "ahL3", " ", "aLe"}], "+", 
  RowBox[{"1.5876915210644443`*^13", " ", "ahtau", " ", "aLe"}], "+", 
  RowBox[{"8.70680753898095`*^13", " ", 
   SuperscriptBox["aLe", "2"]}], "+", 
  RowBox[{"4.8261401657548055`*^7", " ", "all1"}], "+", 
  RowBox[{"6.736467757633442`*^14", " ", "aee", " ", "all1"}], "-", 
  RowBox[{"6.743976403257781`*^13", " ", "ah", " ", "all1"}], "-", 
  RowBox[{"1.3688425304055383`*^14", " ", "ahe", " ", "all1"}], "+", 
  RowBox[{"1.9298162091121022`*^14", " ", "ahl1", " ", "all1"}], "-", 
  RowBox[{"5.6790939584784414`*^13", " ", "ahl3", " ", "all1"}], "+", 
  RowBox[{"3.818643849250764`*^14", " ", "ale", " ", "all1"}], "+", 
  RowBox[{"3.768831806536246`*^14", " ", 
   SuperscriptBox["all1", "2"]}], "+", 
  RowBox[{"308954.0247701262`", " ", "alL1"}], "+", 
  RowBox[{"3.774938479819471`*^14", " ", "aetau", " ", "alL1"}], "-", 
  RowBox[{"3.411276789989748`*^13", " ", "ah", " ", "alL1"}], "-", 
  RowBox[{"3.7257027383433125`*^13", " ", "ahe", " ", "alL1"}], "+", 
  RowBox[{"5.391312995008917`*^13", " ", "ahl1", " ", "alL1"}], "+", 
  RowBox[{"5.391312995008917`*^13", " ", "ahL1", " ", "alL1"}], "-", 
  RowBox[{"8.253794164950073`*^13", " ", "ahl3", " ", "alL1"}], "+", 
  RowBox[{"5.391312995008917`*^13", " ", "ahL3", " ", "alL1"}], "-", 
  RowBox[{"3.7257027383433125`*^13", " ", "ahtau", " ", "alL1"}], "+", 
  RowBox[{"9.280026498759084`*^13", " ", "aLe", " ", "alL1"}], "+", 
  RowBox[{"2.0747954578455994`*^14", " ", 
   SuperscriptBox["alL1", "2"]}], "-", 
  RowBox[{"1.7568740576149642`*^8", " ", "all3"}], "+", 
  RowBox[{"1.3121705091707125`*^14", " ", "aeb", " ", "all3"}], "+", 
  RowBox[{"2.2512817859183647`*^14", " ", "aed", " ", "all3"}], "+", 
  RowBox[{"7.776889647099285`*^14", " ", "aee", " ", "all3"}], "+", 
  RowBox[{"6.201182283078837`*^13", " ", "aetau", " ", "all3"}], "-", 
  RowBox[{"3.9815618005959856`*^14", " ", "aeu", " ", "all3"}], "-", 
  RowBox[{"2.7904429668322276`*^16", " ", "ah", " ", "all3"}], "-", 
  RowBox[{"3.820904652261975`*^14", " ", "ahb", " ", "all3"}], "-", 
  RowBox[{"1.3781891301691015`*^15", " ", "ahd", " ", "all3"}], "+", 
  RowBox[{"1.5512230090596338`*^16", " ", "ahe", " ", "all3"}], "+", 
  RowBox[{"1.946016882579861`*^16", " ", "ahl1", " ", "all3"}], "+", 
  RowBox[{"1.3847439847055782`*^15", " ", "ahL1", " ", "all3"}], "-", 
  RowBox[{"1.552762700944818`*^17", " ", "ahl3", " ", "all3"}], "+", 
  RowBox[{"6.169533019528428`*^15", " ", "ahL3", " ", "all3"}], "+", 
  RowBox[{"1.4987998929424748`*^15", " ", "ahq1", " ", "all3"}], "+", 
  RowBox[{"4.2805642504051525`*^15", " ", "ahQ1", " ", "all3"}], "+", 
  RowBox[{"9.61239070331951`*^16", " ", "ahq3", " ", "all3"}], "+", 
  RowBox[{"4.2805642504051525`*^15", " ", "ahQ3", " ", "all3"}], "+", 
  RowBox[{"2.6497218331582175`*^15", " ", "ahtau", " ", "all3"}], "+", 
  RowBox[{"2.6959761701377285`*^15", " ", "ahu", " ", "all3"}], "+", 
  RowBox[{"4.835674578885769`*^13", " ", "alb", " ", "all3"}], "+", 
  RowBox[{"8.004235894069095`*^13", " ", "ald", " ", "all3"}], "+", 
  RowBox[{"4.28366567066291`*^14", " ", "ale", " ", "all3"}], "-", 
  RowBox[{"2.703524332994832`*^12", " ", "aLe", " ", "all3"}], "+", 
  RowBox[{"8.53566814245695`*^14", " ", "all1", " ", "all3"}], "+", 
  RowBox[{"6.822553579979495`*^13", " ", "alL1", " ", "all3"}], "+", 
  RowBox[{"6.634720994415955`*^16", " ", 
   SuperscriptBox["all3", "2"]}], "+", 
  RowBox[{"7.037802212537076`*^7", " ", "alL3"}], "+", 
  RowBox[{"3.774938479819471`*^14", " ", "aetau", " ", "alL3"}], "-", 
  RowBox[{"3.411276789989748`*^13", " ", "ah", " ", "alL3"}], "-", 
  RowBox[{"3.7257027383433125`*^13", " ", "ahe", " ", "alL3"}], "+", 
  RowBox[{"5.391312995008917`*^13", " ", "ahl1", " ", "alL3"}], "+", 
  RowBox[{"5.391312995008917`*^13", " ", "ahL1", " ", "alL3"}], "+", 
  RowBox[{"3.1857363734674855`*^15", " ", "ahl3", " ", "alL3"}], "-", 
  RowBox[{"3.214361185166897`*^15", " ", "ahL3", " ", "alL3"}], "-", 
  RowBox[{"3.7257027383433125`*^13", " ", "ahtau", " ", "alL3"}], "+", 
  RowBox[{"9.280026498759084`*^13", " ", "aLe", " ", "alL3"}], "+", 
  RowBox[{"4.149590915691199`*^14", " ", "alL1", " ", "alL3"}], "-", 
  RowBox[{"3.2000487793171915`*^15", " ", "all3", " ", "alL3"}], "+", 
  RowBox[{"1.841616703343053`*^15", " ", 
   SuperscriptBox["alL3", "2"]}], "+", 
  RowBox[{"3.7951057068982795`*^7", " ", "alq1"}], "+", 
  RowBox[{"3.8224058266110703`*^12", " ", "aeb", " ", "alq1"}], "-", 
  RowBox[{"5.186159430056217`*^15", " ", "aed", " ", "alq1"}], "-", 
  RowBox[{"4.4268463485685625`*^15", " ", "aeu", " ", "alq1"}], "-", 
  RowBox[{"1.3310174444930334`*^14", " ", "ah", " ", "alq1"}], "-", 
  RowBox[{"5.81111602026802`*^11", " ", "ahb", " ", "alq1"}], "-", 
  RowBox[{"5.153598313846216`*^15", " ", "ahd", " ", "alq1"}], "+", 
  RowBox[{"1.817070184224006`*^15", " ", "ahe", " ", "alq1"}], "-", 
  RowBox[{"2.1317147601931148`*^15", " ", "ahl1", " ", "alq1"}], "-", 
  RowBox[{"1.8376226287924218`*^15", " ", "ahl3", " ", "alq1"}], "-", 
  RowBox[{"9.6710510181164`*^15", " ", "ahq1", " ", "alq1"}], "+", 
  RowBox[{"3.82608935770809`*^12", " ", "ahQ1", " ", "alq1"}], "-", 
  RowBox[{"5.446402920937528`*^14", " ", "ahq3", " ", "alq1"}], "+", 
  RowBox[{"3.82608935770809`*^12", " ", "ahQ3", " ", "alq1"}], "-", 
  RowBox[{"4.569855494059898`*^15", " ", "ahu", " ", "alq1"}], "+", 
  RowBox[{"1.2698264827340762`*^12", " ", "alb", " ", "alq1"}], "+", 
  RowBox[{"5.1147200545571`*^15", " ", "ald", " ", "alq1"}], "-", 
  RowBox[{"9.296214167362875`*^12", " ", "all3", " ", "alq1"}], "+", 
  RowBox[{"4.942006451543632`*^15", " ", 
   SuperscriptBox["alq1", "2"]}], "+", 
  RowBox[{"5.1779316650454596`*^7", " ", "alQ1"}], "+", 
  RowBox[{"4.014951423188297`*^14", " ", "aeb", " ", "alQ1"}], "+", 
  RowBox[{"3.408945183237825`*^13", " ", "aed", " ", "alQ1"}], "-", 
  RowBox[{"5.111098644591706`*^13", " ", "aeu", " ", "alQ1"}], "-", 
  RowBox[{"1.6570886737189838`*^14", " ", "ah", " ", "alQ1"}], "-", 
  RowBox[{"3.0745163164423406`*^13", " ", "ahb", " ", "alQ1"}], "-", 
  RowBox[{"1.0091195412596348`*^12", " ", "ahd", " ", "alQ1"}], "-", 
  RowBox[{"9.99470166473554`*^13", " ", "ahe", " ", "alQ1"}], "+", 
  RowBox[{"2.5919134937166006`*^14", " ", "ahl1", " ", "alQ1"}], "-", 
  RowBox[{"4.036441201159336`*^14", " ", "ahl3", " ", "alQ1"}], "+", 
  RowBox[{"5.145908197359189`*^12", " ", "ahq1", " ", "alQ1"}], "+", 
  RowBox[{"2.0342067053078356`*^14", " ", "ahQ1", " ", "alQ1"}], "+", 
  RowBox[{"1.0577262486360406`*^13", " ", "ahq3", " ", "alQ1"}], "+", 
  RowBox[{"2.0342067053078356`*^14", " ", "ahQ3", " ", "alQ1"}], "+", 
  RowBox[{"2.942372825445`*^11", " ", "ahu", " ", "alQ1"}], "+", 
  RowBox[{"1.5232474266722403`*^14", " ", "alb", " ", "alQ1"}], "+", 
  RowBox[{"1.470138203338557`*^13", " ", "ald", " ", "alQ1"}], "+", 
  RowBox[{"3.314177347437969`*^14", " ", "all3", " ", "alQ1"}], "+", 
  RowBox[{"1.018154065733254`*^13", " ", "alq1", " ", "alQ1"}], "+", 
  RowBox[{"5.0341408536384444`*^14", " ", 
   SuperscriptBox["alQ1", "2"]}], "-", 
  RowBox[{"3.021247687546405`*^8", " ", "alq3"}], "+", 
  RowBox[{"6.435649783814569`*^13", " ", "aeb", " ", "alq3"}], "+", 
  RowBox[{"4.9509473389936175`*^14", " ", "aed", " ", "alq3"}], "-", 
  RowBox[{"1.8580592799219802`*^15", " ", "aeu", " ", "alq3"}], "-", 
  RowBox[{"2.3226477994412622`*^14", " ", "ah", " ", "alq3"}], "-", 
  RowBox[{"1.4371274804924785`*^12", " ", "ahb", " ", "alq3"}], "-", 
  RowBox[{"3.625383066127617`*^14", " ", "ahd", " ", "alq3"}], "-", 
  RowBox[{"1.811801430972457`*^14", " ", "ahe", " ", "alq3"}], "+", 
  RowBox[{"1.204457832441302`*^15", " ", "ahl1", " ", "alq3"}], "+", 
  RowBox[{"7.999629150496963`*^16", " ", "ahl3", " ", "alq3"}], "+", 
  RowBox[{"5.788239895857522`*^14", " ", "ahL3", " ", "alq3"}], "-", 
  RowBox[{"5.792102865537499`*^14", " ", "ahq1", " ", "alq3"}], "+", 
  RowBox[{"1.18970813260115`*^13", " ", "ahQ1", " ", "alq3"}], "-", 
  RowBox[{"8.115607105647286`*^16", " ", "ahq3", " ", "alq3"}], "+", 
  RowBox[{"1.1897081326011516`*^13", " ", "ahQ3", " ", "alq3"}], "-", 
  RowBox[{"1.3195088788694938`*^14", " ", "ahu", " ", "alq3"}], "+", 
  RowBox[{"2.813293758403711`*^13", " ", "alb", " ", "alq3"}], "+", 
  RowBox[{"6.040544762982685`*^14", " ", "ald", " ", "alq3"}], "-", 
  RowBox[{"8.075149932539696`*^16", " ", "all3", " ", "alq3"}], "+", 
  RowBox[{"1.6806265810869594`*^14", " ", "alq1", " ", "alq3"}], "+", 
  RowBox[{"1.5459874799863138`*^14", " ", "alQ1", " ", "alq3"}], "+", 
  RowBox[{"4.3356025580512424`*^16", " ", 
   SuperscriptBox["alq3", "2"]}], "+", 
  RowBox[{"5.1779316650454596`*^7", " ", "alQ3"}], "+", 
  RowBox[{"4.014951423188297`*^14", " ", "aeb", " ", "alQ3"}], "+", 
  RowBox[{"3.408945183237825`*^13", " ", "aed", " ", "alQ3"}], "-", 
  RowBox[{"5.111098644591706`*^13", " ", "aeu", " ", "alQ3"}], "-", 
  RowBox[{"1.6570886737189838`*^14", " ", "ah", " ", "alQ3"}], "-", 
  RowBox[{"3.0745163164423406`*^13", " ", "ahb", " ", "alQ3"}], "-", 
  RowBox[{"1.0091195412596348`*^12", " ", "ahd", " ", "alQ3"}], "-", 
  RowBox[{"9.99470166473554`*^13", " ", "ahe", " ", "alQ3"}], "+", 
  RowBox[{"2.5919134937166006`*^14", " ", "ahl1", " ", "alQ3"}], "-", 
  RowBox[{"4.036441201159336`*^14", " ", "ahl3", " ", "alQ3"}], "+", 
  RowBox[{"5.145908197359191`*^12", " ", "ahq1", " ", "alQ3"}], "+", 
  RowBox[{"2.0342067053078356`*^14", " ", "ahQ1", " ", "alQ3"}], "+", 
  RowBox[{"1.0577262486360406`*^13", " ", "ahq3", " ", "alQ3"}], "+", 
  RowBox[{"2.0342067053078356`*^14", " ", "ahQ3", " ", "alQ3"}], "+", 
  RowBox[{"2.942372825445`*^11", " ", "ahu", " ", "alQ3"}], "+", 
  RowBox[{"1.5232474266722403`*^14", " ", "alb", " ", "alQ3"}], "+", 
  RowBox[{"1.470138203338557`*^13", " ", "ald", " ", "alQ3"}], "+", 
  RowBox[{"3.314177347437969`*^14", " ", "all3", " ", "alQ3"}], "+", 
  RowBox[{"1.018154065733254`*^13", " ", "alq1", " ", "alQ3"}], "+", 
  RowBox[{"1.0068281707276889`*^15", " ", "alQ1", " ", "alQ3"}], "+", 
  RowBox[{"1.5459874799863138`*^14", " ", "alq3", " ", "alQ3"}], "+", 
  RowBox[{"5.0341408536384444`*^14", " ", 
   SuperscriptBox["alQ3", "2"]}], "+", 
  RowBox[{"1.9064856497544844`*^6", " ", "aLq3"}], "+", 
  RowBox[{"5.788239895857522`*^14", " ", "ahl3", " ", "aLq3"}], "-", 
  RowBox[{"5.788239895857522`*^14", " ", "ahL3", " ", "aLq3"}], "-", 
  RowBox[{"5.788239895857522`*^14", " ", "alq3", " ", "aLq3"}], "+", 
  RowBox[{"2.894119947928761`*^14", " ", 
   SuperscriptBox["aLq3", "2"]}], "+", 
  RowBox[{"9.502041503634695`*^6", " ", "altau"}], "+", 
  RowBox[{"8.44310396158205`*^13", " ", "aetau", " ", "altau"}], "+", 
  RowBox[{"1.351762166497414`*^12", " ", "ah", " ", "altau"}], "+", 
  RowBox[{"1.587691521064445`*^13", " ", "ahe", " ", "altau"}], "-", 
  RowBox[{"8.791738661009379`*^12", " ", "ahl1", " ", "altau"}], "-", 
  RowBox[{"8.791738661009379`*^12", " ", "ahL1", " ", "altau"}], "-", 
  RowBox[{"3.384689995019715`*^12", " ", "ahl3", " ", "altau"}], "-", 
  RowBox[{"8.791738661009379`*^12", " ", "ahL3", " ", "altau"}], "+", 
  RowBox[{"1.587691521064445`*^13", " ", "ahtau", " ", "altau"}], "+", 
  RowBox[{"1.7413615077961906`*^14", " ", "aLe", " ", "altau"}], "+", 
  RowBox[{"9.280026498759088`*^13", " ", "alL1", " ", "altau"}], "-", 
  RowBox[{"2.703524332994836`*^12", " ", "all3", " ", "altau"}], "+", 
  RowBox[{"9.280026498759088`*^13", " ", "alL3", " ", "altau"}], "+", 
  RowBox[{"8.706807538980958`*^13", " ", 
   SuperscriptBox["altau", "2"]}], "+", 
  RowBox[{"2.869769529438737`*^7", " ", "alu"}], "-", 
  RowBox[{"9.914363277408836`*^12", " ", "aeb", " ", "alu"}], "-", 
  RowBox[{"2.5388013497103085`*^15", " ", "aed", " ", "alu"}], "-", 
  RowBox[{"1.9174198066812172`*^15", " ", "aeu", " ", "alu"}], "+", 
  RowBox[{"6.342190466831373`*^12", " ", "ah", " ", "alu"}], "+", 
  RowBox[{"9.270397965033398`*^10", " ", "ahb", " ", "alu"}], "-", 
  RowBox[{"2.4976170969080485`*^15", " ", "ahd", " ", "alu"}], "+", 
  RowBox[{"8.870160838436832`*^14", " ", "ahe", " ", "alu"}], "-", 
  RowBox[{"1.163203531804118`*^15", " ", "ahl1", " ", "alu"}], "-", 
  RowBox[{"5.501362082030484`*^14", " ", "ahl3", " ", "alu"}], "-", 
  RowBox[{"4.564466478403017`*^15", " ", "ahq1", " ", "alu"}], "-", 
  RowBox[{"1.0202415880089023`*^12", " ", "ahQ1", " ", "alu"}], "-", 
  RowBox[{"3.873212087371646`*^14", " ", "ahq3", " ", "alu"}], "-", 
  RowBox[{"1.0202415880089102`*^12", " ", "ahQ3", " ", "alu"}], "-", 
  RowBox[{"2.0103878772546582`*^15", " ", "ahu", " ", "alu"}], "-", 
  RowBox[{"4.440913500027293`*^12", " ", "alb", " ", "alu"}], "+", 
  RowBox[{"2.294469447872356`*^15", " ", "ald", " ", "alu"}], "-", 
  RowBox[{"2.0858390151157775`*^14", " ", "all3", " ", "alu"}], "+", 
  RowBox[{"4.662684414579747`*^15", " ", "alq1", " ", "alu"}], "-", 
  RowBox[{"2.355014122376072`*^13", " ", "alQ1", " ", "alu"}], "-", 
  RowBox[{"3.4521271510282594`*^14", " ", "alq3", " ", "alu"}], "-", 
  RowBox[{"2.355014122376072`*^13", " ", "alQ3", " ", "alu"}], "+", 
  RowBox[{"1.2102960213857765`*^15", " ", 
   SuperscriptBox["alu", "2"]}], "+", 
  RowBox[{"3.050815688872363`*^7", " ", "aqe"}], "-", 
  RowBox[{"1.348860831565668`*^13", " ", "aeb", " ", "aqe"}], "+", 
  RowBox[{"4.994588396669287`*^15", " ", "aed", " ", "aqe"}], "+", 
  RowBox[{"4.871928492230591`*^15", " ", "aeu", " ", "aqe"}], "+", 
  RowBox[{"8.848667082013212`*^13", " ", "ah", " ", "aqe"}], "+", 
  RowBox[{"3.376071988645054`*^11", " ", "ahb", " ", "aqe"}], "+", 
  RowBox[{"5.153972303329955`*^15", " ", "ahd", " ", "aqe"}], "-", 
  RowBox[{"1.7484340135139142`*^15", " ", "ahe", " ", "aqe"}], "+", 
  RowBox[{"1.6441290816325578`*^15", " ", "ahl1", " ", "aqe"}], "+", 
  RowBox[{"1.9980757649130865`*^15", " ", "ahl3", " ", "aqe"}], "+", 
  RowBox[{"9.713289166299598`*^15", " ", "ahq1", " ", "aqe"}], "-", 
  RowBox[{"2.722171691225535`*^12", " ", "ahQ1", " ", "aqe"}], "+", 
  RowBox[{"4.357289518948087`*^14", " ", "ahq3", " ", "aqe"}], "-", 
  RowBox[{"2.722171691225535`*^12", " ", "ahQ3", " ", "aqe"}], "+", 
  RowBox[{"4.561579619272565`*^15", " ", "ahu", " ", "aqe"}], "-", 
  RowBox[{"5.867378336874113`*^12", " ", "alb", " ", "aqe"}], "-", 
  RowBox[{"5.203871135182003`*^15", " ", "ald", " ", "aqe"}], "-", 
  RowBox[{"1.769733416402635`*^14", " ", "all3", " ", "aqe"}], "-", 
  RowBox[{"9.676314621440736`*^15", " ", "alq1", " ", "aqe"}], "-", 
  RowBox[{"3.2475061813084094`*^13", " ", "alQ1", " ", "aqe"}], "-", 
  RowBox[{"1.356528364184512`*^15", " ", "alq3", " ", "aqe"}], "-", 
  RowBox[{"3.2475061813084094`*^13", " ", "alQ3", " ", "aqe"}], "-", 
  RowBox[{"4.4636354854989855`*^15", " ", "alu", " ", "aqe"}], "+", 
  RowBox[{"4.936869655920088`*^15", " ", 
   SuperscriptBox["aqe", "2"]}], "-", 
  RowBox[{"1.8425468435484823`*^6", " ", "aQe"}], "-", 
  RowBox[{"1.2527608596881042`*^14", " ", "aeb", " ", "aQe"}], "-", 
  RowBox[{"9.894282566505453`*^12", " ", "aed", " ", "aQe"}], "+", 
  RowBox[{"1.427523547140925`*^13", " ", "aeu", " ", "aQe"}], "+", 
  RowBox[{"5.227236644996075`*^13", " ", "ah", " ", "aQe"}], "+", 
  RowBox[{"6.650034151303512`*^12", " ", "ahb", " ", "aQe"}], "+", 
  RowBox[{"3.710110138276909`*^11", " ", "ahd", " ", "aQe"}], "+", 
  RowBox[{"4.287057616623075`*^13", " ", "ahe", " ", "aQe"}], "-", 
  RowBox[{"8.183752660932195`*^13", " ", "ahl1", " ", "aQe"}], "+", 
  RowBox[{"1.272519391905211`*^14", " ", "ahl3", " ", "aQe"}], "-", 
  RowBox[{"1.706188062900095`*^12", " ", "ahq1", " ", "aQe"}], "-", 
  RowBox[{"7.045585604902897`*^13", " ", "ahQ1", " ", "aQe"}], "-", 
  RowBox[{"3.8436666256275703`*^12", " ", "ahq3", " ", "aQe"}], "-", 
  RowBox[{"7.045585604902897`*^13", " ", "ahQ3", " ", "aQe"}], "-", 
  RowBox[{"1.8874855649174902`*^11", " ", "ahu", " ", "aQe"}], "-", 
  RowBox[{"6.710775877642345`*^13", " ", "alb", " ", "aQe"}], "-", 
  RowBox[{"4.202189454777332`*^12", " ", "ald", " ", "aQe"}], "-", 
  RowBox[{"1.0454473289992153`*^14", " ", "all3", " ", "aQe"}], "-", 
  RowBox[{"3.835332205019926`*^12", " ", "alq1", " ", "aQe"}], "-", 
  RowBox[{"3.1455374745956556`*^14", " ", "alQ1", " ", "aQe"}], "-", 
  RowBox[{"4.431418292417978`*^13", " ", "alq3", " ", "aQe"}], "-", 
  RowBox[{"3.1455374745956556`*^14", " ", "alQ3", " ", "aQe"}], "+", 
  RowBox[{"6.505986054735789`*^12", " ", "alu", " ", "aQe"}], "+", 
  RowBox[{"9.375081620691008`*^12", " ", "aqe", " ", "aQe"}], "+", 
  RowBox[{"6.985443196423621`*^13", " ", 
   SuperscriptBox["aQe", "2"]}], "-", 
  RowBox[{"1.1473148825510636`*^6", " ", "atauBt"}], "-", 
  RowBox[{"1.142040077958136`*^13", " ", "aetau", " ", "atauBt"}], "-", 
  RowBox[{"7.296362996565589`*^12", " ", "ah", " ", "atauBt"}], "+", 
  RowBox[{"3.0639656756370764`*^11", " ", "ahb", " ", "atauBt"}], "+", 
  RowBox[{"6.127931351274153`*^11", " ", "ahd", " ", "atauBt"}], "+", 
  RowBox[{"9.23094355906656`*^12", " ", "ahe", " ", "atauBt"}], "+", 
  RowBox[{"9.996170813025078`*^11", " ", "ahl1", " ", "atauBt"}], "+", 
  RowBox[{"1.5051324325010793`*^13", " ", "ahL1", " ", "atauBt"}], "-", 
  RowBox[{"2.698507235788399`*^13", " ", "ahl3", " ", "atauBt"}], "+", 
  RowBox[{"1.5651705598548725`*^13", " ", "ahL3", " ", "atauBt"}], "-", 
  RowBox[{"6.127931351274143`*^11", " ", "ahq1", " ", "atauBt"}], "-", 
  RowBox[{"1.6825027372033052`*^12", " ", "ahQ1", " ", "atauBt"}], "-", 
  RowBox[{"6.117217813685804`*^12", " ", "ahq3", " ", "atauBt"}], "-", 
  RowBox[{"1.6825027372033052`*^12", " ", "ahQ3", " ", "atauBt"}], "-", 
  RowBox[{"1.5224158170376814`*^12", " ", "ahtau", " ", "atauBt"}], "-", 
  RowBox[{"1.2255862702548306`*^12", " ", "ahu", " ", "atauBt"}], "-", 
  RowBox[{"7.996543268656081`*^12", " ", "aLe", " ", "atauBt"}], "-", 
  RowBox[{"1.2558965744101021`*^13", " ", "alL1", " ", "atauBt"}], "+", 
  RowBox[{"1.459272599313118`*^13", " ", "all3", " ", "atauBt"}], "-", 
  RowBox[{"1.2558965744101021`*^13", " ", "alL3", " ", "atauBt"}], "-", 
  RowBox[{"7.996543268656084`*^12", " ", "altau", " ", "atauBt"}], "+", 
  RowBox[{"5.0318067175019556`*^11", " ", 
   SuperscriptBox["atauBt", "2"]}], "-", 
  RowBox[{"2.5355520620515104`*^6", " ", "atauWt"}], "+", 
  RowBox[{"7.628520571143122`*^12", " ", "aetau", " ", "atauWt"}], "-", 
  RowBox[{"1.5178212462845416`*^13", " ", "ah", " ", "atauWt"}], "+", 
  RowBox[{"5.588526960266877`*^11", " ", "ahb", " ", "atauWt"}], "+", 
  RowBox[{"1.1177053920533755`*^12", " ", "ahd", " ", "atauWt"}], "+", 
  RowBox[{"1.5982545244141059`*^13", " ", "ahe", " ", "atauWt"}], "+", 
  RowBox[{"4.2307537386197676`*^12", " ", "ahl1", " ", "atauWt"}], "+", 
  RowBox[{"2.985907535916393`*^13", " ", "ahL1", " ", "atauWt"}], "-", 
  RowBox[{"5.429188661243289`*^13", " ", "ahl3", " ", "atauWt"}], "+", 
  RowBox[{"3.095418010932846`*^13", " ", "ahL3", " ", "atauWt"}], "-", 
  RowBox[{"1.1177053920533745`*^12", " ", "ahq1", " ", "atauWt"}], "-", 
  RowBox[{"3.0688045830110117`*^12", " ", "ahQ1", " ", "atauWt"}], "-", 
  RowBox[{"1.1157512939990672`*^13", " ", "ahq3", " ", "atauWt"}], "-", 
  RowBox[{"3.0688045830110107`*^12", " ", "ahQ3", " ", "atauWt"}], "-", 
  RowBox[{"3.633512296856827`*^12", " ", "ahtau", " ", "atauWt"}], "-", 
  RowBox[{"2.235410784106751`*^12", " ", "ahu", " ", "atauWt"}], "+", 
  RowBox[{"5.21792656449468`*^12", " ", "aLe", " ", "atauWt"}], "+", 
  RowBox[{"8.389732646656066`*^12", " ", "alL1", " ", "atauWt"}], "+", 
  RowBox[{"3.0356424925690836`*^13", " ", "all3", " ", "atauWt"}], "+", 
  RowBox[{"8.389732646656066`*^12", " ", "alL3", " ", "atauWt"}], "+", 
  RowBox[{"5.217926564494682`*^12", " ", "altau", " ", "atauWt"}], "+", 
  RowBox[{"2.275942036094067`*^11", " ", "atauBt", " ", "atauWt"}], "+", 
  RowBox[{"7.275566542211517`*^11", " ", 
   SuperscriptBox["atauWt", "2"]}], "+", 
  RowBox[{"1.0166032315579371`*^6", " ", "aW"}], "+", 
  RowBox[{"8.956941612206582`*^12", " ", "ah", " ", "aW"}], "+", 
  RowBox[{"2.853318384427856`*^12", " ", "ahe", " ", "aW"}], "+", 
  RowBox[{"1.2622695247677342`*^13", " ", "ahl1", " ", "aW"}], "-", 
  RowBox[{"3.457984606996489`*^12", " ", "ahl3", " ", "aW"}], "+", 
  RowBox[{"1.6024436419425403`*^12", " ", "ahq3", " ", "aW"}], "-", 
  RowBox[{"8.35816270993225`*^12", " ", "all3", " ", "aW"}], "+", 
  RowBox[{"2.621086924689996`*^12", " ", 
   SuperscriptBox["aW", "2"]}], "+", 
  RowBox[{"5.96365661234771`*^8", " ", "aWB"}], "-", 
  RowBox[{"1.3722212406589`*^14", " ", "aeb", " ", "aWB"}], "+", 
  RowBox[{"1.9845691859366382`*^15", " ", "aed", " ", "aWB"}], "-", 
  RowBox[{"7.040904280619256`*^13", " ", "aee", " ", "aWB"}], "-", 
  RowBox[{"4.7461389959633234`*^13", " ", "aetau", " ", "aWB"}], "+", 
  RowBox[{"2.447840382518223`*^15", " ", "aeu", " ", "aWB"}], "+", 
  RowBox[{"6.031777398139479`*^16", " ", "ah", " ", "aWB"}], "-", 
  RowBox[{"6.526199182559486`*^13", " ", "ahb", " ", "aWB"}], "+", 
  RowBox[{"3.5925064394245095`*^15", " ", "ahd", " ", "aWB"}], "-", 
  RowBox[{"5.112932688540952`*^16", " ", "ahe", " ", "aWB"}], "-", 
  RowBox[{"3.1609083266970416`*^16", " ", "ahl1", " ", "aWB"}], "-", 
  RowBox[{"3.2494683832894505`*^15", " ", "ahL1", " ", "aWB"}], "+", 
  RowBox[{"1.4117353739120723`*^17", " ", "ahl3", " ", "aWB"}], "-", 
  RowBox[{"4.778251628465609`*^15", " ", "ahL3", " ", "aWB"}], "+", 
  RowBox[{"2.655144532372248`*^15", " ", "ahq1", " ", "aWB"}], "-", 
  RowBox[{"4.796635517323774`*^15", " ", "ahQ1", " ", "aWB"}], "-", 
  RowBox[{"1.469541804208894`*^16", " ", "ahq3", " ", "aWB"}], "-", 
  RowBox[{"4.796635517323774`*^15", " ", "ahQ3", " ", "aWB"}], "-", 
  RowBox[{"7.210873491187712`*^15", " ", "ahtau", " ", "aWB"}], "-", 
  RowBox[{"5.0903858020093975`*^14", " ", "ahu", " ", "aWB"}], "-", 
  RowBox[{"4.520547590356466`*^13", " ", "alb", " ", "aWB"}], "-", 
  RowBox[{"2.350402298800511`*^15", " ", "ald", " ", "aWB"}], "-", 
  RowBox[{"6.6884165038955125`*^13", " ", "ale", " ", "aWB"}], "-", 
  RowBox[{"2.2211573602592246`*^13", " ", "aLe", " ", "aWB"}], "-", 
  RowBox[{"1.0359491852508227`*^14", " ", "all1", " ", "aWB"}], "-", 
  RowBox[{"5.2215812196050695`*^13", " ", "alL1", " ", "aWB"}], "-", 
  RowBox[{"8.887501709518275`*^16", " ", "all3", " ", "aWB"}], "-", 
  RowBox[{"5.2215812196050695`*^13", " ", "alL3", " ", "aWB"}], "-", 
  RowBox[{"4.3386140743700735`*^15", " ", "alq1", " ", "aWB"}], "-", 
  RowBox[{"3.459421774799329`*^14", " ", "alQ1", " ", "aWB"}], "-", 
  RowBox[{"1.0380452826435332`*^15", " ", "alq3", " ", "aWB"}], "-", 
  RowBox[{"3.459421774799329`*^14", " ", "alQ3", " ", "aWB"}], "-", 
  RowBox[{"2.2211573602592254`*^13", " ", "altau", " ", "aWB"}], "-", 
  RowBox[{"1.711919494265401`*^15", " ", "alu", " ", "aWB"}], "+", 
  RowBox[{"4.4346474988870705`*^15", " ", "aqe", " ", "aWB"}], "+", 
  RowBox[{"9.65928951831769`*^13", " ", "aQe", " ", "aWB"}], "-", 
  RowBox[{"3.4901528932742414`*^13", " ", "atauBt", " ", "aWB"}], "-", 
  RowBox[{"6.852223324548234`*^13", " ", "atauWt", " ", "aWB"}], "+", 
  RowBox[{"1.5283353123283645`*^13", " ", "aW", " ", "aWB"}], "+", 
  RowBox[{"1.0665373042875603`*^17", " ", 
   SuperscriptBox["aWB", "2"]}]}]], "Output",
 CellChangeTimes->{
  3.540540982233466*^9, {3.5405410146363196`*^9, 3.540541025412936*^9}, 
   3.540543338686248*^9, 3.540549494663349*^9, 3.540549662881971*^9, 
   3.5405497001871047`*^9, 3.5405504653378687`*^9, {3.5405511658619366`*^9, 
   3.5405511838509655`*^9}, 3.5405512477616205`*^9, 3.5405516400020556`*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Theoretical formulas and experimental data",
  FontFamily->"Arial",
  FontColor->GrayLevel[0]],
 StyleBox[" (please compile this before starting with the analysis)",
  FontFamily->"Arial",
  FontColor->RGBColor[0., 1., 0.]]
}], "Section",
 CellChangeTimes->{{3.522581210690549*^9, 3.5225812295353813`*^9}, {
  3.5405485580377774`*^9, 3.540548573455659*^9}, {3.540548830094338*^9, 
  3.5405488471803155`*^9}}],

Cell[CellGroupData[{

Cell["Constants", "Subsection",
 CellChangeTimes->{{3.5098759644211454`*^9, 3.5098759663087482`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SigmaTo90CL", "=", "1.64485"}], ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"me", "=", 
    RowBox[{"0.510998910", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"from", " ", "PDG", " ", "2010"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]me", "=", 
   RowBox[{"0.000000013", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mmu", "=", 
    RowBox[{"105.658367", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"from", " ", "PDG", " ", "2010"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]mmu", "=", 
   RowBox[{"0.000004", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"mtau", "=", 
    RowBox[{"1776.82", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "3"}]]}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"from", " ", "PDG", " ", "2010"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]mtau", "=", 
   RowBox[{"0.16", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "3"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mlep", "=", 
   RowBox[{"{", 
    RowBox[{"me", ",", "mmu", ",", "mtau"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ml", "=", 
   RowBox[{"{", 
    RowBox[{"mel", ",", "m\[Mu]", ",", "m\[Tau]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]mlep", "=", 
   RowBox[{"{", 
    RowBox[{"\[Sigma]me", ",", "\[Sigma]mmu", ",", "\[Sigma]mtau"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MW", "=", "80.399"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]MW", "=", "0.023"}], ";"}]}], "Input",
 CellChangeTimes->{{3.523710865746038*^9, 3.523710885033141*^9}, {
  3.523713363896924*^9, 3.52371338410608*^9}, {3.5237134370681095`*^9, 
  3.523713589033801*^9}, {3.523713652849451*^9, 3.5237136560736356`*^9}, {
  3.5237137060214925`*^9, 3.523713723129471*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"MB", "=", "5.27917"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]MB", "=", "0.00029"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MD", "=", "1.86957"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]MD", "=", "0.00016"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MDs", "=", "1.96845"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]MDs", "=", "0.00033"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5177458389297004`*^9, 3.517745847868516*^9}, {
  3.517830870361573*^9, 3.5178308982700224`*^9}, {3.5228593164464893`*^9, 
  3.5228593406577325`*^9}, {3.523710714357379*^9, 3.5237107178485785`*^9}, {
  3.5237107485983377`*^9, 3.523710836218349*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"GF", "=", 
    RowBox[{"1.16637", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "5"}]]}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Fermi", " ", "constant", " ", "from", " ", "\[Mu]", " ", "decay"}], " ", 
    "-", " ", 
    RowBox[{"Value", " ", "from", " ", "PDG", " ", "2010"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MZ", "=", "91.1876"}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"from", " ", "PDG", " ", "2010"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alpha0", "=", 
    FractionBox["1", "137.035999679"]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{"from", " ", "PDG", " ", "2010"}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.5074687331718245`*^9, 3.507468744132452*^9}, {
   3.510659842617818*^9, 3.510659896328712*^9}, {3.5109034232057753`*^9, 
   3.5109034238297763`*^9}, 3.5109092640423937`*^9, {3.510920350259288*^9, 
   3.5109203511952896`*^9}, {3.5109213374446216`*^9, 
   3.5109213429514313`*^9}, {3.510921952007701*^9, 3.5109219606345167`*^9}, {
   3.511089089265937*^9, 3.511089093462344*^9}, {3.511157784843169*^9, 
   3.511157786590372*^9}, 3.5159383403313274`*^9, {3.517133904688362*^9, 
   3.517133908875602*^9}, {3.5171339435965877`*^9, 3.5171339698390884`*^9}, {
   3.5237106039640646`*^9, 3.5237106145576706`*^9}}],

Cell[CellGroupData[{

Cell["alpha electromagnetic at the Z scale", "Subsubsection",
 CellChangeTimes->{{3.510921806787046*^9, 3.5109218122938557`*^9}}],

Cell[BoxData[{
 RowBox[{"\[Beta]lep", ":=", 
  SqrtBox[
   RowBox[{"1", "-", 
    RowBox[{"4", 
     FractionBox[
      SuperscriptBox["mlep", "2"], 
      SuperscriptBox["MZ", "2"]]}]}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalDelta]\[Alpha]l", "=", 
   RowBox[{"Re", "[", 
    RowBox[{
     FractionBox["alpha0", 
      RowBox[{"3", "\[Pi]"}]], 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox["5", "3"]}], "-", 
         RowBox[{"4", 
          FractionBox[
           SuperscriptBox[
            RowBox[{"mlep", "[", 
             RowBox[{"[", "i", "]"}], "]"}], "2"], 
           SuperscriptBox["MZ", "2"]]}], "+", 
         RowBox[{
          RowBox[{"\[Beta]lep", "[", 
           RowBox[{"[", "i", "]"}], "]"}], 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", 
             FractionBox[
              SuperscriptBox[
               RowBox[{"mlep", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "2"], 
              SuperscriptBox["MZ", "2"]]}]}], ")"}], 
          RowBox[{"Log", "[", 
           FractionBox[
            RowBox[{
             RowBox[{"\[Beta]lep", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "+", "1"}], 
            RowBox[{
             RowBox[{"\[Beta]lep", "[", 
              RowBox[{"[", "i", "]"}], "]"}], "-", "1"}]], "]"}]}]}], ")"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "3"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]\[Alpha]h", "=", "0.02793"}], ";"}], "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"from", " ", "PDG", " ", "2010"}], " ", "-", " ", 
    RowBox[{
    "Review", ":", " ", 
     "\"\<Electroweak model and constraints on new physics\>\""}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"alphaMZ", "=", 
    FractionBox["alpha0", 
     RowBox[{
     "1", "-", "\[CapitalDelta]\[Alpha]l", "-", 
      "\[CapitalDelta]\[Alpha]h"}]]}], " ", ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Formnula", " ", "from", " ", "sec", " ", "1.2", " ", "of", " ", "hep"}], 
    "-", 
    RowBox[{
     RowBox[{"ph", "/", "9709229"}], 
     RowBox[{"v1", ":", " ", 
      RowBox[{
      "electroweak", " ", "working", " ", "group", " ", "report", " ", 
       "1997"}]}]}]}], " ", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.511158009296364*^9, 3.511158011355567*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"s2\[Theta]", "=", 
   SqrtBox[
    FractionBox[
     RowBox[{"4", "\[Pi]", " ", "alphaMZ"}], 
     RowBox[{
      SqrtBox["2"], "GF", " ", 
      SuperscriptBox["MZ", "2"]}]]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"s2", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"4", "x", 
         RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}]}], "\[Equal]", 
        SuperscriptBox["s2\[Theta]", "2"]}], ",", "x"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
    SuperscriptBox["sin", "2"], " ", "of", " ", "electroweak", " ", "angle"}],
    " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"s", "=", 
   SqrtBox["s2"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"c2", "=", 
   RowBox[{"1", "-", "s2"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"c", "=", 
    RowBox[{"Cos", "[", 
     RowBox[{"ArcSin", "[", "s", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"v2", "=", 
    FractionBox["1", 
     RowBox[{
      SqrtBox["2"], "GF"}]]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{"vev", " ", "\[Tilde]", " ", 
    RowBox[{"246", " ", "GeV"}]}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"v", "=", 
   SuperscriptBox["v2", 
    FractionBox["1", "2"]]}], ";"}]}], "Input",
 CellChangeTimes->{{3.510903052861125*^9, 3.5109030679931517`*^9}, {
  3.510903319449993*^9, 3.510903335986022*^9}, {3.510904177000099*^9, 
  3.5109042017105427`*^9}, {3.510909148321391*^9, 3.5109092066966934`*^9}, {
  3.5109218731027627`*^9, 3.510921874756366*^9}, {3.515150083901162*^9, 
  3.5151500842561827`*^9}, {3.517133925922577*^9, 3.5171339267216225`*^9}, {
  3.517133985667994*^9, 3.5171339858850064`*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions", "Subsection",
 CellChangeTimes->{{3.5111821519171257`*^9, 3.5111821608676376`*^9}, {
  3.5112491727844353`*^9, 3.511249173065236*^9}}],

Cell[CellGroupData[{

Cell["Find ellipse parameters", "Subsubsection",
 CellChangeTimes->{{3.511182170012161*^9, 3.5111821789116697`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"elli", "[", 
    RowBox[{"pts_List", ",", "\[CapitalDelta]\[Chi]ellipse_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"{", 
         RowBox[{"x_", ",", "y_"}], "}"}], "]"}], ":=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"x", "^", "2"}], ")"}], "para"}], "+", 
        RowBox[{"x", " ", "y", " ", "parb"}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"y", "^", "2"}], ")"}], "parc"}], "+", 
        RowBox[{"x", " ", "pard"}], "+", 
        RowBox[{"y", " ", "pare"}], "-", "\[CapitalDelta]\[Chi]ellipse"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"north", "=", 
       RowBox[{
        RowBox[{"Ordering", "[", 
         RowBox[{"pts", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "//", "Last"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"south", "=", 
       RowBox[{
        RowBox[{"Ordering", "[", 
         RowBox[{"pts", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}], "//", "First"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"east", "=", 
       RowBox[{
        RowBox[{"Ordering", "[", 
         RowBox[{"pts", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}], "//", "Last"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"west", "=", 
       RowBox[{
        RowBox[{"Ordering", "[", 
         RowBox[{"pts", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", "1"}], "]"}], "]"}], "]"}], "//", "First"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xn", ",", "yn"}], "}"}], "=", 
       RowBox[{"pts", "[", 
        RowBox[{"[", "north", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xs", ",", "ys"}], "}"}], "=", 
       RowBox[{"pts", "[", 
        RowBox[{"[", "south", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xe", ",", "ye"}], "}"}], "=", 
       RowBox[{"pts", "[", 
        RowBox[{"[", "east", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"xw", ",", "yw"}], "}"}], "=", 
       RowBox[{"pts", "[", 
        RowBox[{"[", "west", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"a0", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xe", "-", "xw"}], ")"}], "/", "2"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"b0", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"c0", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"yn", "-", "ys"}], ")"}], "/", "2"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"d0", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"e0", "=", "0"}], ";", "\[IndentingNewLine]", 
      RowBox[{"xc", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xe", "+", "xw"}], ")"}], "/", "2"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"yc", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"yn", "+", "ys"}], ")"}], "/", "2"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"FindMinimum", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"f", "/@", "pts"}], ")"}], ".", 
          RowBox[{"(", 
           RowBox[{"f", "/@", "pts"}], ")"}]}], ")"}], ",", 
        RowBox[{"{", 
         RowBox[{"para", ",", "parb", ",", "parc", ",", "pard", ",", "pare"}],
          "}"}]}], "]"}]}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.511184088444889*^9, {3.511262490098089*^9, 3.5112625476803827`*^9}, {
   3.5112625782591314`*^9, 3.5112626024075127`*^9}, {3.511262701536183*^9, 
   3.5112627029922657`*^9}, {3.511264193510519*^9, 3.511264196000661*^9}, {
   3.511264418425383*^9, 3.511264433807263*^9}, {3.5112651281519775`*^9, 
   3.511265186700326*^9}, {3.5112652257285585`*^9, 3.5112652303588233`*^9}, 
   3.5112655046715126`*^9, {3.5112656470466566`*^9, 3.511265742174097*^9}, {
   3.511265777270105*^9, 3.5112657996663857`*^9}, {3.511265840427717*^9, 
   3.511265956270343*^9}, {3.5112660659896183`*^9, 3.511266104040795*^9}, {
   3.511266322659299*^9, 3.511266329884712*^9}, {3.511266572725602*^9, 
   3.51126663807434*^9}, {3.5112666687620955`*^9, 3.511266686760124*^9}, 
   3.5112667190309706`*^9, {3.51126685995203*^9, 3.511266900350341*^9}, {
   3.514876364893238*^9, 3.514876427574148*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Operator definition", "Subsubsection",
 CellChangeTimes->{{3.538746833159153*^9, 3.5387468359083104`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"opnum", "=", 
    RowBox[{"Length", "[", "Ops", "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "tags", " ", "used", " ", "to", " ", "select", " ", "operators", " ", 
      "in", " ", "the", " ", 
      RowBox[{"fit", ".", " ", "1"}]}], "=", "selected"}], ";", " ", 
    RowBox[{"0", "=", 
     RowBox[{"not", " ", "selected"}]}]}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"optags", "=", 
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", "opnum"}], "}"}]}], "]"}]}], ";"}], "\n", 
  RowBox[{"(*", " ", 
   RowBox[{"Operator", " ", "relations"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Example", ":", " ", "operalations"}], "=", 
    RowBox[{"{", 
     RowBox[{"ahu", "\[Rule]", "ahd"}], "}"}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"oprelations", "=", 
    RowBox[{"{", "}"}]}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"inittag", "[", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{"optags", "=", 
      RowBox[{"Table", "[", 
       RowBox[{"0", ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "opnum"}], "}"}]}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"setlist", "[", "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "i", "}"}], ",", "\[IndentingNewLine]", " ", 
     RowBox[{
      RowBox[{"droplist", "=", 
       RowBox[{"{", "}"}]}], ";", "     ", "\[IndentingNewLine]", " ", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"i", "=", "1"}], ",", 
        RowBox[{"i", "\[LessEqual]", "opnum"}], ",", 
        RowBox[{"i", "++"}], ",", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"optags", "[", 
            RowBox[{"[", "i", "]"}], "]"}], "\[Equal]", "0"}], ",", 
          RowBox[{"droplist", "=", 
           RowBox[{"Append", "[", 
            RowBox[{"droplist", ",", 
             RowBox[{
              RowBox[{"Ops", "[", 
               RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", "0"}]}], "]"}]}]}], 
         "]"}]}], "]"}], ";", "droplist"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5060802558180046`*^9, 3.5060802648515215`*^9}, 
   3.5060811453728848`*^9, {3.5060811872022767`*^9, 3.5060811906504745`*^9}, {
   3.506165290790553*^9, 3.506165294090742*^9}, {3.50616569827886*^9, 
   3.5061657009240117`*^9}, {3.5061659521613817`*^9, 3.506165981573064*^9}, {
   3.506166053817196*^9, 3.5061660783595996`*^9}, {3.5061667221834245`*^9, 
   3.5061667304158955`*^9}, {3.5061685985657473`*^9, 3.5061686024499693`*^9}, 
   3.5061707133430266`*^9, 3.506170758130705*^9, {3.5061708414660516`*^9, 
   3.5061709145053797`*^9}, {3.506171816046563*^9, 3.5061718191509686`*^9}, {
   3.5061725432106404`*^9, 3.506172552445857*^9}, {3.5068528736018333`*^9, 
   3.5068528950674715`*^9}, 3.5068608404568796`*^9, {3.5154896350325365`*^9, 
   3.515489643628152*^9}, {3.515838010510657*^9, 3.515838128039379*^9}, {
   3.5158382896486225`*^9, 3.515838316777174*^9}, {3.515838355156369*^9, 
   3.515838355925413*^9}, {3.515839200199703*^9, 3.515839327264971*^9}, {
   3.516516726597229*^9, 3.516516732182039*^9}, 3.5165286230084844`*^9, {
   3.5172971730099974`*^9, 3.517297175561143*^9}, {3.5221464181334505`*^9, 
   3.5221464202862544`*^9}, {3.5387468686201816`*^9, 3.538746871602352*^9}, 
   3.538746977744423*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["First order function", "Subsubsection",
 CellChangeTimes->{{3.5387468451328382`*^9, 3.5387468512521877`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "calculate", " ", "the", " ", "linear", " ", "order", " ", "terms", " ", 
    "for", " ", "a", " ", "given", " ", "function"}], " ", "*)"}], "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"firstorder", "[", "function_", "]"}], ":=", 
    RowBox[{"Block", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"center", ",", "i"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"inittag", "[", "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"center", "=", 
        RowBox[{"setlist", "[", "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"cc", "=", "0"}], ";", "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", "opnum"}], ",", 
         RowBox[{"i", "++"}], ",", 
         RowBox[{"cc", "=", 
          RowBox[{"cc", "+", 
           RowBox[{
            RowBox[{"Ops", "[", 
             RowBox[{"[", "i", "]"}], "]"}], 
            RowBox[{"(", " ", 
             RowBox[{
              RowBox[{"D", "[", 
               RowBox[{"function", ",", 
                RowBox[{"Ops", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "/.", "center"}], 
             ")"}]}]}]}]}], "]"}], ";", "\[IndentingNewLine]", "cc"}]}], 
     "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.5387469832937403`*^9, 3.538746985239852*^9}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Experimental data (the masses are in the constants section)", \
"Subsection",
 CellChangeTimes->{{3.5148754035727496`*^9, 3.514875406349554*^9}, {
  3.5237723795945096`*^9, 3.523772396963503*^9}}],

Cell[CellGroupData[{

Cell["Decay Rates and ratios for W", "Subsubsection",
 CellChangeTimes->{{3.5237105279097147`*^9, 3.523710552766136*^9}, {
  3.5237105864140615`*^9, 3.5237105868080835`*^9}, {3.5237729523402686`*^9, 
  3.523772966837098*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalGamma]WTotExp", "=", "2.085"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]\[CapitalGamma]WTotExp", "=", "0.042"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p\[CapitalGamma]WeExp", "=", 
   RowBox[{"10.75", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]p\[CapitalGamma]WeExp", "=", 
   RowBox[{"0.13", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p\[CapitalGamma]W\[Mu]Exp", "=", 
   RowBox[{"10.57", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]p\[CapitalGamma]W\[Mu]Exp", "=", 
   RowBox[{"0.15", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]W\[Mu]Exp", "=", 
   RowBox[{"p\[CapitalGamma]W\[Mu]Exp", "*", "\[CapitalGamma]WTotExp"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]\[CapitalGamma]W\[Mu]Exp", "=", 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
       "p\[CapitalGamma]W\[Mu]Exp", "*", "\[Sigma]\[CapitalGamma]WTotExp"}], 
       ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
       "\[Sigma]p\[CapitalGamma]W\[Mu]Exp", "*", "\[CapitalGamma]WTotExp"}], 
       ")"}], "2"]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"p\[CapitalGamma]W\[Tau]Exp", "=", 
   RowBox[{"11.25", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]p\[CapitalGamma]W\[Tau]Exp", "=", 
   RowBox[{"0.20", "*", 
    SuperscriptBox["10", 
     RowBox[{"-", "2"}]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]W\[Tau]Exp", "=", 
   RowBox[{"p\[CapitalGamma]W\[Tau]Exp", "*", "\[CapitalGamma]WTotExp"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]\[CapitalGamma]W\[Tau]Exp", "=", 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
       "p\[CapitalGamma]W\[Tau]Exp", "*", "\[Sigma]\[CapitalGamma]WTotExp"}], 
       ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
       "\[Sigma]p\[CapitalGamma]W\[Tau]Exp", "*", "\[CapitalGamma]WTotExp"}], 
       ")"}], "2"]}]]}], ";"}]}], "Input",
 CellChangeTimes->{{3.4929481695818677`*^9, 3.492948170936945*^9}, {
  3.493019859429229*^9, 3.493019892470087*^9}, {3.4946087297343283`*^9, 
  3.4946087560203743`*^9}, {3.4946087957068443`*^9, 3.494608831040906*^9}, {
  3.4946089034094334`*^9, 3.494608903456233*^9}, {3.4946090038892097`*^9, 
  3.494609008132417*^9}, {3.4954864300170755`*^9, 3.4954864447435017`*^9}, {
  3.4954865367836633`*^9, 3.495486548639684*^9}, {3.496770995880619*^9, 
  3.496770998657424*^9}, {3.514818160330076*^9, 3.5148181633408813`*^9}, {
  3.514875478889682*^9, 3.5148754809332857`*^9}, {3.531677922510606*^9, 
  3.5316779359266295`*^9}, {3.5316780586998453`*^9, 3.5316780653766575`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RW\[Tau]\[Mu]Exp", "=", "1.064"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]RW\[Tau]\[Mu]Exp", "=", "0.024"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RW\[Tau]eExp", "=", "1.046"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]RW\[Tau]eExp", "=", "0.023"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"RW\[Tau]lExp", "=", 
  FractionBox[
   RowBox[{"2", "p\[CapitalGamma]W\[Tau]Exp"}], 
   RowBox[{
   "p\[CapitalGamma]W\[Mu]Exp", "+", 
    "p\[CapitalGamma]WeExp"}]]}], "\[IndentingNewLine]", 
 RowBox[{"\[Sigma]RW\[Tau]lExp", "=", 
  RowBox[{"2", 
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["\[Sigma]p\[CapitalGamma]W\[Tau]Exp", 
        RowBox[{"p\[CapitalGamma]W\[Mu]Exp", "+", "p\[CapitalGamma]WeExp"}]], 
       ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{
        "\[Sigma]p\[CapitalGamma]W\[Mu]Exp", " ", 
         "p\[CapitalGamma]W\[Tau]Exp"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"p\[CapitalGamma]W\[Mu]Exp", "+", "p\[CapitalGamma]WeExp"}],
           ")"}], "2"]], ")"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{
        "\[Sigma]p\[CapitalGamma]WeExp", " ", "p\[CapitalGamma]W\[Tau]Exp"}], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"p\[CapitalGamma]W\[Mu]Exp", "+", "p\[CapitalGamma]WeExp"}],
           ")"}], "2"]], ")"}], "2"]}]]}]}]}], "Input",
 CellChangeTimes->{{3.504875500334796*^9, 3.504875525887641*^9}, {
   3.504877128790456*^9, 3.50487714805649*^9}, {3.517121916387514*^9, 
   3.517121920490321*^9}, {3.523772942831725*^9, 3.523772942996734*^9}, {
   3.5237735493154135`*^9, 3.523773571897705*^9}, {3.5238065362289443`*^9, 
   3.5238065375081463`*^9}, 3.5238065966166506`*^9, {3.523806753194125*^9, 
   3.5238068136598315`*^9}, {3.5316782605174*^9, 3.53167826630501*^9}}],

Cell[BoxData["1.055347091932458`"], "Output",
 CellChangeTimes->{
  3.523806262620064*^9, 3.5238068152198343`*^9, 3.5238112626806307`*^9, 
   3.5238649700468426`*^9, 3.523874212302318*^9, 3.5238752229751253`*^9, 
   3.5238762923532906`*^9, 3.5238766279384847`*^9, 3.523969128978662*^9, 
   3.524314060353901*^9, 3.5245626171591253`*^9, 3.5287334497643228`*^9, 
   3.528733579540951*^9, 3.528735404469739*^9, 3.528738422744957*^9, 
   3.528738761905153*^9, 3.5288062544070706`*^9, 3.528808260416462*^9, 
   3.528810885525808*^9, 3.5288295835031395`*^9, 3.528831078422565*^9, 
   3.529176152927363*^9, 3.529176193482682*^9, 3.5292413036482096`*^9, 
   3.529251733586953*^9, 3.5292593963120966`*^9, 3.529262378600535*^9, 
   3.5292631857625523`*^9, 3.529263565077219*^9, 3.5292645350713224`*^9, 
   3.529265195670083*^9, 3.5292657560084667`*^9, 3.529322482811607*^9, 
   3.529326734829808*^9, 3.5293408419108477`*^9, 3.5294308266794605`*^9, 
   3.5299530190311565`*^9, 3.529954370572754*^9, 3.531510649153001*^9, 
   3.531594109364521*^9, 3.531598511898054*^9, 3.5316747478230295`*^9, 
   3.5316782676622124`*^9, 3.5316830943559484`*^9, 3.531763457340125*^9, 
   3.5352826464759636`*^9, 3.5352826969634314`*^9, 3.5352828128143144`*^9, 
   3.5360594624894357`*^9, 3.5360694158148155`*^9, 3.536070208047606*^9, 
   3.5360724825674076`*^9, 3.5375282526635675`*^9, 3.5387414613329024`*^9, 
   3.5387419434814796`*^9, 3.5387425774017377`*^9, 3.5387443797188244`*^9, 
   3.5387461471299143`*^9, 3.5387467160244536`*^9, 3.5387469579262896`*^9, 
   3.5387469922752542`*^9, 3.538747193944789*^9, {3.53883808566549*^9, 
   3.538838096117509*^9}, 3.5388381791720543`*^9, 3.5388966826501646`*^9, {
   3.5405410147173243`*^9, 3.5405410254919405`*^9}, 3.540543338781253*^9, 
   3.540549665713133*^9, 3.540549705545411*^9, {3.5405504422605486`*^9, 
   3.5405504653798714`*^9}, 3.540551191855423*^9, 3.5405512478486257`*^9, 
   3.5405516400910606`*^9}],

Cell[BoxData["0.021178845883677393`"], "Output",
 CellChangeTimes->{
  3.523806262620064*^9, 3.5238068152198343`*^9, 3.5238112626806307`*^9, 
   3.5238649700468426`*^9, 3.523874212302318*^9, 3.5238752229751253`*^9, 
   3.5238762923532906`*^9, 3.5238766279384847`*^9, 3.523969128978662*^9, 
   3.524314060353901*^9, 3.5245626171591253`*^9, 3.5287334497643228`*^9, 
   3.528733579540951*^9, 3.528735404469739*^9, 3.528738422744957*^9, 
   3.528738761905153*^9, 3.5288062544070706`*^9, 3.528808260416462*^9, 
   3.528810885525808*^9, 3.5288295835031395`*^9, 3.528831078422565*^9, 
   3.529176152927363*^9, 3.529176193482682*^9, 3.5292413036482096`*^9, 
   3.529251733586953*^9, 3.5292593963120966`*^9, 3.529262378600535*^9, 
   3.5292631857625523`*^9, 3.529263565077219*^9, 3.5292645350713224`*^9, 
   3.529265195670083*^9, 3.5292657560084667`*^9, 3.529322482811607*^9, 
   3.529326734829808*^9, 3.5293408419108477`*^9, 3.5294308266794605`*^9, 
   3.5299530190311565`*^9, 3.529954370572754*^9, 3.531510649153001*^9, 
   3.531594109364521*^9, 3.531598511898054*^9, 3.5316747478230295`*^9, 
   3.5316782676622124`*^9, 3.5316830943559484`*^9, 3.531763457340125*^9, 
   3.5352826464759636`*^9, 3.5352826969634314`*^9, 3.5352828128143144`*^9, 
   3.5360594624894357`*^9, 3.5360694158148155`*^9, 3.536070208047606*^9, 
   3.5360724825674076`*^9, 3.5375282526635675`*^9, 3.5387414613329024`*^9, 
   3.5387419434814796`*^9, 3.5387425774017377`*^9, 3.5387443797188244`*^9, 
   3.5387461471299143`*^9, 3.5387467160244536`*^9, 3.5387469579262896`*^9, 
   3.5387469922752542`*^9, 3.538747193944789*^9, {3.53883808566549*^9, 
   3.538838096117509*^9}, 3.5388381791720543`*^9, 3.5388966826501646`*^9, {
   3.5405410147173243`*^9, 3.5405410254919405`*^9}, 3.540543338781253*^9, 
   3.540549665713133*^9, 3.540549705545411*^9, {3.5405504422605486`*^9, 
   3.5405504653798714`*^9}, 3.540551191855423*^9, 3.5405512478486257`*^9, 
   3.5405516400930605`*^9}]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["W -> \[Tau] \[Nu] formulas", "Subsection",
 CellChangeTimes->{{3.5148754508252325`*^9, 3.51487546098085*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalGamma]Wl\[Nu]SM", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"GF", " ", 
      SuperscriptBox["MW", "3"]}], 
     RowBox[{"6", 
      SqrtBox["2"], "\[Pi]"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["m", "2"], 
        SuperscriptBox["MW", "2"]]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["m", "2"], 
       RowBox[{"2", 
        SuperscriptBox["MW", "2"]}]]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]Wl\[Nu]hl3", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"GF", " ", 
      SuperscriptBox["MW", "3"]}], 
     RowBox[{"6", 
      SqrtBox["2"], "\[Pi]"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["m", "2"], 
        SuperscriptBox["MW", "2"]]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      FractionBox[
       SuperscriptBox["m", "2"], 
       RowBox[{"2", 
        SuperscriptBox["MW", "2"]}]]}], ")"}], "4", " ", "ahL3"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]Wl\[Nu]EWt", "=", 
   RowBox[{
    FractionBox[
     RowBox[{"GF", " ", 
      SuperscriptBox["MW", "3"]}], 
     RowBox[{"6", 
      SqrtBox["2"], "\[Pi]"}]], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        SuperscriptBox["m", "2"], 
        SuperscriptBox["MW", "2"]]}], ")"}], "2"], "6", 
    SqrtBox["2"], 
    FractionBox[
     RowBox[{" ", "m"}], "MW"], " ", "atauWt"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.514875547171002*^9, 3.514875547358202*^9}, {
   3.514893894855933*^9, 3.514893903264348*^9}, {3.5151459130816097`*^9, 
   3.51514597514616*^9}, {3.5202330976129417`*^9, 3.5202330980341425`*^9}, {
   3.5316769718751364`*^9, 3.531676972857938*^9}, {3.5387464416377597`*^9, 
   3.538746537263229*^9}, {3.5387466804314175`*^9, 3.5387466815974846`*^9}, 
   3.5405500741294928`*^9, 3.5405501389191985`*^9}],

Cell[CellGroupData[{

Cell["SM value and theoretical error", "Subsubsection",
 CellChangeTimes->{{3.538746561115593*^9, 3.5387465737543163`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalGamma]W\[Tau]\[Nu]SM", "=", 
   RowBox[{
    RowBox[{"Expand", "[", "\[CapitalGamma]Wl\[Nu]SM", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{"m", "\[Rule]", "m\[Tau]"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]W\[Mu]\[Nu]SM", "=", 
   RowBox[{
    RowBox[{"Expand", "[", "\[CapitalGamma]Wl\[Nu]SM", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{"m", "\[Rule]", "m\[Mu]"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]We\[Nu]SM", "=", 
   RowBox[{
    RowBox[{"Expand", "[", "\[CapitalGamma]Wl\[Nu]SM", "]"}], "/.", 
    RowBox[{"{", 
     RowBox[{"m", "\[Rule]", "mel"}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.504875080288458*^9, 3.5048751545601883`*^9}, {
   3.5048765678758707`*^9, 3.5048765795758915`*^9}, {3.5048766591828313`*^9, 
   3.504876661819236*^9}, {3.5048768063846893`*^9, 3.5048768095670953`*^9}, {
   3.5048768859760294`*^9, 3.5048768913424387`*^9}, {3.504877156698905*^9, 
   3.5048771604741116`*^9}, {3.5049364411080794`*^9, 
   3.5049364463823814`*^9}, {3.5148742714631615`*^9, 3.5148742755815687`*^9}, 
   3.5237136707574754`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"RW\[Tau]lSMtemp", "=", 
   RowBox[{"2", 
    RowBox[{"\[CapitalGamma]W\[Tau]\[Nu]SM", "/", 
     RowBox[{"(", 
      RowBox[{
      "\[CapitalGamma]We\[Nu]SM", "+", "\[CapitalGamma]W\[Mu]\[Nu]SM"}], 
      ")"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]RW\[Tau]lSM", "=", 
   RowBox[{
    SqrtBox[
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"D", "[", 
          RowBox[{"RW\[Tau]lSMtemp", ",", 
           RowBox[{"ml", "[", 
            RowBox[{"[", "i", "]"}], "]"}]}], "]"}], "2"], 
        SuperscriptBox[
         RowBox[{"\[Sigma]mlep", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "2"]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "ml", "]"}]}], "}"}]}], "]"}]], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m\[Tau]", "\[Rule]", "mtau"}], ",", 
      RowBox[{"m\[Mu]", "\[Rule]", "mmu"}], ",", 
      RowBox[{"mel", "\[Rule]", "me"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RW\[Tau]lSM", "=", 
   RowBox[{"RW\[Tau]lSMtemp", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m\[Tau]", "\[Rule]", "mtau"}], ",", 
      RowBox[{"m\[Mu]", "\[Rule]", "mmu"}], ",", 
      RowBox[{"mel", "\[Rule]", "me"}]}], "}"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.516540264527574*^9, 3.516540292498423*^9}, {
   3.5169696863208685`*^9, 3.516969691203148*^9}, {3.517059587078846*^9, 
   3.5170595885140486`*^9}, {3.5202329652155094`*^9, 
   3.5202329737175245`*^9}, {3.5202330564444695`*^9, 3.520233061186878*^9}, {
   3.5202330917785316`*^9, 3.5202330955693383`*^9}, {3.5224946061601577`*^9, 
   3.522494627516595*^9}, 3.5237110889348035`*^9, {3.523772490330843*^9, 
   3.5237725076678348`*^9}, {3.5238063393097982`*^9, 3.523806368294649*^9}, {
   3.529177224059628*^9, 3.529177315459856*^9}, {3.529177448278453*^9, 
   3.5291775044186635`*^9}, {3.5292498636876345`*^9, 3.529249867228841*^9}, {
   3.529251288420491*^9, 3.5292513088526597`*^9}, {3.5292514422122874`*^9, 
   3.5292514442774057`*^9}, {3.5292515574968815`*^9, 3.529251580914221*^9}, {
   3.5387471809470453`*^9, 3.538747182680145*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"I", " ", "use", " ", "the", " ", "following", " ", "values"}], 
    ",", " ", 
    RowBox[{
    "not", " ", "the", " ", "ones", " ", "calculated", " ", "before", " ", 
     "at", " ", "tree", " ", "level"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"RW\[Tau]lSM", "=", "0.999"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.5387462178639603`*^9, 3.538746250643835*^9}, {
  3.5387465783595796`*^9, 3.53874660651819*^9}, {3.54054113755235*^9, 
  3.5405411408465385`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Universality ratios", "Subsubsection",
 CellChangeTimes->{{3.5387466176288257`*^9, 3.5387466222210884`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[CapitalGamma]W\[Tau]\[Nu]thtau", "=", 
   RowBox[{
    RowBox[{
    "\[CapitalGamma]Wl\[Nu]SM", "+", "\[CapitalGamma]Wl\[Nu]hl3", "+", 
     "\[CapitalGamma]Wl\[Nu]EWt"}], "/.", 
    RowBox[{"{", 
     RowBox[{"m", "\[Rule]", "mtau"}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]W\[Tau]\[Nu]the", "=", 
   RowBox[{
    RowBox[{
    "\[CapitalGamma]Wl\[Nu]SM", "+", "\[CapitalGamma]Wl\[Nu]hl3", "+", 
     "\[CapitalGamma]Wl\[Nu]EWt"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "\[Rule]", "me"}], ",", 
      RowBox[{"ahL3", "\[Rule]", "ahl3"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalGamma]W\[Tau]\[Nu]thmu", "=", 
   RowBox[{
    RowBox[{
    "\[CapitalGamma]Wl\[Nu]SM", "+", "\[CapitalGamma]Wl\[Nu]hl3", "+", 
     "\[CapitalGamma]Wl\[Nu]EWt"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"m", "\[Rule]", "mmu"}], ",", 
      RowBox[{"ahL3", "\[Rule]", "ahl3"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RW\[Tau]l", "=", 
   RowBox[{
    RowBox[{"firstorder", "[", 
     RowBox[{"2", 
      RowBox[{"\[CapitalGamma]W\[Tau]\[Nu]thtau", "/", 
       RowBox[{"(", 
        RowBox[{
        "\[CapitalGamma]W\[Tau]\[Nu]the", "+", 
         "\[CapitalGamma]W\[Tau]\[Nu]thmu"}], ")"}]}]}], "]"}], "+", 
    "RW\[Tau]lSM"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5316769774599457`*^9, 3.5316770803265266`*^9}, {
   3.531677161025469*^9, 3.5316771694806833`*^9}, {3.5316772759040704`*^9, 
   3.5316773078529263`*^9}, {3.5387466981544313`*^9, 
   3.5387466998475285`*^9}, {3.5387471329182987`*^9, 3.5387471334783306`*^9}, 
   3.54055009611175*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "a) GLOBAL ANALYSIS - ",
 StyleBox["[U(2)xU(1)]^5 flavor symmetry",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]]
}], "Section",
 CellChangeTimes->{{3.5067699872735014`*^9, 3.5067700116251445`*^9}, {
   3.507469679480951*^9, 3.50746969030657*^9}, 3.509805539810589*^9, {
   3.51038621135526*^9, 3.5103862114892673`*^9}, {3.511249189024064*^9, 
   3.511249243280959*^9}, {3.5139469165353527`*^9, 3.513946922790964*^9}, {
   3.51463094890903*^9, 3.5146309519510355`*^9}, {3.5147133014232197`*^9, 
   3.5147133224676566`*^9}, {3.5147164669349794`*^9, 
   3.5147164710533867`*^9}, {3.5148046565424595`*^9, 3.514804660816867*^9}, {
   3.514811320872463*^9, 3.514811322682066*^9}, {3.5217898434818373`*^9, 
   3.5217898505174503`*^9}, {3.5224934794197826`*^9, 3.522493484457071*^9}, 
   3.5227360149879007`*^9, {3.5238803276330953`*^9, 3.523880333281418*^9}, {
   3.5288062655922904`*^9, 3.5288062715671005`*^9}, {3.5405423429622955`*^9, 
   3.540542400685597*^9}, {3.540550976966132*^9, 3.540550979566281*^9}}],

Cell[CellGroupData[{

Cell["Dropping unwanted operators", "Subsection",
 CellChangeTimes->{{3.5147134436330695`*^9, 3.5147134599818983`*^9}, {
  3.529953179190193*^9, 3.529953182177664*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Please", " ", "place", " ", "in", " ", "the", " ", "\"\<ops\>\"", " ", 
   "vector", " ", "the", " ", "operators", " ", "you", " ", "want", " ", "to",
    " ", "include", " ", "in", " ", "the", " ", 
   RowBox[{"fit", ".", " ", "The"}], " ", "other", " ", "operators", " ", 
   "will", " ", "be", " ", "dropped", " ", "automatically"}], "  ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.540540553836963*^9, 3.5405405993305655`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ops", "=", 
   RowBox[{"{", 
    RowBox[{
    "aWB", ",", "ah", ",", "aW", ",", "aQe", ",", "alQ3", ",", " ", "aLq3", 
     ",", "alb", ",", "aeb", ",", "alL1", ",", "alL3", ",", "altau", ",", 
     "aetau", ",", "ahQ3", ",", "ahb", ",", "ahL1", ",", "ahL3", ",", 
     "ahtau"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DropOpsTemp", "=", 
   RowBox[{"Complement", "[", 
    RowBox[{"Ops", ",", "ops"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DropOps", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"DropOps", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"DropOps", ",", 
       RowBox[{
        RowBox[{"DropOpsTemp", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", "0"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "DropOpsTemp", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Operators to drop from the total list: \>\"", ",", "DropOpsTemp"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Number of operators used in the fit: \>\"", ",", 
   RowBox[{"Length", "[", "ops", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5147035244465475`*^9, 3.514703554851001*^9}, {
   3.5147036800568204`*^9, 3.514703680290821*^9}, {3.5147037973846264`*^9, 
   3.514703801830634*^9}, 3.514703895680399*^9, {3.5147040714303083`*^9, 
   3.514704079823123*^9}, {3.514712543839089*^9, 3.5147125472086945`*^9}, {
   3.5147125802495527`*^9, 3.514712691914549*^9}, {3.514712766030279*^9, 
   3.5147128134699626`*^9}, {3.5147134294526443`*^9, 3.514713436815858*^9}, {
   3.5147151082495933`*^9, 3.514715137936445*^9}, {3.522497558137742*^9, 
   3.5224975604465466`*^9}, {3.5227370577873325`*^9, 
   3.5227370943069963`*^9}, {3.5287331270309563`*^9, 
   3.5287331335985675`*^9}, {3.5287336071217995`*^9, 
   3.5287336139546113`*^9}, {3.5288301495345335`*^9, 3.528830156960147*^9}, {
   3.528830222277461*^9, 3.5288302298278747`*^9}, {3.529952237100196*^9, 
   3.529952246409374*^9}, {3.529952807648368*^9, 3.529952975271253*^9}, {
   3.529953068155826*^9, 3.5299530896348314`*^9}, {3.531596287971748*^9, 
   3.531596290420952*^9}, {3.5315965445453987`*^9, 3.5315965512066097`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Operators to drop from the total list: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "aEBt", ",", "aed", ",", "aee", ",", "aeu", ",", "aEWt", ",", "ahd", ",", 
     "ahe", ",", "ahl1", ",", "ahl3", ",", "ahq1", ",", "ahQ1", ",", "ahq3", 
     ",", "ahu", ",", "ald", ",", "ale", ",", "aLe", ",", "all1", ",", "all3",
      ",", "alq1", ",", "alQ1", ",", "alq3", ",", "alu", ",", "aqe"}], "}"}]}],
  SequenceForm[
  "Operators to drop from the total list: ", {$CellContext`aEBt, \
$CellContext`aed, $CellContext`aee, $CellContext`aeu, $CellContext`aEWt, \
$CellContext`ahd, $CellContext`ahe, $CellContext`ahl1, $CellContext`ahl3, \
$CellContext`ahq1, $CellContext`ahQ1, $CellContext`ahq3, $CellContext`ahu, \
$CellContext`ald, $CellContext`ale, $CellContext`aLe, $CellContext`all1, \
$CellContext`all3, $CellContext`alq1, $CellContext`alQ1, $CellContext`alq3, \
$CellContext`alu, $CellContext`aqe}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.529952853378755*^9, 3.5299528557412863`*^9}, {
   3.529952912352669*^9, 3.529952989170877*^9}, {3.5299530745857363`*^9, 
   3.5299530914686093`*^9}, 3.5315962917157545`*^9, 3.531596552329812*^9, 
   3.5352829765290527`*^9, 3.5360594675687866`*^9, 3.5360694189859114`*^9, 
   3.536070213244913*^9, {3.536072457570978*^9, 3.536072484933543*^9}, 
   3.5387415430365753`*^9, 3.5387419236993484`*^9, 3.5387425796188645`*^9, 
   3.5387443825179844`*^9, 3.538746156947476*^9, 3.538747026249197*^9, 
   3.538747219861271*^9, {3.5388381091123314`*^9, 3.5388381331207733`*^9}, 
   3.538838180560457*^9, 3.538896691748685*^9, 3.5405410570847473`*^9, 
   3.540543338872258*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of operators used in the fit: \"\>", 
   "\[InvisibleSpace]", "17"}],
  SequenceForm["Number of operators used in the fit: ", 17],
  Editable->False]], "Print",
 CellChangeTimes->{{3.529952853378755*^9, 3.5299528557412863`*^9}, {
   3.529952912352669*^9, 3.529952989170877*^9}, {3.5299530745857363`*^9, 
   3.5299530914686093`*^9}, 3.5315962917157545`*^9, 3.531596552329812*^9, 
   3.5352829765290527`*^9, 3.5360594675687866`*^9, 3.5360694189859114`*^9, 
   3.536070213244913*^9, {3.536072457570978*^9, 3.536072484933543*^9}, 
   3.5387415430365753`*^9, 3.5387419236993484`*^9, 3.5387425796188645`*^9, 
   3.5387443825179844`*^9, 3.538746156947476*^9, 3.538747026249197*^9, 
   3.538747219861271*^9, {3.5388381091123314`*^9, 3.5388381331207733`*^9}, 
   3.538838180560457*^9, 3.538896691748685*^9, 3.5405410570847473`*^9, 
   3.540543338873258*^9}]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["New parametrization", "Subsection",
 CellChangeTimes->{{3.5098759773223677`*^9, 3.5098759823611765`*^9}, {
  3.511249539104279*^9, 3.5112495407734823`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"We", " ", "change", " ", "the", " ", "parametrization"}], ",", 
   " ", 
   RowBox[{
   "defining", " ", "the", " ", "operator", " ", "coefficients", " ", "as", 
    " ", "dimensionless", " ", "parameter"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.5112494699181576`*^9, 3.5112494905725937`*^9}, {
  3.511249547512694*^9, 3.5112495825815554`*^9}, {3.511249645621266*^9, 
  3.5112496583196883`*^9}, {3.5405406506515007`*^9, 3.5405406616231284`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ChangeOP", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ChangeOP", "=", 
      RowBox[{"Append", "[", 
       RowBox[{"ChangeOP", ",", 
        RowBox[{
         RowBox[{"Ops", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"Ops", "[", 
           RowBox[{"[", "i", "]"}], "]"}], 
          RowBox[{"2", "/", 
           SuperscriptBox["v", "2"]}]}]}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "Ops", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"X2", "=", "chi2total"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]2", "=", 
   RowBox[{"X2", "/.", "ChangeOP"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]", "=", 
   RowBox[{"\[Chi]2", "/.", "DropOps"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.506860863966121*^9, 3.506860867429327*^9}, 
   3.507470286691067*^9, 3.509805539858591*^9, {3.5099523420168447`*^9, 
   3.5099523424848456`*^9}, {3.509968853450631*^9, 3.509968856352236*^9}, {
   3.511249671657712*^9, 3.511249671813712*^9}, {3.5146310355515823`*^9, 
   3.514631140945367*^9}, {3.5147134742559233`*^9, 3.5147134744743233`*^9}, 
   3.5215466567818565`*^9, {3.5215473257684107`*^9, 3.5215473284554634`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["M matrix", "Subsection",
 CellChangeTimes->{{3.5134934965268574`*^9, 3.5134935087260785`*^9}, 
   3.5146311872462482`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Length", "[", "ops", "]"}], ",", 
       RowBox[{"Length", "[", "ops", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<=", 
     RowBox[{"Length", "[", "ops", "]"}]}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "<=", 
       RowBox[{"Length", "[", "ops", "]"}]}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"1", "/", "2"}], 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{"\[Chi]", ",", 
            RowBox[{"ops", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"ops", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}]}]}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<M matrix\>\"", ",", 
   RowBox[{"MatrixForm", "[", "M", "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<M eigenvalues: \>\"", ",", 
   RowBox[{"Eigenvalues", "[", "M", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5147035632594156`*^9, 3.514703579842244*^9}, {
  3.514713489887151*^9, 3.5147135069223804`*^9}, {3.514805618424549*^9, 
  3.5148056296097684`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"M matrix\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1.1607500706596534`*^8", "3.282297774746182`*^7", 
        "8316.705447831582`", "52562.723056362585`", 
        RowBox[{"-", "188250.5212615234`"}], "0.`", 
        RowBox[{"-", "24599.35491160201`"}], 
        RowBox[{"-", "74671.83265190518`"}], 
        RowBox[{"-", "28414.15272230153`"}], 
        RowBox[{"-", "28414.15272230153`"}], 
        RowBox[{"-", "12086.81849431104`"}], 
        RowBox[{"-", "25826.95022845447`"}], 
        RowBox[{"-", "2.610173593215924`*^6"}], 
        RowBox[{"-", "35513.46085993277`"}], 
        RowBox[{"-", "1.7682553813854125`*^6"}], 
        RowBox[{"-", "2.6001696767071774`*^6"}], 
        RowBox[{"-", "3.923923654974767`*^6"}]},
       {"3.282297774746182`*^7", "1.168869656878161`*^7", 
        "4874.077337692446`", "28444.927714398997`", 
        RowBox[{"-", "90173.39512533431`"}], "0.`", 
        RowBox[{"-", "13157.086926458227`"}], 
        RowBox[{"-", "35702.03323208745`"}], 
        RowBox[{"-", "18563.062722242277`"}], 
        RowBox[{"-", "18563.062722242277`"}], "735.5851614234158`", 
        RowBox[{"-", "16872.412114233037`"}], 
        RowBox[{"-", "1.1646721676181788`*^6"}], "103960.62395725375`", 
        RowBox[{"-", "376766.3989883177`"}], 
        RowBox[{"-", "789385.4796755267`"}], 
        RowBox[{"-", "720946.373066939`"}]},
       {"8316.705447831582`", "4874.077337692446`", "2852.6211139621855`", 
        "0.`", "0.`", "0.`", "0", "0.`", "0.`", "0.`", "0", "0.`", "0.`", 
        "0.`", "0.`", "0.`", "0"},
       {"52562.723056362585`", "28444.927714398997`", "0.`", 
        "76025.03589177351`", 
        RowBox[{"-", "171169.95491960127`"}], "0.`", 
        RowBox[{"-", "36517.8674146696`"}], 
        RowBox[{"-", "68171.18588149021`"}], "0.`", "0.`", "0", "0.`", 
        RowBox[{"-", "38339.793441133465`"}], "3618.7330625865534`", "0.`", 
        "0.`", "0"},
       {
        RowBox[{"-", "188250.5212615234`"}], 
        RowBox[{"-", "90173.39512533431`"}], "0.`", 
        RowBox[{"-", "171169.95491960127`"}], "547883.2599741844`", "0.`", 
        "82890.18823036028`", "218480.64429748087`", "0.`", "0.`", "0", "0.`",
         "110694.93619352022`", 
        RowBox[{"-", "16730.52136670738`"}], "0.`", "0.`", "0"},
       {"0.`", "0.`", "0.`", "0.`", "0.`", "314977.25588697015`", "0", "0.`", 
        "0.`", "0.`", "0", "0.`", "0.`", "0.`", "0.`", 
        RowBox[{"-", "314977.2558869701`"}], "0.`"},
       {
        RowBox[{"-", "24599.35491160201`"}], 
        RowBox[{"-", "13157.086926458227`"}], "0.`", 
        RowBox[{"-", "36517.8674146696`"}], "82890.18823036028`", "0.`", 
        "17831.09510731388`", "33113.537509413865`", "0.`", "0.`", "0", "0.`",
         "17802.842400136382`", 
        RowBox[{"-", "1644.4137089666644`"}], "0.`", "0.`", "0"},
       {
        RowBox[{"-", "74671.83265190518`"}], 
        RowBox[{"-", "35702.03323208745`"}], "0.`", 
        RowBox[{"-", "68171.18588149021`"}], "218480.64429748087`", "0.`", 
        "33113.537509413865`", "87166.04327464772`", "0.`", "0.`", "0", "0.`",
         "43843.74874770954`", 
        RowBox[{"-", "6623.140216117658`"}], "0.`", "0.`", "0"},
       {
        RowBox[{"-", "28414.15272230153`"}], 
        RowBox[{"-", "18563.062722242277`"}], "0.`", "0.`", "0.`", "0.`", "0",
         "0.`", "225807.2891231262`", "225807.2891231262`", 
        "50498.89662018691`", "205419.91778305787`", "0.`", "0.`", 
        "29337.778035270825`", "29337.778035270825`", 
        RowBox[{"-", "20274.06683012215`"}]},
       {
        RowBox[{"-", "28414.15272230153`"}], 
        RowBox[{"-", "18563.062722242277`"}], "0.`", "0.`", "0.`", "0.`", "0",
         "0.`", "225807.2891231262`", "2.0042962491231256`*^6", 
        "50498.89662018691`", "205419.91778305787`", "0.`", "0.`", 
        "29337.778035270825`", 
        RowBox[{"-", "1.7491511819647285`*^6"}], 
        RowBox[{"-", "20274.06683012215`"}]},
       {
        RowBox[{"-", "12086.81849431104`"}], "735.5851614234158`", "0.`", 
        "0.`", "0.`", "0.`", "0", "0.`", "50498.89662018691`", 
        "50498.89662018691`", "94759.24963396546`", "45944.63541310316`", 
        "0.`", "0.`", 
        RowBox[{"-", "4784.179245753022`"}], 
        RowBox[{"-", "4784.179245753022`"}], "8639.702698877189`"},
       {
        RowBox[{"-", "25826.95022845447`"}], 
        RowBox[{"-", "16872.412114233037`"}], "0.`", "0.`", "0.`", "0.`", "0",
         "0.`", "205419.91778305787`", "205419.91778305787`", 
        "45944.63541310316`", "186875.22831091893`", "0.`", "0.`", 
        "26665.631585787043`", "26665.631585787043`", 
        RowBox[{"-", "18427.201234959437`"}]},
       {
        RowBox[{"-", "2.610173593215924`*^6"}], 
        RowBox[{"-", "1.1646721676181788`*^6"}], "0.`", 
        RowBox[{"-", "38339.793441133465`"}], "110694.93619352022`", "0.`", 
        "17802.842400136382`", "43843.74874770954`", "0.`", "0.`", "0", "0.`",
         "2.8604171742409356`*^6", 
        RowBox[{"-", "496732.81257938605`"}], 
        RowBox[{"-", "1.0325728177259867`*^6"}], 
        RowBox[{"-", "202209.60628424815`"}], "528460.981258295`"},
       {
        RowBox[{"-", "35513.46085993277`"}], "103960.62395725375`", "0.`", 
        "3618.7330625865534`", 
        RowBox[{"-", "16730.52136670738`"}], "0.`", 
        RowBox[{"-", "1644.4137089666644`"}], 
        RowBox[{"-", "6623.140216117658`"}], "0.`", "0.`", "0", "0.`", 
        RowBox[{"-", "496732.81257938605`"}], "104501.95277556873`", 
        "188039.3773603702`", "36823.909955051655`", 
        RowBox[{"-", "96236.77107238185`"}]},
       {
        RowBox[{"-", "1.7682553813854125`*^6"}], 
        RowBox[{"-", "376766.3989883177`"}], "0.`", "0.`", "0.`", "0.`", "0", 
        "0.`", "29337.778035270825`", "29337.778035270825`", 
        RowBox[{"-", "4784.179245753022`"}], "26665.631585787043`", 
        RowBox[{"-", "1.0325728177259867`*^6"}], "188039.3773603702`", 
        "4.784000450400706`*^6", "4.282511016539086`*^6", 
        RowBox[{"-", "2.28042548768407`*^6"}]},
       {
        RowBox[{"-", "2.6001696767071774`*^6"}], 
        RowBox[{"-", "789385.4796755267`"}], "0.`", "0.`", "0.`", 
        RowBox[{"-", "314977.2558869701`"}], "0", "0.`", 
        "29337.778035270825`", 
        RowBox[{"-", "1.7491511819647285`*^6"}], 
        RowBox[{"-", "4784.179245753022`"}], "26665.631585787043`", 
        RowBox[{"-", "202209.60628424815`"}], "36823.909955051655`", 
        "4.282511016539086`*^6", "7.326663454439509`*^6", 
        RowBox[{"-", "2.472904437645085`*^6"}]},
       {
        RowBox[{"-", "3.923923654974767`*^6"}], 
        RowBox[{"-", "720946.373066939`"}], "0.`", "0.`", "0.`", "0.`", "0", 
        "0.`", 
        RowBox[{"-", "20274.06683012215`"}], 
        RowBox[{"-", "20274.06683012215`"}], "8639.702698877189`", 
        RowBox[{"-", "18427.201234959437`"}], "528460.981258295`", 
        RowBox[{"-", "96236.77107238185`"}], 
        RowBox[{"-", "2.28042548768407`*^6"}], 
        RowBox[{"-", "2.472904437645085`*^6"}], "3.9027484609443303`*^6"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["M matrix", 
   MatrixForm[{{1.1607500706596534`*^8, 3.282297774746182*^7, 
     8316.705447831582, 52562.723056362585`, -188250.5212615234, 
     0., -24599.35491160201, -74671.83265190518, -28414.15272230153, \
-28414.15272230153, -12086.81849431104, -25826.95022845447, \
-2.610173593215924*^6, -35513.46085993277, -1.7682553813854125`*^6, \
-2.6001696767071774`*^6, -3.923923654974767*^6}, {3.282297774746182*^7, 
     1.168869656878161*^7, 4874.077337692446, 
     28444.927714398997`, -90173.39512533431, 
     0., -13157.086926458227`, -35702.03323208745, -18563.062722242277`, \
-18563.062722242277`, 
     735.5851614234158, -16872.412114233037`, -1.1646721676181788`*^6, 
     103960.62395725375`, -376766.3989883177, -789385.4796755267, \
-720946.373066939}, {
     8316.705447831582, 4874.077337692446, 2852.6211139621855`, 0., 0., 0., 0,
       0., 0., 0., 0, 0., 0., 0., 0., 0., 0}, {
     52562.723056362585`, 28444.927714398997`, 0., 
      76025.03589177351, -171169.95491960127`, 
      0., -36517.8674146696, -68171.18588149021, 0., 0., 0, 
      0., -38339.793441133465`, 3618.7330625865534`, 0., 0., 
      0}, {-188250.5212615234, -90173.39512533431, 0., -171169.95491960127`, 
      547883.2599741844, 0., 82890.18823036028, 218480.64429748087`, 0., 0., 
      0, 0., 110694.93619352022`, -16730.52136670738, 0., 0., 0}, {
     0., 0., 0., 0., 0., 314977.25588697015`, 0, 0., 0., 0., 0, 0., 0., 0., 
      0., -314977.2558869701, 0.}, {-24599.35491160201, -13157.086926458227`, 
      0., -36517.8674146696, 82890.18823036028, 0., 17831.09510731388, 
      33113.537509413865`, 0., 0., 0, 0., 
      17802.842400136382`, -1644.4137089666644`, 0., 0., 
      0}, {-74671.83265190518, -35702.03323208745, 0., -68171.18588149021, 
      218480.64429748087`, 0., 33113.537509413865`, 87166.04327464772, 0., 0.,
       0, 0., 43843.74874770954, -6623.140216117658, 0., 0., 
      0}, {-28414.15272230153, -18563.062722242277`, 0., 0., 0., 0., 0, 0., 
      225807.2891231262, 225807.2891231262, 50498.89662018691, 
      205419.91778305787`, 0., 0., 29337.778035270825`, 
      29337.778035270825`, -20274.06683012215}, {-28414.15272230153, \
-18563.062722242277`, 0., 0., 0., 0., 0, 0., 225807.2891231262, 
      2.0042962491231256`*^6, 50498.89662018691, 205419.91778305787`, 0., 0., 
      29337.778035270825`, -1.7491511819647285`*^6, -20274.06683012215}, \
{-12086.81849431104, 735.5851614234158, 0., 0., 0., 0., 0, 0., 
      50498.89662018691, 50498.89662018691, 94759.24963396546, 
      45944.63541310316, 0., 0., -4784.179245753022, -4784.179245753022, 
      8639.702698877189}, {-25826.95022845447, -16872.412114233037`, 0., 0., 
      0., 0., 0, 0., 205419.91778305787`, 205419.91778305787`, 
      45944.63541310316, 186875.22831091893`, 0., 0., 26665.631585787043`, 
      26665.631585787043`, -18427.201234959437`}, {-2.610173593215924*^6, \
-1.1646721676181788`*^6, 0., -38339.793441133465`, 110694.93619352022`, 0., 
      17802.842400136382`, 43843.74874770954, 0., 0., 0, 0., 
      2.8604171742409356`*^6, -496732.81257938605`, -1.0325728177259867`*^6, \
-202209.60628424815`, 528460.981258295}, {-35513.46085993277, 
      103960.62395725375`, 0., 3618.7330625865534`, -16730.52136670738, 
      0., -1644.4137089666644`, -6623.140216117658, 0., 0., 0, 
      0., -496732.81257938605`, 104501.95277556873`, 188039.3773603702, 
      36823.909955051655`, -96236.77107238185}, {-1.7682553813854125`*^6, \
-376766.3989883177, 0., 0., 0., 0., 0, 0., 29337.778035270825`, 
      29337.778035270825`, -4784.179245753022, 
      26665.631585787043`, -1.0325728177259867`*^6, 188039.3773603702, 
      4.784000450400706*^6, 
      4.282511016539086*^6, -2.28042548768407*^6}, {-2.6001696767071774`*^6, \
-789385.4796755267, 0., 0., 0., -314977.2558869701, 0, 0., 
      29337.778035270825`, -1.7491511819647285`*^6, -4784.179245753022, 
      26665.631585787043`, -202209.60628424815`, 36823.909955051655`, 
      4.282511016539086*^6, 
      7.326663454439509*^6, -2.472904437645085*^6}, {-3.923923654974767*^6, \
-720946.373066939, 0., 0., 0., 0., 0, 
      0., -20274.06683012215, -20274.06683012215, 
      8639.702698877189, -18427.201234959437`, 
      528460.981258295, -96236.77107238185, -2.28042548768407*^6, \
-2.472904437645085*^6, 3.9027484609443303`*^6}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.514703580481846*^9, 3.514703701818859*^9, 3.5147038116742516`*^9, 
   3.514703864433544*^9, 3.514703930593261*^9, 3.5147040877167363`*^9, 
   3.514712523340653*^9, 3.5147125623875217`*^9, 3.5147126017775908`*^9, 
   3.5147126494200745`*^9, 3.5147127000733633`*^9, 3.5147128216443768`*^9, {
   3.5147134801839333`*^9, 3.5147135084979835`*^9}, 3.514715038829471*^9, 
   3.5147151545192747`*^9, 3.5147165785375757`*^9, 3.514804810265129*^9, {
   3.51480561909535*^9, 3.514805630202569*^9}, 3.516017519372511*^9, 
   3.5165306292968082`*^9, 3.5165395430575066`*^9, 3.5169690258970947`*^9, 
   3.516969871072436*^9, {3.517121610034176*^9, 3.517121631718214*^9}, 
   3.5171217746612654`*^9, 3.5171417252121067`*^9, 3.5173105132466803`*^9, 
   3.5175567602866144`*^9, 3.5183438461468706`*^9, 3.5190390988388166`*^9, 
   3.521544557291131*^9, 3.521546652766738*^9, 3.5215473394655657`*^9, 
   3.521789193023095*^9, 3.521789920405573*^9, 3.5217900126329346`*^9, 
   3.521796101564295*^9, {3.5221557458808093`*^9, 3.522155775579508*^9}, 
   3.5221558140287075`*^9, 3.5221558609523907`*^9, 3.522156281355437*^9, 
   3.522156348169258*^9, 3.522156382907245*^9, 3.5224754442044554`*^9, 
   3.5224766789074926`*^9, 3.5224782059629745`*^9, 3.5224946612594547`*^9, 
   3.5224965093947*^9, 3.522580741207724*^9, 3.522737152417098*^9, 
   3.522763601054867*^9, 3.522906432167075*^9, 3.522906476221552*^9, 
   3.522906533707653*^9, 3.5237725807390146`*^9, 3.5237726597325325`*^9, 
   3.5237733905443325`*^9, 3.5237734731020546`*^9, 3.523806287112107*^9, 
   3.5238112914470806`*^9, 3.523864981076062*^9, 3.5238659552353735`*^9, 
   3.52387424275706*^9, 3.5238752244622107`*^9, 3.524314546559955*^9, 
   3.524562626457658*^9, 3.5287336985847597`*^9, {3.5287337508916516`*^9, 
   3.528733777832899*^9}, 3.528738442073391*^9, 3.5287385005422935`*^9, {
   3.528806370720875*^9, 3.52880639087611*^9}, 3.52880653305476*^9, 
   3.5288066735330067`*^9, 3.52880828743571*^9, 3.528808354406627*^9, 
   3.5288084076027203`*^9, 3.5288085526985755`*^9, 3.5288086086402736`*^9, 
   3.5288108963084245`*^9, 3.528810935305655*^9, {3.5288110252517996`*^9, 
   3.52881105374743*^9}, 3.5288296723764954`*^9, {3.5288300297575235`*^9, 
   3.528830051472761*^9}, 3.528830082548016*^9, 3.529176210782672*^9, 
   3.5292413103575935`*^9, 3.5292594210537405`*^9, 3.529262388085352*^9, 
   3.529263194233368*^9, 3.5292635717852306`*^9, 3.5292645429961367`*^9, 
   3.5292652025184946`*^9, 3.5292657665852857`*^9, 3.529322491101081*^9, 
   3.5293267457564335`*^9, 3.529430838068112*^9, 3.529953099521122*^9, 
   3.531596295475361*^9, 3.5315965560270185`*^9, 3.535282979546599*^9, 
   3.536059467729796*^9, 3.536069419050914*^9, 3.5360702133639193`*^9, {
   3.536072457639982*^9, 3.5360724850105476`*^9}, 3.538741545690727*^9, 
   3.538741927880587*^9, 3.5387425827480435`*^9, 3.5387443855171556`*^9, 
   3.5387461570774837`*^9, 3.5387470263702044`*^9, 3.538747219975278*^9, {
   3.5388381092059317`*^9, 3.5388381360067787`*^9}, 3.5388381834932623`*^9, 
   3.538896691898694*^9, 3.5405410571707525`*^9, 3.540543338953263*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"M eigenvalues: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1.2581896224846865`*^8", ",", "1.2166355237776253`*^7", ",", 
     "3.6221082074547284`*^6", ",", "2.980913184702399`*^6", ",", 
     "2.0005955068807725`*^6", ",", "1.6669606285864005`*^6", ",", 
     "727251.3227774311`", ",", "676974.7762091255`", ",", 
     "343003.7735767973`", ",", "174371.1676145067`", ",", 
     "80351.27134811487`", ",", "25439.36612991266`", ",", 
     "14101.033252752075`", ",", "2849.20259016328`", ",", 
     "265.2195064157502`", ",", "5.227406675298324`", ",", 
     "1.0807068981155534`"}], "}"}]}],
  SequenceForm[
  "M eigenvalues: ", {1.2581896224846865`*^8, 1.2166355237776253`*^7, 
   3.6221082074547284`*^6, 2.980913184702399*^6, 2.0005955068807725`*^6, 
   1.6669606285864005`*^6, 727251.3227774311, 676974.7762091255, 
   343003.7735767973, 174371.1676145067, 80351.27134811487, 25439.36612991266,
    14101.033252752075`, 2849.20259016328, 265.2195064157502, 
   5.227406675298324, 1.0807068981155534`}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.514703580481846*^9, 3.514703701818859*^9, 3.5147038116742516`*^9, 
   3.514703864433544*^9, 3.514703930593261*^9, 3.5147040877167363`*^9, 
   3.514712523340653*^9, 3.5147125623875217`*^9, 3.5147126017775908`*^9, 
   3.5147126494200745`*^9, 3.5147127000733633`*^9, 3.5147128216443768`*^9, {
   3.5147134801839333`*^9, 3.5147135084979835`*^9}, 3.514715038829471*^9, 
   3.5147151545192747`*^9, 3.5147165785375757`*^9, 3.514804810265129*^9, {
   3.51480561909535*^9, 3.514805630202569*^9}, 3.516017519372511*^9, 
   3.5165306292968082`*^9, 3.5165395430575066`*^9, 3.5169690258970947`*^9, 
   3.516969871072436*^9, {3.517121610034176*^9, 3.517121631718214*^9}, 
   3.5171217746612654`*^9, 3.5171417252121067`*^9, 3.5173105132466803`*^9, 
   3.5175567602866144`*^9, 3.5183438461468706`*^9, 3.5190390988388166`*^9, 
   3.521544557291131*^9, 3.521546652766738*^9, 3.5215473394655657`*^9, 
   3.521789193023095*^9, 3.521789920405573*^9, 3.5217900126329346`*^9, 
   3.521796101564295*^9, {3.5221557458808093`*^9, 3.522155775579508*^9}, 
   3.5221558140287075`*^9, 3.5221558609523907`*^9, 3.522156281355437*^9, 
   3.522156348169258*^9, 3.522156382907245*^9, 3.5224754442044554`*^9, 
   3.5224766789074926`*^9, 3.5224782059629745`*^9, 3.5224946612594547`*^9, 
   3.5224965093947*^9, 3.522580741207724*^9, 3.522737152417098*^9, 
   3.522763601054867*^9, 3.522906432167075*^9, 3.522906476221552*^9, 
   3.522906533707653*^9, 3.5237725807390146`*^9, 3.5237726597325325`*^9, 
   3.5237733905443325`*^9, 3.5237734731020546`*^9, 3.523806287112107*^9, 
   3.5238112914470806`*^9, 3.523864981076062*^9, 3.5238659552353735`*^9, 
   3.52387424275706*^9, 3.5238752244622107`*^9, 3.524314546559955*^9, 
   3.524562626457658*^9, 3.5287336985847597`*^9, {3.5287337508916516`*^9, 
   3.528733777832899*^9}, 3.528738442073391*^9, 3.5287385005422935`*^9, {
   3.528806370720875*^9, 3.52880639087611*^9}, 3.52880653305476*^9, 
   3.5288066735330067`*^9, 3.52880828743571*^9, 3.528808354406627*^9, 
   3.5288084076027203`*^9, 3.5288085526985755`*^9, 3.5288086086402736`*^9, 
   3.5288108963084245`*^9, 3.528810935305655*^9, {3.5288110252517996`*^9, 
   3.52881105374743*^9}, 3.5288296723764954`*^9, {3.5288300297575235`*^9, 
   3.528830051472761*^9}, 3.528830082548016*^9, 3.529176210782672*^9, 
   3.5292413103575935`*^9, 3.5292594210537405`*^9, 3.529262388085352*^9, 
   3.529263194233368*^9, 3.5292635717852306`*^9, 3.5292645429961367`*^9, 
   3.5292652025184946`*^9, 3.5292657665852857`*^9, 3.529322491101081*^9, 
   3.5293267457564335`*^9, 3.529430838068112*^9, 3.529953099521122*^9, 
   3.531596295475361*^9, 3.5315965560270185`*^9, 3.535282979546599*^9, 
   3.536059467729796*^9, 3.536069419050914*^9, 3.5360702133639193`*^9, {
   3.536072457639982*^9, 3.5360724850105476`*^9}, 3.538741545690727*^9, 
   3.538741927880587*^9, 3.5387425827480435`*^9, 3.5387443855171556`*^9, 
   3.5387461570774837`*^9, 3.5387470263702044`*^9, 3.538747219975278*^9, {
   3.5388381092059317`*^9, 3.5388381360067787`*^9}, 3.5388381834932623`*^9, 
   3.538896691898694*^9, 3.5405410571707525`*^9, 3.5405433389792643`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error Matrix", "Subsection",
 CellChangeTimes->{{3.514631197651467*^9, 3.514631201192673*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Merr", "=", 
   RowBox[{"Inverse", "[", "M", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Error matrix\>\"", ",", 
   RowBox[{"MatrixForm", "[", "Merr", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5288065145843277`*^9, 3.528806518281534*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Error matrix\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"5.26591160272695`*^-8", 
        RowBox[{"-", "1.3892232607862774`*^-7"}], "8.384141971282567`*^-8", 
        "1.7168172443137243`*^-7", "1.3710656856483347`*^-7", 
        "1.680965626791424`*^-8", "1.8727536452239003`*^-7", 
        RowBox[{"-", "2.9436470634533996`*^-7"}], 
        RowBox[{"-", "3.694675762740062`*^-7"}], "1.680965626791425`*^-8", 
        "8.216428811056438`*^-9", "3.8086946702533255`*^-7", 
        "1.0641797064674668`*^-7", "6.775558403216555`*^-7", 
        "1.2492473505670406`*^-8", "1.6809656267914244`*^-8", 
        "4.747865151981979`*^-8"},
       {
        RowBox[{"-", "1.3892232607862768`*^-7"}], "4.6466875024736884`*^-7", 
        RowBox[{"-", "3.889248921144037`*^-7"}], 
        RowBox[{"-", "3.379934568354855`*^-7"}], 
        RowBox[{"-", "6.550072271527564`*^-8"}], 
        RowBox[{"-", "1.9420597527141376`*^-8"}], 
        RowBox[{"-", "3.8109783757995984`*^-7"}], "9.586650621482049`*^-8", 
        "1.5002644480388975`*^-6", 
        RowBox[{"-", "1.9420597527141405`*^-8"}], 
        RowBox[{"-", "2.823387502772517`*^-8"}], 
        RowBox[{"-", "1.600868638795048`*^-6"}], 
        RowBox[{"-", "1.489543528305486`*^-7"}], 
        RowBox[{"-", "1.2500370318591354`*^-6"}], 
        RowBox[{"-", "2.3681647848374952`*^-8"}], 
        RowBox[{"-", "1.942059752714138`*^-8"}], 
        RowBox[{"-", "9.044003304517799`*^-8"}]},
       {"8.384141971282565`*^-8", 
        RowBox[{"-", "3.889248921144035`*^-7"}], "0.00035097488436521164`", 
        "7.697479146598121`*^-8", 
        RowBox[{"-", "2.878122697434495`*^-7"}], 
        RowBox[{"-", "1.5825258162431065`*^-8"}], "1.051616310893408`*^-7", 
        "6.944083046397284`*^-7", 
        RowBox[{"-", "1.486230302924033`*^-6"}], 
        RowBox[{"-", "1.5825258162431042`*^-8"}], "2.4286601481756146`*^-8", 
        "1.6248839914134935`*^-6", 
        RowBox[{"-", "5.574938780498207`*^-8"}], "1.6046463990863886`*^-7", 
        "4.041882947245605`*^-9", 
        RowBox[{"-", "1.582525816243107`*^-8"}], "1.6106504824700593`*^-8"},
       {"1.716817244316181`*^-7", 
        RowBox[{"-", "3.3799345683572417`*^-7"}], "7.697479146570379`*^-8", 
        "0.004927419024172399`", "0.00976423635446243`", 
        "2.429401170858658`*^-8", "0.010163719033966602`", 
        RowBox[{"-", "0.024481621594465826`"}], 
        RowBox[{"-", "7.37453157543394`*^-7"}], "2.4294011708585597`*^-8", 
        "2.2442513103560304`*^-8", "7.68757671801984`*^-7", 
        "2.4198294280479773`*^-6", "0.000012773000111062846`", 
        "1.2361533973038108`*^-7", "2.4294011708586583`*^-8", 
        "1.8497823875461908`*^-7"},
       {"1.3710656856538944`*^-7", 
        RowBox[{"-", "6.550072271583381`*^-8"}], 
        RowBox[{"-", "2.8781226974394433`*^-7"}], "0.009764236354463645`", 
        "0.023173247868502906`", "7.403296432145766`*^-7", 
        "0.020221709410779005`", 
        RowBox[{"-", "0.058128672272595834`"}], "2.1660191301112923`*^-6", 
        "7.403296432145727`*^-7", 
        RowBox[{"-", "3.307840619535922`*^-8"}], 
        RowBox[{"-", "3.1474785069096622`*^-6"}], "1.9634402247722255`*^-6", 
        "0.000016715427834556457`", 
        RowBox[{"-", "6.892883582020146`*^-7"}], "7.403296432145767`*^-7", 
        "3.387136688678266`*^-7"},
       {"1.6809656267914184`*^-8", 
        RowBox[{"-", "1.9420597527141157`*^-8"}], 
        RowBox[{"-", "1.5825258162431158`*^-8"}], "2.4294011710710938`*^-8", 
        "7.403296432119683`*^-7", "4.072701194076783`*^-6", 
        RowBox[{"-", "3.015363021099228`*^-8"}], 
        RowBox[{"-", "1.705209646044159`*^-6"}], 
        RowBox[{"-", "9.701598162755582`*^-7"}], "8.978687853556571`*^-7", 
        RowBox[{"-", "6.685525859040341`*^-9"}], "8.015976043674271`*^-8", 
        RowBox[{"-", "1.244722459895774`*^-7"}], "6.699981645212227`*^-7", 
        RowBox[{"-", "7.745578608919387`*^-7"}], "8.978687853556571`*^-7", 
        "1.630408041864796`*^-7"},
       {"1.8727536452253535`*^-7", 
        RowBox[{"-", "3.810978375801957`*^-7"}], "1.0516163108945315`*^-7", 
        "0.010163719033966616`", "0.02022170941077654`", 
        RowBox[{"-", "3.015363020386629`*^-8"}], "0.02115969281691753`", 
        RowBox[{"-", "0.0507752338678301`"}], 
        RowBox[{"-", "1.0036474587246994`*^-6"}], 
        RowBox[{"-", "3.015363020386628`*^-8"}], "2.8296273257291064`*^-8", 
        "1.115452858004018`*^-6", "2.3918156891317155`*^-6", 
        "0.000012057493069719816`", "1.9823602601706358`*^-7", 
        RowBox[{"-", "3.01536302038663`*^-8"}], "1.8790407874721277`*^-7"},
       {
        RowBox[{"-", "2.943647063461313`*^-7"}], "9.58665062170171`*^-8", 
        "6.944083046382318`*^-7", 
        RowBox[{"-", "0.02448162159446886`"}], 
        RowBox[{"-", "0.058128672272595855`"}], 
        RowBox[{"-", "1.7052096460412611`*^-6"}], 
        RowBox[{"-", "0.05077523386783628`"}], "0.14585173686293304`", 
        RowBox[{"-", "5.149090392737323`*^-6"}], 
        RowBox[{"-", "1.7052096460412611`*^-6"}], "7.983492383069899`*^-8", 
        "7.422523353006749`*^-6", 
        RowBox[{"-", "4.271865808910813`*^-6"}], 
        RowBox[{"-", "0.00003716281283409201`"}], "1.6016065581031698`*^-6", 
        RowBox[{"-", "1.7052096460412614`*^-6"}], 
        RowBox[{"-", "7.615706746552653`*^-7"}]},
       {
        RowBox[{"-", "3.694675762706356`*^-7"}], "1.5002644480321826`*^-6", 
        RowBox[{"-", "1.4862303029237554`*^-6"}], 
        RowBox[{"-", "7.374531564041809`*^-7"}], "2.166019131718693`*^-6", 
        RowBox[{"-", "9.701598162762058`*^-7"}], 
        RowBox[{"-", "1.0036474553368827`*^-6"}], 
        RowBox[{"-", "5.149090398831062`*^-6"}], "0.4190097027629331`", 
        RowBox[{"-", "1.532434883765748`*^-6"}], "0.00002504380659104579`", 
        RowBox[{"-", "0.46059444283754936`"}], 
        RowBox[{"-", "5.174385570412465`*^-7"}], 
        RowBox[{"-", "1.0892052005967554`*^-6"}], 
        RowBox[{"-", "1.1916802539471825`*^-6"}], 
        RowBox[{"-", "9.70159816276206`*^-7"}], "5.126162524443374`*^-7"},
       {"1.680965626791419`*^-8", 
        RowBox[{"-", "1.9420597527141167`*^-8"}], 
        RowBox[{"-", "1.5825258162431158`*^-8"}], "2.4294011710710968`*^-8", 
        "7.403296432119683`*^-7", "8.978687853556571`*^-7", 
        RowBox[{"-", "3.0153630210992255`*^-8"}], 
        RowBox[{"-", "1.7052096460441593`*^-6"}], 
        RowBox[{"-", "1.5324348837575631`*^-6"}], "1.4601438528376618`*^-6", 
        RowBox[{"-", "6.685525859040341`*^-9"}], "8.015976043674271`*^-8", 
        RowBox[{"-", "1.244722459895774`*^-7"}], "6.699981645212228`*^-7", 
        RowBox[{"-", "7.745578608919388`*^-7"}], "8.978687853556572`*^-7", 
        "1.6304080418647972`*^-7"},
       {"8.21642881105638`*^-9", 
        RowBox[{"-", "2.8233875027725095`*^-8"}], "2.4286601481756083`*^-8", 
        "2.2442513103196467`*^-8", 
        RowBox[{"-", "3.3078406195607175`*^-8"}], 
        RowBox[{"-", "6.685525859041268`*^-9"}], "2.8296273257479664`*^-8", 
        "7.983492383162902`*^-8", "0.00002504380659104953`", 
        RowBox[{"-", "6.685525859041768`*^-9"}], "0.000011991891875844685`", 
        RowBox[{"-", "0.000030476636221170996`"}], "1.851329594277027`*^-8", 
        "5.2108687563374236`*^-8", "2.311047004089389`*^-8", 
        RowBox[{"-", "6.685525859041269`*^-9"}], 
        RowBox[{"-", "2.92910084865237`*^-8"}]},
       {"3.808694670226889`*^-7", 
        RowBox[{"-", "1.6008686387898234`*^-6"}], "1.6248839914153337`*^-6", 
        "7.687576705521588`*^-7", 
        RowBox[{"-", "3.1474785086835585`*^-6"}], "8.015976041322525`*^-8", 
        "1.1154528542940755`*^-6", "7.422523359731466`*^-6", 
        RowBox[{"-", "0.4605944428375493`"}], "8.015976042151077`*^-8", 
        RowBox[{"-", "0.000030476636221168215`"}], "0.5063141205714637`", 
        "6.923751505245351`*^-7", "4.4219117323951957`*^-7", 
        "2.129187735620482`*^-6", "8.015976041322526`*^-8", 
        RowBox[{"-", "7.263312273971039`*^-7"}]},
       {"1.0641797064674653`*^-7", 
        RowBox[{"-", "1.4895435283054853`*^-7"}], 
        RowBox[{"-", "5.574938780498164`*^-8"}], "2.4198294280346167`*^-6", 
        "1.963440224755373`*^-6", 
        RowBox[{"-", "1.2447224598957697`*^-7"}], "2.391815689129981`*^-6", 
        RowBox[{"-", "4.271865808886328`*^-6"}], 
        RowBox[{"-", "5.174385570702556`*^-7"}], 
        RowBox[{"-", "1.24472245989577`*^-7"}], "1.851329594276999`*^-8", 
        "6.923751505505471`*^-7", "2.4855719300759793`*^-6", 
        "0.000011655984807494736`", "2.6927143856271173`*^-7", 
        RowBox[{"-", "1.24472245989577`*^-7"}], "1.0869887798545196`*^-7"},
       {"6.775558403216545`*^-7", 
        RowBox[{"-", "1.2500370318591346`*^-6"}], "1.6046463990864108`*^-7", 
        "0.000012773000111003164`", "0.000016715427834480376`", 
        "6.699981645212217`*^-7", "0.000012057493069700629`", 
        RowBox[{"-", "0.00003716281283394034`"}], 
        RowBox[{"-", "1.089205200753533`*^-6"}], "6.699981645212218`*^-7", 
        "5.210868756337526`*^-8", "4.421911734074879`*^-7", 
        "0.000011655984807494736`", "0.00006737806502252143`", 
        RowBox[{"-", "1.7131599982642418`*^-7"}], "6.699981645212218`*^-7", 
        "8.576902101332223`*^-7"},
       {"1.2492473505670565`*^-8", 
        RowBox[{"-", "2.368164784837524`*^-8"}], "4.041882947245684`*^-9", 
        "1.2361533972913483`*^-7", 
        RowBox[{"-", "6.892883582001445`*^-7"}], 
        RowBox[{"-", "7.745578608919388`*^-7"}], "1.9823602602426942`*^-7", 
        "1.6016065581020722`*^-6", 
        RowBox[{"-", "1.1916802539565048`*^-6"}], 
        RowBox[{"-", "7.745578608919389`*^-7"}], "2.3110470040892644`*^-8", 
        "2.1291877356031624`*^-6", "2.6927143856271295`*^-7", 
        RowBox[{"-", "1.713159998264192`*^-7"}], "9.98893796232783`*^-7", 
        RowBox[{"-", "7.745578608919389`*^-7"}], "6.016962931683913`*^-8"},
       {"1.6809656267914188`*^-8", 
        RowBox[{"-", "1.942059752714116`*^-8"}], 
        RowBox[{"-", "1.5825258162431158`*^-8"}], "2.4294011710710968`*^-8", 
        "7.403296432119683`*^-7", "8.978687853556571`*^-7", 
        RowBox[{"-", "3.0153630210992255`*^-8"}], 
        RowBox[{"-", "1.7052096460441593`*^-6"}], 
        RowBox[{"-", "9.701598162755582`*^-7"}], "8.978687853556572`*^-7", 
        RowBox[{"-", "6.685525859040341`*^-9"}], "8.015976043674271`*^-8", 
        RowBox[{"-", "1.244722459895774`*^-7"}], "6.699981645212228`*^-7", 
        RowBox[{"-", "7.745578608919388`*^-7"}], "8.978687853556572`*^-7", 
        "1.6304080418647972`*^-7"},
       {"4.747865151981992`*^-8", 
        RowBox[{"-", "9.044003304517802`*^-8"}], "1.6106504824700537`*^-8", 
        "1.8497823875780276`*^-7", "3.3871366886922517`*^-7", 
        "1.6304080418647959`*^-7", "1.8790407874746407`*^-7", 
        RowBox[{"-", "7.615706746656798`*^-7"}], "5.126162524158264`*^-7", 
        "1.630408041864796`*^-7", 
        RowBox[{"-", "2.92910084865234`*^-8"}], 
        RowBox[{"-", "7.26331227378912`*^-7"}], "1.086988779854534`*^-7", 
        "8.576902101332328`*^-7", "6.016962931683902`*^-8", 
        "1.630408041864796`*^-7", "4.323010417580892`*^-7"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Error matrix", 
   MatrixForm[CompressedData["
1:eJydVWs01GkYf2NLSS6F2NPFrbZSbaWQ2nfkLBFFkrCdMG6JNK1RusiEXJLI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    "]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.514631203766678*^9, 3.514703832281888*^9, 3.5147038698155537`*^9, 
   3.5147039380032735`*^9, 3.5147040973575535`*^9, 3.514712571638338*^9, 
   3.5147126106072063`*^9, 3.514712658686491*^9, 3.514712712412985*^9, 
   3.5147128335783978`*^9, 3.514713553348062*^9, {3.514715041933877*^9, 
   3.514715047237886*^9}, 3.514715157093279*^9, 3.5147165873983912`*^9, 
   3.5148048265515575`*^9, 3.514805634991778*^9, 3.516017523392741*^9, 
   3.5165306394056263`*^9, 3.516539546099512*^9, 3.516969029175282*^9, 
   3.51696987412161*^9, {3.517121615088585*^9, 3.517121636179822*^9}, 
   3.517121778062071*^9, 3.51714173277812*^9, 3.517310513505695*^9, 
   3.517556760572631*^9, 3.518343846437887*^9, 3.5190390992756176`*^9, 
   3.521544558047174*^9, 3.521547339655566*^9, 3.5217891933194957`*^9, 
   3.521789930841991*^9, 3.5217900127889347`*^9, 3.521796101742305*^9, {
   3.522155746080821*^9, 3.522155775712516*^9}, 3.522155814312723*^9, 
   3.5221558611084003`*^9, 3.5221562814964447`*^9, 3.52215634836827*^9, 
   3.522156383075255*^9, 3.522475444495472*^9, 3.5224766790478926`*^9, 
   3.5224782061033745`*^9, 3.5224946613842545`*^9, 3.5224965095819006`*^9, 
   3.5225807413637247`*^9, 3.5227371525106983`*^9, 3.5227636013108816`*^9, 
   3.522906433321477*^9, 3.5229064765647526`*^9, 3.5229065338636537`*^9, 
   3.523772581416053*^9, 3.5237726599435444`*^9, 3.5237733906753397`*^9, 
   3.5237734732600636`*^9, 3.5238062877205076`*^9, 3.523811291603081*^9, 
   3.5238649813724623`*^9, 3.5238659554069734`*^9, 3.5238742429270697`*^9, 
   3.52387522463922*^9, 3.5243145467159557`*^9, 3.5245626275607204`*^9, 
   3.5287336987251596`*^9, {3.528733752982055*^9, 3.5287337794085016`*^9}, 
   3.528738445552197*^9, 3.5287385033034983`*^9, {3.528806374371281*^9, 
   3.528806393871316*^9}, {3.528806515286329*^9, 3.5288065422275763`*^9}, 
   3.5288066757170105`*^9, 3.528808290087714*^9, 3.528808357651433*^9, 
   3.5288084094591236`*^9, 3.5288085552257795`*^9, 3.528808611760279*^9, 
   3.528810898839569*^9, 3.528810937652789*^9, {3.52881102804696*^9, 
   3.528811056853607*^9}, 3.5288296749505*^9, 3.5288300847164197`*^9, 
   3.529176211029686*^9, 3.5292413130007443`*^9, 3.5292594212097406`*^9, 
   3.529262388241352*^9, 3.529263194373768*^9, 3.529263571910031*^9, 
   3.529264543152137*^9, 3.5292652026432953`*^9, 3.529265766725686*^9, 
   3.52932249126009*^9, 3.5293267459004416`*^9, 3.529430838198119*^9, 
   3.5299531018211565`*^9, 3.531596298423766*^9, 3.5315965581798224`*^9, 
   3.535282983197*^9, 3.536059467821801*^9, 3.536069419079915*^9, 
   3.5360702133929214`*^9, {3.5360724576839848`*^9, 3.5360724850495496`*^9}, 
   3.5387415493429365`*^9, 3.53874193107577*^9, 3.538742584550147*^9, 
   3.5387443874842687`*^9, 3.538746157127486*^9, 3.538747026402206*^9, 
   3.5387472200142803`*^9, 3.538838109408732*^9, 3.5388381858020663`*^9, 
   3.5388966919426966`*^9, 3.540541057368764*^9, 3.5405433390062656`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Minimization", "Subsection",
 CellChangeTimes->{{3.513493527321311*^9, 3.5134935293337145`*^9}, {
  3.513673650670968*^9, 3.5136736512793694`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Chi]min", "=", 
  RowBox[{"Minimize", "[", 
   RowBox[{"\[Chi]", ",", "ops"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Number of degrees of freedom: \>\"", ",", 
   RowBox[{"NMeasurements", "-", 
    RowBox[{"Length", "[", "ops", "]"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<\!\(\*SuperscriptBox[\(\[Chi]\), \(2\)]\)/dof: \>\"", ",", 
   RowBox[{
    RowBox[{"\[Chi]min", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"NMeasurements", "-", 
      RowBox[{"Length", "[", "ops", "]"}]}], ")"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.513423448185052*^9, 3.5134234488090525`*^9}, {
   3.5134258937701473`*^9, 3.513425919946993*^9}, {3.513509635662857*^9, 
   3.513509638736062*^9}, {3.51351604256291*^9, 3.513516043467712*^9}, 
   3.51394719359184*^9, {3.5147040140222073`*^9, 3.5147040218534207`*^9}, {
   3.5293266577584*^9, 3.529326703324006*^9}, {3.529326754373926*^9, 
   3.5293268522155223`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"204.77486323838548`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"aWB", "\[Rule]", 
      RowBox[{"-", "0.00022349183196720184`"}]}], ",", 
     RowBox[{"ah", "\[Rule]", "0.00008380361934864892`"}], ",", 
     RowBox[{"aW", "\[Rule]", 
      RowBox[{"-", "0.005370002319478699`"}]}], ",", 
     RowBox[{"aQe", "\[Rule]", "0.012536598313809787`"}], ",", 
     RowBox[{"alQ3", "\[Rule]", 
      RowBox[{"-", "0.031581429255437186`"}]}], ",", 
     RowBox[{"aLq3", "\[Rule]", 
      RowBox[{"-", "0.002128425460662233`"}]}], ",", 
     RowBox[{"alb", "\[Rule]", "0.053488531674699996`"}], ",", 
     RowBox[{"aeb", "\[Rule]", "0.06449728430425573`"}], ",", 
     RowBox[{"alL1", "\[Rule]", "0.42247441151714654`"}], ",", 
     RowBox[{"alL3", "\[Rule]", 
      RowBox[{"-", "0.0026784552310659747`"}]}], ",", 
     RowBox[{"altau", "\[Rule]", 
      RowBox[{"-", "0.0017509761350279218`"}]}], ",", 
     RowBox[{"aetau", "\[Rule]", 
      RowBox[{"-", "0.4611327893851787`"}]}], ",", 
     RowBox[{"ahQ3", "\[Rule]", 
      RowBox[{"-", "0.0026818699082343397`"}]}], ",", 
     RowBox[{"ahb", "\[Rule]", 
      RowBox[{"-", "0.019843889519467885`"}]}], ",", 
     RowBox[{"ahL1", "\[Rule]", "0.001850766218893008`"}], ",", 
     RowBox[{"ahL3", "\[Rule]", 
      RowBox[{"-", "0.00202858520507119`"}]}], ",", 
     RowBox[{"ahtau", "\[Rule]", 
      RowBox[{"-", "0.0008198217630564628`"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5288066825966225`*^9, 3.528808364889846*^9, 3.5288084149815335`*^9, 
   3.5288085597653875`*^9, 3.528808618468291*^9, 3.5288109024947786`*^9, 
   3.5288109401019297`*^9, {3.528811030739114*^9, 3.5288110590787344`*^9}, 
   3.528829678288906*^9, 3.5288300874620247`*^9, 3.52917621215275*^9, 
   3.5292413171519823`*^9, 3.5292594217245417`*^9, 3.529262388771753*^9, 
   3.5292631948573685`*^9, 3.529263572393632*^9, 3.529264543760538*^9, 
   3.529265203142496*^9, 3.529265767240487*^9, 3.5293224918121214`*^9, 
   3.5293267055991364`*^9, 3.529326746412471*^9, {3.529326823940905*^9, 
   3.529326853167577*^9}, 3.529430838796153*^9, 3.529953104928997*^9, 
   3.531596301106971*^9, 3.5315965603794265`*^9, 3.535282985032105*^9, 
   3.536059468661849*^9, 3.536069419266926*^9, 3.536070213595933*^9, {
   3.5360724578799953`*^9, 3.5360724852345605`*^9}, 3.538741933081885*^9, 
   3.53874258653126*^9, 3.5387443894133787`*^9, 3.538746157312497*^9, 
   3.538747026629219*^9, 3.5387472202232924`*^9, 3.5388381101575336`*^9, 
   3.53883818764287*^9, 3.5388966921827097`*^9, 3.540541057900794*^9, 
   3.5405433391962767`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of degrees of freedom: \"\>", "\[InvisibleSpace]", 
   "262"}],
  SequenceForm["Number of degrees of freedom: ", 262],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5293267052511168`*^9, 3.5293267459674454`*^9, {3.5293268239519053`*^9, 
   3.5293268531775775`*^9}, 3.5294308388071537`*^9, 3.5299531049399977`*^9, 
   3.531596301106971*^9, 3.5315965603794265`*^9, 3.535282985035105*^9, 
   3.5360594686668496`*^9, 3.536069419269926*^9, 3.536070213599933*^9, {
   3.536072457882996*^9, 3.5360724852375603`*^9}, 3.5387419330978856`*^9, 
   3.5387425865342603`*^9, 3.5387443894173794`*^9, 3.538746157316497*^9, 
   3.5387470266322193`*^9, 3.538747220226292*^9, 3.5388381101731334`*^9, 
   3.5388381876584697`*^9, 3.53889669219071*^9, 3.5405410579037943`*^9, 
   3.5405433391982765`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(\[Chi]\\), \\(2\\)]\\)/dof: \"\>", 
   "\[InvisibleSpace]", "0.7815834474747537`"}],
  SequenceForm[
  "\!\(\*SuperscriptBox[\(\[Chi]\), \(2\)]\)/dof: ", 0.7815834474747537],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5293267052511168`*^9, 3.5293267459674454`*^9, {3.5293268239519053`*^9, 
   3.5293268531775775`*^9}, 3.5294308388071537`*^9, 3.5299531049399977`*^9, 
   3.531596301106971*^9, 3.5315965603794265`*^9, 3.535282985035105*^9, 
   3.5360594686668496`*^9, 3.536069419269926*^9, 3.536070213599933*^9, {
   3.536072457882996*^9, 3.5360724852375603`*^9}, 3.5387419330978856`*^9, 
   3.5387425865342603`*^9, 3.5387443894173794`*^9, 3.538746157316497*^9, 
   3.5387470266322193`*^9, 3.538747220226292*^9, 3.5388381101731334`*^9, 
   3.5388381876584697`*^9, 3.53889669219071*^9, 3.5405410579037943`*^9, 
   3.540543339199277*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Errors on the operators coefficients (using the error matrix)\
\>", "Subsection",
 CellChangeTimes->{{3.5134935336549225`*^9, 3.5134935514545536`*^9}, {
  3.5146312174323015`*^9, 3.514631226137117*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"opmin", "=", 
      RowBox[{"\[Chi]min", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "i", ",", "2"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"operr", "=", 
      SqrtBox[
       RowBox[{"Merr", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "i"}], "]"}], "]"}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"i", ",", "\"\< \>\"", ",", 
       RowBox[{"ops", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "\"\<_min = \>\"", ",", 
       RowBox[{"SetAccuracy", "[", 
        RowBox[{"opmin", ",", "11"}], "]"}], ",", "\"\<  //  \[Sigma]_\>\"", 
       ",", 
       RowBox[{"ops", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "\"\< = \>\"", ",", 
       RowBox[{"SetAccuracy", "[", 
        RowBox[{"operr", ",", "11"}], "]"}], ",", "\"\<  //   \>\"", ",", 
       RowBox[{"ops", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "\"\< -> [\>\"", ",", 
       RowBox[{"N", "[", 
        RowBox[{"opmin", "-", 
         RowBox[{"operr", "*", "SigmaTo90CL"}]}], "]"}], ",", "\"\<,\>\"", 
       ",", 
       RowBox[{"N", "[", 
        RowBox[{"opmin", "+", 
         RowBox[{"operr", "*", "SigmaTo90CL"}]}], "]"}], ",", 
       "\"\<]  (90% CL)   //  \[Sigma](90%) = \>\"", ",", 
       RowBox[{"operr", "*", "SigmaTo90CL"}], ",", 
       "\"\<  \[CapitalLambda]NP \[GreaterSlantEqual] \>\"", ",", 
       RowBox[{"v", "/", 
        RadicalBox[
         RowBox[{"Merr", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "i"}], "]"}], "]"}], "4"]}], ",", 
       "\"\< GeV\>\""}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "ops", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5134259227861977`*^9, 3.5134260176811647`*^9}, {
   3.513426074059664*^9, 3.5134261514825993`*^9}, {3.5134924257097764`*^9, 
   3.513492547920391*^9}, {3.5134927209558945`*^9, 3.5134929113230295`*^9}, {
   3.5134930099308023`*^9, 3.5134930120056057`*^9}, {3.5134930491960716`*^9, 
   3.51349315649306*^9}, {3.513493262588846*^9, 3.51349329881211*^9}, {
   3.513493343178588*^9, 3.5134933462829933`*^9}, {3.513508830576643*^9, 
   3.5135088382986565`*^9}, {3.5135096534936886`*^9, 3.513509669639717*^9}, {
   3.513515077872816*^9, 3.5135151188384876`*^9}, 3.5135958648680153`*^9, {
   3.5135959143201027`*^9, 3.513595915724105*^9}, {3.5135960173426833`*^9, 
   3.5135960202598886`*^9}, {3.513947215057477*^9, 3.5139472285047007`*^9}, {
   3.5139477317147846`*^9, 3.513947732432386*^9}, {3.514713604718952*^9, 
   3.514713630786598*^9}, {3.516969111085967*^9, 3.516969115402214*^9}, {
   3.5175567229754806`*^9, 3.5175567366642637`*^9}, {3.5245625895735483`*^9, 
   3.524562607234558*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aWB", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00022349183196720184200849412814449124`7.349261655448294"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "aWB",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00022947574169674122288378748102388727`7.360736782230246", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aWB", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.0006009450056970867`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.00015396134176268294`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.0003774531737298848`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "16253.838476720277`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  1, " ", $CellContext`aWB, 
   "_min = ", -0.00022349183196720184200849412814449124`7.349261655448294, 
   "  //  \[Sigma]_", $CellContext`aWB, " = ", 
   0.00022947574169674122288378748102388727`7.360736782230246, 
   "  //   ", $CellContext`aWB, " -> [", -0.0006009450056970867, ",", 
   0.00015396134176268294`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.0003774531737298848, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   16253.838476720277`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.54054333925028*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "2", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ah", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.00008380361934864891571179967844074099`6.9232627755420015", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "ah", 
   "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00068166615747546749608937188824597797`7.833571733214394", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ah", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.0010374349597748738`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.0012050421984721716`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.0011212385791235227`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "9430.581315150108`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  2, " ", $CellContext`ah, "_min = ", 
   0.00008380361934864891571179967844074099`6.9232627755420015, 
   "  //  \[Sigma]_", $CellContext`ah, " = ", 
   0.00068166615747546749608937188824597797`7.833571733214394, 
   "  //   ", $CellContext`ah, " -> [", -0.0010374349597748738`, ",", 
   0.0012050421984721716`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.0011212385791235227`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   9430.581315150108, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.5405433392632804`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "3", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aW", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00537000231947869915982707311741251033`8.729974473285512"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "aW", 
   "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.01873432369649920617438176861924148398`9.27263801981146", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aW", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.03618515465166541`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.02544515001270802`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.030815152332186718`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "1798.892954408694`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  3, " ", $CellContext`aW, 
   "_min = ", -0.00537000231947869915982707311741251033`8.729974473285512, 
   "  //  \[Sigma]_", $CellContext`aW, " = ", 
   0.01873432369649920617438176861924148398`9.27263801981146, 
   "  //   ", $CellContext`aW, " -> [", -0.03618515465166541, ",", 
   0.02544515001270802, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.030815152332186718`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   1798.892954408694, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.5405433392672806`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "4", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aQe", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.01253659831380978667558778738566616084`9.098179710820565", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "aQe",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.07019557695590512846894881704429280944`9.846309747967974", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aQe", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.10292459644211077`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.12799779306973033`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.11546119475592055`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "929.3289295817209`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  4, " ", $CellContext`aQe, "_min = ", 
   0.01253659831380978667558778738566616084`9.098179710820565, 
   "  //  \[Sigma]_", $CellContext`aQe, " = ", 
   0.07019557695590512846894881704429280944`9.846309747967974, 
   "  //   ", $CellContext`aQe, " -> [", -0.10292459644211077`, ",", 
   0.12799779306973033`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.11546119475592055`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   929.3289295817209, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.540543339270281*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "5", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "alQ3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.03158142925543718643188739747529325541`9.499431780634398"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "alQ3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.15222761861273040318032201412279391661`10.182493453505197", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "alQ3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.28197302773058674`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.21881016921971239`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.2503915984751496`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "631.0701001738702`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  5, " ", $CellContext`alQ3, 
   "_min = ", -0.03158142925543718643188739747529325541`9.499431780634398, 
   "  //  \[Sigma]_", $CellContext`alQ3, " = ", 
   0.15222761861273040318032201412279391661`10.182493453505197, 
   "  //   ", $CellContext`alQ3, " -> [", -0.28197302773058674`, ",", 
   0.21881016921971239`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.2503915984751496, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   631.0701001738702, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.5405433392722807`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "6", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aLq3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.0021284254606622329472620513968195155`8.328058445403494"}],
    "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "aLq3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00201809345523857805448919577884225873`8.304941273969593", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aLq3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.0054478864805114074`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.001191035559186942`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.003319461019849175`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "5480.922910612253`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  6, " ", $CellContext`aLq3, 
   "_min = ", -0.0021284254606622329472620513968195155`8.328058445403494, 
   "  //  \[Sigma]_", $CellContext`aLq3, " = ", 
   0.00201809345523857805448919577884225873`8.304941273969593, 
   "  //   ", $CellContext`aLq3, " -> [", -0.0054478864805114074`, ",", 
   0.001191035559186942, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.003319461019849175, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   5480.922910612253, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.5405433392762814`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "7", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "alb", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.05348853167469999614347386795998318121`9.728260676146506", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "alb",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.14546371649630546185605339815083425492`10.162754679297691", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "alb", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.18577746240424803`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.292754525753648`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.23926599407894802`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "645.5754268754519`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  7, " ", $CellContext`alb, "_min = ", 
   0.05348853167469999614347386795998318121`9.728260676146506, 
   "  //  \[Sigma]_", $CellContext`alb, " = ", 
   0.14546371649630546185605339815083425492`10.162754679297691, 
   "  //   ", $CellContext`alb, " -> [", -0.18577746240424803`, ",", 
   0.292754525753648, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.23926599407894802`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   645.5754268754519, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.540543339278281*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "8", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aeb", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.06449728430425573366679969922188320197`9.80954142879797", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "aeb",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.38190540302924891324920508850482292473`10.581955802623618", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aeb", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.5636798178684044`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.6926743864769158`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.6281771021726601`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "398.4248606535701`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  8, " ", $CellContext`aeb, "_min = ", 
   0.06449728430425573366679969922188320197`9.80954142879797, 
   "  //  \[Sigma]_", $CellContext`aeb, " = ", 
   0.38190540302924891324920508850482292473`10.581955802623618, 
   "  //   ", $CellContext`aeb, " -> [", -0.5636798178684044, ",", 
   0.6926743864769158, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.6281771021726601, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   398.4248606535701, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.5405433392812815`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "9", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "alL1", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.4224744115171465419500407278974307701`10.625800409679934", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "alL1", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.64730958803568872106382059428142383695`10.811112039893187", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "alL1", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.642252764363356`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "1.4872015873976492`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "1.0647271758805026`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "306.0330360432555`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  9, " ", $CellContext`alL1, "_min = ", 
   0.4224744115171465419500407278974307701`10.625800409679934, 
   "  //  \[Sigma]_", $CellContext`alL1, " = ", 
   0.64730958803568872106382059428142383695`10.811112039893187, 
   "  //   ", $CellContext`alL1, " -> [", -0.642252764363356, ",", 
   1.4872015873976492`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   1.0647271758805026`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   306.0330360432555, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.5405433392942824`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "10", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "alL3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00267845523106597467252742994503478258`8.427884391771599"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "alL3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00120836412262101768923250322274043356`8.082197822212771", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "alL3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.004666032958159155`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.000690877503972794`"}], 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.0019875777270931807`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "7083.133375153511`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  10, " ", $CellContext`alL3, 
   "_min = ", -0.00267845523106597467252742994503478258`8.427884391771599, 
   "  //  \[Sigma]_", $CellContext`alL3, " = ", 
   0.00120836412262101768923250322274043356`8.082197822212771, 
   "  //   ", $CellContext`alL3, " -> [", -0.004666032958159155, 
   ",", -0.000690877503972794, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.0019875777270931807`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   7083.133375153511, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.5405433392982826`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "11", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "altau", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00175097613502792179458744659115154718`8.243280226896516"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "altau", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00346293111046764613691895107194795855`8.539443852034198", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "altau", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.007446978372080629`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.003945026102024786`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.005696002237052708`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "4184.103363241106`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  11, " ", $CellContext`altau, 
   "_min = ", -0.00175097613502792179458744659115154718`8.243280226896516, 
   "  //  \[Sigma]_", $CellContext`altau, " = ", 
   0.00346293111046764613691895107194795855`8.539443852034198, 
   "  //   ", $CellContext`altau, " -> [", -0.007446978372080629, ",", 
   0.003945026102024786, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.005696002237052708, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   4184.103363241106, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.540543339301283*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "12", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aetau", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.46113278938517870964020062274357769638`10.663826004333378"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "aetau", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.71155753145579436758083602398983202875`10.852210019787389", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aetau", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1.6315381950002419`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.7092726162298846`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "1.1704054056150632`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "291.89007009937956`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  12, " ", $CellContext`aetau, 
   "_min = ", -0.46113278938517870964020062274357769638`10.663826004333378, 
   "  //  \[Sigma]_", $CellContext`aetau, " = ", 
   0.71155753145579436758083602398983202875`10.852210019787389, 
   "  //   ", $CellContext`aetau, " -> [", -1.6315381950002419`, ",", 
   0.7092726162298846, "]  (90% CL)   //  \[Sigma](90%) = ", 
   1.1704054056150632`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   291.89007009937956`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.540543339304283*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "13", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahQ3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.0026818699082343396521144196498198653`8.428437707331298"}],
    "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahQ3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00157656967181155028764893977211158926`8.197713167862046", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahQ3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.005275090532913568`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.00008864928355511136`"}], 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.0025932206246792283`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "6201.085891228692`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  13, " ", $CellContext`ahQ3, 
   "_min = ", -0.0026818699082343396521144196498198653`8.428437707331298, 
   "  //  \[Sigma]_", $CellContext`ahQ3, " = ", 
   0.00157656967181155028764893977211158926`8.197713167862046, 
   "  //   ", $CellContext`ahQ3, " -> [", -0.005275090532913568, 
   ",", -0.00008864928355511136, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.0025932206246792283`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   6201.085891228692, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.540543339307283*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "14", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahb", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.01984388951946788534619336985542759066`9.297626800443416"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "ahb",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00820841428185258188687800640082059545`8.91425926733184", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahb", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.033345499750973104`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.006342279287962667`"}], 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.013501610231505218`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "2717.6573394005904`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  14, " ", $CellContext`ahb, 
   "_min = ", -0.01984388951946788534619336985542759066`9.297626800443416, 
   "  //  \[Sigma]_", $CellContext`ahb, " = ", 
   0.00820841428185258188687800640082059545`8.91425926733184, 
   "  //   ", $CellContext`ahb, " -> [", -0.033345499750973104`, 
   ",", -0.006342279287962667, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.013501610231505218`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   2717.6573394005904`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.5405433393092833`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "15", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahL1", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.00185076621889300810264167296281812014`8.267351563940974", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahL1", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00099944674507088321693815125001947308`7.999759657945854", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahL1", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   "0.00020682624026316593`", "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.0034947061975228503`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.0016439399786298422`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "7788.332815384954`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  15, " ", $CellContext`ahL1, "_min = ", 
   0.00185076621889300810264167296281812014`8.267351563940974, 
   "  //  \[Sigma]_", $CellContext`ahL1, " = ", 
   0.00099944674507088321693815125001947308`7.999759657945854, 
   "  //   ", $CellContext`ahL1, " -> [", 0.00020682624026316593`, ",", 
   0.0034947061975228503`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.0016439399786298422`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   7788.332815384954, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.5405433393122835`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "16", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahL3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.00202858520507118991402228935783114139`8.30719325375349"}],
    "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahL3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00094755938355105598629862795334588554`7.976606436730236", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahL3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.0035871782571051444`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"-", "0.00046999215303723547`"}], 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.0015585930520339544`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "7998.731383111596`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  16, " ", $CellContext`ahL3, 
   "_min = ", -0.00202858520507118991402228935783114139`8.30719325375349, 
   "  //  \[Sigma]_", $CellContext`ahL3, " = ", 
   0.00094755938355105598629862795334588554`7.976606436730236, 
   "  //   ", $CellContext`ahL3, " -> [", -0.0035871782571051444`, 
   ",", -0.00046999215303723547`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.0015585930520339544`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   7998.731383111596, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.540543339315284*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "17", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahtau", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00081982176305646283376998839642624262`7.913719442950817"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahtau", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00065749603934783448777601222445809981`7.817893141048396", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahtau", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.0019013041233777485`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.0002616605972648227`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.0010814823603212855`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "9602.355052361534`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  17, " ", $CellContext`ahtau, 
   "_min = ", -0.00081982176305646283376998839642624262`7.913719442950817, 
   "  //  \[Sigma]_", $CellContext`ahtau, " = ", 
   0.00065749603934783448777601222445809981`7.817893141048396, 
   "  //   ", $CellContext`ahtau, " -> [", -0.0019013041233777485`, ",", 
   0.0002616605972648227, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.0010814823603212855`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   9602.355052361534, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, {
   3.538741936161061*^9, 3.5387419469086757`*^9}, 3.5387425901614676`*^9, 
   3.538744391114476*^9, 3.5387461589755917`*^9, 3.53874702665322*^9, 
   3.5387472202522936`*^9, 3.5388381103759336`*^9, 3.5388381900140734`*^9, 
   3.538896692216712*^9, 3.540541057928796*^9, 3.5405433393182836`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Bounds on RW\[Tau]l = (\[CapitalGamma](W -> \[Tau] \[Nu])SM + \
\[CapitalGamma](W -> \[Tau] \[Nu])NP) / ( \[CapitalGamma](W -> e \[Nu])SM +  \
\[CapitalGamma](W -> \[Mu] \[Nu])SM) (assuming  \[CapitalGamma](W -> e \
\[Nu])NP =\[CapitalGamma](W -> \[Mu] \[Nu])NP = 0)\
\>", "Subsection",
 CellChangeTimes->{{3.514722940857148*^9, 3.514722959561218*^9}, {
   3.5165401241741276`*^9, 3.5165401617545934`*^9}, {3.5169694899526367`*^9, 
   3.516969524929638*^9}, {3.5169695596296225`*^9, 3.516969582268917*^9}, 
   3.5173115093116517`*^9, {3.5238070763018928`*^9, 3.5238071126343565`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RW\[Tau]lCentral", "=", 
   RowBox[{"RW\[Tau]l", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"ops", "[", 
        RowBox[{"[", "16", "]"}], "]"}], "\[Rule]", 
       RowBox[{"\[Chi]min", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "16", ",", "2"}], "]"}], "]"}]}], ",", 
      RowBox[{"aEWt", "\[Rule]", "0"}], ",", 
      RowBox[{"ahl3", "\[Rule]", "0"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CentralValue", "=", "%"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]RW\[Tau]l", "=", 
   SqrtBox[
    RowBox[{"Sum", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"RW\[Tau]l", ",", 
         RowBox[{"ops", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "]"}], 
       RowBox[{"D", "[", 
        RowBox[{"RW\[Tau]l", ",", 
         RowBox[{"ops", "[", 
          RowBox[{"[", "j", "]"}], "]"}]}], "]"}], 
       RowBox[{"Merr", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "ops", "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", 
        RowBox[{"Length", "[", "ops", "]"}]}], "}"}]}], "]"}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigma", "=", "%"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RW\[Tau]lMax", "=", 
   RowBox[{"RW\[Tau]lCentral", "+", "\[Sigma]RW\[Tau]l"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RW\[Tau]lMin", "=", 
   RowBox[{"RW\[Tau]lCentral", "-", "\[Sigma]RW\[Tau]l"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<RW\[Tau]l = \>\"", ",", "RW\[Tau]lCentral", ",", 
   "\"\< \[PlusMinus] \>\"", ",", "\[Sigma]RW\[Tau]l", ",", 
   "\"\<  (68% CL)        //        RW\[Tau]l: [\>\"", ",", 
   RowBox[{"RW\[Tau]lCentral", "+", 
    RowBox[{"\[Sigma]RW\[Tau]l", "*", "SigmaTo90CL"}]}], ",", "\"\<, \>\"", 
   ",", 
   RowBox[{"RW\[Tau]lCentral", "-", 
    RowBox[{"\[Sigma]RW\[Tau]l", "*", "SigmaTo90CL"}]}], ",", 
   "\"\<]  (90% CL)\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Experimental value:  RW\[Tau]lExp = \>\"", ",", "RW\[Tau]lExp", ",", 
   "\"\< \[PlusMinus] \>\"", ",", "\[Sigma]RW\[Tau]lExp", ",", 
   "\"\< //            SM value:  RW\[Tau]lSM = \>\"", ",", "RW\[Tau]lSM", 
   ",", " ", "\"\<              \[CapitalDelta](SM-NP) = \>\"", ",", 
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"RW\[Tau]lCentral", "-", "RW\[Tau]lSM"}], ")"}], "/", 
     "\[Sigma]RW\[Tau]l"}], "]"}], ",", "\"\<\[Sigma]\>\""}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.5147230284421577`*^9, 3.514723327511263*^9}, {
   3.5147236955613146`*^9, 3.514723732525429*^9}, {3.5147237976961565`*^9, 
   3.514723798098179*^9}, {3.5147238756166134`*^9, 3.5147239007260494`*^9}, {
   3.5148179767801533`*^9, 3.5148179918653803`*^9}, 3.5148182141969705`*^9, {
   3.5148744804099283`*^9, 3.5148745559608607`*^9}, {3.5148746118557587`*^9, 
   3.5148746204201736`*^9}, {3.5148746587182417`*^9, 
   3.5148746723838654`*^9}, {3.5148749541515603`*^9, 
   3.5148749548379617`*^9}, {3.5148751250810604`*^9, 
   3.5148751261418624`*^9}, {3.514875588994675*^9, 3.51487559705989*^9}, {
   3.5148915683614473`*^9, 3.51489157009305*^9}, {3.514894488904977*^9, 
   3.514894501525399*^9}, {3.5148945345038567`*^9, 3.5148945346442575`*^9}, {
   3.514894567685115*^9, 3.514894569541518*^9}, {3.5148946783361096`*^9, 
   3.5148947104877663`*^9}, {3.5148947890027037`*^9, 
   3.5148948052579327`*^9}, {3.514895639188597*^9, 3.514895649469015*^9}, {
   3.5148973907908735`*^9, 3.514897402756095*^9}, {3.5151465254916377`*^9, 
   3.515146677377325*^9}, {3.515146773315812*^9, 3.5151468077057796`*^9}, {
   3.5151468452779284`*^9, 3.515146858553688*^9}, 3.5151483871040525`*^9, {
   3.5151488174776087`*^9, 3.515148833717237*^9}, {3.516531184844984*^9, 
   3.5165311902893934`*^9}, {3.5165312372922764`*^9, 3.5165312398038807`*^9}, 
   3.5165395200942664`*^9, {3.5165401727994127`*^9, 3.5165402446843395`*^9}, {
   3.51654031349606*^9, 3.5165403592509403`*^9}, {3.5165407351960006`*^9, 
   3.516540745850819*^9}, {3.51696952986292*^9, 3.516969546112849*^9}, {
   3.5169695833189774`*^9, 3.5169695979348135`*^9}, {3.5171438696386733`*^9, 
   3.5171438915255117`*^9}, {3.517311439398653*^9, 3.5173114622989626`*^9}, 
   3.5173115374032583`*^9, {3.5217960808421097`*^9, 3.5217960870904665`*^9}, {
   3.5237725891674967`*^9, 3.5237726257865906`*^9}, 3.528829816146348*^9, {
   3.5288298517612104`*^9, 3.5288298682348394`*^9}, {3.5291763276553564`*^9, 
   3.5291763309925475`*^9}, {3.5291765406505394`*^9, 3.52917659696176*^9}, {
   3.5291766387731514`*^9, 3.5291766441574593`*^9}, {3.529176689705065*^9, 
   3.5291767109172783`*^9}, {3.529251331819973*^9, 3.529251334640135*^9}, {
   3.52925162181456*^9, 3.529251657467599*^9}, {3.5315966243863387`*^9, 
   3.531596625774741*^9}, {3.538746288961027*^9, 3.5387463716907587`*^9}, {
   3.538747117126395*^9, 3.538747121520646*^9}, {3.53874720217826*^9, 
   3.5387472362402077`*^9}, {3.5405411125319185`*^9, 3.5405411132779617`*^9}, 
   3.540541165617955*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RW\[Tau]l = \"\>", "\[InvisibleSpace]", "0.9908915933780928`", 
   "\[InvisibleSpace]", "\<\" \[PlusMinus] \"\>", "\[InvisibleSpace]", 
   "0.003787465648979743`", 
   "\[InvisibleSpace]", "\<\"  (68% CL)        //        RW\[Tau]l: [\"\>", 
   "\[InvisibleSpace]", "0.9971214062508171`", 
   "\[InvisibleSpace]", "\<\", \"\>", "\[InvisibleSpace]", 
   "0.9846617805053686`", "\[InvisibleSpace]", "\<\"]  (90% CL)\"\>"}],
  SequenceForm[
  "RW\[Tau]l = ", 0.9908915933780928, " \[PlusMinus] ", 0.003787465648979743, 
   "  (68% CL)        //        RW\[Tau]l: [", 0.9971214062508171, ", ", 
   0.9846617805053686, "]  (90% CL)"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5151466785033894`*^9, {3.5151467839774227`*^9, 3.515146814386162*^9}, {
   3.5151468538954215`*^9, 3.5151468588107023`*^9}, 3.515148387930854*^9, 
   3.515148668185346*^9, {3.5151488141860027`*^9, 3.5151488357140408`*^9}, 
   3.5165305176942124`*^9, 3.5165311913813953`*^9, 3.516531240661882*^9, 
   3.5165395738207607`*^9, 3.516540361232144*^9, {3.5165407330119967`*^9, 
   3.51654074628762*^9}, 3.516969462788083*^9, 3.516969705087942*^9, 
   3.517143866331467*^9, 3.5171438994347253`*^9, 3.51731149826502*^9, 
   3.5173115517440786`*^9, 3.5202329035174007`*^9, 3.5202331293745975`*^9, 
   3.5217961115618668`*^9, {3.5224754608994102`*^9, 3.5224754746701975`*^9}, 
   3.522476698001926*^9, {3.52249464732863*^9, 3.5224946692778683`*^9}, 
   3.523772668285022*^9, 3.523773402081992*^9, 3.523773487200861*^9, 
   3.523806289732911*^9, 3.5238065004268813`*^9, 3.523807067269477*^9, 
   3.5238742444431562`*^9, {3.5288297728562717`*^9, 3.528829801279522*^9}, {
   3.528829852463212*^9, 3.52882986865604*^9}, 3.529176146041969*^9, {
   3.529176319637898*^9, 3.529176331263563*^9}, 3.529176612098626*^9, 
   3.5291766452785234`*^9, {3.5291766901540904`*^9, 3.529176711743325*^9}, 
   3.5292413357970486`*^9, 3.5292513375813026`*^9, {3.529251645138894*^9, 
   3.5292516577656164`*^9}, 3.529322502991761*^9, 3.529953130445402*^9, {
   3.5315966118127165`*^9, 3.531596626663943*^9}, 3.53528299004773*^9, 
   3.5360594691862717`*^9, 3.5360694194309354`*^9, 3.536070213776943*^9, {
   3.536072458183013*^9, 3.536072485489575*^9}, 3.5387419508279*^9, 
   3.5387425936156654`*^9, 3.5387443939376373`*^9, 3.5387461618837585`*^9, 
   3.538746269278901*^9, {3.538746347344366*^9, 3.5387463719657745`*^9}, 
   3.5387470404340086`*^9, {3.538747220346299*^9, 3.5387472365722275`*^9}, 
   3.5388381115147357`*^9, 3.538838192416478*^9, 3.5388966923317184`*^9, 
   3.540541057993799*^9, 3.540541115424084*^9, {3.540541156453431*^9, 
   3.540541166020978*^9}, 3.5405433393452854`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Experimental value:  RW\[Tau]lExp = \"\>", "\[InvisibleSpace]",
    "1.055347091932458`", "\[InvisibleSpace]", "\<\" \[PlusMinus] \"\>", 
   "\[InvisibleSpace]", "0.021178845883677393`", 
   "\[InvisibleSpace]", "\<\" //            SM value:  RW\[Tau]lSM = \"\>", 
   "\[InvisibleSpace]", "0.999`", 
   "\[InvisibleSpace]", "\<\"              \[CapitalDelta](SM-NP) = \"\>", 
   "\[InvisibleSpace]", "2.140852848154905`", 
   "\[InvisibleSpace]", "\<\"\[Sigma]\"\>"}],
  SequenceForm[
  "Experimental value:  RW\[Tau]lExp = ", 1.055347091932458, " \[PlusMinus] ",
    0.021178845883677393`, " //            SM value:  RW\[Tau]lSM = ", 0.999, 
   "              \[CapitalDelta](SM-NP) = ", 2.140852848154905, "\[Sigma]"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5151466785033894`*^9, {3.5151467839774227`*^9, 3.515146814386162*^9}, {
   3.5151468538954215`*^9, 3.5151468588107023`*^9}, 3.515148387930854*^9, 
   3.515148668185346*^9, {3.5151488141860027`*^9, 3.5151488357140408`*^9}, 
   3.5165305176942124`*^9, 3.5165311913813953`*^9, 3.516531240661882*^9, 
   3.5165395738207607`*^9, 3.516540361232144*^9, {3.5165407330119967`*^9, 
   3.51654074628762*^9}, 3.516969462788083*^9, 3.516969705087942*^9, 
   3.517143866331467*^9, 3.5171438994347253`*^9, 3.51731149826502*^9, 
   3.5173115517440786`*^9, 3.5202329035174007`*^9, 3.5202331293745975`*^9, 
   3.5217961115618668`*^9, {3.5224754608994102`*^9, 3.5224754746701975`*^9}, 
   3.522476698001926*^9, {3.52249464732863*^9, 3.5224946692778683`*^9}, 
   3.523772668285022*^9, 3.523773402081992*^9, 3.523773487200861*^9, 
   3.523806289732911*^9, 3.5238065004268813`*^9, 3.523807067269477*^9, 
   3.5238742444431562`*^9, {3.5288297728562717`*^9, 3.528829801279522*^9}, {
   3.528829852463212*^9, 3.52882986865604*^9}, 3.529176146041969*^9, {
   3.529176319637898*^9, 3.529176331263563*^9}, 3.529176612098626*^9, 
   3.5291766452785234`*^9, {3.5291766901540904`*^9, 3.529176711743325*^9}, 
   3.5292413357970486`*^9, 3.5292513375813026`*^9, {3.529251645138894*^9, 
   3.5292516577656164`*^9}, 3.529322502991761*^9, 3.529953130445402*^9, {
   3.5315966118127165`*^9, 3.531596626663943*^9}, 3.53528299004773*^9, 
   3.5360594691862717`*^9, 3.5360694194309354`*^9, 3.536070213776943*^9, {
   3.536072458183013*^9, 3.536072485489575*^9}, 3.5387419508279*^9, 
   3.5387425936156654`*^9, 3.5387443939376373`*^9, 3.5387461618837585`*^9, 
   3.538746269278901*^9, {3.538746347344366*^9, 3.5387463719657745`*^9}, 
   3.5387470404340086`*^9, {3.538747220346299*^9, 3.5387472365722275`*^9}, 
   3.5388381115147357`*^9, 3.538838192416478*^9, 3.5388966923317184`*^9, 
   3.540541057993799*^9, 3.540541115424084*^9, {3.540541156453431*^9, 
   3.540541166020978*^9}, 3.5405433393472853`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "b) GLOBAL ANALYSIS -  ",
 StyleBox["[U(2)xU(1)]^5 flavor symmetry",
  FontFamily->"Arial",
  FontColor->RGBColor[1, 0, 0]],
 " (Including e-\[Mu] operators)"
}], "Section",
 CellChangeTimes->{{3.5067699872735014`*^9, 3.5067700116251445`*^9}, {
   3.507469679480951*^9, 3.50746969030657*^9}, 3.509805539810589*^9, {
   3.51038621135526*^9, 3.5103862114892673`*^9}, {3.511249189024064*^9, 
   3.511249243280959*^9}, {3.5139469165353527`*^9, 3.513946922790964*^9}, {
   3.51463094890903*^9, 3.5146309519510355`*^9}, {3.5147133014232197`*^9, 
   3.5147133224676566`*^9}, {3.5147164669349794`*^9, 
   3.5147164710533867`*^9}, {3.5148046565424595`*^9, 3.514804660816867*^9}, {
   3.514811320872463*^9, 3.514811322682066*^9}, {3.5217898434818373`*^9, 
   3.5217898505174503`*^9}, {3.5224934794197826`*^9, 3.522493484457071*^9}, 
   3.5227360149879007`*^9, {3.5238803276330953`*^9, 3.523880333281418*^9}, {
   3.5288062655922904`*^9, 3.5288062715671005`*^9}, {3.531598083738702*^9, 
   3.5315980840663023`*^9}, {3.5405423593252316`*^9, 3.540542407516988*^9}, {
   3.5405509825584517`*^9, 3.540550983197489*^9}}],

Cell[CellGroupData[{

Cell["Dropping unwanted operators", "Subsection",
 CellChangeTimes->{{3.5147134436330695`*^9, 3.5147134599818983`*^9}, {
  3.529953179190193*^9, 3.529953182177664*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Please", " ", "place", " ", "in", " ", "the", " ", "\"\<ops\>\"", " ", 
   "vector", " ", "the", " ", "operators", " ", "you", " ", "want", " ", "to",
    " ", "include", " ", "in", " ", "the", " ", 
   RowBox[{"fit", ".", " ", "The"}], " ", "other", " ", "operators", " ", 
   "will", " ", "be", " ", "dropped", " ", "automatically"}], "  ", 
  "*)"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ops", "=", 
   RowBox[{"{", 
    RowBox[{
    "aWB", ",", "ah", ",", "aW", ",", "aQe", ",", "alQ3", ",", "aLq3", ",", 
     "alb", ",", "aeb", ",", "alL1", ",", "alL3", ",", "altau", ",", "aetau", 
     ",", "ahQ3", ",", "ahb", ",", "ahL1", ",", "ahL3", ",", "ahtau", ",", 
     "aqe", ",", "ald", ",", "aed", ",", "all1", ",", "all3", ",", "ale", ",",
      "aee", ",", "ahq3", ",", "ahd", ",", "ahl1", ",", "ahl3", ",", "ahe", 
     ",", "alu", ",", "alq3", ",", "alq1", ",", "ahu", ",", "ahq1", ",", 
     "aeu"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DropOpsTemp", "=", 
   RowBox[{"Complement", "[", 
    RowBox[{"Ops", ",", "ops"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DropOps", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"DropOps", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"DropOps", ",", 
       RowBox[{
        RowBox[{"DropOpsTemp", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", "0"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "DropOpsTemp", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Operators to drop from the total list: \>\"", ",", "DropOpsTemp"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Number of operators used in the fit: \>\"", ",", 
   RowBox[{"Length", "[", "ops", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5147035244465475`*^9, 3.514703554851001*^9}, {
   3.5147036800568204`*^9, 3.514703680290821*^9}, {3.5147037973846264`*^9, 
   3.514703801830634*^9}, 3.514703895680399*^9, {3.5147040714303083`*^9, 
   3.514704079823123*^9}, {3.514712543839089*^9, 3.5147125472086945`*^9}, {
   3.5147125802495527`*^9, 3.514712691914549*^9}, {3.514712766030279*^9, 
   3.5147128134699626`*^9}, {3.5147134294526443`*^9, 3.514713436815858*^9}, {
   3.5147151082495933`*^9, 3.514715137936445*^9}, {3.522497558137742*^9, 
   3.5224975604465466`*^9}, {3.5227370577873325`*^9, 
   3.5227370943069963`*^9}, {3.5287331270309563`*^9, 
   3.5287331335985675`*^9}, {3.5287336071217995`*^9, 
   3.5287336139546113`*^9}, {3.5288301495345335`*^9, 3.528830156960147*^9}, {
   3.528830222277461*^9, 3.5288302298278747`*^9}, {3.529952237100196*^9, 
   3.529952246409374*^9}, {3.529952807648368*^9, 3.529952975271253*^9}, {
   3.529953068155826*^9, 3.5299530896348314`*^9}, {3.531594147522188*^9, 
   3.531594272166407*^9}, {3.531597196159543*^9, 3.5315971995759487`*^9}, 
   3.531597269620072*^9, {3.5315973459354057`*^9, 3.5315973487122107`*^9}, {
   3.5315974054027104`*^9, 3.531597515445304*^9}, {3.531683133137616*^9, 
   3.531683133917618*^9}, 3.531684272443634*^9, {3.5387447120998354`*^9, 
   3.538744774370397*^9}, 3.5387449023767185`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Operators to drop from the total list: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"aEBt", ",", "aEWt", ",", "ahQ1", ",", "aLe", ",", "alQ1"}], 
    "}"}]}],
  SequenceForm[
  "Operators to drop from the total list: ", {$CellContext`aEBt, \
$CellContext`aEWt, $CellContext`ahQ1, $CellContext`aLe, $CellContext`alQ1}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.529952853378755*^9, 3.5299528557412863`*^9}, {
   3.529952912352669*^9, 3.529952989170877*^9}, {3.5299530745857363`*^9, 
   3.5299530914686093`*^9}, 3.531594279155219*^9, 3.5315972003715506`*^9, 
   3.5315972711020746`*^9, {3.5315974269151487`*^9, 3.531597516318905*^9}, 
   3.5316768230976753`*^9, 3.5316772194319715`*^9, 3.531677336026576*^9, 
   3.531683103559964*^9, 3.531683134682019*^9, 3.5316842745184374`*^9, 
   3.535282662101827*^9, 3.5352828168456144`*^9, 3.536059495147625*^9, 
   3.5387446953638783`*^9, {3.538744738390339*^9, 3.5387447746954155`*^9}, 
   3.538744904086817*^9, 3.5387472809207635`*^9, 3.538838225129735*^9, 
   3.5388967728873262`*^9, 3.5405411764545746`*^9, 3.5405433393872876`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of operators used in the fit: \"\>", 
   "\[InvisibleSpace]", "35"}],
  SequenceForm["Number of operators used in the fit: ", 35],
  Editable->False]], "Print",
 CellChangeTimes->{{3.529952853378755*^9, 3.5299528557412863`*^9}, {
   3.529952912352669*^9, 3.529952989170877*^9}, {3.5299530745857363`*^9, 
   3.5299530914686093`*^9}, 3.531594279155219*^9, 3.5315972003715506`*^9, 
   3.5315972711020746`*^9, {3.5315974269151487`*^9, 3.531597516318905*^9}, 
   3.5316768230976753`*^9, 3.5316772194319715`*^9, 3.531677336026576*^9, 
   3.531683103559964*^9, 3.531683134682019*^9, 3.5316842745184374`*^9, 
   3.535282662101827*^9, 3.5352828168456144`*^9, 3.536059495147625*^9, 
   3.5387446953638783`*^9, {3.538744738390339*^9, 3.5387447746954155`*^9}, 
   3.538744904086817*^9, 3.5387472809207635`*^9, 3.538838225129735*^9, 
   3.5388967728873262`*^9, 3.5405411764545746`*^9, 3.540543339394288*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New parametrization", "Subsection",
 CellChangeTimes->{{3.5098759773223677`*^9, 3.5098759823611765`*^9}, {
  3.511249539104279*^9, 3.5112495407734823`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"We", " ", "change", " ", "the", " ", "parametrization"}], ",", 
   " ", 
   RowBox[{
   "defining", " ", "the", " ", "operator", " ", "coefficients", " ", "as", 
    " ", "dimensionless", " ", "parameter"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.5112494699181576`*^9, 3.5112494905725937`*^9}, {
  3.511249547512694*^9, 3.5112495825815554`*^9}, {3.511249645621266*^9, 
  3.5112496583196883`*^9}, {3.5405406977281933`*^9, 3.5405407015394115`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ChangeOP", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ChangeOP", "=", 
      RowBox[{"Append", "[", 
       RowBox[{"ChangeOP", ",", 
        RowBox[{
         RowBox[{"Ops", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"Ops", "[", 
           RowBox[{"[", "i", "]"}], "]"}], 
          RowBox[{"2", "/", 
           SuperscriptBox["v", "2"]}]}]}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "Ops", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"X2", "=", "chi2total"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]2", "=", 
   RowBox[{"X2", "/.", "ChangeOP"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]", "=", 
   RowBox[{"\[Chi]2", "/.", "DropOps"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.506860863966121*^9, 3.506860867429327*^9}, 
   3.507470286691067*^9, 3.509805539858591*^9, {3.5099523420168447`*^9, 
   3.5099523424848456`*^9}, {3.509968853450631*^9, 3.509968856352236*^9}, {
   3.511249671657712*^9, 3.511249671813712*^9}, {3.5146310355515823`*^9, 
   3.514631140945367*^9}, {3.5147134742559233`*^9, 3.5147134744743233`*^9}, 
   3.5215466567818565`*^9, {3.5215473257684107`*^9, 3.5215473284554634`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["M matrix", "Subsection",
 CellChangeTimes->{{3.5134934965268574`*^9, 3.5134935087260785`*^9}, 
   3.5146311872462482`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Length", "[", "ops", "]"}], ",", 
       RowBox[{"Length", "[", "ops", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<=", 
     RowBox[{"Length", "[", "ops", "]"}]}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "<=", 
       RowBox[{"Length", "[", "ops", "]"}]}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"1", "/", "2"}], 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{"\[Chi]", ",", 
            RowBox[{"ops", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"ops", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}]}]}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<M matrix\>\"", ",", 
   RowBox[{"MatrixForm", "[", "M", "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<M eigenvalues: \>\"", ",", 
   RowBox[{"Eigenvalues", "[", "M", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5147035632594156`*^9, 3.514703579842244*^9}, {
  3.514713489887151*^9, 3.5147135069223804`*^9}, {3.514805618424549*^9, 
  3.5148056296097684`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"M matrix\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1.1607500706596534`*^8", "3.282297774746182`*^7", 
        "8316.705447831582`", "52562.723056362585`", 
        RowBox[{"-", "188250.5212615234`"}], "0", 
        RowBox[{"-", "24599.35491160201`"}], 
        RowBox[{"-", "74671.83265190518`"}], 
        RowBox[{"-", "28414.15272230153`"}], 
        RowBox[{"-", "28414.15272230153`"}], 
        RowBox[{"-", "12086.81849431104`"}], 
        RowBox[{"-", "25826.95022845447`"}], 
        RowBox[{"-", "2.610173593215924`*^6"}], 
        RowBox[{"-", "35513.46085993277`"}], 
        RowBox[{"-", "1.7682553813854125`*^6"}], 
        RowBox[{"-", "2.6001696767071774`*^6"}], 
        RowBox[{"-", "3.923923654974767`*^6"}], "2.413191445339237`*^6", 
        RowBox[{"-", "1.2790127562550397`*^6"}], "1.079938232607675`*^6", 
        RowBox[{"-", "56372.9972287725`"}], 
        RowBox[{"-", "4.836290393143941`*^7"}], 
        RowBox[{"-", "36396.19494924243`"}], 
        RowBox[{"-", "38314.31919156351`"}], 
        RowBox[{"-", "7.996770231174575`*^6"}], "1.9549255739314212`*^6", 
        RowBox[{"-", "1.720063868751952`*^7"}], "7.682206372124001`*^7", 
        RowBox[{"-", "2.782292262841379`*^7"}], 
        RowBox[{"-", "931571.1067694809`"}], 
        RowBox[{"-", "564870.6005559147`"}], 
        RowBox[{"-", "2.3609331680873903`*^6"}], 
        RowBox[{"-", "277002.2977918364`"}], "1.444843603300593`*^6", 
        "1.3320354035199783`*^6"},
       {"3.282297774746182`*^7", "1.168869656878161`*^7", 
        "4874.077337692446`", "28444.927714398997`", 
        RowBox[{"-", "90173.39512533431`"}], "0", 
        RowBox[{"-", "13157.086926458227`"}], 
        RowBox[{"-", "35702.03323208745`"}], 
        RowBox[{"-", "18563.062722242277`"}], 
        RowBox[{"-", "18563.062722242277`"}], "735.5851614234158`", 
        RowBox[{"-", "16872.412114233037`"}], 
        RowBox[{"-", "1.1646721676181788`*^6"}], "103960.62395725375`", 
        RowBox[{"-", "376766.3989883177`"}], 
        RowBox[{"-", "789385.4796755267`"}], 
        RowBox[{"-", "720946.373066939`"}], "48151.57847456449`", 
        "6497.880756467706`", 
        RowBox[{"-", "61253.729278253224`"}], 
        RowBox[{"-", "36698.53391503077`"}], 
        RowBox[{"-", "1.5184686264142798`*^7"}], 
        RowBox[{"-", "11993.37706652532`"}], 
        RowBox[{"-", "28308.193648229702`"}], 
        RowBox[{"-", "4.059100898222396`*^6"}], "403259.0388560894`", 
        RowBox[{"-", "4.7110845700907`*^6"}], "2.399660233092636`*^7", 
        RowBox[{"-", "4.257022158232974`*^6"}], "3451.2145064766682`", 
        RowBox[{"-", "126390.96572059672`"}], 
        RowBox[{"-", "72429.6556029306`"}], 
        RowBox[{"-", "786832.5136970711`"}], 
        RowBox[{"-", "482758.168223178`"}], "108331.84462461836`"},
       {"8316.705447831582`", "4874.077337692446`", "2852.6211139621855`", 
        "0.`", "0.`", "0.`", "0", "0.`", "0.`", "0.`", "0", "0.`", "0.`", 
        "0.`", "0", "0.`", "0", "0.`", "0", "0.`", "0.`", 
        RowBox[{"-", "4548.241265043905`"}], "0.`", "0", "871.9978959645523`",
         "0.`", "6868.86166182628`", 
        RowBox[{"-", "1881.7231524744448`"}], "1552.6833909253219`", "0", 
        "0.`", "0", "0.`", "0.`", "0.`"},
       {"52562.723056362585`", "28444.927714398997`", "0.`", 
        "76025.03589177351`", 
        RowBox[{"-", "171169.95491960127`"}], "0.`", 
        RowBox[{"-", "36517.8674146696`"}], 
        RowBox[{"-", "68171.18588149021`"}], "0.`", "0", "0", "0.`", 
        RowBox[{"-", "38339.793441133465`"}], "3618.7330625865534`", "0", "0",
         "0", "5101.615578709782`", 
        RowBox[{"-", "2286.6953115232586`"}], 
        RowBox[{"-", "5384.147906513941`"}], "0.`", 
        RowBox[{"-", "56889.85542879801`"}], "0", "0", 
        RowBox[{"-", "2091.5988073523736`"}], "201.89216954003962`", 
        RowBox[{"-", "44533.329688752114`"}], "69246.38116884389`", 
        "23328.778146870864`", "3540.346756923732`", 
        RowBox[{"-", "24114.34215834884`"}], 
        RowBox[{"-", "2087.0634857699315`"}], 
        RowBox[{"-", "102.71084724554282`"}], 
        RowBox[{"-", "928.452247571816`"}], "7768.120494008464`"},
       {
        RowBox[{"-", "188250.5212615234`"}], 
        RowBox[{"-", "90173.39512533431`"}], "0.`", 
        RowBox[{"-", "171169.95491960127`"}], "547883.2599741844`", "0.`", 
        "82890.18823036028`", "218480.64429748087`", "0.`", "0", "0", "0.`", 
        "110694.93619352022`", 
        RowBox[{"-", "16730.52136670738`"}], "0", "0", "0", 
        RowBox[{"-", "17671.876146608047`"}], "8000.015641949776`", 
        "18550.37487395434`", "0.`", "180346.7902506687`", "0", "0", 
        "5755.80344403887`", 
        RowBox[{"-", "549.1301495560919`"}], "141043.5321334097`", 
        RowBox[{"-", "219650.04836792764`"}], 
        RowBox[{"-", "54387.927252641006`"}], 
        RowBox[{"-", "12815.223611791627`"}], "84127.62823292761`", 
        "5540.464449725635`", "160.11439315400997`", "2800.236466029086`", 
        RowBox[{"-", "27812.9423556417`"}]},
       {"0.`", "0.`", "0.`", "0.`", "0.`", "314977.25588697015`", "0", "0.`", 
        "0.`", "0.`", "0", "0.`", "0.`", "0.`", "0.`", 
        RowBox[{"-", "314977.2558869701`"}], "0.`", "0.`", "0.`", "0.`", "0", 
        "0.`", "0.`", "0.`", "0", "0.`", "0.`", "314977.25588697015`", "0.`", 
        "0", 
        RowBox[{"-", "314977.2558869701`"}], "0.`", "0.`", "0.`", "0.`"},
       {
        RowBox[{"-", "24599.35491160201`"}], 
        RowBox[{"-", "13157.086926458227`"}], "0.`", 
        RowBox[{"-", "36517.8674146696`"}], "82890.18823036028`", "0.`", 
        "17831.09510731388`", "33113.537509413865`", "0.`", "0", "0", "0.`", 
        "17802.842400136382`", 
        RowBox[{"-", "1644.4137089666644`"}], "0", "0", "0", 
        RowBox[{"-", "3192.837133654202`"}], "1459.8815682304712`", 
        "3333.1700081073336`", "0.`", "26314.173852916465`", "0", "0", 
        "766.5446725383918`", 
        RowBox[{"-", "71.64160326949096`"}], "20573.5455326944`", 
        RowBox[{"-", "32054.802173138552`"}], 
        RowBox[{"-", "10558.448902032856`"}], 
        RowBox[{"-", "2416.601200083411`"}], "15309.032866106929`", 
        "690.9984177926469`", 
        RowBox[{"-", "6.985889720197709`"}], "429.5930002592481`", 
        RowBox[{"-", "5191.04478559493`"}]},
       {
        RowBox[{"-", "74671.83265190518`"}], 
        RowBox[{"-", "35702.03323208745`"}], "0.`", 
        RowBox[{"-", "68171.18588149021`"}], "218480.64429748087`", "0.`", 
        "33113.537509413865`", "87166.04327464772`", "0.`", "0", "0", "0.`", 
        "43843.74874770954`", 
        RowBox[{"-", "6623.140216117658`"}], "0", "0", "0", 
        RowBox[{"-", "7340.063489836197`"}], "3333.170008107336`", 
        "7691.828965417972`", "0.`", "71404.06646417492`", "0", "0", 
        "2195.6164124837887`", 
        RowBox[{"-", "208.40848967425617`"}], "55833.52116344271`", 
        RowBox[{"-", "86974.61176490712`"}], 
        RowBox[{"-", "21418.200671482464`"}], 
        RowBox[{"-", "5395.075178586983`"}], "35020.72037833489`", 
        "2080.0293695739324`", "40.87658904247498`", "1108.6156241747806`", 
        RowBox[{"-", "11670.627425396635`"}]},
       {
        RowBox[{"-", "28414.15272230153`"}], 
        RowBox[{"-", "18563.062722242277`"}], "0.`", "0.`", "0.`", "0.`", "0",
         "0.`", "225807.2891231262`", "225807.2891231262`", 
        "50498.89662018691`", "205419.91778305787`", "0.`", "0.`", 
        "29337.778035270825`", "29337.778035270825`", 
        RowBox[{"-", "20274.06683012215`"}], "0.`", "0", "0", "0.`", 
        "37126.12544448455`", "0", "0", "0", "0.`", "29337.778035270825`", 
        RowBox[{"-", "44914.47285369827`"}], 
        RowBox[{"-", "20274.06683012215`"}], "0", "0", "0", "0.`", "0.`", 
        "0.`"},
       {
        RowBox[{"-", "28414.15272230153`"}], 
        RowBox[{"-", "18563.062722242277`"}], "0.`", "0.`", "0.`", "0.`", "0",
         "0.`", "225807.2891231262`", "2.0042962491231256`*^6", 
        "50498.89662018691`", "205419.91778305787`", "0.`", "0.`", 
        "29337.778035270825`", 
        RowBox[{"-", "1.7491511819647285`*^6"}], 
        RowBox[{"-", "20274.06683012215`"}], "0.`", "0", "0", "0.`", 
        RowBox[{"-", "1.741362834555515`*^6"}], "0", "0", "0", "0.`", 
        "29337.778035270825`", "1.7335744871463012`*^6", 
        RowBox[{"-", "20274.06683012215`"}], "0", "0", "0", "0.`", "0.`", 
        "0.`"},
       {
        RowBox[{"-", "12086.81849431104`"}], "735.5851614234158`", "0.`", 
        "0.`", "0.`", "0.`", "0", "0.`", "50498.89662018691`", 
        "50498.89662018691`", "94759.24963396546`", "45944.63541310316`", 
        "0.`", "0.`", 
        RowBox[{"-", "4784.179245753022`"}], 
        RowBox[{"-", "4784.179245753022`"}], "8639.702698877189`", "0.`", "0",
         "0", "0.`", 
        RowBox[{"-", "1471.170322846836`"}], "0", "0", "0", "0.`", 
        RowBox[{"-", "4784.179245753022`"}], 
        RowBox[{"-", "1841.8386000593543`"}], "8639.702698877189`", "0", "0", 
        "0", "0.`", "0.`", "0.`"},
       {
        RowBox[{"-", "25826.95022845447`"}], 
        RowBox[{"-", "16872.412114233037`"}], "0.`", "0.`", "0.`", "0.`", "0",
         "0.`", "205419.91778305787`", "205419.91778305787`", 
        "45944.63541310316`", "186875.22831091893`", "0.`", "0.`", 
        "26665.631585787043`", "26665.631585787043`", 
        RowBox[{"-", "18427.201234959437`"}], "0.`", "0", "0", "0.`", 
        "33744.82422846607`", "0", "0", "0", "0.`", "26665.631585787043`", 
        RowBox[{"-", "40824.01687114509`"}], 
        RowBox[{"-", "18427.201234959437`"}], "0", "0", "0", "0.`", "0.`", 
        "0.`"},
       {
        RowBox[{"-", "2.610173593215924`*^6"}], 
        RowBox[{"-", "1.1646721676181788`*^6"}], "0.`", 
        RowBox[{"-", "38339.793441133465`"}], "110694.93619352022`", "0.`", 
        "17802.842400136382`", "43843.74874770954`", "0.`", "0", "0", "0.`", 
        "2.8604171742409356`*^6", 
        RowBox[{"-", "496732.81257938605`"}], 
        RowBox[{"-", "1.0325728177259867`*^6"}], 
        RowBox[{"-", "202209.60628424815`"}], "528460.981258295`", 
        RowBox[{"-", "1481.317610849274`"}], "598.068836398818`", 
        "1652.116018329269`", "0.`", "2.329344335236357`*^6", "0", "0", 
        "3.4761565752359973`*^6", 
        RowBox[{"-", "344928.17186754645`"}], 
        RowBox[{"-", "4.567304230858769`*^6"}], 
        RowBox[{"-", "7.565266478448006`*^6"}], "3.6155263635912645`*^6", 
        RowBox[{"-", "555.1824069399652`"}], "6474.006082251472`", 
        "2082.0338278164872`", "725034.6754995803`", "312474.3782139918`", 
        RowBox[{"-", "1465.670923483938`"}]},
       {
        RowBox[{"-", "35513.46085993277`"}], "103960.62395725375`", "0.`", 
        "3618.7330625865534`", 
        RowBox[{"-", "16730.52136670738`"}], "0.`", 
        RowBox[{"-", "1644.4137089666644`"}], 
        RowBox[{"-", "6623.140216117658`"}], "0.`", "0", "0", "0.`", 
        RowBox[{"-", "496732.81257938605`"}], "104501.95277556873`", 
        "188039.3773603702`", "36823.909955051655`", 
        RowBox[{"-", "96236.77107238185`"}], "183.7148960293301`", 
        RowBox[{"-", "71.64160326949069`"}], 
        RowBox[{"-", "208.40848967425563`"}], "0.`", 
        RowBox[{"-", "207921.24791450746`"}], "0", "0", 
        RowBox[{"-", "654738.732631418`"}], "64700.13558835509`", 
        "981767.5246322635`", "1.095179085650641`*^6", 
        RowBox[{"-", "485847.43762684637`"}], "50.44650126018631`", 
        RowBox[{"-", "782.0381986745808`"}], 
        RowBox[{"-", "316.2221004376088`"}], 
        RowBox[{"-", "133481.02188336942`"}], 
        RowBox[{"-", "55896.08187283231`"}], "150.73986660865282`"},
       {
        RowBox[{"-", "1.7682553813854125`*^6"}], 
        RowBox[{"-", "376766.3989883177`"}], "0.`", "0.`", "0", "0.`", "0", 
        "0", "29337.778035270825`", "29337.778035270825`", 
        RowBox[{"-", "4784.179245753022`"}], "26665.631585787043`", 
        RowBox[{"-", "1.0325728177259867`*^6"}], "188039.3773603702`", 
        "4.784000450400706`*^6", "4.282511016539086`*^6", 
        RowBox[{"-", "2.28042548768407`*^6"}], "0", "0", "0", "0.`", 
        "753532.7979766368`", "0", "0", 
        RowBox[{"-", "3.7542125161832077`*^6"}], "376078.7547207404`", 
        "2.0449576775826993`*^6", 
        RowBox[{"-", "465086.7860938153`"}], 
        RowBox[{"-", "1.1990620907634883`*^6"}], "0", "0", "0", 
        RowBox[{"-", "752157.5094414807`"}], 
        RowBox[{"-", "376078.75472074014`"}], "0.`"},
       {
        RowBox[{"-", "2.6001696767071774`*^6"}], 
        RowBox[{"-", "789385.4796755267`"}], "0.`", "0.`", "0", 
        RowBox[{"-", "314977.2558869701`"}], "0", "0", "29337.778035270825`", 
        RowBox[{"-", "1.7491511819647285`*^6"}], 
        RowBox[{"-", "4784.179245753022`"}], "26665.631585787043`", 
        RowBox[{"-", "202209.60628424815`"}], "36823.909955051655`", 
        "4.282511016539086`*^6", "7.326663454439509`*^6", 
        RowBox[{"-", "2.472904437645085`*^6"}], "0", "0", "0", "0", 
        "3.357259919351053`*^6", "0", "0", 
        RowBox[{"-", "735190.6052268898`"}], "73647.81991010331`", 
        RowBox[{"-", "4.465045720770989`*^6"}], 
        RowBox[{"-", "7.814681411333157`*^6"}], "3.175947076754208`*^6", "0", 
        "314977.25588697015`", "0", 
        RowBox[{"-", "147295.6398202066`"}], 
        RowBox[{"-", "73647.81991010316`"}], "0.`"},
       {
        RowBox[{"-", "3.923923654974767`*^6"}], 
        RowBox[{"-", "720946.373066939`"}], "0.`", "0.`", "0", "0.`", "0", 
        "0", 
        RowBox[{"-", "20274.06683012215`"}], 
        RowBox[{"-", "20274.06683012215`"}], "8639.702698877189`", 
        RowBox[{"-", "18427.201234959437`"}], "528460.981258295`", 
        RowBox[{"-", "96236.77107238185`"}], 
        RowBox[{"-", "2.28042548768407`*^6"}], 
        RowBox[{"-", "2.472904437645085`*^6"}], "3.9027484609443303`*^6", "0",
         "0", "0", "0.`", "1.441892746133878`*^6", "0", "0", 
        "1.921370382888417`*^6", 
        RowBox[{"-", "192473.5421447637`"}], "1.1407137436852073`*^6", 
        RowBox[{"-", "2.128029648504579`*^6"}], 
        RowBox[{"-", "722858.2160561838`"}], "0", "0", "0", 
        "384947.08428952744`", "192473.54214476357`", "0.`"},
       {"2.413191445339237`*^6", "48151.57847456449`", "0.`", 
        "5101.615578709782`", 
        RowBox[{"-", "17671.876146608047`"}], "0.`", 
        RowBox[{"-", "3192.837133654202`"}], 
        RowBox[{"-", "7340.063489836197`"}], "0.`", "0", "0", "0.`", 
        RowBox[{"-", "1481.317610849274`"}], "183.7148960293301`", "0", "0", 
        "0", "5.372968933116369`*^6", 
        RowBox[{"-", "2.8317780182574964`*^6"}], "2.7178931346533773`*^6", 
        "0.`", 
        RowBox[{"-", "96303.15694912858`"}], "0", "0", "237109.573976978`", 
        "2.8046246911468296`*^6", "894681.7612504404`", 
        "1.0872880751486984`*^6", 
        RowBox[{"-", "951441.124736704`"}], 
        RowBox[{"-", "2.4289657681748257`*^6"}], 
        RowBox[{"-", "738178.7717358897`"}], 
        RowBox[{"-", "5.265536814985166`*^6"}], "2.4822637914794697`*^6", 
        "5.285657163980462`*^6", "2.6511455899721202`*^6"},
       {
        RowBox[{"-", "1.2790127562550397`*^6"}], "6497.880756467706`", "0.`", 
        RowBox[{"-", "2286.6953115232586`"}], "8000.015641949776`", "0.`", 
        "1459.8815682304712`", "3333.170008107336`", "0.`", "0", "0", "0.`", 
        "598.068836398818`", 
        RowBox[{"-", "71.64160326949069`"}], "0", "0", "0", 
        RowBox[{"-", "2.8317780182574964`*^6"}], "1.5164322126506087`*^6", 
        RowBox[{"-", "1.4477970272923782`*^6"}], "0.`", "43556.457623502945`",
         "0", "0", 
        RowBox[{"-", "129322.6105219843`"}], 
        RowBox[{"-", "1.4601842647592376`*^6"}], 
        RowBox[{"-", "428767.6509774883`"}], 
        RowBox[{"-", "572432.7853609333`"}], "507514.7034512543`", 
        "1.2485759115211274`*^6", "328706.8690550223`", 
        "2.783264889500193`*^6", 
        RowBox[{"-", "1.359122278265438`*^6"}], 
        RowBox[{"-", "2.803124920666969`*^6"}], 
        RowBox[{"-", "1.3815334138900947`*^6"}]},
       {"1.079938232607675`*^6", 
        RowBox[{"-", "61253.729278253224`"}], "0.`", 
        RowBox[{"-", "5384.147906513941`"}], "18550.37487395434`", "0.`", 
        "3333.1700081073336`", "7691.828965417972`", "0.`", "0", "0", "0.`", 
        "1652.116018329269`", 
        RowBox[{"-", "208.40848967425563`"}], "0", "0", "0", 
        "2.7178931346533773`*^6", 
        RowBox[{"-", "1.4477970272923782`*^6"}], "1.5625829750150095`*^6", 
        "0.`", "122507.45855650667`", "0", "0", "231396.4744818552`", 
        "1.475161122888462`*^6", "603990.605375807`", "358975.6882627941`", 
        RowBox[{"-", "547162.1511762419`"}], 
        RowBox[{"-", "1.3815334138900947`*^6"}], "269414.50854397897`", 
        RowBox[{"-", "2.8221398823509463`*^6"}], "1.3290141379474879`*^6", 
        "2.8061327759044864`*^6", "1.1614889278028365`*^6"},
       {
        RowBox[{"-", "56372.9972287725`"}], 
        RowBox[{"-", "36698.53391503077`"}], "0.`", "0.`", "0.`", "0", "0", 
        "0.`", "0.`", "0", "0", "0.`", "0.`", "0.`", "0", "0.`", "0", "0.`", 
        "0", "0", "410175.2248284975`", "464483.3968607683`", 
        "207798.22234172808`", "366576.742990381`", "0", "0.`", 
        "105014.3437122129`", 
        RowBox[{"-", "30903.78877084885`"}], 
        RowBox[{"-", "74487.97419006037`"}], "0", "0.`", "0", "0.`", "0.`", 
        "0.`"},
       {
        RowBox[{"-", "4.836290393143941`*^7"}], 
        RowBox[{"-", "1.5184686264142798`*^7"}], 
        RowBox[{"-", "4548.241265043905`"}], 
        RowBox[{"-", "56889.85542879801`"}], "180346.7902506687`", "0", 
        "26314.173852916465`", "71404.06646417492`", "37126.12544448455`", 
        RowBox[{"-", "1.741362834555515`*^6"}], 
        RowBox[{"-", "1471.170322846836`"}], "33744.82422846607`", 
        "2.329344335236357`*^6", 
        RowBox[{"-", "207921.24791450746`"}], "753532.7979766368`", 
        "3.357259919351053`*^6", "1.441892746133878`*^6", 
        RowBox[{"-", "96303.15694912858`"}], "43556.457623502945`", 
        "122507.45855650667`", "464483.3968607683`", "7.220800277792244`*^7", 
        "233103.20276259555`", "423193.1302868405`", "5.2307514904692`*^7", 
        RowBox[{"-", "749965.8585757399`"}], "1.0589593185717687`*^7", 
        RowBox[{"-", "8.449631379951319`*^7"}], "8.441252875714585`*^6", 
        RowBox[{"-", "113504.59915687639`"}], 
        RowBox[{"-", "4.3942348838159025`*^7"}], 
        RowBox[{"-", "5058.698466642835`"}], "1.4670628572502197`*^6", 
        "815598.3267738525`", 
        RowBox[{"-", "216663.6892492365`"}]},
       {
        RowBox[{"-", "36396.19494924243`"}], 
        RowBox[{"-", "11993.37706652532`"}], "0.`", "0.`", "0.`", "0", "0", 
        "0.`", "0.`", "0", "0", "0.`", "0.`", "0.`", "0", "0.`", "0", "0.`", 
        "0", "0", "207798.22234172808`", "233103.20276259555`", 
        "984864.2942425335`", "193383.08815571357`", "0", "0.`", 
        "37552.160992843324`", 
        RowBox[{"-", "19952.466181804244`"}], 
        RowBox[{"-", "9566.862895629114`"}], "0", "0.`", "0", "0.`", "0.`", 
        "0.`"},
       {
        RowBox[{"-", "38314.31919156351`"}], 
        RowBox[{"-", "28308.193648229702`"}], "0.`", "0.`", "0.`", "0", "0", 
        "0.`", "0.`", "0", "0", "0.`", "0.`", "0.`", "0", "0.`", "0", "0.`", 
        "0", "0", "366576.742990381`", "423193.1302868405`", 
        "193383.08815571357`", "335547.12728907744`", "0", "0.`", 
        "92228.78890115539`", 
        RowBox[{"-", "21003.985691763457`"}], 
        RowBox[{"-", "67785.3414707026`"}], "0", "0.`", "0", "0.`", "0.`", 
        "0.`"},
       {
        RowBox[{"-", "7.996770231174575`*^6"}], 
        RowBox[{"-", "4.059100898222396`*^6"}], "871.9978959645523`", 
        RowBox[{"-", "2091.5988073523736`"}], "5755.80344403887`", "0.`", 
        "766.5446725383918`", "2195.6164124837887`", "0.`", "0", "0", "0.`", 
        "3.4761565752359973`*^6", 
        RowBox[{"-", "654738.732631418`"}], 
        RowBox[{"-", "3.7542125161832077`*^6"}], 
        RowBox[{"-", "735190.6052268898`"}], "1.921370382888417`*^6", 
        "237109.573976978`", 
        RowBox[{"-", "129322.6105219843`"}], "231396.4744818552`", "0.`", 
        "5.2307514904692`*^7", "0", "0", "6.426498652591577`*^7", 
        RowBox[{"-", "1.8081133464760242`*^6"}], 
        RowBox[{"-", "1.74696668166091`*^7"}], 
        RowBox[{"-", "7.13918268720891`*^7"}], "1.2348793018444212`*^7", 
        RowBox[{"-", "210767.64900875394`"}], 
        RowBox[{"-", "4.41625036623482`*^7"}], 
        RowBox[{"-", "296375.5955794801`"}], "4.0354876184180425`*^6", 
        "2.343226209078015`*^6", "5768.439607313586`"},
       {"1.9549255739314212`*^6", "403259.0388560894`", "0.`", 
        "201.89216954003962`", 
        RowBox[{"-", "549.1301495560919`"}], "0.`", 
        RowBox[{"-", "71.64160326949096`"}], 
        RowBox[{"-", "208.40848967425617`"}], "0.`", "0", "0", "0.`", 
        RowBox[{"-", "344928.17186754645`"}], "64700.13558835509`", 
        "376078.7547207404`", "73647.81991010331`", 
        RowBox[{"-", "192473.5421447637`"}], "2.8046246911468296`*^6", 
        RowBox[{"-", "1.4601842647592376`*^6"}], "1.475161122888462`*^6", 
        "0.`", 
        RowBox[{"-", "749965.8585757399`"}], "0", "0", 
        RowBox[{"-", "1.8081133464760242`*^6"}], "1.7027493746646799`*^6", 
        "2.312570142901091`*^6", "3.151087771294859`*^6", 
        RowBox[{"-", "1.7561724779485008`*^6"}], 
        RowBox[{"-", "1.359122278265438`*^6"}], 
        RowBox[{"-", "197281.59686767668`"}], 
        RowBox[{"-", "2.804421178190494`*^6"}], "882648.3098005388`", 
        "2.582400228815438`*^6", "1.3290141379474879`*^6"},
       {
        RowBox[{"-", "1.720063868751952`*^7"}], 
        RowBox[{"-", "4.7110845700907`*^6"}], "6868.86166182628`", 
        RowBox[{"-", "44533.329688752114`"}], "141043.5321334097`", "0", 
        "20573.5455326944`", "55833.52116344271`", "29337.778035270825`", 
        "29337.778035270825`", 
        RowBox[{"-", "4784.179245753022`"}], "26665.631585787043`", 
        RowBox[{"-", "4.567304230858769`*^6"}], "981767.5246322635`", 
        "2.0449576775826993`*^6", 
        RowBox[{"-", "4.465045720770989`*^6"}], "1.1407137436852073`*^6", 
        "894681.7612504404`", 
        RowBox[{"-", "428767.6509774883`"}], "603990.605375807`", 
        "105014.3437122129`", "1.0589593185717687`*^7", "37552.160992843324`",
         "92228.78890115539`", 
        RowBox[{"-", "1.74696668166091`*^7"}], "2.312570142901091`*^6", 
        "5.217417867240287`*^7", "1.7059066024418294`*^7", 
        RowBox[{"-", "2.6086993710150104`*^7"}], 
        RowBox[{"-", "632977.66346537`"}], "655426.916851595`", 
        RowBox[{"-", "1.1600100852418183`*^6"}], 
        RowBox[{"-", "3.1472800574488216`*^6"}], 
        RowBox[{"-", "913569.8671756756`"}], "292594.3001469485`"},
       {"7.682206372124001`*^7", "2.399660233092636`*^7", 
        RowBox[{"-", "1881.7231524744448`"}], "69246.38116884389`", 
        RowBox[{"-", "219650.04836792764`"}], "314977.25588697015`", 
        RowBox[{"-", "32054.802173138552`"}], 
        RowBox[{"-", "86974.61176490712`"}], 
        RowBox[{"-", "44914.47285369827`"}], "1.7335744871463012`*^6", 
        RowBox[{"-", "1841.8386000593543`"}], 
        RowBox[{"-", "40824.01687114509`"}], 
        RowBox[{"-", "7.565266478448006`*^6"}], "1.095179085650641`*^6", 
        RowBox[{"-", "465086.7860938153`"}], 
        RowBox[{"-", "7.814681411333157`*^6"}], 
        RowBox[{"-", "2.128029648504579`*^6"}], "1.0872880751486984`*^6", 
        RowBox[{"-", "572432.7853609333`"}], "358975.6882627941`", 
        RowBox[{"-", "30903.78877084885`"}], 
        RowBox[{"-", "8.449631379951319`*^7"}], 
        RowBox[{"-", "19952.466181804244`"}], 
        RowBox[{"-", "21003.985691763457`"}], 
        RowBox[{"-", "7.13918268720891`*^7"}], "3.151087771294859`*^6", 
        "1.7059066024418294`*^7", "1.2888910336081311`*^8", 
        RowBox[{"-", "3.439599355740326`*^7"}], 
        RowBox[{"-", "299366.29500769457`"}], "4.353138921799398`*^7", 
        RowBox[{"-", "999974.67863603`"}], 
        RowBox[{"-", "4.76507986256279`*^6"}], 
        RowBox[{"-", "1.7899866414296015`*^6"}], "725921.6786454219`"},
       {
        RowBox[{"-", "2.782292262841379`*^7"}], 
        RowBox[{"-", "4.257022158232974`*^6"}], "1552.6833909253219`", 
        "23328.778146870864`", 
        RowBox[{"-", "54387.927252641006`"}], "0", 
        RowBox[{"-", "10558.448902032856`"}], 
        RowBox[{"-", "21418.200671482464`"}], 
        RowBox[{"-", "20274.06683012215`"}], 
        RowBox[{"-", "20274.06683012215`"}], "8639.702698877189`", 
        RowBox[{"-", "18427.201234959437`"}], "3.6155263635912645`*^6", 
        RowBox[{"-", "485847.43762684637`"}], 
        RowBox[{"-", "1.1990620907634883`*^6"}], "3.175947076754208`*^6", 
        RowBox[{"-", "722858.2160561838`"}], 
        RowBox[{"-", "951441.124736704`"}], "507514.7034512543`", 
        RowBox[{"-", "547162.1511762419`"}], 
        RowBox[{"-", "74487.97419006037`"}], "8.441252875714585`*^6", 
        RowBox[{"-", "9566.862895629114`"}], 
        RowBox[{"-", "67785.3414707026`"}], "1.2348793018444212`*^7", 
        RowBox[{"-", "1.7561724779485008`*^6"}], 
        RowBox[{"-", "2.6086993710150104`*^7"}], 
        RowBox[{"-", "3.439599355740326`*^7"}], "3.39433399309619`*^7", 
        "482685.40531058726`", 
        RowBox[{"-", "98592.36196278023`"}], "988790.7043910067`", 
        "1.9823401551188908`*^6", "250068.97441755416`", 
        RowBox[{"-", "405598.8713868286`"}]},
       {
        RowBox[{"-", "931571.1067694809`"}], "3451.2145064766682`", "0.`", 
        "3540.346756923732`", 
        RowBox[{"-", "12815.223611791627`"}], "0.`", 
        RowBox[{"-", "2416.601200083411`"}], 
        RowBox[{"-", "5395.075178586983`"}], "0.`", "0", "0", "0.`", 
        RowBox[{"-", "555.1824069399652`"}], "50.44650126018631`", "0", "0", 
        "0", 
        RowBox[{"-", "2.4289657681748257`*^6"}], "1.2485759115211274`*^6", 
        RowBox[{"-", "1.3815334138900947`*^6"}], "0.`", 
        RowBox[{"-", "113504.59915687639`"}], "0", "0", 
        RowBox[{"-", "210767.64900875394`"}], 
        RowBox[{"-", "1.359122278265438`*^6"}], 
        RowBox[{"-", "632977.66346537`"}], 
        RowBox[{"-", "299366.29500769457`"}], "482685.40531058726`", 
        "1.3172077401278228`*^6", 
        RowBox[{"-", "187853.57147722307`"}], "2.537281744356062`*^6", 
        RowBox[{"-", "1.093987927658778`*^6"}], 
        RowBox[{"-", "2.483834726657351`*^6"}], 
        RowBox[{"-", "1.0433977166772229`*^6"}]},
       {
        RowBox[{"-", "564870.6005559147`"}], 
        RowBox[{"-", "126390.96572059672`"}], "0.`", 
        RowBox[{"-", "24114.34215834884`"}], "84127.62823292761`", 
        RowBox[{"-", "314977.2558869701`"}], "15309.032866106929`", 
        "35020.72037833489`", "0.`", "0", "0", "0.`", "6474.006082251472`", 
        RowBox[{"-", "782.0381986745808`"}], "0", "314977.25588697015`", "0", 
        RowBox[{"-", "738178.7717358897`"}], "328706.8690550223`", 
        "269414.50854397897`", "0", 
        RowBox[{"-", "4.3942348838159025`*^7"}], "0", "0", 
        RowBox[{"-", "4.41625036623482`*^7"}], 
        RowBox[{"-", "197281.59686767668`"}], "655426.916851595`", 
        "4.353138921799398`*^7", 
        RowBox[{"-", "98592.36196278023`"}], 
        RowBox[{"-", "187853.57147722307`"}], "4.718588797015275`*^7", 
        "91454.25175973064`", 
        RowBox[{"-", "71803.3967600841`"}], 
        RowBox[{"-", "315187.46617736324`"}], 
        RowBox[{"-", "1.0110956418444044`*^6"}]},
       {
        RowBox[{"-", "2.3609331680873903`*^6"}], 
        RowBox[{"-", "72429.6556029306`"}], "0.`", 
        RowBox[{"-", "2087.0634857699315`"}], "5540.464449725635`", "0.`", 
        "690.9984177926469`", "2080.0293695739324`", "0.`", "0", "0", "0.`", 
        "2082.0338278164872`", 
        RowBox[{"-", "316.2221004376088`"}], "0", "0", "0", 
        RowBox[{"-", "5.265536814985166`*^6"}], "2.783264889500193`*^6", 
        RowBox[{"-", "2.8221398823509463`*^6"}], "0.`", 
        RowBox[{"-", "5058.698466642835`"}], "0", "0", 
        RowBox[{"-", "296375.5955794801`"}], 
        RowBox[{"-", "2.804421178190494`*^6"}], 
        RowBox[{"-", "1.1600100852418183`*^6"}], 
        RowBox[{"-", "999974.67863603`"}], "988790.7043910067`", 
        "2.537281744356062`*^6", "91454.25175973064`", "5.37855948851375`*^6", 
        RowBox[{"-", "2.486767254323924`*^6"}], 
        RowBox[{"-", "5.262672532645446`*^6"}], 
        RowBox[{"-", "2.408946312165258`*^6"}]},
       {
        RowBox[{"-", "277002.2977918364`"}], 
        RowBox[{"-", "786832.5136970711`"}], "0.`", 
        RowBox[{"-", "102.71084724554282`"}], "160.11439315400997`", "0.`", 
        RowBox[{"-", "6.985889720197709`"}], "40.87658904247498`", "0.`", "0",
         "0", "0.`", "725034.6754995803`", 
        RowBox[{"-", "133481.02188336942`"}], 
        RowBox[{"-", "752157.5094414807`"}], 
        RowBox[{"-", "147295.6398202066`"}], "384947.08428952744`", 
        "2.4822637914794697`*^6", 
        RowBox[{"-", "1.359122278265438`*^6"}], "1.3290141379474879`*^6", 
        "0.`", "1.4670628572502197`*^6", "0", "0", "4.0354876184180425`*^6", 
        "882648.3098005388`", 
        RowBox[{"-", "3.1472800574488216`*^6"}], 
        RowBox[{"-", "4.76507986256279`*^6"}], "1.9823401551188908`*^6", 
        RowBox[{"-", "1.093987927658778`*^6"}], 
        RowBox[{"-", "71803.3967600841`"}], 
        RowBox[{"-", "2.486767254323924`*^6"}], "2.076098160298922`*^6", 
        "2.900430942910044`*^6", "1.151951236373497`*^6"},
       {"1.444843603300593`*^6", 
        RowBox[{"-", "482758.168223178`"}], "0.`", 
        RowBox[{"-", "928.452247571816`"}], "2800.236466029086`", "0.`", 
        "429.5930002592481`", "1108.6156241747806`", "0.`", "0", "0", "0.`", 
        "312474.3782139918`", 
        RowBox[{"-", "55896.08187283231`"}], 
        RowBox[{"-", "376078.75472074014`"}], 
        RowBox[{"-", "73647.81991010316`"}], "192473.54214476357`", 
        "5.285657163980462`*^6", 
        RowBox[{"-", "2.803124920666969`*^6"}], "2.8061327759044864`*^6", 
        "0.`", "815598.3267738525`", "0", "0", "2.343226209078015`*^6", 
        "2.582400228815438`*^6", 
        RowBox[{"-", "913569.8671756756`"}], 
        RowBox[{"-", "1.7899866414296015`*^6"}], "250068.97441755416`", 
        RowBox[{"-", "2.483834726657351`*^6"}], 
        RowBox[{"-", "315187.46617736324`"}], 
        RowBox[{"-", "5.262672532645446`*^6"}], "2.900430942910044`*^6", 
        "5.625030866628096`*^6", "2.485675887342974`*^6"},
       {"1.3320354035199783`*^6", "108331.84462461836`", "0.`", 
        "7768.120494008464`", 
        RowBox[{"-", "27812.9423556417`"}], "0.`", 
        RowBox[{"-", "5191.04478559493`"}], 
        RowBox[{"-", "11670.627425396635`"}], "0.`", "0", "0", "0.`", 
        RowBox[{"-", "1465.670923483938`"}], "150.73986660865282`", "0", "0", 
        "0", "2.6511455899721202`*^6", 
        RowBox[{"-", "1.3815334138900947`*^6"}], "1.1614889278028365`*^6", 
        "0.`", 
        RowBox[{"-", "216663.6892492365`"}], "0", "0", "5768.439607313586`", 
        "1.3290141379474879`*^6", "292594.3001469485`", "725921.6786454219`", 
        RowBox[{"-", "405598.8713868286`"}], 
        RowBox[{"-", "1.0433977166772229`*^6"}], 
        RowBox[{"-", "1.0110956418444044`*^6"}], 
        RowBox[{"-", "2.408946312165258`*^6"}], "1.151951236373497`*^6", 
        "2.485675887342974`*^6", "1.5026982925401088`*^6"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["M matrix", 
   MatrixForm[{{
     1.1607500706596534`*^8, 3.282297774746182*^7, 8316.705447831582, 
      52562.723056362585`, -188250.5212615234, 
      0, -24599.35491160201, -74671.83265190518, -28414.15272230153, \
-28414.15272230153, -12086.81849431104, -25826.95022845447, \
-2.610173593215924*^6, -35513.46085993277, -1.7682553813854125`*^6, \
-2.6001696767071774`*^6, -3.923923654974767*^6, 
      2.413191445339237*^6, -1.2790127562550397`*^6, 
      1.079938232607675*^6, -56372.9972287725, -4.836290393143941*^7, \
-36396.19494924243, -38314.31919156351, -7.996770231174575*^6, 
      1.9549255739314212`*^6, -1.720063868751952*^7, 
      7.682206372124001*^7, -2.782292262841379*^7, -931571.1067694809, \
-564870.6005559147, -2.3609331680873903`*^6, -277002.2977918364, 
      1.444843603300593*^6, 1.3320354035199783`*^6}, {
     3.282297774746182*^7, 1.168869656878161*^7, 4874.077337692446, 
      28444.927714398997`, -90173.39512533431, 
      0, -13157.086926458227`, -35702.03323208745, -18563.062722242277`, \
-18563.062722242277`, 
      735.5851614234158, -16872.412114233037`, -1.1646721676181788`*^6, 
      103960.62395725375`, -376766.3989883177, -789385.4796755267, \
-720946.373066939, 48151.57847456449, 
      6497.880756467706, -61253.729278253224`, -36698.53391503077, \
-1.5184686264142798`*^7, -11993.37706652532, -28308.193648229702`, \
-4.059100898222396*^6, 403259.0388560894, -4.7110845700907*^6, 
      2.399660233092636*^7, -4.257022158232974*^6, 
      3451.2145064766682`, -126390.96572059672`, -72429.6556029306, \
-786832.5136970711, -482758.168223178, 108331.84462461836`}, {
     8316.705447831582, 4874.077337692446, 2852.6211139621855`, 0., 0., 0., 0,
       0., 0., 0., 0, 0., 0., 0., 0, 0., 0, 0., 0, 0., 0., -4548.241265043905,
       0., 0, 871.9978959645523, 0., 6868.86166182628, -1881.7231524744448`, 
      1552.6833909253219`, 0, 0., 0, 0., 0., 0.}, {
     52562.723056362585`, 28444.927714398997`, 0., 
      76025.03589177351, -171169.95491960127`, 
      0., -36517.8674146696, -68171.18588149021, 0., 0, 0, 
      0., -38339.793441133465`, 3618.7330625865534`, 0, 0, 0, 
      5101.615578709782, -2286.6953115232586`, -5384.147906513941, 
      0., -56889.85542879801, 0, 0, -2091.5988073523736`, 
      201.89216954003962`, -44533.329688752114`, 69246.38116884389, 
      23328.778146870864`, 
      3540.346756923732, -24114.34215834884, -2087.0634857699315`, \
-102.71084724554282`, -928.452247571816, 
      7768.120494008464}, {-188250.5212615234, -90173.39512533431, 
      0., -171169.95491960127`, 547883.2599741844, 0., 82890.18823036028, 
      218480.64429748087`, 0., 0, 0, 0., 
      110694.93619352022`, -16730.52136670738, 0, 0, 0, -17671.876146608047`, 
      8000.015641949776, 18550.37487395434, 0., 180346.7902506687, 0, 0, 
      5755.80344403887, -549.1301495560919, 
      141043.5321334097, -219650.04836792764`, -54387.927252641006`, \
-12815.223611791627`, 84127.62823292761, 5540.464449725635, 
      160.11439315400997`, 2800.236466029086, -27812.9423556417}, {
     0., 0., 0., 0., 0., 314977.25588697015`, 0, 0., 0., 0., 0, 0., 0., 0., 
      0., -314977.2558869701, 0., 0., 0., 0., 0, 0., 0., 0., 0, 0., 0., 
      314977.25588697015`, 0., 0, -314977.2558869701, 0., 0., 0., 
      0.}, {-24599.35491160201, -13157.086926458227`, 0., -36517.8674146696, 
      82890.18823036028, 0., 17831.09510731388, 33113.537509413865`, 0., 0, 0,
       0., 17802.842400136382`, -1644.4137089666644`, 0, 0, 
      0, -3192.837133654202, 1459.8815682304712`, 3333.1700081073336`, 0., 
      26314.173852916465`, 0, 0, 766.5446725383918, -71.64160326949096, 
      20573.5455326944, -32054.802173138552`, -10558.448902032856`, \
-2416.601200083411, 15309.032866106929`, 
      690.9984177926469, -6.985889720197709, 
      429.5930002592481, -5191.04478559493}, {-74671.83265190518, \
-35702.03323208745, 0., -68171.18588149021, 218480.64429748087`, 0., 
      33113.537509413865`, 87166.04327464772, 0., 0, 0, 0., 
      43843.74874770954, -6623.140216117658, 0, 0, 0, -7340.063489836197, 
      3333.170008107336, 7691.828965417972, 0., 71404.06646417492, 0, 0, 
      2195.6164124837887`, -208.40848967425617`, 
      55833.52116344271, -86974.61176490712, -21418.200671482464`, \
-5395.075178586983, 35020.72037833489, 2080.0293695739324`, 40.87658904247498,
       1108.6156241747806`, -11670.627425396635`}, {-28414.15272230153, \
-18563.062722242277`, 0., 0., 0., 0., 0, 0., 225807.2891231262, 
      225807.2891231262, 50498.89662018691, 205419.91778305787`, 0., 0., 
      29337.778035270825`, 29337.778035270825`, -20274.06683012215, 0., 0, 0, 
      0., 37126.12544448455, 0, 0, 0, 0., 
      29337.778035270825`, -44914.47285369827, -20274.06683012215, 0, 0, 0, 
      0., 0., 0.}, {-28414.15272230153, -18563.062722242277`, 0., 0., 0., 0., 
      0, 0., 225807.2891231262, 2.0042962491231256`*^6, 50498.89662018691, 
      205419.91778305787`, 0., 0., 
      29337.778035270825`, -1.7491511819647285`*^6, -20274.06683012215, 0., 0,
       0, 0., -1.741362834555515*^6, 0, 0, 0, 0., 29337.778035270825`, 
      1.7335744871463012`*^6, -20274.06683012215, 0, 0, 0, 0., 0., 
      0.}, {-12086.81849431104, 735.5851614234158, 0., 0., 0., 0., 0, 0., 
      50498.89662018691, 50498.89662018691, 94759.24963396546, 
      45944.63541310316, 0., 0., -4784.179245753022, -4784.179245753022, 
      8639.702698877189, 0., 0, 0, 0., -1471.170322846836, 0, 0, 0, 
      0., -4784.179245753022, -1841.8386000593543`, 8639.702698877189, 0, 0, 
      0, 0., 0., 0.}, {-25826.95022845447, -16872.412114233037`, 0., 0., 0., 
      0., 0, 0., 205419.91778305787`, 205419.91778305787`, 45944.63541310316, 
      186875.22831091893`, 0., 0., 26665.631585787043`, 
      26665.631585787043`, -18427.201234959437`, 0., 0, 0, 0., 
      33744.82422846607, 0, 0, 0, 0., 
      26665.631585787043`, -40824.01687114509, -18427.201234959437`, 0, 0, 0, 
      0., 0., 0.}, {-2.610173593215924*^6, -1.1646721676181788`*^6, 
      0., -38339.793441133465`, 110694.93619352022`, 0., 17802.842400136382`, 
      43843.74874770954, 0., 0, 0, 0., 
      2.8604171742409356`*^6, -496732.81257938605`, -1.0325728177259867`*^6, \
-202209.60628424815`, 528460.981258295, -1481.317610849274, 598.068836398818, 
      1652.116018329269, 0., 2.329344335236357*^6, 0, 0, 
      3.4761565752359973`*^6, -344928.17186754645`, -4.567304230858769*^6, \
-7.565266478448006*^6, 3.6155263635912645`*^6, -555.1824069399652, 
      6474.006082251472, 2082.0338278164872`, 725034.6754995803, 
      312474.3782139918, -1465.670923483938}, {-35513.46085993277, 
      103960.62395725375`, 0., 3618.7330625865534`, -16730.52136670738, 
      0., -1644.4137089666644`, -6623.140216117658, 0., 0, 0, 
      0., -496732.81257938605`, 104501.95277556873`, 188039.3773603702, 
      36823.909955051655`, -96236.77107238185, 
      183.7148960293301, -71.64160326949069, -208.40848967425563`, 
      0., -207921.24791450746`, 0, 0, -654738.732631418, 64700.13558835509, 
      981767.5246322635, 1.095179085650641*^6, -485847.43762684637`, 
      50.44650126018631, -782.0381986745808, -316.2221004376088, \
-133481.02188336942`, -55896.08187283231, 
      150.73986660865282`}, {-1.7682553813854125`*^6, -376766.3989883177, 0., 
      0., 0, 0., 0, 0, 29337.778035270825`, 
      29337.778035270825`, -4784.179245753022, 
      26665.631585787043`, -1.0325728177259867`*^6, 188039.3773603702, 
      4.784000450400706*^6, 4.282511016539086*^6, -2.28042548768407*^6, 0, 0, 
      0, 0., 753532.7979766368, 0, 0, -3.7542125161832077`*^6, 
      376078.7547207404, 
      2.0449576775826993`*^6, -465086.7860938153, -1.1990620907634883`*^6, 0, 
      0, 0, -752157.5094414807, -376078.75472074014`, 
      0.}, {-2.6001696767071774`*^6, -789385.4796755267, 0., 0., 
      0, -314977.2558869701, 0, 0, 
      29337.778035270825`, -1.7491511819647285`*^6, -4784.179245753022, 
      26665.631585787043`, -202209.60628424815`, 36823.909955051655`, 
      4.282511016539086*^6, 7.326663454439509*^6, -2.472904437645085*^6, 0, 0,
       0, 0, 3.357259919351053*^6, 0, 0, -735190.6052268898, 
      73647.81991010331, -4.465045720770989*^6, -7.814681411333157*^6, 
      3.175947076754208*^6, 0, 314977.25588697015`, 
      0, -147295.6398202066, -73647.81991010316, 
      0.}, {-3.923923654974767*^6, -720946.373066939, 0., 0., 0, 0., 0, 
      0, -20274.06683012215, -20274.06683012215, 
      8639.702698877189, -18427.201234959437`, 
      528460.981258295, -96236.77107238185, -2.28042548768407*^6, \
-2.472904437645085*^6, 3.9027484609443303`*^6, 0, 0, 0, 0., 
      1.441892746133878*^6, 0, 0, 1.921370382888417*^6, -192473.5421447637, 
      1.1407137436852073`*^6, -2.128029648504579*^6, -722858.2160561838, 0, 0,
       0, 384947.08428952744`, 192473.54214476357`, 0.}, {
     2.413191445339237*^6, 48151.57847456449, 0., 
      5101.615578709782, -17671.876146608047`, 
      0., -3192.837133654202, -7340.063489836197, 0., 0, 0, 
      0., -1481.317610849274, 183.7148960293301, 0, 0, 0, 
      5.372968933116369*^6, -2.8317780182574964`*^6, 2.7178931346533773`*^6, 
      0., -96303.15694912858, 0, 0, 237109.573976978, 2.8046246911468296`*^6, 
      894681.7612504404, 
      1.0872880751486984`*^6, -951441.124736704, -2.4289657681748257`*^6, \
-738178.7717358897, -5.265536814985166*^6, 2.4822637914794697`*^6, 
      5.285657163980462*^6, 2.6511455899721202`*^6}, {-1.2790127562550397`*^6,
       6497.880756467706, 0., -2286.6953115232586`, 8000.015641949776, 0., 
      1459.8815682304712`, 3333.170008107336, 0., 0, 0, 0., 
      598.068836398818, -71.64160326949069, 0, 0, 0, -2.8317780182574964`*^6, 
      1.5164322126506087`*^6, -1.4477970272923782`*^6, 0., 
      43556.457623502945`, 0, 
      0, -129322.6105219843, -1.4601842647592376`*^6, -428767.6509774883, \
-572432.7853609333, 507514.7034512543, 1.2485759115211274`*^6, 
      328706.8690550223, 
      2.783264889500193*^6, -1.359122278265438*^6, -2.803124920666969*^6, \
-1.3815334138900947`*^6}, {
     1.079938232607675*^6, -61253.729278253224`, 0., -5384.147906513941, 
      18550.37487395434, 0., 3333.1700081073336`, 7691.828965417972, 0., 0, 0,
       0., 1652.116018329269, -208.40848967425563`, 0, 0, 0, 
      2.7178931346533773`*^6, -1.4477970272923782`*^6, 1.5625829750150095`*^6,
       0., 122507.45855650667`, 0, 0, 231396.4744818552, 1.475161122888462*^6,
       603990.605375807, 
      358975.6882627941, -547162.1511762419, -1.3815334138900947`*^6, 
      269414.50854397897`, -2.8221398823509463`*^6, 1.3290141379474879`*^6, 
      2.8061327759044864`*^6, 
      1.1614889278028365`*^6}, {-56372.9972287725, -36698.53391503077, 0., 0.,
       0., 0, 0, 0., 0., 0, 0, 0., 0., 0., 0, 0., 0, 0., 0, 0, 
      410175.2248284975, 464483.3968607683, 207798.22234172808`, 
      366576.742990381, 0, 0., 
      105014.3437122129, -30903.78877084885, -74487.97419006037, 0, 0., 0, 0.,
       0., 
      0.}, {-4.836290393143941*^7, -1.5184686264142798`*^7, \
-4548.241265043905, -56889.85542879801, 180346.7902506687, 0, 
      26314.173852916465`, 71404.06646417492, 
      37126.12544448455, -1.741362834555515*^6, -1471.170322846836, 
      33744.82422846607, 2.329344335236357*^6, -207921.24791450746`, 
      753532.7979766368, 3.357259919351053*^6, 
      1.441892746133878*^6, -96303.15694912858, 43556.457623502945`, 
      122507.45855650667`, 464483.3968607683, 7.220800277792244*^7, 
      233103.20276259555`, 423193.1302868405, 
      5.2307514904692*^7, -749965.8585757399, 
      1.0589593185717687`*^7, -8.449631379951319*^7, 
      8.441252875714585*^6, -113504.59915687639`, -4.3942348838159025`*^7, \
-5058.698466642835, 1.4670628572502197`*^6, 
      815598.3267738525, -216663.6892492365}, {-36396.19494924243, \
-11993.37706652532, 0., 0., 0., 0, 0, 0., 0., 0, 0, 0., 0., 0., 0, 0., 0, 0., 
      0, 0, 207798.22234172808`, 233103.20276259555`, 984864.2942425335, 
      193383.08815571357`, 0, 0., 
      37552.160992843324`, -19952.466181804244`, -9566.862895629114, 0, 0., 0,
       0., 0., 0.}, {-38314.31919156351, -28308.193648229702`, 0., 0., 0., 0, 
      0, 0., 0., 0, 0, 0., 0., 0., 0, 0., 0, 0., 0, 0, 366576.742990381, 
      423193.1302868405, 193383.08815571357`, 335547.12728907744`, 0, 0., 
      92228.78890115539, -21003.985691763457`, -67785.3414707026, 0, 0., 0, 
      0., 0., 0.}, {-7.996770231174575*^6, -4.059100898222396*^6, 
      871.9978959645523, -2091.5988073523736`, 5755.80344403887, 0., 
      766.5446725383918, 2195.6164124837887`, 0., 0, 0, 0., 
      3.4761565752359973`*^6, -654738.732631418, -3.7542125161832077`*^6, \
-735190.6052268898, 1.921370382888417*^6, 
      237109.573976978, -129322.6105219843, 231396.4744818552, 0., 
      5.2307514904692*^7, 0, 0, 
      6.426498652591577*^7, -1.8081133464760242`*^6, -1.74696668166091*^7, \
-7.13918268720891*^7, 
      1.2348793018444212`*^7, -210767.64900875394`, -4.41625036623482*^7, \
-296375.5955794801, 4.0354876184180425`*^6, 2.343226209078015*^6, 
      5768.439607313586}, {
     1.9549255739314212`*^6, 403259.0388560894, 0., 
      201.89216954003962`, -549.1301495560919, 
      0., -71.64160326949096, -208.40848967425617`, 0., 0, 0, 
      0., -344928.17186754645`, 64700.13558835509, 376078.7547207404, 
      73647.81991010331, -192473.5421447637, 
      2.8046246911468296`*^6, -1.4601842647592376`*^6, 1.475161122888462*^6, 
      0., -749965.8585757399, 0, 0, -1.8081133464760242`*^6, 
      1.7027493746646799`*^6, 2.312570142901091*^6, 
      3.151087771294859*^6, -1.7561724779485008`*^6, -1.359122278265438*^6, \
-197281.59686767668`, -2.804421178190494*^6, 882648.3098005388, 
      2.582400228815438*^6, 
      1.3290141379474879`*^6}, {-1.720063868751952*^7, -4.7110845700907*^6, 
      6868.86166182628, -44533.329688752114`, 141043.5321334097, 0, 
      20573.5455326944, 55833.52116344271, 29337.778035270825`, 
      29337.778035270825`, -4784.179245753022, 
      26665.631585787043`, -4.567304230858769*^6, 981767.5246322635, 
      2.0449576775826993`*^6, -4.465045720770989*^6, 1.1407137436852073`*^6, 
      894681.7612504404, -428767.6509774883, 603990.605375807, 
      105014.3437122129, 1.0589593185717687`*^7, 37552.160992843324`, 
      92228.78890115539, -1.74696668166091*^7, 2.312570142901091*^6, 
      5.217417867240287*^7, 
      1.7059066024418294`*^7, -2.6086993710150104`*^7, -632977.66346537, 
      655426.916851595, -1.1600100852418183`*^6, -3.1472800574488216`*^6, \
-913569.8671756756, 292594.3001469485}, {7.682206372124001*^7, 
     2.399660233092636*^7, -1881.7231524744448`, 
     69246.38116884389, -219650.04836792764`, 
     314977.25588697015`, -32054.802173138552`, -86974.61176490712, \
-44914.47285369827, 
     1.7335744871463012`*^6, -1841.8386000593543`, -40824.01687114509, \
-7.565266478448006*^6, 
     1.095179085650641*^6, -465086.7860938153, -7.814681411333157*^6, \
-2.128029648504579*^6, 1.0872880751486984`*^6, -572432.7853609333, 
     358975.6882627941, -30903.78877084885, -8.449631379951319*^7, \
-19952.466181804244`, -21003.985691763457`, -7.13918268720891*^7, 
     3.151087771294859*^6, 1.7059066024418294`*^7, 
     1.2888910336081311`*^8, -3.439599355740326*^7, -299366.29500769457`, 
     4.353138921799398*^7, -999974.67863603, -4.76507986256279*^6, \
-1.7899866414296015`*^6, 
     725921.6786454219}, {-2.782292262841379*^7, -4.257022158232974*^6, 
      1552.6833909253219`, 23328.778146870864`, -54387.927252641006`, 
      0, -10558.448902032856`, -21418.200671482464`, -20274.06683012215, \
-20274.06683012215, 8639.702698877189, -18427.201234959437`, 
      3.6155263635912645`*^6, -485847.43762684637`, -1.1990620907634883`*^6, 
      3.175947076754208*^6, -722858.2160561838, -951441.124736704, 
      507514.7034512543, -547162.1511762419, -74487.97419006037, 
      8.441252875714585*^6, -9566.862895629114, -67785.3414707026, 
      1.2348793018444212`*^7, -1.7561724779485008`*^6, \
-2.6086993710150104`*^7, -3.439599355740326*^7, 3.39433399309619*^7, 
      482685.40531058726`, -98592.36196278023, 988790.7043910067, 
      1.9823401551188908`*^6, 
      250068.97441755416`, -405598.8713868286}, {-931571.1067694809, 
      3451.2145064766682`, 0., 3540.346756923732, -12815.223611791627`, 
      0., -2416.601200083411, -5395.075178586983, 0., 0, 0, 
      0., -555.1824069399652, 50.44650126018631, 0, 0, 
      0, -2.4289657681748257`*^6, 
      1.2485759115211274`*^6, -1.3815334138900947`*^6, 
      0., -113504.59915687639`, 0, 
      0, -210767.64900875394`, -1.359122278265438*^6, -632977.66346537, \
-299366.29500769457`, 482685.40531058726`, 
      1.3172077401278228`*^6, -187853.57147722307`, 
      2.537281744356062*^6, -1.093987927658778*^6, -2.483834726657351*^6, \
-1.0433977166772229`*^6}, {-564870.6005559147, -126390.96572059672`, 
      0., -24114.34215834884, 84127.62823292761, -314977.2558869701, 
      15309.032866106929`, 35020.72037833489, 0., 0, 0, 0., 
      6474.006082251472, -782.0381986745808, 0, 314977.25588697015`, 
      0, -738178.7717358897, 328706.8690550223, 269414.50854397897`, 
      0, -4.3942348838159025`*^7, 0, 
      0, -4.41625036623482*^7, -197281.59686767668`, 655426.916851595, 
      4.353138921799398*^7, -98592.36196278023, -187853.57147722307`, 
      4.718588797015275*^7, 
      91454.25175973064, -71803.3967600841, -315187.46617736324`, \
-1.0110956418444044`*^6}, {-2.3609331680873903`*^6, -72429.6556029306, 
      0., -2087.0634857699315`, 5540.464449725635, 0., 690.9984177926469, 
      2080.0293695739324`, 0., 0, 0, 0., 
      2082.0338278164872`, -316.2221004376088, 0, 0, 0, -5.265536814985166*^6,
       2.783264889500193*^6, -2.8221398823509463`*^6, 0., -5058.698466642835, 
      0, 0, -296375.5955794801, -2.804421178190494*^6, \
-1.1600100852418183`*^6, -999974.67863603, 988790.7043910067, 
      2.537281744356062*^6, 91454.25175973064, 
      5.37855948851375*^6, -2.486767254323924*^6, -5.262672532645446*^6, \
-2.408946312165258*^6}, {-277002.2977918364, -786832.5136970711, 
      0., -102.71084724554282`, 160.11439315400997`, 0., -6.985889720197709, 
      40.87658904247498, 0., 0, 0, 0., 
      725034.6754995803, -133481.02188336942`, -752157.5094414807, \
-147295.6398202066, 384947.08428952744`, 
      2.4822637914794697`*^6, -1.359122278265438*^6, 1.3290141379474879`*^6, 
      0., 1.4670628572502197`*^6, 0, 0, 4.0354876184180425`*^6, 
      882648.3098005388, -3.1472800574488216`*^6, -4.76507986256279*^6, 
      1.9823401551188908`*^6, -1.093987927658778*^6, -71803.3967600841, \
-2.486767254323924*^6, 2.076098160298922*^6, 2.900430942910044*^6, 
      1.151951236373497*^6}, {
     1.444843603300593*^6, -482758.168223178, 0., -928.452247571816, 
      2800.236466029086, 0., 429.5930002592481, 1108.6156241747806`, 0., 0, 0,
       0., 312474.3782139918, -55896.08187283231, -376078.75472074014`, \
-73647.81991010316, 192473.54214476357`, 
      5.285657163980462*^6, -2.803124920666969*^6, 2.8061327759044864`*^6, 0.,
       815598.3267738525, 0, 0, 2.343226209078015*^6, 
      2.582400228815438*^6, -913569.8671756756, -1.7899866414296015`*^6, 
      250068.97441755416`, -2.483834726657351*^6, -315187.46617736324`, \
-5.262672532645446*^6, 2.900430942910044*^6, 5.625030866628096*^6, 
      2.485675887342974*^6}, {
     1.3320354035199783`*^6, 108331.84462461836`, 0., 
      7768.120494008464, -27812.9423556417, 
      0., -5191.04478559493, -11670.627425396635`, 0., 0, 0, 
      0., -1465.670923483938, 150.73986660865282`, 0, 0, 0, 
      2.6511455899721202`*^6, -1.3815334138900947`*^6, 1.1614889278028365`*^6,
       0., -216663.6892492365, 0, 0, 5768.439607313586, 
      1.3290141379474879`*^6, 292594.3001469485, 
      725921.6786454219, -405598.8713868286, -1.0433977166772229`*^6, \
-1.0110956418444044`*^6, -2.408946312165258*^6, 1.151951236373497*^6, 
      2.485675887342974*^6, 1.5026982925401088`*^6}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.514703580481846*^9, 3.514703701818859*^9, 3.5147038116742516`*^9, 
   3.514703864433544*^9, 3.514703930593261*^9, 3.5147040877167363`*^9, 
   3.514712523340653*^9, 3.5147125623875217`*^9, 3.5147126017775908`*^9, 
   3.5147126494200745`*^9, 3.5147127000733633`*^9, 3.5147128216443768`*^9, {
   3.5147134801839333`*^9, 3.5147135084979835`*^9}, 3.514715038829471*^9, 
   3.5147151545192747`*^9, 3.5147165785375757`*^9, 3.514804810265129*^9, {
   3.51480561909535*^9, 3.514805630202569*^9}, 3.516017519372511*^9, 
   3.5165306292968082`*^9, 3.5165395430575066`*^9, 3.5169690258970947`*^9, 
   3.516969871072436*^9, {3.517121610034176*^9, 3.517121631718214*^9}, 
   3.5171217746612654`*^9, 3.5171417252121067`*^9, 3.5173105132466803`*^9, 
   3.5175567602866144`*^9, 3.5183438461468706`*^9, 3.5190390988388166`*^9, 
   3.521544557291131*^9, 3.521546652766738*^9, 3.5215473394655657`*^9, 
   3.521789193023095*^9, 3.521789920405573*^9, 3.5217900126329346`*^9, 
   3.521796101564295*^9, {3.5221557458808093`*^9, 3.522155775579508*^9}, 
   3.5221558140287075`*^9, 3.5221558609523907`*^9, 3.522156281355437*^9, 
   3.522156348169258*^9, 3.522156382907245*^9, 3.5224754442044554`*^9, 
   3.5224766789074926`*^9, 3.5224782059629745`*^9, 3.5224946612594547`*^9, 
   3.5224965093947*^9, 3.522580741207724*^9, 3.522737152417098*^9, 
   3.522763601054867*^9, 3.522906432167075*^9, 3.522906476221552*^9, 
   3.522906533707653*^9, 3.5237725807390146`*^9, 3.5237726597325325`*^9, 
   3.5237733905443325`*^9, 3.5237734731020546`*^9, 3.523806287112107*^9, 
   3.5238112914470806`*^9, 3.523864981076062*^9, 3.5238659552353735`*^9, 
   3.52387424275706*^9, 3.5238752244622107`*^9, 3.524314546559955*^9, 
   3.524562626457658*^9, 3.5287336985847597`*^9, {3.5287337508916516`*^9, 
   3.528733777832899*^9}, 3.528738442073391*^9, 3.5287385005422935`*^9, {
   3.528806370720875*^9, 3.52880639087611*^9}, 3.52880653305476*^9, 
   3.5288066735330067`*^9, 3.52880828743571*^9, 3.528808354406627*^9, 
   3.5288084076027203`*^9, 3.5288085526985755`*^9, 3.5288086086402736`*^9, 
   3.5288108963084245`*^9, 3.528810935305655*^9, {3.5288110252517996`*^9, 
   3.52881105374743*^9}, 3.5288296723764954`*^9, {3.5288300297575235`*^9, 
   3.528830051472761*^9}, 3.528830082548016*^9, 3.529176210782672*^9, 
   3.5292413103575935`*^9, 3.5292594210537405`*^9, 3.529262388085352*^9, 
   3.529263194233368*^9, 3.5292635717852306`*^9, 3.5292645429961367`*^9, 
   3.5292652025184946`*^9, 3.5292657665852857`*^9, 3.529322491101081*^9, 
   3.5293267457564335`*^9, 3.529430838068112*^9, 3.529953099521122*^9, 
   3.531594282961626*^9, 3.53159720583156*^9, 3.531597275345282*^9, {
   3.5315974438255777`*^9, 3.531597520811713*^9}, {3.5316768275904827`*^9, 
   3.5316768564973335`*^9}, 3.5316772225051765`*^9, 3.5316773395677824`*^9, 
   3.5316831037159643`*^9, 3.5316831378332243`*^9, 3.5316842780284443`*^9, 
   3.5352826623080807`*^9, 3.535282702645816*^9, 3.5352828211887426`*^9, 
   3.5360594954176292`*^9, 3.5387446955408883`*^9, {3.538744742109552*^9, 
   3.5387447789686604`*^9}, 3.5387449073690042`*^9, 3.538747281065772*^9, 
   3.5388382252545357`*^9, 3.5388967730663366`*^9, 3.5405411765875826`*^9, 
   3.5405433396823044`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"M eigenvalues: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "3.096924906894709`*^8", ",", "1.1790177619879988`*^8", ",", 
     "7.841460761176491`*^7", ",", "2.3992655806645393`*^7", ",", 
     "1.4749563913763277`*^7", ",", "1.211648588527358`*^7", ",", 
     "6.309013422667321`*^6", ",", "3.570381842194793`*^6", ",", 
     "2.578642286402923`*^6", ",", "2.20256543988591`*^6", ",", 
     "1.3868242436930272`*^6", ",", "885789.1286136847`", ",", 
     "696909.6047429524`", ",", "612955.609142281`", ",", 
     "556532.1299478917`", ",", "375789.0397211101`", ",", 
     "250921.67726160586`", ",", "131935.56388329377`", ",", 
     "113476.09707425594`", ",", "79988.20348787136`", ",", 
     "42358.85722377576`", ",", "25459.24842351626`", ",", 
     "22082.53181683671`", ",", "17167.0664696597`", ",", 
     "13119.475450761189`", ",", "4858.7687380977495`", ",", 
     "3920.209789457634`", ",", "1196.191469558572`", ",", 
     "977.5358419480935`", ",", "272.0340667367994`", ",", 
     "190.4557630386127`", ",", "7.216087192996534`", ",", 
     "5.189963676360953`", ",", "2.126864715725132`", ",", 
     "1.0806665303249323`"}], "}"}]}],
  SequenceForm[
  "M eigenvalues: ", {3.096924906894709*^8, 1.1790177619879988`*^8, 
   7.841460761176491*^7, 2.3992655806645393`*^7, 1.4749563913763277`*^7, 
   1.211648588527358*^7, 6.309013422667321*^6, 3.570381842194793*^6, 
   2.578642286402923*^6, 2.20256543988591*^6, 1.3868242436930272`*^6, 
   885789.1286136847, 696909.6047429524, 612955.609142281, 556532.1299478917, 
   375789.0397211101, 250921.67726160586`, 131935.56388329377`, 
   113476.09707425594`, 79988.20348787136, 42358.85722377576, 
   25459.24842351626, 22082.53181683671, 17167.0664696597, 
   13119.475450761189`, 4858.7687380977495`, 3920.209789457634, 
   1196.191469558572, 977.5358419480935, 272.0340667367994, 190.4557630386127,
    7.216087192996534, 5.189963676360953, 2.126864715725132, 
   1.0806665303249323`}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.514703580481846*^9, 3.514703701818859*^9, 3.5147038116742516`*^9, 
   3.514703864433544*^9, 3.514703930593261*^9, 3.5147040877167363`*^9, 
   3.514712523340653*^9, 3.5147125623875217`*^9, 3.5147126017775908`*^9, 
   3.5147126494200745`*^9, 3.5147127000733633`*^9, 3.5147128216443768`*^9, {
   3.5147134801839333`*^9, 3.5147135084979835`*^9}, 3.514715038829471*^9, 
   3.5147151545192747`*^9, 3.5147165785375757`*^9, 3.514804810265129*^9, {
   3.51480561909535*^9, 3.514805630202569*^9}, 3.516017519372511*^9, 
   3.5165306292968082`*^9, 3.5165395430575066`*^9, 3.5169690258970947`*^9, 
   3.516969871072436*^9, {3.517121610034176*^9, 3.517121631718214*^9}, 
   3.5171217746612654`*^9, 3.5171417252121067`*^9, 3.5173105132466803`*^9, 
   3.5175567602866144`*^9, 3.5183438461468706`*^9, 3.5190390988388166`*^9, 
   3.521544557291131*^9, 3.521546652766738*^9, 3.5215473394655657`*^9, 
   3.521789193023095*^9, 3.521789920405573*^9, 3.5217900126329346`*^9, 
   3.521796101564295*^9, {3.5221557458808093`*^9, 3.522155775579508*^9}, 
   3.5221558140287075`*^9, 3.5221558609523907`*^9, 3.522156281355437*^9, 
   3.522156348169258*^9, 3.522156382907245*^9, 3.5224754442044554`*^9, 
   3.5224766789074926`*^9, 3.5224782059629745`*^9, 3.5224946612594547`*^9, 
   3.5224965093947*^9, 3.522580741207724*^9, 3.522737152417098*^9, 
   3.522763601054867*^9, 3.522906432167075*^9, 3.522906476221552*^9, 
   3.522906533707653*^9, 3.5237725807390146`*^9, 3.5237726597325325`*^9, 
   3.5237733905443325`*^9, 3.5237734731020546`*^9, 3.523806287112107*^9, 
   3.5238112914470806`*^9, 3.523864981076062*^9, 3.5238659552353735`*^9, 
   3.52387424275706*^9, 3.5238752244622107`*^9, 3.524314546559955*^9, 
   3.524562626457658*^9, 3.5287336985847597`*^9, {3.5287337508916516`*^9, 
   3.528733777832899*^9}, 3.528738442073391*^9, 3.5287385005422935`*^9, {
   3.528806370720875*^9, 3.52880639087611*^9}, 3.52880653305476*^9, 
   3.5288066735330067`*^9, 3.52880828743571*^9, 3.528808354406627*^9, 
   3.5288084076027203`*^9, 3.5288085526985755`*^9, 3.5288086086402736`*^9, 
   3.5288108963084245`*^9, 3.528810935305655*^9, {3.5288110252517996`*^9, 
   3.52881105374743*^9}, 3.5288296723764954`*^9, {3.5288300297575235`*^9, 
   3.528830051472761*^9}, 3.528830082548016*^9, 3.529176210782672*^9, 
   3.5292413103575935`*^9, 3.5292594210537405`*^9, 3.529262388085352*^9, 
   3.529263194233368*^9, 3.5292635717852306`*^9, 3.5292645429961367`*^9, 
   3.5292652025184946`*^9, 3.5292657665852857`*^9, 3.529322491101081*^9, 
   3.5293267457564335`*^9, 3.529430838068112*^9, 3.529953099521122*^9, 
   3.531594282961626*^9, 3.53159720583156*^9, 3.531597275345282*^9, {
   3.5315974438255777`*^9, 3.531597520811713*^9}, {3.5316768275904827`*^9, 
   3.5316768564973335`*^9}, 3.5316772225051765`*^9, 3.5316773395677824`*^9, 
   3.5316831037159643`*^9, 3.5316831378332243`*^9, 3.5316842780284443`*^9, 
   3.5352826623080807`*^9, 3.535282702645816*^9, 3.5352828211887426`*^9, 
   3.5360594954176292`*^9, 3.5387446955408883`*^9, {3.538744742109552*^9, 
   3.5387447789686604`*^9}, 3.5387449073690042`*^9, 3.538747281065772*^9, 
   3.5388382252545357`*^9, 3.5388967730663366`*^9, 3.5405411765875826`*^9, 
   3.5405433397043056`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error Matrix", "Subsection",
 CellChangeTimes->{{3.514631197651467*^9, 3.514631201192673*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Merr", "=", 
   RowBox[{"Inverse", "[", "M", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Error matrix\>\"", ",", 
   RowBox[{"MatrixForm", "[", "Merr", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5288065145843277`*^9, 3.528806518281534*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Error matrix\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"0.0173933195928975`", 
        RowBox[{"-", "0.041828171127420724`"}], 
        RowBox[{"-", "0.012246035698058336`"}], 
        RowBox[{"-", "0.00001862283382475906`"}], "0.00021328013053744993`", 
        RowBox[{"-", "0.0008081021540711246`"}], 
        RowBox[{"-", "0.000036279887178789806`"}], 
        RowBox[{"-", "0.0005380301863594722`"}], "0.00038156969042921055`", 
        RowBox[{"-", "0.00038989905187562844`"}], "8.400418698834271`*^-8", 
        "9.023110055870164`*^-6", 
        RowBox[{"-", "0.0004169641351349923`"}], "0.0069604860918208705`", 
        "0.011243774198845799`", "0.0022849511089736317`", 
        "0.020915671694878984`", 
        RowBox[{"-", "0.002625137519969533`"}], "0.001429943752382016`", 
        "0.0008165133727098862`", "0.00032514701638889764`", 
        "0.0007901436844263976`", "7.53904301531105`*^-6", 
        RowBox[{"-", "0.0012229449253685172`"}], "0.0030467012502860685`", 
        "0.006688751327496928`", "0.010064663322005594`", 
        "0.003464993845275662`", "0.020916274032841468`", 
        "0.0003042938753490613`", "0.00037194058223090397`", 
        RowBox[{"-", "0.001770332248877661`"}], 
        RowBox[{"-", "0.013951339897055054`"}], 
        RowBox[{"-", "0.0035129933103818295`"}], "0.0032391685497021386`"},
       {
        RowBox[{"-", "0.041828171134647534`"}], "0.16987089983345985`", 
        RowBox[{"-", "0.049996363961851364`"}], "0.00005378077595834946`", 
        RowBox[{"-", "0.0006122393531839861`"}], "0.002343274446376363`", 
        "0.00010451234861915543`", "0.0015446165179519994`", 
        RowBox[{"-", "0.0011047797673110656`"}], "0.001129933918963267`", 
        RowBox[{"-", "2.5579477016266297`*^-7"}], 
        RowBox[{"-", "0.000027248704014871256`"}], 
        RowBox[{"-", "0.05085954845886016`"}], 
        RowBox[{"-", "0.028279825037476582`"}], 
        RowBox[{"-", "0.04475197293144958`"}], 
        RowBox[{"-", "0.06274104330008848`"}], 
        RowBox[{"-", "0.08494163131402276`"}], "0.007600270013097116`", 
        RowBox[{"-", "0.004139910134272933`"}], 
        RowBox[{"-", "0.002351815761868173`"}], 
        RowBox[{"-", "0.0009453363980145083`"}], 
        RowBox[{"-", "0.002295199783595464`"}], 
        RowBox[{"-", "0.000021894784010978742`"}], "0.0035533438895128198`", 
        RowBox[{"-", "0.06495257753321468`"}], 
        RowBox[{"-", "0.02749861936349835`"}], 
        RowBox[{"-", "0.041329620175859644`"}], 
        RowBox[{"-", "0.06616617700264721`"}], 
        RowBox[{"-", "0.0849434191470614`"}], 
        RowBox[{"-", "0.0008808931857002709`"}], 
        RowBox[{"-", "0.0010818592561823888`"}], "0.005125660907627769`", 
        "0.05664962917748091`", "0.014234834532081159`", 
        RowBox[{"-", "0.009385647381073725`"}]},
       {
        RowBox[{"-", "0.012246035689749824`"}], 
        RowBox[{"-", "0.04999636398694519`"}], "0.10019499950697554`", 
        "3.637247403425782`*^-6", 
        RowBox[{"-", "0.000040559783883664484`"}], "0.00007529338810160406`", 
        "7.011082760466358`*^-6", "0.00010241493556103608`", 
        RowBox[{"-", "0.00003379289499150229`"}], "0.000034496778174562944`", 
        RowBox[{"-", "2.1983129567994947`*^-9"}], 
        RowBox[{"-", "7.637304539169498`*^-7"}], "0.05976583074447134`", 
        "0.008335903667729853`", "0.012433764771476523`", 
        "0.06399814902025672`", "0.024999792140229557`", 
        "0.00019966815459652662`", 
        RowBox[{"-", "0.00016834803629132023`"}], 
        RowBox[{"-", "0.00011112867801918203`"}], 
        RowBox[{"-", "0.000025697686076506243`"}], 
        RowBox[{"-", "0.00006488724813878688`"}], 
        RowBox[{"-", "6.23406864450216`*^-7"}], "0.00009933957140608688`", 
        "0.06393957033068268`", "0.008412753795814396`", 
        "0.012532987921194434`", "0.06389876499394334`", 
        "0.02499967291317674`", 
        RowBox[{"-", "0.000020117076224805165`"}], 
        RowBox[{"-", "0.000024090638211744352`"}], "0.00015908485567181063`", 
        RowBox[{"-", "0.016667855615333144`"}], 
        RowBox[{"-", "0.004159752617099615`"}], 
        RowBox[{"-", "0.0002769370336503634`"}]},
       {
        RowBox[{"-", "0.00001862283431542688`"}], "0.00005378078151860318`", 
        "3.6372427254123348`*^-6", "0.004928909525690244`", 
        "0.009747644181400892`", "3.773547438618411`*^-6", 
        "0.01016659843551561`", 
        RowBox[{"-", "0.024439619422265985`"}], 
        RowBox[{"-", "9.138630535751218`*^-7"}], "1.3539982033552583`*^-7", 
        "2.616688315325441`*^-8", "8.387369503821835`*^-7", 
        RowBox[{"-", "3.6011776634101964`*^-6"}], "4.965458539340136`*^-6", 
        RowBox[{"-", "0.000013736274997855422`"}], 
        RowBox[{"-", "0.000010396347994164121`"}], 
        RowBox[{"-", "0.00002689203723666926`"}], 
        RowBox[{"-", "0.00002470053712966425`"}], 
        RowBox[{"-", "0.000025246357557810087`"}], 
        RowBox[{"-", "0.000016026113551556652`"}], 
        RowBox[{"-", "1.1442999525882593`*^-7"}], 
        RowBox[{"-", "4.373249663872272`*^-7"}], "1.3198688314065845`*^-9", 
        "5.951810042952062`*^-7", 
        RowBox[{"-", "7.332355438323712`*^-6"}], "0.000022143795892807034`", 
        RowBox[{"-", "0.000013359936535519905`"}], 
        RowBox[{"-", "0.000010969072780886872`"}], 
        RowBox[{"-", "0.000027111257660486593`"}], "5.6115725190762725`*^-6", 
        "3.200822651895637`*^-6", 
        RowBox[{"-", "1.3991307166652257`*^-6"}], "0.000015566698701639988`", 
        "6.682682591615512`*^-6", "7.411766678129386`*^-6"},
       {"0.00021328012913252194`", 
        RowBox[{"-", "0.0006122393403105135`"}], 
        RowBox[{"-", "0.00004055979378110893`"}], "0.009747644181410534`", 
        "0.023391568964506382`", 
        RowBox[{"-", "0.0000453902325393756`"}], "0.02018713907667045`", 
        RowBox[{"-", "0.05868008622263388`"}], "0.000012777907721119081`", 
        RowBox[{"-", "3.4706578587251575`*^-6"}], 
        RowBox[{"-", "1.3786856776874253`*^-7"}], 
        RowBox[{"-", "0.000010071481471504246`"}], "0.00007010079436862616`", 
        "0.00011589750011756602`", "0.0001583364559797066`", 
        "0.0001142838336294021`", "0.0003061512647824945`", 
        "0.00030039213332258184`", "0.0003014805952130108`", 
        "0.00021870306843826764`", "1.929284745073401`*^-6", 
        "4.523756252115872`*^-6", "3.4978741467102035`*^-8", 
        RowBox[{"-", "6.941499221143584`*^-6"}], "0.00008037822910583146`", 
        RowBox[{"-", "0.00030057611041524584`"}], "0.0001501718153622223`", 
        "0.0001222782477402432`", "0.0003059770470018515`", 
        RowBox[{"-", "0.00006779716065884062`"}], 
        RowBox[{"-", "0.00003739581842853452`"}], "0.000010431716889589801`", 
        RowBox[{"-", "0.00019160093145430756`"}], 
        RowBox[{"-", "0.00008571284885073557`"}], 
        RowBox[{"-", "0.0000765448954802863`"}]},
       {
        RowBox[{"-", "0.0008081021541106482`"}], "0.0023432744461121054`", 
        "0.00007529338854252882`", "3.7735473911332544`*^-6", 
        RowBox[{"-", "0.00004539023265752955`"}], "0.00006447350378775571`", 
        "7.504694616916233`*^-6", "0.00011445403669972975`", 
        RowBox[{"-", "0.000028302243241661596`"}], "0.000026242697382047134`",
         "2.8171782030745945`*^-8", "2.229240308303362`*^-6", 
        RowBox[{"-", "0.00027971450298169105`"}], 
        RowBox[{"-", "0.00038879083254409906`"}], 
        RowBox[{"-", "0.0006365056624445235`"}], 
        RowBox[{"-", "0.0004243891650697551`"}], 
        RowBox[{"-", "0.0011714884336289971`"}], "0.00008829063136171723`", 
        RowBox[{"-", "0.00015746602714962905`"}], 
        RowBox[{"-", "0.00009609812265518083`"}], 
        RowBox[{"-", "0.000020213413648048585`"}], 
        RowBox[{"-", "0.000049146601347928504`"}], 
        RowBox[{"-", "4.6280845521521657`*^-7"}], "0.00007599147657966633`", 
        RowBox[{"-", "0.0004647386932469014`"}], 
        RowBox[{"-", "0.0002819490671646792`"}], 
        RowBox[{"-", "0.0005611759665579303`"}], 
        RowBox[{"-", "0.000499778463799731`"}], 
        RowBox[{"-", "0.0011717912799472578`"}], 
        RowBox[{"-", "4.6166503759297045`*^-6"}], 
        RowBox[{"-", "0.00001409062735094159`"}], "0.00010515680127333357`", 
        "0.0007783533065818176`", "0.00020448508913336328`", 
        RowBox[{"-", "0.00017960161162669177`"}]},
       {
        RowBox[{"-", "0.00003627988771753626`"}], "0.00010451235778421621`", 
        "7.011074116071886`*^-6", "0.010166598435515185`", 
        "0.020187139076656795`", "7.504694686104254`*^-6", 
        "0.021165445610844866`", 
        RowBox[{"-", "0.050687804570670035`"}], 
        RowBox[{"-", "1.9435262044424213`*^-6"}], "3.983646758490431`*^-7", 
        "3.9657994179112`*^-8", "1.6678581726189533`*^-6", 
        RowBox[{"-", "9.285518324537848`*^-6"}], 
        RowBox[{"-", "3.878999667922056`*^-6"}], 
        RowBox[{"-", "0.000026831088514715368`"}], 
        RowBox[{"-", "0.000019917256176398358`"}], 
        RowBox[{"-", "0.000052260225910754145`"}], 
        RowBox[{"-", "0.000049424203789065206`"}], 
        RowBox[{"-", "0.000050084523523199825`"}], 
        RowBox[{"-", "0.00003406020637732371`"}], 
        RowBox[{"-", "2.661272745475707`*^-7"}], 
        RowBox[{"-", "8.177097806862002`*^-7"}], 
        RowBox[{"-", "9.344954514507956`*^-10"}], "1.167755548552026`*^-6", 
        RowBox[{"-", "0.000014030019256644212`"}], "0.000046718985301052684`", 
        RowBox[{"-", "0.000025828089671819318`"}], 
        RowBox[{"-", "0.00002113333063293362`"}], 
        RowBox[{"-", "0.00005249918301458219`"}], "0.000011225793764599529`", 
        "6.288620229568954`*^-6", 
        RowBox[{"-", "2.400654110144881`*^-6"}], "0.00003134175226744522`", 
        "0.00001373509084916293`", "0.000013742619235907995`"},
       {
        RowBox[{"-", "0.0005380301835113694`"}], "0.0015446164928753713`", 
        "0.00010241495445206924`", 
        RowBox[{"-", "0.02443961942228936`"}], 
        RowBox[{"-", "0.058680086222645214`"}], "0.00011445403646620343`", 
        RowBox[{"-", "0.05068780457070259`"}], "0.14724459209299984`", 
        RowBox[{"-", "0.00003115562881885476`"}], "8.609631697275101`*^-6", 
        "3.3829280214778834`*^-7", "0.000024396205147694854`", 
        RowBox[{"-", "0.00017622177816158417`"}], 
        RowBox[{"-", "0.00028686329898477275`"}], 
        RowBox[{"-", "0.00039933245209004906`"}], 
        RowBox[{"-", "0.0002885771506445954`"}], 
        RowBox[{"-", "0.0007723637689663129`"}], 
        RowBox[{"-", "0.0007569987483216788`"}], 
        RowBox[{"-", "0.000760801571507797`"}], 
        RowBox[{"-", "0.0005529014415642857`"}], 
        RowBox[{"-", "4.823070281543271`*^-6"}], 
        RowBox[{"-", "0.000011400848793286097`"}], 
        RowBox[{"-", "8.758695729637982`*^-8"}], "0.00001746453011406649`", 
        RowBox[{"-", "0.00020279250013406424`"}], "0.0007581504035385774`", 
        RowBox[{"-", "0.00037897096436550256`"}], 
        RowBox[{"-", "0.0003085876311351563`"}], 
        RowBox[{"-", "0.0007720114049050793`"}], "0.00017110356932845017`", 
        "0.0000944435559756423`", 
        RowBox[{"-", "0.000026753170427777515`"}], "0.00048310785878194934`", 
        "0.00021595416910528097`", "0.00019258511992606002`"},
       {"0.00038156968298589305`", 
        RowBox[{"-", "0.0011047796699643491`"}], 
        RowBox[{"-", "0.00003379298078784118`"}], 
        RowBox[{"-", "9.138630131063613`*^-7"}], "0.000012777907578455968`", 
        RowBox[{"-", "0.00002830224245955238`"}], 
        RowBox[{"-", "1.943526137109132`*^-6"}], 
        RowBox[{"-", "0.00003115562842779104`"}], "0.4190374959433349`", 
        RowBox[{"-", "0.00001704244683147068`"}], "0.000024859983287006695`", 
        RowBox[{"-", "0.46060773412794176`"}], "0.0001304960884628737`", 
        "0.00018634698387403562`", "0.00030229559216520983`", 
        "0.0001942873695836691`", "0.0005533255360749953`", 
        RowBox[{"-", "0.00010675522453282325`"}], "0.00003381302821621091`", 
        "0.00002467797029741256`", "0.000010321650811599773`", 
        "0.000024352655076895072`", "2.048635644498121`*^-7", 
        RowBox[{"-", "0.000037696161350078155`"}], "0.00022329497229026275`", 
        "0.0001927553024727263`", "0.00026320685892330297`", 
        "0.00023512019642454995`", "0.0005528017407618331`", 
        "0.000013964173391401406`", "0.00001253058438132823`", 
        RowBox[{"-", "0.00006189651795770828`"}], 
        RowBox[{"-", "0.0003697389410002634`"}], 
        RowBox[{"-", "0.00009162904874492387`"}], "0.00011233016509301022`"},
       {
        RowBox[{"-", "0.0003898990519004586`"}], "0.001129933918893149`", 
        "0.00003449677834144429`", "1.3539979707727102`*^-7", 
        RowBox[{"-", "3.47065791644461`*^-6"}], "0.000026242697382563302`", 
        "3.983646419714759`*^-7", "8.609631811010531`*^-6", 
        RowBox[{"-", "0.00001704244720826172`"}], "0.000015009535471676187`", 
        "2.1585962891840606`*^-8", "2.2019620248619006`*^-6", 
        RowBox[{"-", "0.00013469527098268133`"}], 
        RowBox[{"-", "0.0001889108620060748`"}], 
        RowBox[{"-", "0.00030926877056189627`"}], 
        RowBox[{"-", "0.00020173896270642367`"}], 
        RowBox[{"-", "0.0005647658675384812`"}], "0.00009881917619495731`", 
        RowBox[{"-", "0.000036057664858917524`"}], 
        RowBox[{"-", "0.000021205379233276324`"}], 
        RowBox[{"-", "0.000010293177612929035`"}], 
        RowBox[{"-", "0.000024968139479305867`"}], 
        RowBox[{"-", "2.335554928777346`*^-7"}], "0.00003860038106967309`", 
        RowBox[{"-", "0.00022935605597380524`"}], 
        RowBox[{"-", "0.00019307109289493367`"}], 
        RowBox[{"-", "0.00026979882488764606`"}], 
        RowBox[{"-", "0.00024115436258992362`"}], 
        RowBox[{"-", "0.0005649922246184938`"}], 
        RowBox[{"-", "0.000012413382504416709`"}], 
        RowBox[{"-", "0.000013172702500936792`"}], "0.000059266131320198135`",
         "0.00037744703647423503`", "0.00009389770790401424`", 
        RowBox[{"-", "0.00010962632934479664`"}]},
       {"8.400418627455008`*^-8", 
        RowBox[{"-", "2.557947678101951`*^-7"}], 
        RowBox[{"-", "2.1983131794931105`*^-9"}], "2.61668831604692`*^-8", 
        RowBox[{"-", "1.3786856776059397`*^-7"}], "2.8171782066901927`*^-8", 
        "3.965799419066761`*^-8", "3.3829280213717883`*^-7", 
        "0.000024859983287135322`", "2.1585962909627196`*^-8", 
        "0.000011994260282039837`", 
        RowBox[{"-", "0.000030308327824928694`"}], "5.740855952938975`*^-8", 
        "7.211147026362621`*^-8", "6.643975757573065`*^-8", 
        "7.738681984201762`*^-8", "8.828873362959195`*^-8", 
        "8.100079402151016`*^-8", "6.079514520744884`*^-9", 
        RowBox[{"-", "5.7675075974031455`*^-8"}], 
        RowBox[{"-", "3.606199808817289`*^-10"}], "7.374022866411669`*^-9", 
        "4.981174416028752`*^-10", 
        RowBox[{"-", "1.1770326054788907`*^-8"}], "6.976493039482104`*^-8", 
        "9.854844348082056`*^-9", "6.725424895863008`*^-8", 
        "6.317487979880193`*^-8", "1.1851600087919797`*^-7", 
        RowBox[{"-", "1.549862026584314`*^-8"}], "1.3959842023686204`*^-8", 
        "2.9269618785897422`*^-8", 
        RowBox[{"-", "8.407202420643738`*^-8"}], 
        RowBox[{"-", "2.376693555404069`*^-8"}], 
        RowBox[{"-", "1.886427309699432`*^-8"}]},
       {"9.023117438353133`*^-6", 
        RowBox[{"-", "0.000027248696197600516`"}], 
        RowBox[{"-", "7.637650873194168`*^-7"}], "8.387369417280095`*^-7", 
        RowBox[{"-", "0.000010071481362197612`"}], "2.229240132765258`*^-6", 
        "1.6678581553638084`*^-6", "0.00002439620487278305`", 
        RowBox[{"-", "0.46060773412785655`"}], "2.2019619489239663`*^-6", 
        RowBox[{"-", "0.00003030832782487714`"}], "0.5063262064909088`", 
        "4.5450944422486125`*^-6", "2.7658774230285243`*^-6", 
        "7.554910692486393`*^-6", "8.071583458853148`*^-6", 
        "0.000012399885270710871`", "8.59680042394151`*^-6", 
        "2.4357164631528445`*^-6", 
        RowBox[{"-", "3.7561772512944366`*^-6"}], 
        RowBox[{"-", "3.0826695813679484`*^-8"}], "6.664564023168593`*^-7", 
        "3.1029640677466585`*^-8", 
        RowBox[{"-", "9.7887009524885`*^-7"}], "6.5636631936297946`*^-6", 
        "3.4041149870028973`*^-7", "7.140787263031644`*^-6", 
        "6.536077912249294`*^-6", "0.00001320687042814243`", 
        RowBox[{"-", "1.679991106531716`*^-6"}], "6.937345861619014`*^-7", 
        "2.8487887064391536`*^-6", 
        RowBox[{"-", "8.34848306021979`*^-6"}], 
        RowBox[{"-", "2.457384272698138`*^-6"}], 
        RowBox[{"-", "2.9311341491362104`*^-6"}]},
       {
        RowBox[{"-", "0.0004169641297251947`"}], 
        RowBox[{"-", "0.05085954847203988`"}], "0.059765830740839195`", 
        RowBox[{"-", "3.601174396133163`*^-6"}], "0.00007010080144268524`", 
        RowBox[{"-", "0.0002797145032515752`"}], 
        RowBox[{"-", "9.28551244644242`*^-6"}], 
        RowBox[{"-", "0.00017622179173808986`"}], "0.0001304961477567798`", 
        RowBox[{"-", "0.00013469527108042297`"}], "5.7408559986761934`*^-8", 
        "4.545113762219159`*^-6", "0.0388359541325882`", 
        "0.008484884291013822`", "0.012990052635621537`", 
        "0.042798546667602994`", "0.02543162695245558`", 
        RowBox[{"-", "0.0009007588161339675`"}], "0.0004874630025418188`", 
        "0.0002697436943623288`", "0.00011472498730581617`", 
        "0.0002769342818174179`", "2.6420173974790257`*^-6", 
        RowBox[{"-", "0.00042947461289793293`"}], "0.04306512647083946`", 
        "0.008384484240913589`", "0.012578635322573492`", 
        "0.04321017622050084`", "0.02543172508677464`", 
        "0.00010466199794408894`", "0.00013191504964629123`", 
        RowBox[{"-", "0.0006071154386415893`"}], 
        RowBox[{"-", "0.016958448591226756`"}], 
        RowBox[{"-", "0.004247745924728695`"}], "0.0011170852996727695`"},
       {"0.006960486093024652`", 
        RowBox[{"-", "0.02827982503746867`"}], "0.00833590366354086`", 
        "4.965459465507962`*^-6", "0.00011589750226171378`", 
        RowBox[{"-", "0.00038879083258806736`"}], 
        RowBox[{"-", "3.878998141194825`*^-6"}], 
        RowBox[{"-", "0.0002868633031611629`"}], "0.00018634700008732274`", 
        RowBox[{"-", "0.00018891086201773392`"}], "7.211147065518423`*^-8", 
        "2.765878731588421`*^-6", "0.008484884288812545`", 
        "0.004779546553392228`", "0.007451186832583755`", 
        "0.01044966507185404`", "0.014141029340108054`", 
        RowBox[{"-", "0.0012752502549593365`"}], "0.0006769878991412545`", 
        "0.00039081683947325544`", "0.00015774711280928727`", 
        "0.0003822352400977367`", "3.6623510320499683`*^-6", 
        RowBox[{"-", "0.0005920792609589124`"}], "0.010820888083025955`", 
        "0.0045838115547894055`", "0.0068797090467869184`", 
        "0.011020811173969504`", "0.0141404354123843`", 
        "0.00014909591234348865`", "0.00018235526952740076`", 
        RowBox[{"-", "0.000856322809048223`"}], 
        RowBox[{"-", "0.009436879167033362`"}], 
        RowBox[{"-", "0.002371839732346839`"}], "0.0015704354658294113`"},
       {"0.011243774200702716`", 
        RowBox[{"-", "0.044751972931304264`"}], "0.012433764764861504`", 
        RowBox[{"-", "0.000013736273560562527`"}], "0.00015833645931518682`", 
        RowBox[{"-", "0.0006365056625116065`"}], 
        RowBox[{"-", "0.000026831086154551105`"}], 
        RowBox[{"-", "0.0003993324585899226`"}], "0.00030229561726736174`", 
        RowBox[{"-", "0.00030926877057940944`"}], "6.643975819921148`*^-8", 
        "7.554912495554705`*^-6", "0.01299005263212627`", 
        "0.007451186832561571`", "0.01181147251554114`", 
        "0.016098465933830235`", "0.022377678928970975`", 
        RowBox[{"-", "0.002092792138033854`"}], "0.0011067573426930457`", 
        "0.000627845741433317`", "0.00025721004086268987`", 
        "0.0006243159460203821`", "5.95116385759948`*^-6", 
        RowBox[{"-", "0.0009665578208675678`"}], "0.01670474342812547`", 
        "0.007264277791595072`", "0.010878222530918262`", 
        "0.017032050650430026`", "0.022378184772806405`", 
        "0.00024430713828226674`", "0.00029707905408819053`", 
        RowBox[{"-", "0.0013976059753741076`"}], 
        RowBox[{"-", "0.014925441545539927`"}], 
        RowBox[{"-", "0.003748601563704602`"}], "0.0025625162839358227`"},
       {"0.002284951114935754`", 
        RowBox[{"-", "0.06274104331341458`"}], "0.06399814901487519`", 
        RowBox[{"-", "0.000010396344310524726`"}], "0.00011428384165972907`", 
        RowBox[{"-", "0.0004243891653606343`"}], 
        RowBox[{"-", "0.000019917249603074692`"}], 
        RowBox[{"-", "0.00028857716608129014`"}], "0.00019428743622870118`", 
        RowBox[{"-", "0.00020173896281002715`"}], "7.738682045936411`*^-8", 
        "8.07160358089979`*^-6", "0.04279854666670528`", 
        "0.01044966507408032`", "0.016098465937374205`", 
        "0.0476168528352784`", "0.03137300064334816`", 
        RowBox[{"-", "0.0013384975266275915`"}], "0.0007632458514274867`", 
        "0.0004252829923464411`", "0.00017268224048368197`", 
        "0.0004178558724706148`", "3.987445477263701`*^-6", 
        RowBox[{"-", "0.0006476148988970075`"}], "0.04801375098629998`", 
        "0.010286957816871528`", "0.01547951641013392`", 
        "0.048236447670559034`", "0.03137314675230937`", 
        "0.00015326360608720413`", "0.0001952056699200174`", 
        RowBox[{"-", "0.0009170704068889313`"}], 
        RowBox[{"-", "0.020918087261181263`"}], 
        RowBox[{"-", "0.005244752497886657`"}], "0.0016813435081319758`"},
       {"0.020915671698492545`", 
        RowBox[{"-", "0.08494163131402147`"}], "0.02499979212768065`", 
        RowBox[{"-", "0.00002689203445633507`"}], "0.000306151271219704`", 
        RowBox[{"-", "0.0011714884337611089`"}], 
        RowBox[{"-", "0.00005226022132788326`"}], 
        RowBox[{"-", "0.0007723637815055416`"}], "0.0005533255847517821`", 
        RowBox[{"-", "0.0005647658675735296`"}], "8.828873480502993`*^-8", 
        "0.000012399889179826734`", "0.025431626945864472`", 
        "0.014141029340111784`", "0.022377678929043292`", 
        "0.03137300063668377`", "0.04247438881931434`", 
        RowBox[{"-", "0.003799123746177153`"}], "0.0020696431658976215`", 
        "0.0011751883888038574`", "0.00047279217513333804`", 
        "0.0011477619747714725`", "0.00001094835239242754`", 
        RowBox[{"-", "0.0017769815403144784`"}], "0.032478676471946126`", 
        "0.013750476338027773`", "0.020666358999574207`", 
        "0.033085528479028764`", "0.042474898443384285`", 
        "0.000440321018079472`", "0.0005410394085838986`", 
        RowBox[{"-", "0.0025622684902374786`"}], 
        RowBox[{"-", "0.028326954340912314`"}], 
        RowBox[{"-", "0.007117943318714549`"}], "0.004692111251811373`"},
       {
        RowBox[{"-", "0.0026251375203056914`"}], "0.007600270014263369`", 
        "0.0001996681544266647`", 
        RowBox[{"-", "0.000024700537292823518`"}], "0.00030039213291925944`", 
        "0.0000882906313799653`", 
        RowBox[{"-", "0.00004942420402635815`"}], 
        RowBox[{"-", "0.0007569987475334605`"}], 
        RowBox[{"-", "0.00010675522706997113`"}], "0.0000988191762021596`", 
        "8.100079389488561`*^-8", "8.596800787168601`*^-6", 
        RowBox[{"-", "0.0009007588163938793`"}], 
        RowBox[{"-", "0.0012752502551537771`"}], 
        RowBox[{"-", "0.0020927921383401106`"}], 
        RowBox[{"-", "0.0013384975269700324`"}], 
        RowBox[{"-", "0.0037991237467603625`"}], "0.002649096908419246`", 
        "0.0012739428588277022`", "0.0004305429307049688`", 
        RowBox[{"-", "0.00007790191105079656`"}], 
        RowBox[{"-", "0.00019034455021671708`"}], 
        RowBox[{"-", "1.8233100580403347`*^-6"}], "0.00029395974964366604`", 
        RowBox[{"-", "0.0016382648434577942`"}], 
        RowBox[{"-", "0.0024416660637642243`"}], 
        RowBox[{"-", "0.0018028489490864684`"}], 
        RowBox[{"-", "0.0016276612533889085`"}], 
        RowBox[{"-", "0.0037984841119523332`"}], "0.00009060174171050848`", 
        RowBox[{"-", "0.0002008730950389118`"}], "0.0006797425307083116`", 
        "0.002539957762092247`", "0.0005088918750884131`", 
        RowBox[{"-", "0.0015783627392950668`"}]},
       {"0.00142994375232487`", 
        RowBox[{"-", "0.004139910132677512`"}], 
        RowBox[{"-", "0.00016834803792495164`"}], 
        RowBox[{"-", "0.000025246357478957848`"}], "0.00030148059541030203`", 
        RowBox[{"-", "0.00015746602713912215`"}], 
        RowBox[{"-", "0.000050084523408237965`"}], 
        RowBox[{"-", "0.0007608015719026535`"}], "0.00003381302958615718`", 
        RowBox[{"-", "0.00003605766485287543`"}], "6.07951457996499`*^-9", 
        "2.435716051514211`*^-6", "0.00048746300145178145`", 
        "0.0006769878988755619`", "0.0011067573422819704`", 
        "0.0007632458502166395`", "0.002069643165099874`", 
        "0.0012739428588947029`", "0.0018028523660732383`", 
        "0.0007343454862525947`", "0.00002920976464827529`", 
        "0.00007180875577238199`", "6.782568899865085`*^-7", 
        RowBox[{"-", "0.00011077570036544524`"}], "0.0007496977356620102`", 
        RowBox[{"-", "0.00017742600628718654`"}], "0.000999262312184688`", 
        "0.0008711122708418969`", "0.002070171284913597`", 
        "0.00040054780321880653`", 
        RowBox[{"-", "0.00004959960651386444`"}], 
        RowBox[{"-", "0.00008961455074391587`"}], 
        RowBox[{"-", "0.0013503135206969885`"}], 
        RowBox[{"-", "0.000416265416106534`"}], 
        RowBox[{"-", "0.00019417154442139645`"}]},
       {"0.0008165133726931822`", 
        RowBox[{"-", "0.0023518157610932433`"}], 
        RowBox[{"-", "0.00011112867885105917`"}], 
        RowBox[{"-", "0.000016026113507808972`"}], "0.0002187030685486861`", 
        RowBox[{"-", "0.00009609812265043167`"}], 
        RowBox[{"-", "0.00003406020631397446`"}], 
        RowBox[{"-", "0.000552901441785091`"}], "0.000024677971065972717`", 
        RowBox[{"-", "0.00002120537923047028`"}], 
        RowBox[{"-", "5.767507594051129`*^-8"}], 
        RowBox[{"-", "3.7561775064169774`*^-6"}], "0.00026974369381271607`", 
        "0.00039081683934420714`", "0.0006278457412339109`", 
        "0.00042528299173788325`", "0.0011751883884163746`", 
        "0.0004305429307378992`", "0.0007343454862541027`", 
        "0.00046980720857243367`", "0.000015680336667512186`", 
        "0.00003913950163665343`", "3.7025174792084727`*^-7", 
        RowBox[{"-", "0.00006004960418240401`"}], "0.0004108102880416944`", 
        RowBox[{"-", "0.0002116039789062868`"}], "0.0005674967123254518`", 
        "0.0004856278726050071`", "0.0011752490594522695`", 
        "0.00006209735587235567`", 
        RowBox[{"-", "0.00003575324178330756`"}], 
        RowBox[{"-", "0.00008743294825275353`"}], 
        RowBox[{"-", "0.0007861726511645853`"}], 
        RowBox[{"-", "0.00024828172440997704`"}], "0.00005371876106381572`"},
       {"0.0003251470164098104`", 
        RowBox[{"-", "0.0009453363979545121`"}], 
        RowBox[{"-", "0.00002569768621815796`"}], 
        RowBox[{"-", "1.1442997561235158`*^-7"}], "1.929284793666407`*^-6", 
        RowBox[{"-", "0.00002021341364847834`"}], 
        RowBox[{"-", "2.661272458053237`*^-7"}], 
        RowBox[{"-", "4.82307037698403`*^-6"}], "0.000010321651128877685`", 
        RowBox[{"-", "0.000010293177612926782`"}], 
        RowBox[{"-", "3.606199660516709`*^-10"}], 
        RowBox[{"-", "3.082675731096629`*^-8"}], "0.00011472498722276889`", 
        "0.00015774711279931315`", "0.0002572100408476943`", 
        "0.0001726822403956232`", "0.00047279217510334115`", 
        RowBox[{"-", "0.00007790191104471188`"}], "0.000029209764653357394`", 
        "0.000015680336669872277`", "0.00011190875306929872`", 
        "0.000020914521438206114`", "6.091626029978326`*^-7", 
        RowBox[{"-", "0.00014545602561886768`"}], "0.00019396744372706667`", 
        "0.0001612230251161255`", "0.0002259977994802239`", 
        "0.00020388993944675608`", "0.00047279336106485667`", 
        "9.719626752504296`*^-6", "0.000010994285402654536`", 
        RowBox[{"-", "0.000047057924478366724`"}], 
        RowBox[{"-", "0.0003158279859013986`"}], 
        RowBox[{"-", "0.00007860435405700135`"}], "0.0000878363767501928`"},
       {"0.0007901436844766197`", 
        RowBox[{"-", "0.0022951997834468503`"}], 
        RowBox[{"-", "0.00006488724848418168`"}], 
        RowBox[{"-", "4.373249188891669`*^-7"}], "4.523756369880259`*^-6", 
        RowBox[{"-", "0.00004914660134893512`"}], 
        RowBox[{"-", "8.177097113692521`*^-7"}], 
        RowBox[{"-", "0.000011400849025277823`"}], "0.000024352655846986352`", 
        RowBox[{"-", "0.000024968139479284136`"}], "7.374022902461219`*^-9", 
        "6.664562506797844`*^-7", "0.0002769342816145731`", 
        "0.00038223524007303`", "0.0006243159459832074`", 
        "0.0004178558722553996`", "0.0011477619746971784`", 
        RowBox[{"-", "0.00019034455020186509`"}], "0.00007180875578462924`", 
        "0.00003913950164233617`", "0.00002091452143819191`", 
        "0.000050729002463433545`", "4.840395064945483`*^-7", 
        RowBox[{"-", "0.0000785586170255096`"}], "0.00046936901843544856`", 
        "0.00039094928413024806`", "0.0005486638883666601`", 
        "0.0004935530141981173`", "0.001147793839864027`", 
        "0.000023707487519050332`", "0.000026550540593782868`", 
        RowBox[{"-", "0.000115080167316041`"}], 
        RowBox[{"-", "0.0007665980341301695`"}], 
        RowBox[{"-", "0.00019083386533060468`"}], "0.0002143404961583653`"},
       {"7.539043015790977`*^-6", 
        RowBox[{"-", "0.000021894784009574774`"}], 
        RowBox[{"-", "6.23406867732158`*^-7"}], "1.3198692845573992`*^-9", 
        "3.49787425899134`*^-8", 
        RowBox[{"-", "4.6280845522492373`*^-7"}], 
        RowBox[{"-", "9.344947891507843`*^-10"}], 
        RowBox[{"-", "8.758695950771328`*^-8"}], "2.0486357179862335`*^-7", 
        RowBox[{"-", "2.3355549287757657`*^-7"}], "4.981174419466762`*^-10", 
        "3.102963922753957`*^-8", "2.6420173955527982`*^-6", 
        "3.662351031816547`*^-6", "5.951163857248388`*^-6", 
        "3.987445475220502`*^-6", "0.000010948352391725611`", 
        RowBox[{"-", "1.8233100578991337`*^-6"}], "6.782568901034685`*^-7", 
        "3.702517479751289`*^-7", "6.091626029977435`*^-7", 
        "4.840395064946604`*^-7", "1.1512464264736193`*^-6", 
        RowBox[{"-", "1.8583267593108004`*^-6"}], "4.4757349154066875`*^-6", 
        "3.7341682321720435`*^-6", "5.2337840077694836`*^-6", 
        "4.705040474592739`*^-6", "0.000010947084532520236`", 
        "2.2759297356842017`*^-7", "2.5478654414731383`*^-7", 
        RowBox[{"-", "1.0998060155081236`*^-6"}], 
        RowBox[{"-", "7.31514931601347`*^-6"}], 
        RowBox[{"-", "1.8205399541677012`*^-6"}], "2.0502900741092447`*^-6"},
       {
        RowBox[{"-", "0.001222944925446511`"}], "0.003553343889283975`", 
        "0.00009933957194022529`", "5.95180930667926`*^-7", 
        RowBox[{"-", "6.9414994035591154`*^-6"}], "0.00007599147658124045`", 
        "1.1677554410266262`*^-6", "0.00001746453047310329`", 
        RowBox[{"-", "0.00003769616254245203`"}], "0.00003860038106964557`", 
        RowBox[{"-", "1.1770326110581604`*^-8"}], 
        RowBox[{"-", "9.788698615823444`*^-7"}], 
        RowBox[{"-", "0.0004294746125843858`"}], 
        RowBox[{"-", "0.0005920792609208648`"}], 
        RowBox[{"-", "0.0009665578208103372`"}], 
        RowBox[{"-", "0.0006476148985643951`"}], 
        RowBox[{"-", "0.0017769815402000637`"}], "0.00029395974962070714`", 
        RowBox[{"-", "0.00011077570038444556`"}], 
        RowBox[{"-", "0.00006004960419122221`"}], 
        RowBox[{"-", "0.0001454560256188518`"}], 
        RowBox[{"-", "0.00007855861702552426`"}], 
        RowBox[{"-", "1.8583267593107656`*^-6"}], "0.0002487973714379424`", 
        RowBox[{"-", "0.000727374261256699`"}], 
        RowBox[{"-", "0.0006054169287875524`"}], 
        RowBox[{"-", "0.0008494518104497899`"}], 
        RowBox[{"-", "0.000764773896659565`"}], 
        RowBox[{"-", "0.0017770131812403097`"}], 
        RowBox[{"-", "0.00003662331135072391`"}], 
        RowBox[{"-", "0.00004116752151392988`"}], "0.00017771019780309864`", 
        "0.0011869030635247167`", "0.000295449781004202`", 
        RowBox[{"-", "0.0003312285126100701`"}]},
       {"0.0030467012563084733`", 
        RowBox[{"-", "0.06495257754651572`"}], "0.06393957032506263`", 
        RowBox[{"-", "7.332351708152704`*^-6"}], "0.00008037823725119035`", 
        RowBox[{"-", "0.0004647386935398188`"}], 
        RowBox[{"-", "0.000014030012615434684`"}], 
        RowBox[{"-", "0.00020279251579665824`"}], "0.0002232950396767908`", 
        RowBox[{"-", "0.00022935605607792746`"}], "6.976493104786721`*^-8", 
        "6.5636831876889415`*^-6", "0.04306512646981307`", 
        "0.010820888085248124`", "0.016704743431664223`", 
        "0.048013750986168176`", "0.032478676478598006`", 
        RowBox[{"-", "0.001638264843104335`"}], "0.0007496977368866694`", 
        "0.0004108102886567895`", "0.00019396744381555524`", 
        "0.00046936901865169897`", "4.475734917459795`*^-6", 
        RowBox[{"-", "0.0007273742615909202`"}], "0.04847704196299602`", 
        "0.010782062760808966`", "0.01600654006323184`", 
        "0.048712476060897784`", "0.03247900432238548`", 
        "0.00019719276700047562`", "0.00023398638118980828`", 
        RowBox[{"-", "0.0010455547658599663`"}], 
        RowBox[{"-", "0.02166114026523617`"}], 
        RowBox[{"-", "0.005418874714113146`"}], "0.0019353437466943305`"},
       {"0.006688751328809731`", 
        RowBox[{"-", "0.027498619364807176`"}], "0.008412753792758127`", 
        "0.000022143796811227752`", 
        RowBox[{"-", "0.00030057610829374777`"}], 
        RowBox[{"-", "0.0002819490672196535`"}], "0.00004671898681676053`", 
        "0.0007581503994130902`", "0.00019275531843733994`", 
        RowBox[{"-", "0.0001930710929120601`"}], "9.854844734203706`*^-9", 
        "3.404130467614397`*^-7", "0.008384484239499109`", 
        "0.004583811555008749`", "0.007264277791957543`", 
        "0.010286957815530736`", "0.013750476338682446`", 
        RowBox[{"-", "0.002441666063609802`"}], 
        RowBox[{"-", "0.000177426006004084`"}], 
        RowBox[{"-", "0.00021160397876776734`"}], "0.00016122302513071375`", 
        "0.0003909492841661262`", "3.734168232511938`*^-6", 
        RowBox[{"-", "0.000605416928842904`"}], "0.010782062759483398`", 
        "0.0057579123378506715`", "0.006680311833001081`", 
        "0.010870978192608923`", "0.013750293859015151`", 
        "0.0003554623977037502`", "0.0003020713098585324`", 
        RowBox[{"-", "0.00098545914373152`"}], 
        RowBox[{"-", "0.009162766193779525`"}], 
        RowBox[{"-", "0.002185383006652675`"}], "0.0019605532395164933`"},
       {"0.010064663323787389`", 
        RowBox[{"-", "0.04132962017593203`"}], "0.012532987915090804`", 
        RowBox[{"-", "0.000013359935168928087`"}], "0.000150171818522359`", 
        RowBox[{"-", "0.0005611759666234784`"}], 
        RowBox[{"-", "0.00002582808741476844`"}], 
        RowBox[{"-", "0.0003789709705199315`"}], "0.0002632068828795466`", 
        RowBox[{"-", "0.0002697988249051649`"}], "6.725424952808579`*^-8", 
        "7.140789293390293`*^-6", "0.01257863531937818`", 
        "0.006879709046800931`", "0.010878222530972677`", 
        "0.015479516406908067`", "0.02066635899961073`", 
        RowBox[{"-", "0.0018028489488022149`"}], "0.000999262312577476`", 
        "0.0005674967125163675`", "0.00022599779949522558`", 
        "0.0005486638884038136`", "5.233784008120437`*^-6", 
        RowBox[{"-", "0.0008494518105069942`"}], "0.01600654006001274`", 
        "0.006680311832691432`", "0.01006048776407168`", 
        "0.016297979120217042`", "0.020666822000135174`", 
        "0.00020803814891595803`", "0.00025728674668550446`", 
        RowBox[{"-", "0.001222998351550781`"}], 
        RowBox[{"-", "0.013782192710011987`"}], 
        RowBox[{"-", "0.0034641074910549824`"}], "0.0022380579709016376`"},
       {"0.0034649938513127195`", 
        RowBox[{"-", "0.06616617701575406`"}], "0.06389876498804938`", 
        RowBox[{"-", "0.00001096906902648331`"}], "0.00012227825594604948`", 
        RowBox[{"-", "0.0004997784640921319`"}], 
        RowBox[{"-", "0.000021133323956410745`"}], 
        RowBox[{"-", "0.0003085876469175689`"}], "0.00023512026421647456`", 
        RowBox[{"-", "0.00024115436269351578`"}], "6.317488047123156`*^-8", 
        "6.536097806719883`*^-6", "0.04321017621930237`", 
        "0.011020811176159344`", "0.01703205065391919`", 
        "0.04823644767024001`", "0.033085528485583555`", 
        RowBox[{"-", "0.001627661253024399`"}], "0.0008711122720710205`", 
        "0.00048562787322204364`", "0.0002038899395348081`", 
        "0.0004935530144133393`", "4.7050404766359554`*^-6", 
        RowBox[{"-", "0.0007647738969921861`"}], "0.04871247606070901`", 
        "0.010870978193896633`", "0.016297979123388106`", 
        "0.04897115504734685`", "0.033085932816791626`", 
        "0.00018938447611066924`", "0.0002349289130147399`", 
        RowBox[{"-", "0.0010914167055251622`"}], 
        RowBox[{"-", "0.02206213233178549`"}], 
        RowBox[{"-", "0.005529484071121242`"}], "0.002005310333635126`"},
       {"0.02091627403645503`", 
        RowBox[{"-", "0.08494341914705976`"}], "0.02499967290062737`", 
        RowBox[{"-", "0.000027111254880115947`"}], "0.00030597705343915135`", 
        RowBox[{"-", "0.0011717912800793767`"}], 
        RowBox[{"-", "0.00005249917843165933`"}], 
        RowBox[{"-", "0.0007720114174444908`"}], "0.0005528017894392582`", 
        RowBox[{"-", "0.0005649922246535643`"}], "1.1851600205435922`*^-7", 
        "0.00001320687433704719`", "0.02543172508018327`", 
        "0.014140435412387986`", "0.02237818477287865`", 
        "0.03137314674564466`", "0.042474898443384104`", 
        RowBox[{"-", "0.0037984841113691045`"}], "0.0020701712857113617`", 
        "0.0011752490598397562`", "0.00047279336109485454`", 
        "0.0011477938399383075`", "0.000010947084533222153`", 
        RowBox[{"-", "0.0017770131813547186`"}], "0.03247900431573329`", 
        "0.013750293858360412`", "0.02066682200009858`", 
        "0.03308593281023653`", "0.04247585439030649`", 
        "0.0004401830831108331`", "0.0005409947845125031`", 
        RowBox[{"-", "0.002562127641389732`"}], 
        RowBox[{"-", "0.028327389084877145`"}], 
        RowBox[{"-", "0.007118096250729029`"}], "0.00469183985070294`"},
       {"0.0003042938753612323`", 
        RowBox[{"-", "0.0008808931856385759`"}], 
        RowBox[{"-", "0.000020117076338182605`"}], "5.611572538444915`*^-6", 
        RowBox[{"-", "0.00006779716061176654`"}], 
        RowBox[{"-", "4.61665037609564`*^-6"}], "0.000011225793792929176`", 
        "0.00017110356923651578`", "0.0000139641736837482`", 
        RowBox[{"-", "0.000012413382504268949`"}], 
        RowBox[{"-", "1.5498620251211943`*^-8"}], 
        RowBox[{"-", "1.679991132037413`*^-6"}], "0.00010466199787571211`", 
        "0.00014909591233323443`", "0.0002443071382665556`", 
        "0.00015326360601396834`", "0.0004403210180486265`", 
        "0.00009060174171801`", "0.00040054780322374876`", 
        "0.00006209735587462266`", "9.719626752382638`*^-6", 
        "0.0000237074875187717`", "2.2759297356570734`*^-7", 
        RowBox[{"-", "0.000036623311350285273`"}], "0.00019719276692650072`", 
        "0.00035546239768858835`", "0.00020803814890067702`", 
        "0.00018938447603700898`", "0.0004401830830799887`", 
        "0.0003072430583193676`", "0.0000315042196469451`", 
        RowBox[{"-", "0.00008145884282478565`"}], 
        RowBox[{"-", "0.0002997688355045686`"}], 
        RowBox[{"-", "0.0000504025348517321`"}], "0.00004656885828305008`"},
       {"0.000371940582266421`", 
        RowBox[{"-", "0.0010818592562276395`"}], 
        RowBox[{"-", "0.00002409063828335684`"}], "3.200822675166837`*^-6", 
        RowBox[{"-", "0.00003739581837120494`"}], 
        RowBox[{"-", "0.000014090627352461564`"}], "6.288620263575614`*^-6", 
        "0.00009444355586344211`", "0.000012530584746102268`", 
        RowBox[{"-", "0.000013172702501429057`"}], "1.3959842041373334`*^-8", 
        "6.937345341213001`*^-7", "0.00013191504961538903`", 
        "0.00018235526953496334`", "0.0002970790541005141`", 
        "0.0001952056698918753`", "0.0005410394086065354`", 
        RowBox[{"-", "0.00020087309503509886`"}], 
        RowBox[{"-", "0.00004959960650608503`"}], 
        RowBox[{"-", "0.00003575324177956987`"}], "0.000010994285403071602`", 
        "0.000026550540594809716`", "2.5478654415704846`*^-7", 
        RowBox[{"-", "0.000041167521515513494`"}], "0.00023398638116215676`", 
        "0.00030207130986046026`", "0.00025728674669631303`", 
        "0.00023492891298811404`", "0.0005409947845351357`", 
        "0.000031504219647536584`", "0.00002563261574377719`", 
        RowBox[{"-", "0.00006918949736290142`"}], 
        RowBox[{"-", "0.00036569176402250197`"}], 
        RowBox[{"-", "0.00008024648410123435`"}], "0.0001443652138764626`"},
       {
        RowBox[{"-", "0.001770332249007329`"}], "0.005125660907500588`", 
        "0.0001590848562690509`", 
        RowBox[{"-", "1.3991308225411322`*^-6"}], "0.000010431716626788492`", 
        "0.00010515680127730626`", 
        RowBox[{"-", "2.400654264225863`*^-6"}], 
        RowBox[{"-", "0.00002675316991055884`"}], 
        RowBox[{"-", "0.00006189651966400476`"}], "0.00005926613132099718`", 
        "2.9269618704569193`*^-8", "2.8487890410367834`*^-6", 
        RowBox[{"-", "0.0006071154383098917`"}], 
        RowBox[{"-", "0.0008563228090271409`"}], 
        RowBox[{"-", "0.0013976059753439845`"}], 
        RowBox[{"-", "0.0009170704065449611`"}], 
        RowBox[{"-", "0.002562268490173904`"}], "0.0006797425306810845`", 
        RowBox[{"-", "0.00008961455077417427`"}], 
        RowBox[{"-", "0.00008743294826700756`"}], 
        RowBox[{"-", "0.000047057924479049825`"}], 
        RowBox[{"-", "0.00011508016731777144`"}], 
        RowBox[{"-", "1.0998060155243735`*^-6"}], "0.0001777101978057475`", 
        RowBox[{"-", "0.001045554765515359`"}], 
        RowBox[{"-", "0.000985459143685298`"}], 
        RowBox[{"-", "0.0012229983515181517`"}], 
        RowBox[{"-", "0.0010914167051837298`"}], 
        RowBox[{"-", "0.0025621276413261796`"}], 
        RowBox[{"-", "0.00008145884282616771`"}], 
        RowBox[{"-", "0.00006918949736146299`"}], "0.0003407526597529044`", 
        "0.0017128994950579527`", "0.0004067017634036417`", 
        RowBox[{"-", "0.0006247074374532539`"}]},
       {
        RowBox[{"-", "0.013951339899466692`"}], "0.05664962917749178`", 
        RowBox[{"-", "0.016667855606971642`"}], "0.000015566696847341827`", 
        RowBox[{"-", "0.00019160093574749956`"}], "0.0007783533066700477`", 
        "0.00003134174921113654`", "0.0004831078671441707`", 
        RowBox[{"-", "0.0003697389734584485`"}], "0.00037744703649766334`", 
        RowBox[{"-", "8.407202499167814`*^-8"}], 
        RowBox[{"-", "8.348485671393763`*^-6"}], 
        RowBox[{"-", "0.016958448586836726`"}], 
        RowBox[{"-", "0.009436879167037813`"}], 
        RowBox[{"-", "0.014925441545591214`"}], 
        RowBox[{"-", "0.020918087256743222`"}], 
        RowBox[{"-", "0.02832695434091818`"}], "0.002539957761703733`", 
        RowBox[{"-", "0.0013503135212292105`"}], 
        RowBox[{"-", "0.0007861726514231028`"}], 
        RowBox[{"-", "0.000315827985921455`"}], 
        RowBox[{"-", "0.0007665980341798433`"}], 
        RowBox[{"-", "7.315149316482749`*^-6"}], "0.0011869030636012085`", 
        RowBox[{"-", "0.02166114026080658`"}], 
        RowBox[{"-", "0.009162766193344874`"}], 
        RowBox[{"-", "0.013782192709990511`"}], 
        RowBox[{"-", "0.022062132327420724`"}], 
        RowBox[{"-", "0.028327389084883123`"}], 
        RowBox[{"-", "0.00029976883552519564`"}], 
        RowBox[{"-", "0.00036569176400746755`"}], "0.0017128994951006171`", 
        "0.018917481047237346`", "0.004747839085213857`", 
        RowBox[{"-", "0.00313946242449638`"}]},
       {
        RowBox[{"-", "0.003512993310973431`"}], "0.014234834531948478`", 
        RowBox[{"-", "0.004159752614893078`"}], "6.6826821273336095`*^-6", 
        RowBox[{"-", "0.00008571284992612129`"}], "0.00020448508915428816`", 
        "0.000013735090084047172`", "0.00021595417120063697`", 
        RowBox[{"-", "0.00009162905688283592`"}], "0.00009389770790931042`", 
        RowBox[{"-", "2.376693575048528`*^-8"}], 
        RowBox[{"-", "2.457384903280452`*^-6"}], 
        RowBox[{"-", "0.004247745923550449`"}], 
        RowBox[{"-", "0.0023718397323253945`"}], 
        RowBox[{"-", "0.0037486015636824274`"}], 
        RowBox[{"-", "0.005244752496686268`"}], 
        RowBox[{"-", "0.0071179433186483055`"}], "0.0005088918749871483`", 
        RowBox[{"-", "0.00041626541623781405`"}], 
        RowBox[{"-", "0.0002482817244736388`"}], 
        RowBox[{"-", "0.00007860435406153998`"}], 
        RowBox[{"-", "0.0001908338653418707`"}], 
        RowBox[{"-", "1.8205399542740597`*^-6"}], "0.0002954497810215427`", 
        RowBox[{"-", "0.005418874712913725`"}], 
        RowBox[{"-", "0.002185383006521448`"}], 
        RowBox[{"-", "0.003464107491016328`"}], 
        RowBox[{"-", "0.005529484069937449`"}], 
        RowBox[{"-", "0.007118096250662817`"}], 
        RowBox[{"-", "0.00005040253485638879`"}], 
        RowBox[{"-", "0.0000802464840968948`"}], "0.000406701763411719`", 
        "0.004747839085168702`", "0.0012132383651050282`", 
        RowBox[{"-", "0.0007376375654396001`"}]},
       {"0.0032391685499692045`", 
        RowBox[{"-", "0.00938564738109336`"}], 
        RowBox[{"-", "0.0002769370345569716`"}], "7.411766873464227`*^-6", 
        RowBox[{"-", "0.00007654489499582886`"}], 
        RowBox[{"-", "0.00017960161163635275`"}], "0.000013742619520311534`", 
        "0.0001925851189738025`", "0.000112330168225172`", 
        RowBox[{"-", "0.00010962632934742396`"}], 
        RowBox[{"-", "1.8864272946869263`*^-8"}], 
        RowBox[{"-", "2.931134734946144`*^-6"}], "0.0011170852992004013`", 
        "0.0015704354658328786`", "0.0025625162839461577`", 
        "0.0016813435076557912`", "0.004692111251821249`", 
        RowBox[{"-", "0.0015783627392531292`"}], 
        RowBox[{"-", "0.0001941715443617854`"}], "0.00005371876109217006`", 
        "0.0000878363767524259`", "0.00021434049616391457`", 
        "2.0502900741616815`*^-6", 
        RowBox[{"-", "0.0003312285126186058`"}], "0.0019353437462192933`", 
        "0.0019605532394734535`", "0.002238057970903841`", 
        "0.0020053103331671295`", "0.004691839850712815`", 
        "0.00004656885828662911`", "0.00014436521387498633`", 
        RowBox[{"-", "0.0006247074374585394`"}], 
        RowBox[{"-", "0.0031394624245024553`"}], 
        RowBox[{"-", "0.0007376375654459127`"}], "0.001277883806064719`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Error matrix", 
   MatrixForm[CompressedData["
1:eJwtWnc0lu8bf7TM8hpZRVaykllIzy2UkZWIIquUZCYy81qJKMqOUlIkEg3K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    "]]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.514631203766678*^9, 3.514703832281888*^9, 3.5147038698155537`*^9, 
   3.5147039380032735`*^9, 3.5147040973575535`*^9, 3.514712571638338*^9, 
   3.5147126106072063`*^9, 3.514712658686491*^9, 3.514712712412985*^9, 
   3.5147128335783978`*^9, 3.514713553348062*^9, {3.514715041933877*^9, 
   3.514715047237886*^9}, 3.514715157093279*^9, 3.5147165873983912`*^9, 
   3.5148048265515575`*^9, 3.514805634991778*^9, 3.516017523392741*^9, 
   3.5165306394056263`*^9, 3.516539546099512*^9, 3.516969029175282*^9, 
   3.51696987412161*^9, {3.517121615088585*^9, 3.517121636179822*^9}, 
   3.517121778062071*^9, 3.51714173277812*^9, 3.517310513505695*^9, 
   3.517556760572631*^9, 3.518343846437887*^9, 3.5190390992756176`*^9, 
   3.521544558047174*^9, 3.521547339655566*^9, 3.5217891933194957`*^9, 
   3.521789930841991*^9, 3.5217900127889347`*^9, 3.521796101742305*^9, {
   3.522155746080821*^9, 3.522155775712516*^9}, 3.522155814312723*^9, 
   3.5221558611084003`*^9, 3.5221562814964447`*^9, 3.52215634836827*^9, 
   3.522156383075255*^9, 3.522475444495472*^9, 3.5224766790478926`*^9, 
   3.5224782061033745`*^9, 3.5224946613842545`*^9, 3.5224965095819006`*^9, 
   3.5225807413637247`*^9, 3.5227371525106983`*^9, 3.5227636013108816`*^9, 
   3.522906433321477*^9, 3.5229064765647526`*^9, 3.5229065338636537`*^9, 
   3.523772581416053*^9, 3.5237726599435444`*^9, 3.5237733906753397`*^9, 
   3.5237734732600636`*^9, 3.5238062877205076`*^9, 3.523811291603081*^9, 
   3.5238649813724623`*^9, 3.5238659554069734`*^9, 3.5238742429270697`*^9, 
   3.52387522463922*^9, 3.5243145467159557`*^9, 3.5245626275607204`*^9, 
   3.5287336987251596`*^9, {3.528733752982055*^9, 3.5287337794085016`*^9}, 
   3.528738445552197*^9, 3.5287385033034983`*^9, {3.528806374371281*^9, 
   3.528806393871316*^9}, {3.528806515286329*^9, 3.5288065422275763`*^9}, 
   3.5288066757170105`*^9, 3.528808290087714*^9, 3.528808357651433*^9, 
   3.5288084094591236`*^9, 3.5288085552257795`*^9, 3.528808611760279*^9, 
   3.528810898839569*^9, 3.528810937652789*^9, {3.52881102804696*^9, 
   3.528811056853607*^9}, 3.5288296749505*^9, 3.5288300847164197`*^9, 
   3.529176211029686*^9, 3.5292413130007443`*^9, 3.5292594212097406`*^9, 
   3.529262388241352*^9, 3.529263194373768*^9, 3.529263571910031*^9, 
   3.529264543152137*^9, 3.5292652026432953`*^9, 3.529265766725686*^9, 
   3.52932249126009*^9, 3.5293267459004416`*^9, 3.529430838198119*^9, 
   3.5299531018211565`*^9, 3.531594286237632*^9, 3.5315972090451655`*^9, 
   3.5315972777476864`*^9, 3.5315974462435822`*^9, {3.5315974944164667`*^9, 
   3.531597523541718*^9}, {3.531676829727687*^9, 3.531676858135337*^9}, 
   3.5316772242679796`*^9, 3.531677341736186*^9, 3.531683103762765*^9, 
   3.5316831400016284`*^9, 3.531684279479246*^9, 3.535282662746837*^9, 
   3.5352827057656612`*^9, 3.535282823351143*^9, 3.53605949547263*^9, {
   3.5387446955928917`*^9, 3.5387447008581924`*^9}, 3.5387447442496743`*^9, 
   3.538744781712817*^9, 3.53874490939212*^9, 3.5387472811277757`*^9, 
   3.5388382253325357`*^9, 3.5388967731603413`*^9, 3.540541176659587*^9, 
   3.540543339748308*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Minimization", "Subsection",
 CellChangeTimes->{{3.513493527321311*^9, 3.5134935293337145`*^9}, {
  3.513673650670968*^9, 3.5136736512793694`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Chi]min", "=", 
  RowBox[{"Minimize", "[", 
   RowBox[{"\[Chi]", ",", "ops"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Number of degrees of freedom: \>\"", ",", 
   RowBox[{"NMeasurements", "-", 
    RowBox[{"Length", "[", "ops", "]"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<\!\(\*SuperscriptBox[\(\[Chi]\), \(2\)]\)/dof: \>\"", ",", 
   RowBox[{
    RowBox[{"\[Chi]min", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"NMeasurements", "-", 
      RowBox[{"Length", "[", "ops", "]"}]}], ")"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.513423448185052*^9, 3.5134234488090525`*^9}, {
   3.5134258937701473`*^9, 3.513425919946993*^9}, {3.513509635662857*^9, 
   3.513509638736062*^9}, {3.51351604256291*^9, 3.513516043467712*^9}, 
   3.51394719359184*^9, {3.5147040140222073`*^9, 3.5147040218534207`*^9}, {
   3.5293266577584*^9, 3.529326703324006*^9}, {3.529326754373926*^9, 
   3.5293268522155223`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"190.71822849433823`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"aWB", "\[Rule]", "0.06349614539010368`"}], ",", 
     RowBox[{"ah", "\[Rule]", 
      RowBox[{"-", "0.10699151607053962`"}]}], ",", 
     RowBox[{"aW", "\[Rule]", 
      RowBox[{"-", "0.12689723893663807`"}]}], ",", 
     RowBox[{"aQe", "\[Rule]", "0.010939533118124258`"}], ",", 
     RowBox[{"alQ3", "\[Rule]", 
      RowBox[{"-", "0.010313718547821453`"}]}], ",", 
     RowBox[{"aLq3", "\[Rule]", "0.0015914303223045132`"}], ",", 
     RowBox[{"alb", "\[Rule]", "0.05013345656135055`"}], ",", 
     RowBox[{"aeb", "\[Rule]", "0.010806375891583238`"}], ",", 
     RowBox[{"alL1", "\[Rule]", "0.42113831765898746`"}], ",", 
     RowBox[{"alL3", "\[Rule]", 
      RowBox[{"-", "0.0008429218998686865`"}]}], ",", 
     RowBox[{"altau", "\[Rule]", 
      RowBox[{"-", "0.0017582481691713844`"}]}], ",", 
     RowBox[{"aetau", "\[Rule]", 
      RowBox[{"-", "0.4616732699905292`"}]}], ",", 
     RowBox[{"ahQ3", "\[Rule]", 
      RowBox[{"-", "0.03903204031323807`"}]}], ",", 
     RowBox[{"ahb", "\[Rule]", 
      RowBox[{"-", "0.0020679821667138926`"}]}], ",", 
     RowBox[{"ahL1", "\[Rule]", "0.024167168225298075`"}], ",", 
     RowBox[{"ahL3", "\[Rule]", 
      RowBox[{"-", "0.02488026020892455`"}]}], ",", 
     RowBox[{"ahtau", "\[Rule]", "0.05260998268240614`"}], ",", 
     RowBox[{"aqe", "\[Rule]", 
      RowBox[{"-", "0.006075772895636583`"}]}], ",", 
     RowBox[{"ald", "\[Rule]", 
      RowBox[{"-", "0.018928177403367726`"}]}], ",", 
     RowBox[{"aed", "\[Rule]", 
      RowBox[{"-", "0.00010014252178005116`"}]}], ",", 
     RowBox[{"all1", "\[Rule]", 
      RowBox[{"-", "0.002925495004818091`"}]}], ",", 
     RowBox[{"all3", "\[Rule]", 
      RowBox[{"-", "0.005135783284385227`"}]}], ",", 
     RowBox[{"ale", "\[Rule]", "0.0002239447543693425`"}], ",", 
     RowBox[{"aee", "\[Rule]", "0.006531266923411446`"}], ",", 
     RowBox[{"ahq3", "\[Rule]", 
      RowBox[{"-", "0.027964448349887993`"}]}], ",", 
     RowBox[{"ahd", "\[Rule]", "0.015571460046199812`"}], ",", 
     RowBox[{"ahl1", "\[Rule]", "0.029185489000487327`"}], ",", 
     RowBox[{"ahl3", "\[Rule]", 
      RowBox[{"-", "0.029822991619435874`"}]}], ",", 
     RowBox[{"ahe", "\[Rule]", "0.05349677536719131`"}], ",", 
     RowBox[{"alu", "\[Rule]", 
      RowBox[{"-", "0.008441348102954117`"}]}], ",", 
     RowBox[{"alq3", "\[Rule]", 
      RowBox[{"-", "0.003251460832615776`"}]}], ",", 
     RowBox[{"alq1", "\[Rule]", "0.003406158382955795`"}], ",", 
     RowBox[{"ahu", "\[Rule]", 
      RowBox[{"-", "0.033139520618888814`"}]}], ",", 
     RowBox[{"ahq1", "\[Rule]", 
      RowBox[{"-", "0.0082232156158535`"}]}], ",", 
     RowBox[{"aeu", "\[Rule]", 
      RowBox[{"-", "0.010895013255295696`"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5288066825966225`*^9, 3.528808364889846*^9, 3.5288084149815335`*^9, 
   3.5288085597653875`*^9, 3.528808618468291*^9, 3.5288109024947786`*^9, 
   3.5288109401019297`*^9, {3.528811030739114*^9, 3.5288110590787344`*^9}, 
   3.528829678288906*^9, 3.5288300874620247`*^9, 3.52917621215275*^9, 
   3.5292413171519823`*^9, 3.5292594217245417`*^9, 3.529262388771753*^9, 
   3.5292631948573685`*^9, 3.529263572393632*^9, 3.529264543760538*^9, 
   3.529265203142496*^9, 3.529265767240487*^9, 3.5293224918121214`*^9, 
   3.5293267055991364`*^9, 3.529326746412471*^9, {3.529326823940905*^9, 
   3.529326853167577*^9}, 3.529430838796153*^9, 3.529953104928997*^9, 
   3.531594289544838*^9, 3.5315972118063707`*^9, 3.5315972806804914`*^9, {
   3.5315974975832725`*^9, 3.531597526349723*^9}, {3.531676832098891*^9, 
   3.531676860865341*^9}, 3.5316772263115835`*^9, 3.5316773438889894`*^9, 
   3.531683104199566*^9, 3.531683143262034*^9, 3.53168428138245*^9, 
   3.5352826636231008`*^9, 3.5352827089167595`*^9, 3.535282826079732*^9, 
   3.536059495807897*^9, 3.5387447029973145`*^9, 3.5387447846399846`*^9, 
   3.538744912693309*^9, 3.5387472823908477`*^9, 3.5388382268769383`*^9, 
   3.5388967740203905`*^9, 3.5405411782446775`*^9, 3.5405433413473997`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of degrees of freedom: \"\>", "\[InvisibleSpace]", 
   "244"}],
  SequenceForm["Number of degrees of freedom: ", 244],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5293267052511168`*^9, 3.5293267459674454`*^9, {3.5293268239519053`*^9, 
   3.5293268531775775`*^9}, 3.5294308388071537`*^9, 3.5299531049399977`*^9, 
   3.531594289544838*^9, 3.5315972118063707`*^9, 3.5315972806804914`*^9, {
   3.5315974975832725`*^9, 3.531597526349723*^9}, {3.531676832098891*^9, 
   3.5316768608809414`*^9}, 3.5316772263115835`*^9, 3.5316773438889894`*^9, 
   3.531683104199566*^9, 3.531683143262034*^9, 3.53168428138245*^9, 
   3.535282663625601*^9, 3.53528270892076*^9, 3.535282826083482*^9, 
   3.5360594958108974`*^9, 3.538744703000315*^9, 3.538744784643985*^9, 
   3.5387449126973095`*^9, 3.538747282394848*^9, 3.538838226892538*^9, 
   3.538896774023391*^9, 3.5405411782486773`*^9, 3.5405433413504*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(\[Chi]\\), \\(2\\)]\\)/dof: \"\>", 
   "\[InvisibleSpace]", "0.7816320839931895`"}],
  SequenceForm[
  "\!\(\*SuperscriptBox[\(\[Chi]\), \(2\)]\)/dof: ", 0.7816320839931895],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5293267052511168`*^9, 3.5293267459674454`*^9, {3.5293268239519053`*^9, 
   3.5293268531775775`*^9}, 3.5294308388071537`*^9, 3.5299531049399977`*^9, 
   3.531594289544838*^9, 3.5315972118063707`*^9, 3.5315972806804914`*^9, {
   3.5315974975832725`*^9, 3.531597526349723*^9}, {3.531676832098891*^9, 
   3.5316768608809414`*^9}, 3.5316772263115835`*^9, 3.5316773438889894`*^9, 
   3.531683104199566*^9, 3.531683143262034*^9, 3.53168428138245*^9, 
   3.535282663625601*^9, 3.53528270892076*^9, 3.535282826083482*^9, 
   3.5360594958108974`*^9, 3.538744703000315*^9, 3.538744784643985*^9, 
   3.5387449126973095`*^9, 3.538747282394848*^9, 3.538838226892538*^9, 
   3.538896774023391*^9, 3.5405411782486773`*^9, 3.5405433413514*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Errors on the operators coefficients (using the error matrix)\
\>", "Subsection",
 CellChangeTimes->{{3.5134935336549225`*^9, 3.5134935514545536`*^9}, {
  3.5146312174323015`*^9, 3.514631226137117*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"opmin", "=", 
      RowBox[{"\[Chi]min", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "i", ",", "2"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"operr", "=", 
      SqrtBox[
       RowBox[{"Merr", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "i"}], "]"}], "]"}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"i", ",", "\"\< \>\"", ",", 
       RowBox[{"ops", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "\"\<_min = \>\"", ",", 
       RowBox[{"SetAccuracy", "[", 
        RowBox[{"opmin", ",", "11"}], "]"}], ",", "\"\<  //  \[Sigma]_\>\"", 
       ",", 
       RowBox[{"ops", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "\"\< = \>\"", ",", 
       RowBox[{"SetAccuracy", "[", 
        RowBox[{"operr", ",", "11"}], "]"}], ",", "\"\<  //   \>\"", ",", 
       RowBox[{"ops", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "\"\< -> [\>\"", ",", 
       RowBox[{"N", "[", 
        RowBox[{"opmin", "-", 
         RowBox[{"operr", "*", "SigmaTo90CL"}]}], "]"}], ",", "\"\<,\>\"", 
       ",", 
       RowBox[{"N", "[", 
        RowBox[{"opmin", "+", 
         RowBox[{"operr", "*", "SigmaTo90CL"}]}], "]"}], ",", 
       "\"\<]  (90% CL)   //  \[Sigma](90%) = \>\"", ",", 
       RowBox[{"operr", "*", "SigmaTo90CL"}], ",", 
       "\"\<  \[CapitalLambda]NP \[GreaterSlantEqual] \>\"", ",", 
       RowBox[{"v", "/", 
        RadicalBox[
         RowBox[{"Merr", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "i"}], "]"}], "]"}], "4"]}], ",", 
       "\"\< GeV\>\""}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "ops", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5134259227861977`*^9, 3.5134260176811647`*^9}, {
   3.513426074059664*^9, 3.5134261514825993`*^9}, {3.5134924257097764`*^9, 
   3.513492547920391*^9}, {3.5134927209558945`*^9, 3.5134929113230295`*^9}, {
   3.5134930099308023`*^9, 3.5134930120056057`*^9}, {3.5134930491960716`*^9, 
   3.51349315649306*^9}, {3.513493262588846*^9, 3.51349329881211*^9}, {
   3.513493343178588*^9, 3.5134933462829933`*^9}, {3.513508830576643*^9, 
   3.5135088382986565`*^9}, {3.5135096534936886`*^9, 3.513509669639717*^9}, {
   3.513515077872816*^9, 3.5135151188384876`*^9}, 3.5135958648680153`*^9, {
   3.5135959143201027`*^9, 3.513595915724105*^9}, {3.5135960173426833`*^9, 
   3.5135960202598886`*^9}, {3.513947215057477*^9, 3.5139472285047007`*^9}, {
   3.5139477317147846`*^9, 3.513947732432386*^9}, {3.514713604718952*^9, 
   3.514713630786598*^9}, {3.516969111085967*^9, 3.516969115402214*^9}, {
   3.5175567229754806`*^9, 3.5175567366642637`*^9}, {3.5245625895735483`*^9, 
   3.524562607234558*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aWB", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.06349614539010367542104518179257865995`9.802747361723172", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "aWB",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.13188373513400922232285950030927779153`10.120191238479595", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aWB", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.1534328163450714`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.28042510712527874`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.21692896173517506`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "677.9984663640471`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  1, " ", $CellContext`aWB, "_min = ", 
   0.06349614539010367542104518179257865995`9.802747361723172, 
   "  //  \[Sigma]_", $CellContext`aWB, " = ", 
   0.13188373513400922232285950030927779153`10.120191238479595, 
   "  //   ", $CellContext`aWB, " -> [", -0.1534328163450714, ",", 
   0.28042510712527874`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.21692896173517506`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   677.9984663640471, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341485408*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "2", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ah", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.10699151607053962453885986860768753104`10.02934934151859"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "ah", 
   "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.41215397587971880355439679988194257021`10.615059493659993", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ah", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.7849229832962951`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.5709399511552159`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.6779314672257555`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "383.5257994663244`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  2, " ", $CellContext`ah, 
   "_min = ", -0.10699151607053962453885986860768753104`10.02934934151859, 
   "  //  \[Sigma]_", $CellContext`ah, " = ", 
   0.41215397587971880355439679988194257021`10.615059493659993, 
   "  //   ", $CellContext`ah, " -> [", -0.7849229832962951, ",", 
   0.5709399511552159, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.6779314672257555, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   383.5257994663244, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341488408*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "3", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aW", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.12689723893663806819631645339541137218`10.103452172704419"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "aW", 
   "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.31653593714928413005438301297544967383`10.500423023736081", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aW", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.6475513751566381`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.39375689728336194`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.52065413622`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "437.63577724175866`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  3, " ", $CellContext`aW, 
   "_min = ", -0.12689723893663806819631645339541137218`10.103452172704419, 
   "  //  \[Sigma]_", $CellContext`aW, " = ", 
   0.31653593714928413005438301297544967383`10.500423023736081, 
   "  //   ", $CellContext`aW, " -> [", -0.6475513751566381, ",", 
   0.39375689728336194`, "]  (90% CL)   //  \[Sigma](90%) = ", 0.52065413622, 
   "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 437.63577724175866`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433414914083`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "4", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aQe", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.01093953311812425818749794359519000864`9.038998787395117", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "aQe",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.07020619292975686931423950909447739832`9.846375423192384", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aQe", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.10453912332238632`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.12641818955863485`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.11547865644051059`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "929.2586643801392`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  4, " ", $CellContext`aQe, "_min = ", 
   0.01093953311812425818749794359519000864`9.038998787395117, 
   "  //  \[Sigma]_", $CellContext`aQe, " = ", 
   0.07020619292975686931423950909447739832`9.846375423192384, 
   "  //   ", $CellContext`aQe, " -> [", -0.10453912332238632`, ",", 
   0.12641818955863485`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.11547865644051059`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   929.2586643801392, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341493408*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "5", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "alQ3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.0103137185478214526285212215839237615`9.013415275723416"}],
    "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "alQ3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.15294302522346803208108667604392394423`10.184529676312339", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "alQ3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.2618820535866428`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.2412546164909999`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.25156833503882137`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "629.5924227495424`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  5, " ", $CellContext`alQ3, 
   "_min = ", -0.0103137185478214526285212215839237615`9.013415275723416, 
   "  //  \[Sigma]_", $CellContext`alQ3, " = ", 
   0.15294302522346803208108667604392394423`10.184529676312339, 
   "  //   ", $CellContext`alQ3, " -> [", -0.2618820535866428, ",", 
   0.2412546164909999, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.25156833503882137`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   629.5924227495424, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433414964085`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "6", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aLq3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.00159143032230451317125818899711475751`8.20178762863022", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "aLq3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00802953945053859995117928605168344802`8.904690636209475", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aLq3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.011615957642913902`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.014798818287522927`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.013207387965218415`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "2747.761363742398`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  6, " ", $CellContext`aLq3, "_min = ", 
   0.00159143032230451317125818899711475751`8.20178762863022, 
   "  //  \[Sigma]_", $CellContext`aLq3, " = ", 
   0.00802953945053859995117928605168344802`8.904690636209475, 
   "  //   ", $CellContext`aLq3, " -> [", -0.011615957642913902`, ",", 
   0.014798818287522927`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.013207387965218415`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   2747.761363742398, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341500408*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "7", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "alb", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.05013345656135054922986071801460639108`9.700127649032943", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "alb",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.14548348913483230560039771717129042372`10.16281370820501", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "alb", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.18916506054207838`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.28943197366477946`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.23929851710342892`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "645.5315553565052`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  7, " ", $CellContext`alb, "_min = ", 
   0.05013345656135054922986071801460639108`9.700127649032943, 
   "  //  \[Sigma]_", $CellContext`alb, " = ", 
   0.14548348913483230560039771717129042372`10.16281370820501, 
   "  //   ", $CellContext`alb, " -> [", -0.18916506054207838`, ",", 
   0.28943197366477946`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.23929851710342892`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   645.5315553565052, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341503409*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "8", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aeb", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.01080637589158323780269554958977096248`9.033680070069838", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "aeb",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.3837246305529524170729871457297122106`10.584019676628392", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aeb", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.6203630826734404`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.641975834456607`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.6311694585650237`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "397.4792781295494`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  8, " ", $CellContext`aeb, "_min = ", 
   0.01080637589158323780269554958977096248`9.033680070069838, 
   "  //  \[Sigma]_", $CellContext`aeb, " = ", 
   0.3837246305529524170729871457297122106`10.584019676628392, 
   "  //   ", $CellContext`aeb, " -> [", -0.6203630826734404, ",", 
   0.641975834456607, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.6311694585650237, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   397.4792781295494, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415064087`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "9", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "alL1", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.42113831765898745995713170486851595342`10.624424757902762", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "alL1", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.64733105590828476927356405212776735425`10.811126442930277", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "alL1", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.6436241696517547`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "1.4859008049697295`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "1.0647624873107422`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "306.02796141209177`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  9, " ", $CellContext`alL1, "_min = ", 
   0.42113831765898745995713170486851595342`10.624424757902762, 
   "  //  \[Sigma]_", $CellContext`alL1, " = ", 
   0.64733105590828476927356405212776735425`10.811126442930277, 
   "  //   ", $CellContext`alL1, " -> [", -0.6436241696517547, ",", 
   1.4859008049697295`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   1.0647624873107422`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   306.02796141209177`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341509409*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "10", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "alL3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00084292189986868645834583446685428498`7.925787337344366"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "alL3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00387421417472965561382136634449580015`8.588183625761557", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "alL3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.00721542308517276`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.005529579285435387`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.006372501185304073`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "3955.783529228582`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  10, " ", $CellContext`alL3, 
   "_min = ", -0.00084292189986868645834583446685428498`7.925787337344366, 
   "  //  \[Sigma]_", $CellContext`alL3, " = ", 
   0.00387421417472965561382136634449580015`8.588183625761557, 
   "  //   ", $CellContext`alL3, " -> [", -0.00721542308517276, ",", 
   0.005529579285435387, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.006372501185304073, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   3955.783529228582, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415114093`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "11", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "altau", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.00175824816917138438202017347578021145`8.24508017386353"}],
    "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "altau", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00346327305912193933457032812839315739`8.539486734516474", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "altau", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.007454812860468106`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.003938316522125337`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.005696564691296722`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "4183.8967979763565`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  11, " ", $CellContext`altau, 
   "_min = ", -0.00175824816917138438202017347578021145`8.24508017386353, 
   "  //  \[Sigma]_", $CellContext`altau, " = ", 
   0.00346327305912193933457032812839315739`8.539486734516474, 
   "  //   ", $CellContext`altau, " -> [", -0.007454812860468106, ",", 
   0.003938316522125337, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.005696564691296722, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   4183.8967979763565`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415154095`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "12", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aetau", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.46167326999052921143729122377408202738`10.664334730449626"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "aetau", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.71156602398576396240059693809598684311`10.85221520311654", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aetau", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1.632092644543513`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.7087461045624546`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "1.1704193745529838`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "291.888328242348`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  12, " ", $CellContext`aetau, 
   "_min = ", -0.46167326999052921143729122377408202738`10.664334730449626, 
   "  //  \[Sigma]_", $CellContext`aetau, " = ", 
   0.71156602398576396240059693809598684311`10.85221520311654, 
   "  //   ", $CellContext`aetau, " -> [", -1.632092644543513, ",", 
   0.7087461045624546, "]  (90% CL)   //  \[Sigma](90%) = ", 
   1.1704193745529838`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   291.888328242348, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415184097`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "13", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahQ3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.03903204031323807138287307338941900525`9.59142125365432"}],
    "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahQ3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.19706839962964178836202222555584739894`10.29461698974499", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahQ3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.3631799974440544`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.2851159168175782`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.3241479571308163`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "554.6459368731971`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  13, " ", $CellContext`ahQ3, 
   "_min = ", -0.03903204031323807138287307338941900525`9.59142125365432, 
   "  //  \[Sigma]_", $CellContext`ahQ3, " = ", 
   0.19706839962964178836202222555584739894`10.29461698974499, 
   "  //   ", $CellContext`ahQ3, " -> [", -0.3631799974440544, ",", 
   0.2851159168175782, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.3241479571308163, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   554.6459368731971, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415204096`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "14", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahb", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.00206798216671389258405899802539806842`8.31554678929079"}],
    "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahb", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.0691342646839628177657388619081757497`9.839693348023541", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahb", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.11578347743213012`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.11164751309870234`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.11371549526541623`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "936.4350415970231`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  14, " ", $CellContext`ahb, 
   "_min = ", -0.00206798216671389258405899802539806842`8.31554678929079, 
   "  //  \[Sigma]_", $CellContext`ahb, " = ", 
   0.0691342646839628177657388619081757497`9.839693348023541, 
   "  //   ", $CellContext`ahb, " -> [", -0.11578347743213012`, ",", 
   0.11164751309870234`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.11371549526541623`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   936.4350415970231, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.54054334152341*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "15", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahL1", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.02416716822529807462416329144616611302`9.383225765170739", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahL1", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.10868059861604158211623172292092931457`10.036152021859651", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahL1", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.1545961144082979`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.20293045085889405`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.17876328263359598`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "746.8756830369344`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  15, " ", $CellContext`ahL1, "_min = ", 
   0.02416716822529807462416329144616611302`9.383225765170739, 
   "  //  \[Sigma]_", $CellContext`ahL1, " = ", 
   0.10868059861604158211623172292092931457`10.036152021859651, 
   "  //   ", $CellContext`ahL1, " -> [", -0.1545961144082979, ",", 
   0.20293045085889405`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.17876328263359598`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   746.8756830369344, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.54054334152641*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "16", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahL3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.02488026020892454906463520103443443077`9.395854918089086"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahL3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.21821286129666694897366596705978736281`10.33888034398635", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahL3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.38380768511274715`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.3340471646948981`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.3589274249038226`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "527.0892498559581`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  16, " ", $CellContext`ahL3, 
   "_min = ", -0.02488026020892454906463520103443443077`9.395854918089086, 
   "  //  \[Sigma]_", $CellContext`ahL3, " = ", 
   0.21821286129666694897366596705978736281`10.33888034398635, 
   "  //   ", $CellContext`ahL3, " -> [", -0.38380768511274715`, ",", 
   0.3340471646948981, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.3589274249038226, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   527.0892498559581, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.54054334152941*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "17", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahtau", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.05260998268240613812141148741829965729`9.72106815884075", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahtau", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.20609315568284730657566683476034086198`10.31406356917597", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahtau", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.28638234444252525`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.3916023098073375`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.3389923271249314`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "542.3661119115455`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  17, " ", $CellContext`ahtau, "_min = ", 
   0.05260998268240613812141148741829965729`9.72106815884075, 
   "  //  \[Sigma]_", $CellContext`ahtau, " = ", 
   0.20609315568284730657566683476034086198`10.31406356917597, 
   "  //   ", $CellContext`ahtau, " -> [", -0.28638234444252525`, ",", 
   0.3916023098073375, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.3389923271249314, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   542.3661119115455, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.54054334153141*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "18", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aqe", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00607577289563658324428319090770855837`8.783601532140196"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "aqe",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.05146937835664276011948814470997604076`9.711548922905111", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aqe", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.09073517988556043`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.07858363409428726`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.08465940698992384`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "1085.3001656060758`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  18, " ", $CellContext`aqe, 
   "_min = ", -0.00607577289563658324428319090770855837`8.783601532140196, 
   "  //  \[Sigma]_", $CellContext`aqe, " = ", 
   0.05146937835664276011948814470997604076`9.711548922905111, 
   "  //   ", $CellContext`aqe, " -> [", -0.09073517988556043, ",", 
   0.07858363409428726, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.08465940698992384, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   1085.3001656060758`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415344105`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "19", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ald", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.01892817740336772552867117269670416135`9.277108797705592"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "ald",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.04246000902111583819031892517159576528`9.627980082100834", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ald", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.08876852324175011`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.050912168435014664`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.06984034583838239`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "1194.9075072501903`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  19, " ", $CellContext`ald, 
   "_min = ", -0.01892817740336772552867117269670416135`9.277108797705592, 
   "  //  \[Sigma]_", $CellContext`ald, " = ", 
   0.04246000902111583819031892517159576528`9.627980082100834, 
   "  //   ", $CellContext`ald, " -> [", -0.08876852324175011, ",", 
   0.050912168435014664`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.06984034583838239, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   1194.9075072501903`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415374107`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "20", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aed", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00010014252178005116360355597482367784`7.000618523565498"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "aed",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.02167503652989848442200759848219604464`9.33595983808458", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aed", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.035752326357983574`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.035552041314423466`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.03565218383620352`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "1672.4163769889556`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  20, " ", $CellContext`aed, 
   "_min = ", -0.00010014252178005116360355597482367784`7.000618523565498, 
   "  //  \[Sigma]_", $CellContext`aed, " = ", 
   0.02167503652989848442200759848219604464`9.33595983808458, 
   "  //   ", $CellContext`aed, " -> [", -0.035752326357983574`, ",", 
   0.035552041314423466`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.03565218383620352, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   1672.4163769889556`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341540411*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "21", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "all1", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00292549500481809098342833586059441586`8.466199360904508"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "all1", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.01057869335359044871136546817069756798`9.024432028344721", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "all1", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.02032585876747134`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.014474868757835158`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.017400363762653248`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "2393.9127431719494`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  21, " ", $CellContext`all1, 
   "_min = ", -0.00292549500481809098342833586059441586`8.466199360904508, 
   "  //  \[Sigma]_", $CellContext`all1, " = ", 
   0.01057869335359044871136546817069756798`9.024432028344721, 
   "  //   ", $CellContext`all1, " -> [", -0.02032585876747134, ",", 
   0.014474868757835158`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.017400363762653248`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   2393.9127431719494`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341543411*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "22", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "all3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00513578328438522684062927936565756681`8.710606689441372"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "all3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00712242953376399090537063329975353554`8.852628161211083", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "all3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.016851111502996927`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.006579544934226474`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.0117153282186117`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "2917.4958713064957`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  22, " ", $CellContext`all3, 
   "_min = ", -0.00513578328438522684062927936565756681`8.710606689441372, 
   "  //  \[Sigma]_", $CellContext`all3, " = ", 
   0.00712242953376399090537063329975353554`8.852628161211083, 
   "  //   ", $CellContext`all3, " -> [", -0.016851111502996927`, ",", 
   0.006579544934226474, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.0117153282186117, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   2917.4958713064957`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415464115`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "23", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ale", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.0002239447543693425012392705930608372`7.350140894085327", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "ale",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00107296152143197538568475390974299444`8.030584147567623", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ale", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.0015409160041580422`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.001988805512896727`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.0017648607585273846`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "7516.787224063658`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  23, " ", $CellContext`ale, "_min = ", 
   0.0002239447543693425012392705930608372`7.350140894085327, 
   "  //  \[Sigma]_", $CellContext`ale, " = ", 
   0.00107296152143197538568475390974299444`8.030584147567623, 
   "  //   ", $CellContext`ale, " -> [", -0.0015409160041580422`, ",", 
   0.001988805512896727, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.0017648607585273846`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   7516.787224063658, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415494113`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "24", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aee", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.00653126692341144624714965871703498124`8.814997433109376", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "aee",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.01577331199963857844004166963713942096`9.197922893845352", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aee", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.01941346531919407`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.03247599916601696`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.025944732242605514`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "1960.4821110152734`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  24, " ", $CellContext`aee, "_min = ", 
   0.00653126692341144624714965871703498124`8.814997433109376, 
   "  //  \[Sigma]_", $CellContext`aee, " = ", 
   0.01577331199963857844004166963713942096`9.197922893845352, 
   "  //   ", $CellContext`aee, " -> [", -0.01941346531919407, ",", 
   0.03247599916601696, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.025944732242605514`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   1960.4821110152734`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415514116`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "25", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahq3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.02796444834988799296726647014565969585`9.44660625649235"}],
    "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahq3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.22017502574769015621924950210086535662`10.34276805580249", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahq3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.3901193394509761`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.33419044275120013`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.3621548911010881`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "524.73532632196`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  25, " ", $CellContext`ahq3, 
   "_min = ", -0.02796444834988799296726647014565969585`9.44660625649235, 
   "  //  \[Sigma]_", $CellContext`ahq3, " = ", 
   0.22017502574769015621924950210086535662`10.34276805580249, 
   "  //   ", $CellContext`ahq3, " -> [", -0.3901193394509761, ",", 
   0.33419044275120013`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.3621548911010881, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   524.73532632196, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341554412*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "26", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahd", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.01557146004619981184691202003023136058`9.192329335771685", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "ahd",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.07588090891555444861271695344839827158`9.88013252430737", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahd", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.1092412529835499`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.14038417307594953`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.12481271302974972`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "893.8364658056087`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  26, " ", $CellContext`ahd, "_min = ", 
   0.01557146004619981184691202003023136058`9.192329335771685, 
   "  //  \[Sigma]_", $CellContext`ahd, " = ", 
   0.07588090891555444861271695344839827158`9.88013252430737, 
   "  //   ", $CellContext`ahd, " -> [", -0.1092412529835499, ",", 
   0.14038417307594953`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.12481271302974972`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   893.8364658056087, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415574117`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "27", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahl1", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.02918548900048732741563384252003743313`9.465166974275755", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahl1", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.10030198285214346476390545603862847202`10.001309518596013", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahl1", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.13579622749386083`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.19416720549483552`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.16498171649434817`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "777.4448149317508`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  27, " ", $CellContext`ahl1, "_min = ", 
   0.02918548900048732741563384252003743313`9.465166974275755, 
   "  //  \[Sigma]_", $CellContext`ahl1, " = ", 
   0.10030198285214346476390545603862847202`10.001309518596013, 
   "  //   ", $CellContext`ahl1, " -> [", -0.13579622749386083`, ",", 
   0.19416720549483552`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.16498171649434817`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   777.4448149317508, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341560412*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "28", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahl3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.02982299161943587420542378652044135379`9.474551206475983"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahl3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.22129427251365285655992920510470867157`10.344970173765013", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahl3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.39381887576351776`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.33417289252464605`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.3639958841440819`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "523.4066592805693`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  28, " ", $CellContext`ahl3, 
   "_min = ", -0.02982299161943587420542378652044135379`9.474551206475983, 
   "  //  \[Sigma]_", $CellContext`ahl3, " = ", 
   0.22129427251365285655992920510470867157`10.344970173765013, 
   "  //   ", $CellContext`ahl3, " -> [", -0.39381887576351776`, ",", 
   0.33417289252464605`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.3639958841440819, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   523.4066592805693, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415634117`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "29", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahe", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.05349677536719130849229841828673670534`9.728327604779336", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "ahe",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.20609671125543582714811918776831589639`10.314071061672411", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahe", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.28550140014131226`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.3924949508756949`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.3389981755085036`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "542.3614334516468`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  29, " ", $CellContext`ahe, "_min = ", 
   0.05349677536719130849229841828673670534`9.728327604779336, 
   "  //  \[Sigma]_", $CellContext`ahe, " = ", 
   0.20609671125543582714811918776831589639`10.314071061672411, 
   "  //   ", $CellContext`ahe, " -> [", -0.28550140014131226`, ",", 
   0.3924949508756949, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.3389981755085036, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   542.3614334516468, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415664124`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "30", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "alu", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00844134810295411701364098888689113664`8.926411810004891"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "alu",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.01752835013112664930279294139836565591`9.243741039729368", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "alu", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.03727285481613778`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.020390158610229553`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.028831506713183668`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "1859.7467604362819`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  30, " ", $CellContext`alu, 
   "_min = ", -0.00844134810295411701364098888689113664`8.926411810004891, 
   "  //  \[Sigma]_", $CellContext`alu, " = ", 
   0.01752835013112664930279294139836565591`9.243741039729368, 
   "  //   ", $CellContext`alu, " -> [", -0.03727285481613778, ",", 
   0.020390158610229553`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.028831506713183668`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   1859.7467604362819`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341569412*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "31", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "alq3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00325146083261577609202497285423305584`8.512078526825759"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "alq3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00506286635649976293760410328559373738`8.704396463551026", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "alq3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.01157911655910441`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.0050761948938728586`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.008327655726488635`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "3460.3983714544092`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  31, " ", $CellContext`alq3, 
   "_min = ", -0.00325146083261577609202497285423305584`8.512078526825759, 
   "  //  \[Sigma]_", $CellContext`alq3, " = ", 
   0.00506286635649976293760410328559373738`8.704396463551026, 
   "  //   ", $CellContext`alq3, " -> [", -0.01157911655910441, ",", 
   0.0050761948938728586`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.008327655726488635, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   3460.3983714544092`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341571412*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "32", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "alq1", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.00340615838295579495542675374508689856`8.532264838354852", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "alq1", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.01845948698509534274814214427351544145`9.266219627207871", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "alq1", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.02695692878447828`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.03376924555038987`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.030363087167434074`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "1812.2350140848532`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  32, " ", $CellContext`alq1, "_min = ", 
   0.00340615838295579495542675374508689856`8.532264838354852, 
   "  //  \[Sigma]_", $CellContext`alq1, " = ", 
   0.01845948698509534274814214427351544145`9.266219627207871, 
   "  //   ", $CellContext`alq1, " -> [", -0.02695692878447828, ",", 
   0.03376924555038987, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.030363087167434074`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   1812.2350140848532`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415754128`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "33", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahu", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.03313952061888881389650762798737559933`9.520346221823903"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", "ahu",
    "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.13754083410841067003360649323440156877`10.138431653767688", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahu", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.2593735616021081`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.19309452036433047`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.22623404098321928`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "663.9089202512678`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  33, " ", $CellContext`ahu, 
   "_min = ", -0.03313952061888881389650762798737559933`9.520346221823903, 
   "  //  \[Sigma]_", $CellContext`ahu, " = ", 
   0.13754083410841067003360649323440156877`10.138431653767688, 
   "  //   ", $CellContext`ahu, " -> [", -0.2593735616021081, ",", 
   0.19309452036433047`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.22623404098321928`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   663.9089202512678, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.5405433415774126`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "34", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahq1", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{
   "-", "0.00822321561585349913858777881614514627`8.915041677775609"}], 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahq1", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.03483157138437811134457078310333599802`9.541973067572515", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahq1", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.06551592580744783`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.049069494575740835`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.057292710191594334`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "1319.2824856998168`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  34, " ", $CellContext`ahq1, 
   "_min = ", -0.00822321561585349913858777881614514627`8.915041677775609, 
   "  //  \[Sigma]_", $CellContext`ahq1, " = ", 
   0.03483157138437811134457078310333599802`9.541973067572515, 
   "  //   ", $CellContext`ahq1, " -> [", -0.06551592580744783, ",", 
   0.049069494575740835`, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.057292710191594334`, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   1319.2824856998168`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341580413*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "35", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "aeu", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.01089501325529569630834458848767098971`9.03722776296211"}],
    "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "aeu", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.03574750069675807634395070522259629797`9.553245683296543", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "aeu", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.06969428977635822`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.04790426326576682`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.05879927652106252`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "1302.271358721816`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  35, " ", $CellContext`aeu, 
   "_min = ", -0.01089501325529569630834458848767098971`9.03722776296211, 
   "  //  \[Sigma]_", $CellContext`aeu, " = ", 
   0.03574750069675807634395070522259629797`9.553245683296543, 
   "  //   ", $CellContext`aeu, " -> [", -0.06969428977635822, ",", 
   0.04790426326576682, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.05879927652106252, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   1302.271358721816, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.531594292259242*^9, 3.5315972141307745`*^9, 
   3.5315972827396955`*^9, {3.5315975007812777`*^9, 3.531597527972126*^9}, 
   3.5316768648589487`*^9, 3.531677228401987*^9, 3.531677345901393*^9, 
   3.5316831070231705`*^9, 3.5316831457112384`*^9, 3.531684282692852*^9, 
   3.5352826654256287`*^9, 3.535282710799867*^9, {3.5352828029083786`*^9, 
   3.5352828278072586`*^9}, 3.536059495957906*^9, 3.538744704852421*^9, 
   3.5387447883301954`*^9, 3.538744914532414*^9, 3.538747282463852*^9, 
   3.5388382269549384`*^9, 3.5388967741063957`*^9, 3.5405411783156815`*^9, 
   3.540543341583413*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Bounds on RW\[Tau]l = (\[CapitalGamma](W -> \[Tau] \[Nu])SM + \
\[CapitalGamma](W -> \[Tau] \[Nu])NP) / ( \[CapitalGamma](W -> e \[Nu])SM +  \
\[CapitalGamma](W -> \[Mu] \[Nu])SM) using also contribution to mu and e\
\>", "Subsection",
 CellChangeTimes->{{3.514722940857148*^9, 3.514722959561218*^9}, {
   3.5165401241741276`*^9, 3.5165401617545934`*^9}, {3.5169694899526367`*^9, 
   3.516969524929638*^9}, {3.5169695596296225`*^9, 3.516969582268917*^9}, 
   3.5173115093116517`*^9, {3.5238070763018928`*^9, 3.5238071126343565`*^9}, 
   3.531677097470957*^9, {3.5316818332165327`*^9, 3.531681859221779*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RW\[Tau]lCentral", "=", 
   RowBox[{"RW\[Tau]l", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"ops", "[", 
        RowBox[{"[", "16", "]"}], "]"}], "\[Rule]", 
       RowBox[{"\[Chi]min", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "16", ",", "2"}], "]"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{"ops", "[", 
        RowBox[{"[", "28", "]"}], "]"}], "\[Rule]", 
       RowBox[{"\[Chi]min", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "28", ",", "2"}], "]"}], "]"}]}], ",", 
      RowBox[{"aEWt", "\[Rule]", "0"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CentralValue", "=", "%"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]RW\[Tau]l", "=", 
   SqrtBox[
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"RW\[Tau]l", ",", 
          RowBox[{"ops", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}], 
        RowBox[{"D", "[", 
         RowBox[{"RW\[Tau]l", ",", 
          RowBox[{"ops", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], "]"}], 
        RowBox[{"Merr", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "ops", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Length", "[", "ops", "]"}]}], "}"}]}], "]"}], "+", 
     SuperscriptBox["\[Sigma]RW\[Tau]lSM", "2"]}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigma", "=", "%"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RW\[Tau]lMax", "=", 
   RowBox[{"RW\[Tau]lCentral", "+", "\[Sigma]RW\[Tau]l"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RW\[Tau]lMin", "=", 
   RowBox[{"RW\[Tau]lCentral", "-", "\[Sigma]RW\[Tau]l"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<RW\[Tau]l = \>\"", ",", "RW\[Tau]lCentral", ",", 
   "\"\< \[PlusMinus] \>\"", ",", "\[Sigma]RW\[Tau]l", ",", 
   "\"\<  (68% CL)        //        RW\[Tau]l: [\>\"", ",", 
   RowBox[{"RW\[Tau]lCentral", "+", 
    RowBox[{"\[Sigma]RW\[Tau]l", "*", "SigmaTo90CL"}]}], ",", "\"\<, \>\"", 
   ",", 
   RowBox[{"RW\[Tau]lCentral", "-", 
    RowBox[{"\[Sigma]RW\[Tau]l", "*", "SigmaTo90CL"}]}], ",", 
   "\"\<]  (90% CL)\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Experimental value:  RW\[Tau]lExp = \>\"", ",", "RW\[Tau]lExp", ",", 
   "\"\< \[PlusMinus] \>\"", ",", "\[Sigma]RW\[Tau]lExp", ",", 
   "\"\< //            SM value:  RW\[Tau]lSM = \>\"", ",", 
   RowBox[{"RW\[Tau]lSM", "\"\<              \[CapitalDelta](SM-NP) = \>\""}],
    ",", 
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"RW\[Tau]lCentral", "-", "RW\[Tau]lSM"}], ")"}], "/", 
     "\[Sigma]RW\[Tau]l"}], "]"}], ",", "\"\<\[Sigma]\>\""}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.5147230284421577`*^9, 3.514723327511263*^9}, {
   3.5147236955613146`*^9, 3.514723732525429*^9}, {3.5147237976961565`*^9, 
   3.514723798098179*^9}, {3.5147238756166134`*^9, 3.5147239007260494`*^9}, {
   3.5148179767801533`*^9, 3.5148179918653803`*^9}, 3.5148182141969705`*^9, {
   3.5148744804099283`*^9, 3.5148745559608607`*^9}, {3.5148746118557587`*^9, 
   3.5148746204201736`*^9}, {3.5148746587182417`*^9, 
   3.5148746723838654`*^9}, {3.5148749541515603`*^9, 
   3.5148749548379617`*^9}, {3.5148751250810604`*^9, 
   3.5148751261418624`*^9}, {3.514875588994675*^9, 3.51487559705989*^9}, {
   3.5148915683614473`*^9, 3.51489157009305*^9}, {3.514894488904977*^9, 
   3.514894501525399*^9}, {3.5148945345038567`*^9, 3.5148945346442575`*^9}, {
   3.514894567685115*^9, 3.514894569541518*^9}, {3.5148946783361096`*^9, 
   3.5148947104877663`*^9}, {3.5148947890027037`*^9, 
   3.5148948052579327`*^9}, {3.514895639188597*^9, 3.514895649469015*^9}, {
   3.5148973907908735`*^9, 3.514897402756095*^9}, {3.5151465254916377`*^9, 
   3.515146677377325*^9}, {3.515146773315812*^9, 3.5151468077057796`*^9}, {
   3.5151468452779284`*^9, 3.515146858553688*^9}, 3.5151483871040525`*^9, {
   3.5151488174776087`*^9, 3.515148833717237*^9}, {3.516531184844984*^9, 
   3.5165311902893934`*^9}, {3.5165312372922764`*^9, 3.5165312398038807`*^9}, 
   3.5165395200942664`*^9, {3.5165401727994127`*^9, 3.5165402446843395`*^9}, {
   3.51654031349606*^9, 3.5165403592509403`*^9}, {3.5165407351960006`*^9, 
   3.516540745850819*^9}, {3.51696952986292*^9, 3.516969546112849*^9}, {
   3.5169695833189774`*^9, 3.5169695979348135`*^9}, {3.5171438696386733`*^9, 
   3.5171438915255117`*^9}, {3.517311439398653*^9, 3.5173114622989626`*^9}, 
   3.5173115374032583`*^9, {3.5217960808421097`*^9, 3.5217960870904665`*^9}, {
   3.5237725891674967`*^9, 3.5237726257865906`*^9}, 3.528829816146348*^9, {
   3.5288298517612104`*^9, 3.5288298682348394`*^9}, {3.5291763276553564`*^9, 
   3.5291763309925475`*^9}, {3.5291765406505394`*^9, 3.52917659696176*^9}, {
   3.5291766387731514`*^9, 3.5291766441574593`*^9}, {3.529176689705065*^9, 
   3.5291767109172783`*^9}, {3.529251331819973*^9, 3.529251334640135*^9}, {
   3.52925162181456*^9, 3.529251657467599*^9}, {3.5316771027905664`*^9, 
   3.5316771256446066`*^9}, {3.535282886612171*^9, 3.5352829357038574`*^9}, {
   3.5387448203530273`*^9, 3.5387448211100707`*^9}, {3.5387472883501883`*^9, 
   3.5387472926414337`*^9}, 3.5405411896593304`*^9, 3.540541223984294*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RW\[Tau]l = \"\>", "\[InvisibleSpace]", "1.018756466723266`", 
   "\[InvisibleSpace]", "\<\" \[PlusMinus] \"\>", "\[InvisibleSpace]", 
   "0.04288481962763108`", 
   "\[InvisibleSpace]", "\<\"  (68% CL)        //        RW\[Tau]l: [\"\>", 
   "\[InvisibleSpace]", "1.089295562287775`", 
   "\[InvisibleSpace]", "\<\", \"\>", "\[InvisibleSpace]", 
   "0.948217371158757`", "\[InvisibleSpace]", "\<\"]  (90% CL)\"\>"}],
  SequenceForm[
  "RW\[Tau]l = ", 1.018756466723266, " \[PlusMinus] ", 0.04288481962763108, 
   "  (68% CL)        //        RW\[Tau]l: [", 1.089295562287775, ", ", 
   0.948217371158757, "]  (90% CL)"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5151466785033894`*^9, {3.5151467839774227`*^9, 3.515146814386162*^9}, {
   3.5151468538954215`*^9, 3.5151468588107023`*^9}, 3.515148387930854*^9, 
   3.515148668185346*^9, {3.5151488141860027`*^9, 3.5151488357140408`*^9}, 
   3.5165305176942124`*^9, 3.5165311913813953`*^9, 3.516531240661882*^9, 
   3.5165395738207607`*^9, 3.516540361232144*^9, {3.5165407330119967`*^9, 
   3.51654074628762*^9}, 3.516969462788083*^9, 3.516969705087942*^9, 
   3.517143866331467*^9, 3.5171438994347253`*^9, 3.51731149826502*^9, 
   3.5173115517440786`*^9, 3.5202329035174007`*^9, 3.5202331293745975`*^9, 
   3.5217961115618668`*^9, {3.5224754608994102`*^9, 3.5224754746701975`*^9}, 
   3.522476698001926*^9, {3.52249464732863*^9, 3.5224946692778683`*^9}, 
   3.523772668285022*^9, 3.523773402081992*^9, 3.523773487200861*^9, 
   3.523806289732911*^9, 3.5238065004268813`*^9, 3.523807067269477*^9, 
   3.5238742444431562`*^9, {3.5288297728562717`*^9, 3.528829801279522*^9}, {
   3.528829852463212*^9, 3.52882986865604*^9}, 3.529176146041969*^9, {
   3.529176319637898*^9, 3.529176331263563*^9}, 3.529176612098626*^9, 
   3.5291766452785234`*^9, {3.5291766901540904`*^9, 3.529176711743325*^9}, 
   3.5292413357970486`*^9, 3.5292513375813026`*^9, {3.529251645138894*^9, 
   3.5292516577656164`*^9}, 3.529322502991761*^9, 3.529953130445402*^9, 
   3.5315943891666126`*^9, 3.531597534695738*^9, {3.531677106924574*^9, 
   3.5316771259878073`*^9}, 3.5316772333315954`*^9, 3.5316773486625977`*^9, 
   3.5352826774822893`*^9, 3.5352827136454096`*^9, 3.5352828308698053`*^9, 
   3.5352828943133364`*^9, {3.5352829316100383`*^9, 3.5352829360148754`*^9}, 
   3.536059496086913*^9, {3.5387447926494427`*^9, 3.538744821715105*^9}, 
   3.5387472970176845`*^9, 3.538838227095339*^9, 3.5388967743124075`*^9, {
   3.5405411784366884`*^9, 3.540541190306367*^9}, 3.5405412250973573`*^9, 
   3.540543341614415*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Experimental value:  RW\[Tau]lExp = \"\>", "\[InvisibleSpace]",
    "1.055347091932458`", "\[InvisibleSpace]", "\<\" \[PlusMinus] \"\>", 
   "\[InvisibleSpace]", "0.021178845883677393`", 
   "\[InvisibleSpace]", "\<\" //            SM value:  RW\[Tau]lSM = \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"0.999`", " ", "\<\"              \[CapitalDelta](SM-NP) = \"\>"}],
    "\[InvisibleSpace]", "0.46068671606436606`", 
   "\[InvisibleSpace]", "\<\"\[Sigma]\"\>"}],
  SequenceForm[
  "Experimental value:  RW\[Tau]lExp = ", 1.055347091932458, " \[PlusMinus] ",
    0.021178845883677393`, " //            SM value:  RW\[Tau]lSM = ", 0.999 
   "              \[CapitalDelta](SM-NP) = ", 0.46068671606436606`, 
   "\[Sigma]"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5151466785033894`*^9, {3.5151467839774227`*^9, 3.515146814386162*^9}, {
   3.5151468538954215`*^9, 3.5151468588107023`*^9}, 3.515148387930854*^9, 
   3.515148668185346*^9, {3.5151488141860027`*^9, 3.5151488357140408`*^9}, 
   3.5165305176942124`*^9, 3.5165311913813953`*^9, 3.516531240661882*^9, 
   3.5165395738207607`*^9, 3.516540361232144*^9, {3.5165407330119967`*^9, 
   3.51654074628762*^9}, 3.516969462788083*^9, 3.516969705087942*^9, 
   3.517143866331467*^9, 3.5171438994347253`*^9, 3.51731149826502*^9, 
   3.5173115517440786`*^9, 3.5202329035174007`*^9, 3.5202331293745975`*^9, 
   3.5217961115618668`*^9, {3.5224754608994102`*^9, 3.5224754746701975`*^9}, 
   3.522476698001926*^9, {3.52249464732863*^9, 3.5224946692778683`*^9}, 
   3.523772668285022*^9, 3.523773402081992*^9, 3.523773487200861*^9, 
   3.523806289732911*^9, 3.5238065004268813`*^9, 3.523807067269477*^9, 
   3.5238742444431562`*^9, {3.5288297728562717`*^9, 3.528829801279522*^9}, {
   3.528829852463212*^9, 3.52882986865604*^9}, 3.529176146041969*^9, {
   3.529176319637898*^9, 3.529176331263563*^9}, 3.529176612098626*^9, 
   3.5291766452785234`*^9, {3.5291766901540904`*^9, 3.529176711743325*^9}, 
   3.5292413357970486`*^9, 3.5292513375813026`*^9, {3.529251645138894*^9, 
   3.5292516577656164`*^9}, 3.529322502991761*^9, 3.529953130445402*^9, 
   3.5315943891666126`*^9, 3.531597534695738*^9, {3.531677106924574*^9, 
   3.5316771259878073`*^9}, 3.5316772333315954`*^9, 3.5316773486625977`*^9, 
   3.5352826774822893`*^9, 3.5352827136454096`*^9, 3.5352828308698053`*^9, 
   3.5352828943133364`*^9, {3.5352829316100383`*^9, 3.5352829360148754`*^9}, 
   3.536059496086913*^9, {3.5387447926494427`*^9, 3.538744821715105*^9}, 
   3.5387472970176845`*^9, 3.538838227095339*^9, 3.5388967743124075`*^9, {
   3.5405411784366884`*^9, 3.540541190306367*^9}, 3.5405412250973573`*^9, 
   3.540543341616415*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
c) SINGLE OPERATOR ANALYSIS (Bounds on hl3 operator)\
\>", "Section",
 CellChangeTimes->{{3.5067699872735014`*^9, 3.5067700116251445`*^9}, {
   3.507469679480951*^9, 3.50746969030657*^9}, 3.509805539810589*^9, {
   3.51038621135526*^9, 3.5103862114892673`*^9}, {3.511249189024064*^9, 
   3.511249243280959*^9}, {3.5139469165353527`*^9, 3.513946922790964*^9}, {
   3.51463094890903*^9, 3.5146309519510355`*^9}, {3.5147133014232197`*^9, 
   3.5147133224676566`*^9}, {3.5147164669349794`*^9, 
   3.5147164710533867`*^9}, {3.5148046565424595`*^9, 3.514804660816867*^9}, {
   3.514811320872463*^9, 3.514811322682066*^9}, {3.5217898434818373`*^9, 
   3.5217898505174503`*^9}, {3.5224934794197826`*^9, 3.522493484457071*^9}, 
   3.5227360149879007`*^9, {3.5238803276330953`*^9, 3.523880333281418*^9}, {
   3.5288062655922904`*^9, 3.5288062715671005`*^9}, {3.537528204991841*^9, 
   3.5375282204107227`*^9}, {3.54054075256133*^9, 3.5405407591587067`*^9}, {
   3.5405423684707546`*^9, 3.5405423758471766`*^9}, {3.5405424101691394`*^9, 
   3.5405424137863464`*^9}, {3.5405509847375765`*^9, 3.5405509852916083`*^9}}],

Cell[CellGroupData[{

Cell["Dropping unwanted operators", "Subsection",
 CellChangeTimes->{{3.5147134436330695`*^9, 3.5147134599818983`*^9}, {
  3.529953179190193*^9, 3.529953182177664*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Please", " ", "place", " ", "in", " ", "the", " ", "\"\<ops\>\"", " ", 
   "vector", " ", "the", " ", "operators", " ", "you", " ", "want", " ", "to",
    " ", "include", " ", "in", " ", "the", " ", 
   RowBox[{"fit", ".", " ", "The"}], " ", "other", " ", "operators", " ", 
   "will", " ", "be", " ", "dropped", " ", "automatically"}], "  ", 
  "*)"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ops", "=", 
   RowBox[{"{", "ahL3", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DropOpsTemp", "=", 
   RowBox[{"Complement", "[", 
    RowBox[{"Ops", ",", "ops"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DropOps", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"DropOps", "=", 
     RowBox[{"Append", "[", 
      RowBox[{"DropOps", ",", 
       RowBox[{
        RowBox[{"DropOpsTemp", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", "0"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "DropOpsTemp", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Operators to drop from the total list: \>\"", ",", "DropOpsTemp"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Number of operators used in the fit: \>\"", ",", 
   RowBox[{"Length", "[", "ops", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5147035244465475`*^9, 3.514703554851001*^9}, {
   3.5147036800568204`*^9, 3.514703680290821*^9}, {3.5147037973846264`*^9, 
   3.514703801830634*^9}, 3.514703895680399*^9, {3.5147040714303083`*^9, 
   3.514704079823123*^9}, {3.514712543839089*^9, 3.5147125472086945`*^9}, {
   3.5147125802495527`*^9, 3.514712691914549*^9}, {3.514712766030279*^9, 
   3.5147128134699626`*^9}, {3.5147134294526443`*^9, 3.514713436815858*^9}, {
   3.5147151082495933`*^9, 3.514715137936445*^9}, {3.522497558137742*^9, 
   3.5224975604465466`*^9}, {3.5227370577873325`*^9, 
   3.5227370943069963`*^9}, {3.5287331270309563`*^9, 
   3.5287331335985675`*^9}, {3.5287336071217995`*^9, 
   3.5287336139546113`*^9}, {3.5288301495345335`*^9, 3.528830156960147*^9}, {
   3.528830222277461*^9, 3.5288302298278747`*^9}, {3.529952237100196*^9, 
   3.529952246409374*^9}, {3.529952807648368*^9, 3.529952975271253*^9}, {
   3.529953068155826*^9, 3.5299530896348314`*^9}, {3.531596287971748*^9, 
   3.531596290420952*^9}, {3.5315965445453987`*^9, 3.5315965512066097`*^9}, {
   3.5375282411819105`*^9, 3.5375282438520637`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Operators to drop from the total list: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "aeb", ",", "aEBt", ",", "aed", ",", "aee", ",", "aetau", ",", "aeu", ",",
      "aEWt", ",", "ah", ",", "ahb", ",", "ahd", ",", "ahe", ",", "ahl1", ",",
      "ahL1", ",", "ahl3", ",", "ahq1", ",", "ahQ1", ",", "ahq3", ",", "ahQ3",
      ",", "ahtau", ",", "ahu", ",", "alb", ",", "ald", ",", "ale", ",", 
     "aLe", ",", "all1", ",", "alL1", ",", "all3", ",", "alL3", ",", "alq1", 
     ",", "alQ1", ",", "alq3", ",", "alQ3", ",", "aLq3", ",", "altau", ",", 
     "alu", ",", "aqe", ",", "aQe", ",", "aW", ",", "aWB"}], "}"}]}],
  SequenceForm[
  "Operators to drop from the total list: ", {$CellContext`aeb, \
$CellContext`aEBt, $CellContext`aed, $CellContext`aee, $CellContext`aetau, \
$CellContext`aeu, $CellContext`aEWt, $CellContext`ah, $CellContext`ahb, \
$CellContext`ahd, $CellContext`ahe, $CellContext`ahl1, $CellContext`ahL1, \
$CellContext`ahl3, $CellContext`ahq1, $CellContext`ahQ1, $CellContext`ahq3, \
$CellContext`ahQ3, $CellContext`ahtau, $CellContext`ahu, $CellContext`alb, \
$CellContext`ald, $CellContext`ale, $CellContext`aLe, $CellContext`all1, \
$CellContext`alL1, $CellContext`all3, $CellContext`alL3, $CellContext`alq1, \
$CellContext`alQ1, $CellContext`alq3, $CellContext`alQ3, $CellContext`aLq3, \
$CellContext`altau, $CellContext`alu, $CellContext`aqe, $CellContext`aQe, \
$CellContext`aW, $CellContext`aWB}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.529952853378755*^9, 3.5299528557412863`*^9}, {
   3.529952912352669*^9, 3.529952989170877*^9}, {3.5299530745857363`*^9, 
   3.5299530914686093`*^9}, 3.5315962917157545`*^9, 3.531596552329812*^9, 
   3.5352829765290527`*^9, 3.5360594675687866`*^9, 3.5360694189859114`*^9, 
   3.536070213244913*^9, {3.536072457570978*^9, 3.536072484933543*^9}, {
   3.537528244766116*^9, 3.537528254576677*^9}, 3.5388386851901436`*^9, 
   3.5388968452174635`*^9, 3.5405412743361735`*^9, 3.540543341654417*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of operators used in the fit: \"\>", 
   "\[InvisibleSpace]", "1"}],
  SequenceForm["Number of operators used in the fit: ", 1],
  Editable->False]], "Print",
 CellChangeTimes->{{3.529952853378755*^9, 3.5299528557412863`*^9}, {
   3.529952912352669*^9, 3.529952989170877*^9}, {3.5299530745857363`*^9, 
   3.5299530914686093`*^9}, 3.5315962917157545`*^9, 3.531596552329812*^9, 
   3.5352829765290527`*^9, 3.5360594675687866`*^9, 3.5360694189859114`*^9, 
   3.536070213244913*^9, {3.536072457570978*^9, 3.536072484933543*^9}, {
   3.537528244766116*^9, 3.537528254576677*^9}, 3.5388386851901436`*^9, 
   3.5388968452174635`*^9, 3.5405412743361735`*^9, 3.5405433416614175`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["New parametrization", "Subsection",
 CellChangeTimes->{{3.5098759773223677`*^9, 3.5098759823611765`*^9}, {
  3.511249539104279*^9, 3.5112495407734823`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "I", " ", "change", " ", "the", " ", "parametrization", " ", "defining", 
   " ", "the", " ", "operator", " ", "coefficients", " ", "as", " ", 
   "dimensionless", " ", "parameter"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.5112494699181576`*^9, 3.5112494905725937`*^9}, {
  3.511249547512694*^9, 3.5112495825815554`*^9}, {3.511249645621266*^9, 
  3.5112496583196883`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ChangeOP", "=", 
   RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ChangeOP", "=", 
      RowBox[{"Append", "[", 
       RowBox[{"ChangeOP", ",", 
        RowBox[{
         RowBox[{"Ops", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"Ops", "[", 
           RowBox[{"[", "i", "]"}], "]"}], 
          RowBox[{"2", "/", 
           SuperscriptBox["v", "2"]}]}]}]}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", 
      RowBox[{"Length", "[", "Ops", "]"}]}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"X2", "=", "chi2total"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]2", "=", 
   RowBox[{"X2", "/.", "ChangeOP"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Chi]", "=", 
   RowBox[{"\[Chi]2", "/.", "DropOps"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.506860863966121*^9, 3.506860867429327*^9}, 
   3.507470286691067*^9, 3.509805539858591*^9, {3.5099523420168447`*^9, 
   3.5099523424848456`*^9}, {3.509968853450631*^9, 3.509968856352236*^9}, {
   3.511249671657712*^9, 3.511249671813712*^9}, {3.5146310355515823`*^9, 
   3.514631140945367*^9}, {3.5147134742559233`*^9, 3.5147134744743233`*^9}, 
   3.5215466567818565`*^9, {3.5215473257684107`*^9, 3.5215473284554634`*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["M matrix", "Subsection",
 CellChangeTimes->{{3.5134934965268574`*^9, 3.5134935087260785`*^9}, 
   3.5146311872462482`*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"M", "=", 
   RowBox[{"Array", "[", 
    RowBox[{"1", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Length", "[", "ops", "]"}], ",", 
       RowBox[{"Length", "[", "ops", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"i", "=", "1"}], ",", 
    RowBox[{"i", "<=", 
     RowBox[{"Length", "[", "ops", "]"}]}], ",", 
    RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "<=", 
       RowBox[{"Length", "[", "ops", "]"}]}], ",", 
      RowBox[{"j", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"M", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "j"}], "]"}], "]"}], "=", 
       RowBox[{
        RowBox[{"1", "/", "2"}], 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{"\[Chi]", ",", 
            RowBox[{"ops", "[", 
             RowBox[{"[", "i", "]"}], "]"}]}], "]"}], ",", 
          RowBox[{"ops", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], "]"}]}]}]}], "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<M matrix\>\"", ",", 
   RowBox[{"MatrixForm", "[", "M", "]"}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<M eigenvalues: \>\"", ",", 
   RowBox[{"Eigenvalues", "[", "M", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5147035632594156`*^9, 3.514703579842244*^9}, {
  3.514713489887151*^9, 3.5147135069223804`*^9}, {3.514805618424549*^9, 
  3.5148056296097684`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"M matrix\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"7.326663454439509`*^6"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["M matrix", 
   MatrixForm[{{7.326663454439509*^6}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.514703580481846*^9, 3.514703701818859*^9, 3.5147038116742516`*^9, 
   3.514703864433544*^9, 3.514703930593261*^9, 3.5147040877167363`*^9, 
   3.514712523340653*^9, 3.5147125623875217`*^9, 3.5147126017775908`*^9, 
   3.5147126494200745`*^9, 3.5147127000733633`*^9, 3.5147128216443768`*^9, {
   3.5147134801839333`*^9, 3.5147135084979835`*^9}, 3.514715038829471*^9, 
   3.5147151545192747`*^9, 3.5147165785375757`*^9, 3.514804810265129*^9, {
   3.51480561909535*^9, 3.514805630202569*^9}, 3.516017519372511*^9, 
   3.5165306292968082`*^9, 3.5165395430575066`*^9, 3.5169690258970947`*^9, 
   3.516969871072436*^9, {3.517121610034176*^9, 3.517121631718214*^9}, 
   3.5171217746612654`*^9, 3.5171417252121067`*^9, 3.5173105132466803`*^9, 
   3.5175567602866144`*^9, 3.5183438461468706`*^9, 3.5190390988388166`*^9, 
   3.521544557291131*^9, 3.521546652766738*^9, 3.5215473394655657`*^9, 
   3.521789193023095*^9, 3.521789920405573*^9, 3.5217900126329346`*^9, 
   3.521796101564295*^9, {3.5221557458808093`*^9, 3.522155775579508*^9}, 
   3.5221558140287075`*^9, 3.5221558609523907`*^9, 3.522156281355437*^9, 
   3.522156348169258*^9, 3.522156382907245*^9, 3.5224754442044554`*^9, 
   3.5224766789074926`*^9, 3.5224782059629745`*^9, 3.5224946612594547`*^9, 
   3.5224965093947*^9, 3.522580741207724*^9, 3.522737152417098*^9, 
   3.522763601054867*^9, 3.522906432167075*^9, 3.522906476221552*^9, 
   3.522906533707653*^9, 3.5237725807390146`*^9, 3.5237726597325325`*^9, 
   3.5237733905443325`*^9, 3.5237734731020546`*^9, 3.523806287112107*^9, 
   3.5238112914470806`*^9, 3.523864981076062*^9, 3.5238659552353735`*^9, 
   3.52387424275706*^9, 3.5238752244622107`*^9, 3.524314546559955*^9, 
   3.524562626457658*^9, 3.5287336985847597`*^9, {3.5287337508916516`*^9, 
   3.528733777832899*^9}, 3.528738442073391*^9, 3.5287385005422935`*^9, {
   3.528806370720875*^9, 3.52880639087611*^9}, 3.52880653305476*^9, 
   3.5288066735330067`*^9, 3.52880828743571*^9, 3.528808354406627*^9, 
   3.5288084076027203`*^9, 3.5288085526985755`*^9, 3.5288086086402736`*^9, 
   3.5288108963084245`*^9, 3.528810935305655*^9, {3.5288110252517996`*^9, 
   3.52881105374743*^9}, 3.5288296723764954`*^9, {3.5288300297575235`*^9, 
   3.528830051472761*^9}, 3.528830082548016*^9, 3.529176210782672*^9, 
   3.5292413103575935`*^9, 3.5292594210537405`*^9, 3.529262388085352*^9, 
   3.529263194233368*^9, 3.5292635717852306`*^9, 3.5292645429961367`*^9, 
   3.5292652025184946`*^9, 3.5292657665852857`*^9, 3.529322491101081*^9, 
   3.5293267457564335`*^9, 3.529430838068112*^9, 3.529953099521122*^9, 
   3.531596295475361*^9, 3.5315965560270185`*^9, 3.535282979546599*^9, 
   3.536059467729796*^9, 3.536069419050914*^9, 3.5360702133639193`*^9, {
   3.536072457639982*^9, 3.5360724850105476`*^9}, 3.537528261359065*^9, 
   3.5388386852369432`*^9, 3.538896845291467*^9, 3.540541274371176*^9, 
   3.5405433417264214`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"M eigenvalues: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "7.326663454439509`*^6", "}"}]}],
  SequenceForm["M eigenvalues: ", {7.326663454439509*^6}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.514703580481846*^9, 3.514703701818859*^9, 3.5147038116742516`*^9, 
   3.514703864433544*^9, 3.514703930593261*^9, 3.5147040877167363`*^9, 
   3.514712523340653*^9, 3.5147125623875217`*^9, 3.5147126017775908`*^9, 
   3.5147126494200745`*^9, 3.5147127000733633`*^9, 3.5147128216443768`*^9, {
   3.5147134801839333`*^9, 3.5147135084979835`*^9}, 3.514715038829471*^9, 
   3.5147151545192747`*^9, 3.5147165785375757`*^9, 3.514804810265129*^9, {
   3.51480561909535*^9, 3.514805630202569*^9}, 3.516017519372511*^9, 
   3.5165306292968082`*^9, 3.5165395430575066`*^9, 3.5169690258970947`*^9, 
   3.516969871072436*^9, {3.517121610034176*^9, 3.517121631718214*^9}, 
   3.5171217746612654`*^9, 3.5171417252121067`*^9, 3.5173105132466803`*^9, 
   3.5175567602866144`*^9, 3.5183438461468706`*^9, 3.5190390988388166`*^9, 
   3.521544557291131*^9, 3.521546652766738*^9, 3.5215473394655657`*^9, 
   3.521789193023095*^9, 3.521789920405573*^9, 3.5217900126329346`*^9, 
   3.521796101564295*^9, {3.5221557458808093`*^9, 3.522155775579508*^9}, 
   3.5221558140287075`*^9, 3.5221558609523907`*^9, 3.522156281355437*^9, 
   3.522156348169258*^9, 3.522156382907245*^9, 3.5224754442044554`*^9, 
   3.5224766789074926`*^9, 3.5224782059629745`*^9, 3.5224946612594547`*^9, 
   3.5224965093947*^9, 3.522580741207724*^9, 3.522737152417098*^9, 
   3.522763601054867*^9, 3.522906432167075*^9, 3.522906476221552*^9, 
   3.522906533707653*^9, 3.5237725807390146`*^9, 3.5237726597325325`*^9, 
   3.5237733905443325`*^9, 3.5237734731020546`*^9, 3.523806287112107*^9, 
   3.5238112914470806`*^9, 3.523864981076062*^9, 3.5238659552353735`*^9, 
   3.52387424275706*^9, 3.5238752244622107`*^9, 3.524314546559955*^9, 
   3.524562626457658*^9, 3.5287336985847597`*^9, {3.5287337508916516`*^9, 
   3.528733777832899*^9}, 3.528738442073391*^9, 3.5287385005422935`*^9, {
   3.528806370720875*^9, 3.52880639087611*^9}, 3.52880653305476*^9, 
   3.5288066735330067`*^9, 3.52880828743571*^9, 3.528808354406627*^9, 
   3.5288084076027203`*^9, 3.5288085526985755`*^9, 3.5288086086402736`*^9, 
   3.5288108963084245`*^9, 3.528810935305655*^9, {3.5288110252517996`*^9, 
   3.52881105374743*^9}, 3.5288296723764954`*^9, {3.5288300297575235`*^9, 
   3.528830051472761*^9}, 3.528830082548016*^9, 3.529176210782672*^9, 
   3.5292413103575935`*^9, 3.5292594210537405`*^9, 3.529262388085352*^9, 
   3.529263194233368*^9, 3.5292635717852306`*^9, 3.5292645429961367`*^9, 
   3.5292652025184946`*^9, 3.5292657665852857`*^9, 3.529322491101081*^9, 
   3.5293267457564335`*^9, 3.529430838068112*^9, 3.529953099521122*^9, 
   3.531596295475361*^9, 3.5315965560270185`*^9, 3.535282979546599*^9, 
   3.536059467729796*^9, 3.536069419050914*^9, 3.5360702133639193`*^9, {
   3.536072457639982*^9, 3.5360724850105476`*^9}, 3.537528261359065*^9, 
   3.5388386852369432`*^9, 3.538896845291467*^9, 3.540541274371176*^9, 
   3.5405433417284217`*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Error Matrix", "Subsection",
 CellChangeTimes->{{3.514631197651467*^9, 3.514631201192673*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Merr", "=", 
   RowBox[{"Inverse", "[", "M", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Error matrix\>\"", ",", 
   RowBox[{"MatrixForm", "[", "Merr", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.5288065145843277`*^9, 3.528806518281534*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Error matrix\"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"1.3648777594582447`*^-7"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["Error matrix", 
   MatrixForm[{{1.3648777594582447`*^-7}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.514631203766678*^9, 3.514703832281888*^9, 3.5147038698155537`*^9, 
   3.5147039380032735`*^9, 3.5147040973575535`*^9, 3.514712571638338*^9, 
   3.5147126106072063`*^9, 3.514712658686491*^9, 3.514712712412985*^9, 
   3.5147128335783978`*^9, 3.514713553348062*^9, {3.514715041933877*^9, 
   3.514715047237886*^9}, 3.514715157093279*^9, 3.5147165873983912`*^9, 
   3.5148048265515575`*^9, 3.514805634991778*^9, 3.516017523392741*^9, 
   3.5165306394056263`*^9, 3.516539546099512*^9, 3.516969029175282*^9, 
   3.51696987412161*^9, {3.517121615088585*^9, 3.517121636179822*^9}, 
   3.517121778062071*^9, 3.51714173277812*^9, 3.517310513505695*^9, 
   3.517556760572631*^9, 3.518343846437887*^9, 3.5190390992756176`*^9, 
   3.521544558047174*^9, 3.521547339655566*^9, 3.5217891933194957`*^9, 
   3.521789930841991*^9, 3.5217900127889347`*^9, 3.521796101742305*^9, {
   3.522155746080821*^9, 3.522155775712516*^9}, 3.522155814312723*^9, 
   3.5221558611084003`*^9, 3.5221562814964447`*^9, 3.52215634836827*^9, 
   3.522156383075255*^9, 3.522475444495472*^9, 3.5224766790478926`*^9, 
   3.5224782061033745`*^9, 3.5224946613842545`*^9, 3.5224965095819006`*^9, 
   3.5225807413637247`*^9, 3.5227371525106983`*^9, 3.5227636013108816`*^9, 
   3.522906433321477*^9, 3.5229064765647526`*^9, 3.5229065338636537`*^9, 
   3.523772581416053*^9, 3.5237726599435444`*^9, 3.5237733906753397`*^9, 
   3.5237734732600636`*^9, 3.5238062877205076`*^9, 3.523811291603081*^9, 
   3.5238649813724623`*^9, 3.5238659554069734`*^9, 3.5238742429270697`*^9, 
   3.52387522463922*^9, 3.5243145467159557`*^9, 3.5245626275607204`*^9, 
   3.5287336987251596`*^9, {3.528733752982055*^9, 3.5287337794085016`*^9}, 
   3.528738445552197*^9, 3.5287385033034983`*^9, {3.528806374371281*^9, 
   3.528806393871316*^9}, {3.528806515286329*^9, 3.5288065422275763`*^9}, 
   3.5288066757170105`*^9, 3.528808290087714*^9, 3.528808357651433*^9, 
   3.5288084094591236`*^9, 3.5288085552257795`*^9, 3.528808611760279*^9, 
   3.528810898839569*^9, 3.528810937652789*^9, {3.52881102804696*^9, 
   3.528811056853607*^9}, 3.5288296749505*^9, 3.5288300847164197`*^9, 
   3.529176211029686*^9, 3.5292413130007443`*^9, 3.5292594212097406`*^9, 
   3.529262388241352*^9, 3.529263194373768*^9, 3.529263571910031*^9, 
   3.529264543152137*^9, 3.5292652026432953`*^9, 3.529265766725686*^9, 
   3.52932249126009*^9, 3.5293267459004416`*^9, 3.529430838198119*^9, 
   3.5299531018211565`*^9, 3.531596298423766*^9, 3.5315965581798224`*^9, 
   3.535282983197*^9, 3.536059467821801*^9, 3.536069419079915*^9, 
   3.5360702133929214`*^9, {3.5360724576839848`*^9, 3.5360724850495496`*^9}, 
   3.5388386852993436`*^9, 3.53889684533247*^9, 3.5405412743901763`*^9, 
   3.540543341758423*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Minimization", "Subsection",
 CellChangeTimes->{{3.513493527321311*^9, 3.5134935293337145`*^9}, {
  3.513673650670968*^9, 3.5136736512793694`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Chi]min", "=", 
  RowBox[{"Minimize", "[", 
   RowBox[{"\[Chi]", ",", "ops"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<Number of degrees of freedom: \>\"", ",", 
   RowBox[{"NMeasurements", "-", 
    RowBox[{"Length", "[", "ops", "]"}]}]}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<\!\(\*SuperscriptBox[\(\[Chi]\), \(2\)]\)/dof: \>\"", ",", 
   RowBox[{
    RowBox[{"\[Chi]min", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"NMeasurements", "-", 
      RowBox[{"Length", "[", "ops", "]"}]}], ")"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.513423448185052*^9, 3.5134234488090525`*^9}, {
   3.5134258937701473`*^9, 3.513425919946993*^9}, {3.513509635662857*^9, 
   3.513509638736062*^9}, {3.51351604256291*^9, 3.513516043467712*^9}, 
   3.51394719359184*^9, {3.5147040140222073`*^9, 3.5147040218534207`*^9}, {
   3.5293266577584*^9, 3.529326703324006*^9}, {3.529326754373926*^9, 
   3.5293268522155223`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"223.14197260836747`", ",", 
   RowBox[{"{", 
    RowBox[{"ahL3", "\[Rule]", "0.0001199603698172422`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5288066825966225`*^9, 3.528808364889846*^9, 3.5288084149815335`*^9, 
   3.5288085597653875`*^9, 3.528808618468291*^9, 3.5288109024947786`*^9, 
   3.5288109401019297`*^9, {3.528811030739114*^9, 3.5288110590787344`*^9}, 
   3.528829678288906*^9, 3.5288300874620247`*^9, 3.52917621215275*^9, 
   3.5292413171519823`*^9, 3.5292594217245417`*^9, 3.529262388771753*^9, 
   3.5292631948573685`*^9, 3.529263572393632*^9, 3.529264543760538*^9, 
   3.529265203142496*^9, 3.529265767240487*^9, 3.5293224918121214`*^9, 
   3.5293267055991364`*^9, 3.529326746412471*^9, {3.529326823940905*^9, 
   3.529326853167577*^9}, 3.529430838796153*^9, 3.529953104928997*^9, 
   3.531596301106971*^9, 3.5315965603794265`*^9, 3.535282985032105*^9, 
   3.536059468661849*^9, 3.536069419266926*^9, 3.536070213595933*^9, {
   3.5360724578799953`*^9, 3.5360724852345605`*^9}, 3.5375282749738436`*^9, 
   3.5388386854085436`*^9, 3.5388968454554768`*^9, 3.540541274554186*^9, 
   3.540543341858429*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of degrees of freedom: \"\>", "\[InvisibleSpace]", 
   "278"}],
  SequenceForm["Number of degrees of freedom: ", 278],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5293267052511168`*^9, 3.5293267459674454`*^9, {3.5293268239519053`*^9, 
   3.5293268531775775`*^9}, 3.5294308388071537`*^9, 3.5299531049399977`*^9, 
   3.531596301106971*^9, 3.5315965603794265`*^9, 3.535282985035105*^9, 
   3.5360594686668496`*^9, 3.536069419269926*^9, 3.536070213599933*^9, {
   3.536072457882996*^9, 3.5360724852375603`*^9}, 3.537528274986844*^9, 
   3.538838685424144*^9, 3.5388968454714775`*^9, 3.5405412745551863`*^9, 
   3.540543341859429*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\!\\(\\*SuperscriptBox[\\(\[Chi]\\), \\(2\\)]\\)/dof: \"\>", 
   "\[InvisibleSpace]", "0.8026689662171492`"}],
  SequenceForm[
  "\!\(\*SuperscriptBox[\(\[Chi]\), \(2\)]\)/dof: ", 0.8026689662171492],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5293267052511168`*^9, 3.5293267459674454`*^9, {3.5293268239519053`*^9, 
   3.5293268531775775`*^9}, 3.5294308388071537`*^9, 3.5299531049399977`*^9, 
   3.531596301106971*^9, 3.5315965603794265`*^9, 3.535282985035105*^9, 
   3.5360594686668496`*^9, 3.536069419269926*^9, 3.536070213599933*^9, {
   3.536072457882996*^9, 3.5360724852375603`*^9}, 3.537528274986844*^9, 
   3.538838685424144*^9, 3.5388968454714775`*^9, 3.5405412745551863`*^9, 
   3.540543341861429*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Errors on the operators coefficients (using the error matrix)\
\>", "Subsection",
 CellChangeTimes->{{3.5134935336549225`*^9, 3.5134935514545536`*^9}, {
  3.5146312174323015`*^9, 3.514631226137117*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"opmin", "=", 
      RowBox[{"\[Chi]min", "[", 
       RowBox[{"[", 
        RowBox[{"2", ",", "i", ",", "2"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"operr", "=", 
      SqrtBox[
       RowBox[{"Merr", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "i"}], "]"}], "]"}]]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"i", ",", "\"\< \>\"", ",", 
       RowBox[{"ops", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "\"\<_min = \>\"", ",", 
       RowBox[{"SetAccuracy", "[", 
        RowBox[{"opmin", ",", "11"}], "]"}], ",", "\"\<  //  \[Sigma]_\>\"", 
       ",", 
       RowBox[{"ops", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "\"\< = \>\"", ",", 
       RowBox[{"SetAccuracy", "[", 
        RowBox[{"operr", ",", "11"}], "]"}], ",", "\"\<  //   \>\"", ",", 
       RowBox[{"ops", "[", 
        RowBox[{"[", "i", "]"}], "]"}], ",", "\"\< -> [\>\"", ",", 
       RowBox[{"N", "[", 
        RowBox[{"opmin", "-", 
         RowBox[{"operr", "*", "SigmaTo90CL"}]}], "]"}], ",", "\"\<,\>\"", 
       ",", 
       RowBox[{"N", "[", 
        RowBox[{"opmin", "+", 
         RowBox[{"operr", "*", "SigmaTo90CL"}]}], "]"}], ",", 
       "\"\<]  (90% CL)   //  \[Sigma](90%) = \>\"", ",", 
       RowBox[{"operr", "*", "SigmaTo90CL"}], ",", 
       "\"\<  \[CapitalLambda]NP \[GreaterSlantEqual] \>\"", ",", 
       RowBox[{"v", "/", 
        RadicalBox[
         RowBox[{"Merr", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "i"}], "]"}], "]"}], "4"]}], ",", 
       "\"\< GeV\>\""}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"i", ",", "1", ",", 
     RowBox[{"Length", "[", "ops", "]"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.5134259227861977`*^9, 3.5134260176811647`*^9}, {
   3.513426074059664*^9, 3.5134261514825993`*^9}, {3.5134924257097764`*^9, 
   3.513492547920391*^9}, {3.5134927209558945`*^9, 3.5134929113230295`*^9}, {
   3.5134930099308023`*^9, 3.5134930120056057`*^9}, {3.5134930491960716`*^9, 
   3.51349315649306*^9}, {3.513493262588846*^9, 3.51349329881211*^9}, {
   3.513493343178588*^9, 3.5134933462829933`*^9}, {3.513508830576643*^9, 
   3.5135088382986565`*^9}, {3.5135096534936886`*^9, 3.513509669639717*^9}, {
   3.513515077872816*^9, 3.5135151188384876`*^9}, 3.5135958648680153`*^9, {
   3.5135959143201027`*^9, 3.513595915724105*^9}, {3.5135960173426833`*^9, 
   3.5135960202598886`*^9}, {3.513947215057477*^9, 3.5139472285047007`*^9}, {
   3.5139477317147846`*^9, 3.513947732432386*^9}, {3.514713604718952*^9, 
   3.514713630786598*^9}, {3.516969111085967*^9, 3.516969115402214*^9}, {
   3.5175567229754806`*^9, 3.5175567366642637`*^9}, {3.5245625895735483`*^9, 
   3.524562607234558*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
  "1", "\[InvisibleSpace]", "\<\" \"\>", "\[InvisibleSpace]", "ahL3", 
   "\[InvisibleSpace]", "\<\"_min = \"\>", "\[InvisibleSpace]", 
   "0.00011996036981724220160921284827892919`7.0790377959449415", 
   "\[InvisibleSpace]", "\<\"  //  \[Sigma]_\"\>", "\[InvisibleSpace]", 
   "ahL3", "\[InvisibleSpace]", "\<\" = \"\>", "\[InvisibleSpace]", 
   "0.00036944252048975691682039523833225303`7.567546878519882", 
   "\[InvisibleSpace]", "\<\"  //   \"\>", "\[InvisibleSpace]", "ahL3", 
   "\[InvisibleSpace]", "\<\" -> [\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "0.0004877171600103344`"}], "\[InvisibleSpace]", "\<\",\"\>", 
   "\[InvisibleSpace]", "0.0007276378996448188`", 
   "\[InvisibleSpace]", "\<\"]  (90% CL)   //  \[Sigma](90%) = \"\>", 
   "\[InvisibleSpace]", "0.0006076775298275766`", 
   "\[InvisibleSpace]", "\<\"  \[CapitalLambda]NP \[GreaterSlantEqual] \"\>", 
   "\[InvisibleSpace]", "12810.051964208677`", 
   "\[InvisibleSpace]", "\<\" GeV\"\>"}],
  SequenceForm[
  1, " ", $CellContext`ahL3, "_min = ", 
   0.00011996036981724220160921284827892919`7.0790377959449415, 
   "  //  \[Sigma]_", $CellContext`ahL3, " = ", 
   0.00036944252048975691682039523833225303`7.567546878519882, 
   "  //   ", $CellContext`ahL3, " -> [", -0.0004877171600103344, ",", 
   0.0007276378996448188, "]  (90% CL)   //  \[Sigma](90%) = ", 
   0.0006076775298275766, "  \[CapitalLambda]NP \[GreaterSlantEqual] ", 
   12810.051964208677`, " GeV"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.517556769932166*^9, 3.5183438878162537`*^9, 3.5190391084172335`*^9, 
   3.521544573273524*^9, 3.5215473512565594`*^9, 3.5217892029915123`*^9, 
   3.5217900181085443`*^9, 3.521796102667358*^9, 3.522156286099708*^9, 
   3.522156386920475*^9, 3.522475449863779*^9, 3.522476682136698*^9, 
   3.5224965130763073`*^9, 3.522580745029731*^9, 3.5227371547883024`*^9, 
   3.5227636028099675`*^9, 3.522906435661481*^9, 3.5229064792323575`*^9, 
   3.5229065367496586`*^9, 3.5237725835911775`*^9, 3.5237726609606028`*^9, 
   3.523773391815405*^9, 3.523773474808152*^9, 3.5238062894833107`*^9, 
   3.5238112926794834`*^9, 3.523864984508068*^9, 3.5238659578717775`*^9, 
   3.5238742441821413`*^9, 3.5243145474335566`*^9, 3.524562629858852*^9, 
   3.528733705136771*^9, 3.52873845313381*^9, 3.528738513537116*^9, 
   3.5288066278873267`*^9, 3.528806686278229*^9, 3.5288083705214553`*^9, 
   3.5288084167599363`*^9, 3.528808563540594*^9, 3.5288086200906935`*^9, 
   3.5288109041768746`*^9, 3.5288109412259936`*^9, {3.5288110326232214`*^9, 
   3.528811060970843*^9}, 3.528829680254509*^9, 3.5288300889752274`*^9, 
   3.529176155599516*^9, 3.529176212784786*^9, 3.529241319286104*^9, 
   3.52926454491494*^9, 3.5293224951823144`*^9, 3.529430843150402*^9, 
   3.529953107546376*^9, 3.5315963054905787`*^9, 3.5315965621734295`*^9, 
   3.535282987052887*^9, 3.5360594689998684`*^9, 3.53606941933393*^9, 
   3.5360702136619368`*^9, {3.5360724579850016`*^9, 3.536072485300564*^9}, 
   3.538896847713606*^9, 3.5405412745771875`*^9, 3.5405433418864307`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Bounds on RW\[Tau]l = (\[CapitalGamma](W -> \[Tau] \[Nu])SM + \
\[CapitalGamma](W -> \[Tau] \[Nu])NP) / ( \[CapitalGamma](W -> e \[Nu])SM +  \
\[CapitalGamma](W -> \[Mu] \[Nu])SM) (assuming  \[CapitalGamma](W -> e \
\[Nu])NP =\[CapitalGamma](W -> \[Mu] \[Nu])NP = 0)\
\>", "Subsection",
 CellChangeTimes->{{3.514722940857148*^9, 3.514722959561218*^9}, {
   3.5165401241741276`*^9, 3.5165401617545934`*^9}, {3.5169694899526367`*^9, 
   3.516969524929638*^9}, {3.5169695596296225`*^9, 3.516969582268917*^9}, 
   3.5173115093116517`*^9, {3.5238070763018928`*^9, 3.5238071126343565`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"RW\[Tau]lCentral", "=", 
   RowBox[{"RW\[Tau]l", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"ops", "[", 
        RowBox[{"[", "1", "]"}], "]"}], "\[Rule]", 
       RowBox[{"\[Chi]min", "[", 
        RowBox[{"[", 
         RowBox[{"2", ",", "1", ",", "2"}], "]"}], "]"}]}], ",", 
      RowBox[{"aEWt", "\[Rule]", "0"}], ",", 
      RowBox[{"ahl3", "\[Rule]", "0"}]}], "}"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CentralValue", "=", "%"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Sigma]RW\[Tau]l", "=", 
   SqrtBox[
    RowBox[{
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"RW\[Tau]l", ",", 
          RowBox[{"ops", "[", 
           RowBox[{"[", "i", "]"}], "]"}]}], "]"}], 
        RowBox[{"D", "[", 
         RowBox[{"RW\[Tau]l", ",", 
          RowBox[{"ops", "[", 
           RowBox[{"[", "j", "]"}], "]"}]}], "]"}], 
        FractionBox["1", 
         RowBox[{"M", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "ops", "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"j", ",", "1", ",", 
         RowBox[{"Length", "[", "ops", "]"}]}], "}"}]}], "]"}], "+", 
     SuperscriptBox["\[Sigma]RW\[Tau]lSM", "2"]}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sigma", "=", "%"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RW\[Tau]lMax", "=", 
   RowBox[{"RW\[Tau]lCentral", "+", "\[Sigma]RW\[Tau]l"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RW\[Tau]lMin", "=", 
   RowBox[{"RW\[Tau]lCentral", "-", "\[Sigma]RW\[Tau]l"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<RW\[Tau]l = \>\"", ",", "RW\[Tau]lCentral", ",", 
   "\"\< \[PlusMinus] \>\"", ",", "\[Sigma]RW\[Tau]l", ",", 
   "\"\<  (68% CL)        //        RW\[Tau]l: [\>\"", ",", 
   RowBox[{"RW\[Tau]lCentral", "+", 
    RowBox[{"\[Sigma]RW\[Tau]l", "*", "SigmaTo90CL"}]}], ",", "\"\<, \>\"", 
   ",", 
   RowBox[{"RW\[Tau]lCentral", "-", 
    RowBox[{"\[Sigma]RW\[Tau]l", "*", "SigmaTo90CL"}]}], ",", 
   "\"\<]  (90% CL)\>\""}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Experimental value:  RW\[Tau]lExp = \>\"", ",", "RW\[Tau]lExp", ",", 
   "\"\< \[PlusMinus] \>\"", ",", "\[Sigma]RW\[Tau]lExp", ",", 
   "\"\< //            SM value:  RW\[Tau]lSM = \>\"", ",", "RW\[Tau]lSM", 
   ",", "\"\<              \[CapitalDelta](SM-NP) = \>\"", ",", 
   RowBox[{"Abs", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"RW\[Tau]lCentral", "-", "RW\[Tau]lSM"}], ")"}], "/", 
     "\[Sigma]RW\[Tau]l"}], "]"}], ",", "\"\<\[Sigma]\>\""}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.5147230284421577`*^9, 3.514723327511263*^9}, {
   3.5147236955613146`*^9, 3.514723732525429*^9}, {3.5147237976961565`*^9, 
   3.514723798098179*^9}, {3.5147238756166134`*^9, 3.5147239007260494`*^9}, {
   3.5148179767801533`*^9, 3.5148179918653803`*^9}, 3.5148182141969705`*^9, {
   3.5148744804099283`*^9, 3.5148745559608607`*^9}, {3.5148746118557587`*^9, 
   3.5148746204201736`*^9}, {3.5148746587182417`*^9, 
   3.5148746723838654`*^9}, {3.5148749541515603`*^9, 
   3.5148749548379617`*^9}, {3.5148751250810604`*^9, 
   3.5148751261418624`*^9}, {3.514875588994675*^9, 3.51487559705989*^9}, {
   3.5148915683614473`*^9, 3.51489157009305*^9}, {3.514894488904977*^9, 
   3.514894501525399*^9}, {3.5148945345038567`*^9, 3.5148945346442575`*^9}, {
   3.514894567685115*^9, 3.514894569541518*^9}, {3.5148946783361096`*^9, 
   3.5148947104877663`*^9}, {3.5148947890027037`*^9, 
   3.5148948052579327`*^9}, {3.514895639188597*^9, 3.514895649469015*^9}, {
   3.5148973907908735`*^9, 3.514897402756095*^9}, {3.5151465254916377`*^9, 
   3.515146677377325*^9}, {3.515146773315812*^9, 3.5151468077057796`*^9}, {
   3.5151468452779284`*^9, 3.515146858553688*^9}, 3.5151483871040525`*^9, {
   3.5151488174776087`*^9, 3.515148833717237*^9}, {3.516531184844984*^9, 
   3.5165311902893934`*^9}, {3.5165312372922764`*^9, 3.5165312398038807`*^9}, 
   3.5165395200942664`*^9, {3.5165401727994127`*^9, 3.5165402446843395`*^9}, {
   3.51654031349606*^9, 3.5165403592509403`*^9}, {3.5165407351960006`*^9, 
   3.516540745850819*^9}, {3.51696952986292*^9, 3.516969546112849*^9}, {
   3.5169695833189774`*^9, 3.5169695979348135`*^9}, {3.5171438696386733`*^9, 
   3.5171438915255117`*^9}, {3.517311439398653*^9, 3.5173114622989626`*^9}, 
   3.5173115374032583`*^9, {3.5217960808421097`*^9, 3.5217960870904665`*^9}, {
   3.5237725891674967`*^9, 3.5237726257865906`*^9}, 3.528829816146348*^9, {
   3.5288298517612104`*^9, 3.5288298682348394`*^9}, {3.5291763276553564`*^9, 
   3.5291763309925475`*^9}, {3.5291765406505394`*^9, 3.52917659696176*^9}, {
   3.5291766387731514`*^9, 3.5291766441574593`*^9}, {3.529176689705065*^9, 
   3.5291767109172783`*^9}, {3.529251331819973*^9, 3.529251334640135*^9}, {
   3.52925162181456*^9, 3.529251657467599*^9}, {3.5315966243863387`*^9, 
   3.531596625774741*^9}, {3.5375283367573776`*^9, 3.5375283596426864`*^9}, {
   3.5388968746681476`*^9, 3.5388968814945383`*^9}, {3.5405412681478195`*^9, 
   3.5405412691808786`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"RW\[Tau]l = \"\>", "\[InvisibleSpace]", "0.9994794905604956`", 
   "\[InvisibleSpace]", "\<\" \[PlusMinus] \"\>", "\[InvisibleSpace]", 
   "0.001476689361640905`", 
   "\[InvisibleSpace]", "\<\"  (68% CL)        //        RW\[Tau]l: [\"\>", 
   "\[InvisibleSpace]", "1.0019084230569906`", 
   "\[InvisibleSpace]", "\<\", \"\>", "\[InvisibleSpace]", 
   "0.9970505580640006`", "\[InvisibleSpace]", "\<\"]  (90% CL)\"\>"}],
  SequenceForm[
  "RW\[Tau]l = ", 0.9994794905604956, " \[PlusMinus] ", 0.001476689361640905, 
   "  (68% CL)        //        RW\[Tau]l: [", 1.0019084230569906`, ", ", 
   0.9970505580640006, "]  (90% CL)"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5151466785033894`*^9, {3.5151467839774227`*^9, 3.515146814386162*^9}, {
   3.5151468538954215`*^9, 3.5151468588107023`*^9}, 3.515148387930854*^9, 
   3.515148668185346*^9, {3.5151488141860027`*^9, 3.5151488357140408`*^9}, 
   3.5165305176942124`*^9, 3.5165311913813953`*^9, 3.516531240661882*^9, 
   3.5165395738207607`*^9, 3.516540361232144*^9, {3.5165407330119967`*^9, 
   3.51654074628762*^9}, 3.516969462788083*^9, 3.516969705087942*^9, 
   3.517143866331467*^9, 3.5171438994347253`*^9, 3.51731149826502*^9, 
   3.5173115517440786`*^9, 3.5202329035174007`*^9, 3.5202331293745975`*^9, 
   3.5217961115618668`*^9, {3.5224754608994102`*^9, 3.5224754746701975`*^9}, 
   3.522476698001926*^9, {3.52249464732863*^9, 3.5224946692778683`*^9}, 
   3.523772668285022*^9, 3.523773402081992*^9, 3.523773487200861*^9, 
   3.523806289732911*^9, 3.5238065004268813`*^9, 3.523807067269477*^9, 
   3.5238742444431562`*^9, {3.5288297728562717`*^9, 3.528829801279522*^9}, {
   3.528829852463212*^9, 3.52882986865604*^9}, 3.529176146041969*^9, {
   3.529176319637898*^9, 3.529176331263563*^9}, 3.529176612098626*^9, 
   3.5291766452785234`*^9, {3.5291766901540904`*^9, 3.529176711743325*^9}, 
   3.5292413357970486`*^9, 3.5292513375813026`*^9, {3.529251645138894*^9, 
   3.5292516577656164`*^9}, 3.529322502991761*^9, 3.529953130445402*^9, {
   3.5315966118127165`*^9, 3.531596626663943*^9}, 3.53528299004773*^9, 
   3.5360594691862717`*^9, 3.5360694194309354`*^9, 3.536070213776943*^9, {
   3.536072458183013*^9, 3.536072485489575*^9}, {3.537528352931302*^9, 
   3.5375283600527096`*^9}, {3.538896866612687*^9, 3.538896881814556*^9}, {
   3.540541270584959*^9, 3.5405412745961885`*^9}, 3.540543341920432*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Experimental value:  RW\[Tau]lExp = \"\>", "\[InvisibleSpace]",
    "1.055347091932458`", "\[InvisibleSpace]", "\<\" \[PlusMinus] \"\>", 
   "\[InvisibleSpace]", "0.021178845883677393`", 
   "\[InvisibleSpace]", "\<\" //            SM value:  RW\[Tau]lSM = \"\>", 
   "\[InvisibleSpace]", "0.999`", 
   "\[InvisibleSpace]", "\<\"              \[CapitalDelta](SM-NP) = \"\>", 
   "\[InvisibleSpace]", "0.3247064500842298`", 
   "\[InvisibleSpace]", "\<\"\[Sigma]\"\>"}],
  SequenceForm[
  "Experimental value:  RW\[Tau]lExp = ", 1.055347091932458, " \[PlusMinus] ",
    0.021178845883677393`, " //            SM value:  RW\[Tau]lSM = ", 0.999, 
   "              \[CapitalDelta](SM-NP) = ", 0.3247064500842298, "\[Sigma]"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.5151466785033894`*^9, {3.5151467839774227`*^9, 3.515146814386162*^9}, {
   3.5151468538954215`*^9, 3.5151468588107023`*^9}, 3.515148387930854*^9, 
   3.515148668185346*^9, {3.5151488141860027`*^9, 3.5151488357140408`*^9}, 
   3.5165305176942124`*^9, 3.5165311913813953`*^9, 3.516531240661882*^9, 
   3.5165395738207607`*^9, 3.516540361232144*^9, {3.5165407330119967`*^9, 
   3.51654074628762*^9}, 3.516969462788083*^9, 3.516969705087942*^9, 
   3.517143866331467*^9, 3.5171438994347253`*^9, 3.51731149826502*^9, 
   3.5173115517440786`*^9, 3.5202329035174007`*^9, 3.5202331293745975`*^9, 
   3.5217961115618668`*^9, {3.5224754608994102`*^9, 3.5224754746701975`*^9}, 
   3.522476698001926*^9, {3.52249464732863*^9, 3.5224946692778683`*^9}, 
   3.523772668285022*^9, 3.523773402081992*^9, 3.523773487200861*^9, 
   3.523806289732911*^9, 3.5238065004268813`*^9, 3.523807067269477*^9, 
   3.5238742444431562`*^9, {3.5288297728562717`*^9, 3.528829801279522*^9}, {
   3.528829852463212*^9, 3.52882986865604*^9}, 3.529176146041969*^9, {
   3.529176319637898*^9, 3.529176331263563*^9}, 3.529176612098626*^9, 
   3.5291766452785234`*^9, {3.5291766901540904`*^9, 3.529176711743325*^9}, 
   3.5292413357970486`*^9, 3.5292513375813026`*^9, {3.529251645138894*^9, 
   3.5292516577656164`*^9}, 3.529322502991761*^9, 3.529953130445402*^9, {
   3.5315966118127165`*^9, 3.531596626663943*^9}, 3.53528299004773*^9, 
   3.5360594691862717`*^9, 3.5360694194309354`*^9, 3.536070213776943*^9, {
   3.536072458183013*^9, 3.536072485489575*^9}, {3.537528352931302*^9, 
   3.5375283600527096`*^9}, {3.538896866612687*^9, 3.538896881814556*^9}, {
   3.540541270584959*^9, 3.5405412745961885`*^9}, 3.540543341922433*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1350, 611},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Linux x86 (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 245, 6, 37, "Subsubtitle"],
Cell[827, 30, 1574, 35, 155, "Subsubtitle"],
Cell[2404, 67, 878, 16, 198, "Section"],
Cell[CellGroupData[{
Cell[3307, 87, 182, 2, 42, "Section"],
Cell[CellGroupData[{
Cell[3514, 93, 109, 1, 37, "Subsection"],
Cell[3626, 96, 1833, 28, 52, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[5496, 129, 108, 1, 29, "Subsection"],
Cell[5607, 132, 374, 9, 31, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[6018, 146, 305, 7, 31, "Subsection"],
Cell[6326, 155, 591, 14, 52, "Input"],
Cell[CellGroupData[{
Cell[6942, 173, 133, 2, 31, "Input"],
Cell[7078, 177, 38760, 598, 1475, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[45899, 782, 435, 10, 72, "Section"],
Cell[CellGroupData[{
Cell[46359, 796, 101, 1, 36, "Subsection"],
Cell[46463, 799, 83, 2, 31, "Input"],
Cell[46549, 803, 2109, 65, 232, "Input"],
Cell[48661, 870, 748, 16, 132, "Input"],
Cell[49412, 888, 1404, 34, 87, "Input"],
Cell[CellGroupData[{
Cell[50841, 926, 129, 1, 27, "Subsubsection"],
Cell[50973, 929, 2498, 77, 170, "Input"],
Cell[53474, 1008, 1912, 56, 247, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[55435, 1070, 152, 2, 28, "Subsection"],
Cell[CellGroupData[{
Cell[55612, 1076, 116, 1, 27, "Subsubsection"],
Cell[55731, 1079, 4604, 118, 352, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[60372, 1202, 112, 1, 21, "Subsubsection"],
Cell[60487, 1205, 3603, 87, 232, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[64127, 1297, 115, 1, 27, "Subsubsection"],
Cell[64245, 1300, 1418, 36, 152, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[65712, 1342, 202, 3, 28, "Subsection"],
Cell[CellGroupData[{
Cell[65939, 1349, 225, 3, 27, "Subsubsection"],
Cell[66167, 1354, 3103, 81, 269, "Input"],
Cell[CellGroupData[{
Cell[69295, 1439, 1979, 50, 187, "Input"],
Cell[71277, 1491, 1933, 27, 70, "Output"],
Cell[73213, 1520, 1936, 27, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[75210, 1554, 115, 1, 28, "Subsection"],
Cell[75328, 1557, 2080, 65, 151, "Input"],
Cell[CellGroupData[{
Cell[77433, 1626, 123, 1, 27, "Subsubsection"],
Cell[77559, 1629, 1184, 27, 72, "Input"],
Cell[78746, 1658, 2212, 52, 98, "Input"],
Cell[80961, 1712, 557, 13, 52, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[81555, 1730, 114, 1, 27, "Subsubsection"],
Cell[81672, 1733, 1712, 47, 92, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[83445, 1787, 1031, 17, 42, "Section"],
Cell[CellGroupData[{
Cell[84501, 1808, 168, 2, 36, "Subsection"],
Cell[84672, 1812, 480, 9, 31, "Input"],
Cell[CellGroupData[{
Cell[85177, 1825, 2364, 50, 132, "Input"],
Cell[CellGroupData[{
Cell[87566, 1879, 1686, 28, 23, "Print"],
Cell[89255, 1909, 904, 15, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[90220, 1931, 162, 2, 28, "Subsection"],
Cell[90385, 1935, 512, 10, 31, "Input"],
Cell[90900, 1947, 1426, 36, 115, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[92363, 1988, 128, 2, 28, "Subsection"],
Cell[CellGroupData[{
Cell[92516, 1994, 1637, 46, 132, "Input"],
Cell[CellGroupData[{
Cell[94178, 2044, 15112, 264, 281, "Print"],
Cell[109293, 2310, 4210, 64, 45, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[113564, 2381, 100, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[113689, 2386, 317, 7, 52, "Input"],
Cell[114009, 2395, 16998, 291, 311, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[131056, 2692, 153, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[131234, 2698, 1033, 21, 74, "Input"],
Cell[132270, 2721, 2602, 49, 50, "Output"],
Cell[CellGroupData[{
Cell[134897, 2774, 846, 15, 23, "Print"],
Cell[135746, 2791, 920, 16, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[136727, 2814, 212, 4, 36, "Subsection"],
Cell[CellGroupData[{
Cell[136964, 2822, 2808, 60, 145, "Input"],
Cell[CellGroupData[{
Cell[139797, 2886, 3309, 53, 23, "Print"],
Cell[143109, 2941, 3285, 52, 23, "Print"],
Cell[146397, 2995, 3289, 53, 23, "Print"],
Cell[149689, 3050, 3275, 52, 23, "Print"],
Cell[152967, 3104, 3302, 53, 23, "Print"],
Cell[156272, 3159, 3303, 52, 23, "Print"],
Cell[159578, 3213, 3272, 52, 23, "Print"],
Cell[162853, 3267, 3268, 52, 23, "Print"],
Cell[166124, 3321, 3276, 52, 23, "Print"],
Cell[169403, 3375, 3331, 54, 23, "Print"],
Cell[172737, 3431, 3312, 53, 23, "Print"],
Cell[176052, 3486, 3309, 53, 23, "Print"],
Cell[179364, 3541, 3327, 53, 23, "Print"],
Cell[182694, 3596, 3325, 54, 23, "Print"],
Cell[186022, 3652, 3283, 52, 23, "Print"],
Cell[189308, 3706, 3331, 53, 23, "Print"],
Cell[192642, 3761, 3322, 53, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[196025, 3821, 594, 9, 36, "Subsection"],
Cell[CellGroupData[{
Cell[196644, 3834, 5248, 108, 215, "Input"],
Cell[CellGroupData[{
Cell[201917, 3946, 2696, 41, 23, "Print"],
Cell[204616, 3989, 2787, 42, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[207476, 4039, 1121, 19, 42, "Section"],
Cell[CellGroupData[{
Cell[208622, 4062, 168, 2, 36, "Subsection"],
Cell[208793, 4066, 412, 8, 31, "Input"],
Cell[CellGroupData[{
Cell[209230, 4078, 2875, 57, 152, "Input"],
Cell[CellGroupData[{
Cell[212130, 4139, 1150, 20, 23, "Print"],
Cell[213283, 4161, 950, 15, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[214294, 4183, 162, 2, 36, "Subsection"],
Cell[214459, 4187, 512, 10, 31, "Input"],
Cell[214974, 4199, 1426, 36, 115, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[216437, 4240, 128, 2, 28, "Subsection"],
Cell[CellGroupData[{
Cell[216590, 4246, 1637, 46, 132, "Input"],
Cell[CellGroupData[{
Cell[218252, 4296, 55403, 959, 599, "Print"],
Cell[273658, 5257, 5260, 81, 66, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[278979, 5345, 100, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[279104, 5350, 317, 7, 52, "Input"],
Cell[279424, 5359, 62373, 1053, 635, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[341846, 6418, 153, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[342024, 6424, 1033, 21, 74, "Input"],
Cell[343060, 6447, 4102, 78, 88, "Output"],
Cell[CellGroupData[{
Cell[347187, 6529, 955, 16, 23, "Print"],
Cell[348145, 6547, 1031, 17, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[349237, 6571, 212, 4, 36, "Subsection"],
Cell[CellGroupData[{
Cell[349474, 6579, 2808, 60, 145, "Input"],
Cell[CellGroupData[{
Cell[352307, 6643, 3376, 54, 23, "Print"],
Cell[355686, 6699, 3384, 55, 23, "Print"],
Cell[359073, 6756, 3380, 54, 23, "Print"],
Cell[362456, 6812, 3377, 54, 23, "Print"],
Cell[365836, 6868, 3395, 54, 23, "Print"],
Cell[369234, 6924, 3387, 54, 23, "Print"],
Cell[372624, 6980, 3377, 54, 23, "Print"],
Cell[376004, 7036, 3368, 54, 23, "Print"],
Cell[379375, 7092, 3383, 54, 23, "Print"],
Cell[382761, 7148, 3408, 55, 23, "Print"],
Cell[386172, 7205, 3413, 54, 23, "Print"],
Cell[389588, 7261, 3403, 55, 23, "Print"],
Cell[392994, 7318, 3392, 54, 23, "Print"],
Cell[396389, 7374, 3390, 54, 23, "Print"],
Cell[399782, 7430, 3383, 54, 23, "Print"],
Cell[403168, 7486, 3398, 55, 23, "Print"],
Cell[406569, 7543, 3382, 54, 23, "Print"],
Cell[409954, 7599, 3401, 55, 23, "Print"],
Cell[413358, 7656, 3404, 55, 23, "Print"],
Cell[416765, 7713, 3403, 55, 23, "Print"],
Cell[420171, 7770, 3411, 55, 23, "Print"],
Cell[423585, 7827, 3410, 55, 23, "Print"],
Cell[426998, 7884, 3388, 54, 23, "Print"],
Cell[430389, 7940, 3384, 54, 23, "Print"],
Cell[433776, 7996, 3389, 54, 23, "Print"],
Cell[437168, 8052, 3376, 54, 23, "Print"],
Cell[440547, 8108, 3387, 54, 23, "Print"],
Cell[443937, 8164, 3406, 55, 23, "Print"],
Cell[447346, 8221, 3377, 54, 23, "Print"],
Cell[450726, 8277, 3405, 55, 23, "Print"],
Cell[454134, 8334, 3412, 55, 23, "Print"],
Cell[457549, 8391, 3390, 54, 23, "Print"],
Cell[460942, 8447, 3400, 55, 23, "Print"],
Cell[464345, 8504, 3411, 55, 23, "Print"],
Cell[467759, 8561, 3390, 54, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[471210, 8622, 617, 9, 36, "Subsection"],
Cell[CellGroupData[{
Cell[471852, 8635, 5494, 115, 221, "Input"],
Cell[CellGroupData[{
Cell[477371, 8754, 2603, 40, 23, "Print"],
Cell[479977, 8796, 2704, 42, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[482754, 8846, 1115, 16, 42, "Section"],
Cell[CellGroupData[{
Cell[483894, 8866, 168, 2, 36, "Subsection"],
Cell[484065, 8870, 412, 8, 31, "Input"],
Cell[CellGroupData[{
Cell[484502, 8882, 2173, 46, 132, "Input"],
Cell[CellGroupData[{
Cell[486700, 8932, 2038, 32, 43, "Print"],
Cell[488741, 8966, 730, 12, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[489532, 8985, 162, 2, 36, "Subsection"],
Cell[489697, 8989, 426, 8, 31, "Input"],
Cell[490126, 8999, 1426, 36, 115, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[491589, 9040, 128, 2, 28, "Subsection"],
Cell[CellGroupData[{
Cell[491742, 9046, 1637, 46, 132, "Input"],
Cell[CellGroupData[{
Cell[493404, 9096, 3681, 62, 25, "Print"],
Cell[497088, 9160, 3134, 46, 26, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[500283, 9213, 100, 1, 36, "Subsection"],
Cell[CellGroupData[{
Cell[500408, 9218, 317, 7, 52, "Input"],
Cell[500728, 9227, 3530, 60, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[504307, 9293, 153, 2, 36, "Subsection"],
Cell[CellGroupData[{
Cell[504485, 9299, 1033, 21, 74, "Input"],
Cell[505521, 9322, 1169, 20, 30, "Output"],
Cell[CellGroupData[{
Cell[506715, 9346, 695, 13, 23, "Print"],
Cell[507413, 9361, 771, 14, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[508245, 9382, 212, 4, 36, "Subsection"],
Cell[CellGroupData[{
Cell[508482, 9390, 2808, 60, 145, "Input"],
Cell[511293, 9452, 3076, 49, 23, "Print"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[514418, 9507, 594, 9, 36, "Subsection"],
Cell[CellGroupData[{
Cell[515037, 9520, 5291, 110, 253, "Input"],
Cell[CellGroupData[{
Cell[520353, 9634, 2427, 37, 23, "Print"],
Cell[522783, 9673, 2519, 38, 23, "Print"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
